@@ -41,6 +41,7 @@ int optWhichCoarseScan;
 int optWhichMenu;
 int optWhichFonts;
 int optWhichIntro;
+int optWhichShield;
 int optSmoothScroll;
 int optMeleeScale;
 
@@ -51,6 +52,8 @@ uio_DirHandle *configDir;
 uio_DirHandle *saveDir;
 uio_DirHandle *meleeDir;
 
+uio_DirList *availableAddons;
+
 extern uio_Repository *repository;
 extern uio_DirHandle *rootDir;
 
@@ -159,18 +162,22 @@ prepareConfigDir (const char *configDirName) {
 
 		if (configDirName == NULL)
 			configDirName = CONFIGDIR;
-
-		if (expandPath (buf, PATH_MAX - 13, configDirName, EP_ALL_SYSTEM)
-				== -1)
-		{
-			// Doesn't have to be fatal, but might mess up things when saving
-			// config files.
-			fprintf (stderr, "Fatal error: Invalid path to config files.\n");
-			exit (EXIT_FAILURE);
-		}
-		configDirName = buf;
 	}
 
+	if (expandPath (buf, PATH_MAX - 13, configDirName, EP_ALL_SYSTEM)
+			== -1)
+	{
+		// Doesn't have to be fatal, but might mess up things when saving
+		// config files.
+		fprintf (stderr, "Fatal error: Invalid path to config files.\n");
+		exit (EXIT_FAILURE);
+	}
+	configDirName = buf;
+
+#ifdef DEBUG
+	fprintf (stderr, "Using config dir '%s'\n", configDirName);
+#endif
+
 	// Set the environment variable UQM_CONFIG_DIR so UQM_MELEE_DIR
 	// and UQM_SAVE_DIR can refer to it.
 	setenv("UQM_CONFIG_DIR", configDirName, 1);
@@ -273,6 +280,7 @@ mountContentDir (uio_Repository *repository, const char *contentPath,
 	uio_MountHandle *contentHandle;
 	uio_DirHandle *packagesDir, *addonsDir, *addonDir;
 	static uio_AutoMount *autoMount[] = { NULL };
+	availableAddons = NULL;
 
 	contentHandle = uio_mountDir (repository, "/",
 			uio_FSTYPE_STDIO, NULL, NULL, contentPath, autoMount,
@@ -320,6 +328,26 @@ mountContentDir (uio_Repository *repository, const char *contentPath,
 			
 	uio_closeDir (packagesDir);
 
+	availableAddons = uio_getDirList (addonsDir, "", "", match_MATCH_PREFIX);
+	if (availableAddons != NULL) {
+		int i, count;
+		count = availableAddons->numNames;
+		
+		if (count != 1)
+		{
+			fprintf (stderr, "%d available addon packs.\n", count);
+		}
+		else
+		{
+			fprintf (stderr, "1 available addon pack.\n");
+		}
+		for (i = 0; i < count; i++) {
+			fprintf (stderr, "    %d. %s\n", i+1, availableAddons->names[i]);
+		}
+	} else {
+		fprintf (stderr, "0 available addon packs.\n");
+	}
+
 	for (; *addons != NULL; addons++)
 	{
 		addonDir = uio_openDirRelative (addonsDir, *addons, 0);
@@ -361,23 +389,3 @@ mountDirZips (uio_MountHandle *contentHandle, uio_DirHandle *dirHandle)
 	uio_freeDirList (dirList);
 }
 
-void
-initLanguage (void)
-{
-	STRING_TABLE langDef;
-	STRING locString;
-	UNICODE *str;
-
-	langDef = LoadStringTableFile (contentDir, "language.txt");
-	if (!langDef)
-		return;
-
-	locString = SetAbsStringTableIndex (langDef, 0);
-	str = GetStringAddress (locString);
-	if (str)
-		setlocale (LC_ALL, str);
-
-	DestroyStringTable (langDef);
-}
-
-
