@@ -35,6 +35,7 @@ extern int optWhichCoarseScan;
 extern int optWhichMenu;
 extern int optWhichFonts;
 extern int optWhichIntro;
+extern int optWhichShield;
 extern int optSmoothScroll;
 extern int optMeleeScale;
 
@@ -46,11 +47,12 @@ extern uio_DirHandle *configDir;
 extern uio_DirHandle *saveDir;
 extern uio_DirHandle *meleeDir;
 
+extern uio_DirList *availableAddons;
+
 void prepareContentDir (const char *contentDirName, const char **addons);
 void prepareConfigDir (const char *configDirName);
 void prepareMeleeDir (void);
 void prepareSaveDir (void);
-void initLanguage (void);
 
 #endif
 
