@@ -3,7 +3,7 @@
 
 #include "config.h"
 
-#ifdef WIN32
+#ifdef _MSC_VER
 #	include <io.h>
 #else
 #	include <unistd.h>
@@ -66,12 +66,10 @@ typedef unsigned short mode_t;
 
 // Directories
 #include <sys/stat.h>
-#ifdef WIN32
-#	ifdef _MSC_VER
-#		define MKDIR(name, mode) ((void) mode, _mkdir(name))
-#	else
-#		define MKDIR(name, mode) ((void) mode, mkdir(name))
-#	endif
+#ifdef _MSC_VER
+#	define MKDIR(name, mode) ((void) mode, _mkdir(name))
+#elif defined(__MINGW32__)
+#	define MKDIR(name, mode) ((void) mode, mkdir(name))
 #else
 #	define MKDIR mkdir
 #endif
@@ -129,17 +127,6 @@ typedef unsigned short wchar_t;
 typedef unsigned int wint_t;
 #endif
 
-#ifdef HAVE_ISWGRAPH
-#	include <wctype.h>
-#else
-#	include <ctype.h>
-static inline int
-iswgraph(wint_t wc)
-{
-	return wc > 0x7f || isgraph((int) wc);
-}
-#endif
-
 // Use SDL_INCLUDE and SDL_IMAGE_INCLUDE to portably include the SDL files
 // from the right location.
 // TODO: Where the SDL and SDL_image headers are located could be detected
