@@ -25,11 +25,13 @@
 #include "endian_uqm.h"
 #include "gamestr.h"
 #include "options.h"
+#include "load.h"
 #include "oscill.h"
 #include "resinst.h"
 #include "settings.h"
 #include "setup.h"
 #include "sounds.h"
+#include "uqmdebug.h"
 #include "libs/graphics/drawable.h"
 #include "libs/graphics/gfx_common.h"
 #include "libs/mathlib.h"
@@ -41,12 +43,19 @@
 
 #include <ctype.h>
 
+// Maximum ambient animation frame rate (actual execution rate)
+// A gfx frame is not always produced during an execution frame,
+// and several animations are combined into one gfx frame.
+// The rate was originally 120fps which allowed for more animation
+// precision which is ultimately wasted on the human eye anyway.
+// The highest known stable animation rate is 40fps, so that's what we use.
+#define AMBIENT_ANIM_RATE   40
+
+// Oscilloscope frame rate
+// Should be <= AMBIENT_ANIM_RATE
+// XXX: was 32 picked experimentally?
+#define OSCILLOSCOPE_RATE   32
 
-static void init_xform_control (void);
-static void uninit_xform_control (void);
-static void xform_complete (void);
-static void xform_PLUT_step (SIZE TDelta);
-static void FlushPLUTXForms (void);
 static int ambient_anim_task (void *data);
 
 static BOOLEAN getLineWithinWidth(TEXT *pText,
@@ -63,7 +72,7 @@ static BOOLEAN getLineWithinWidth(TEXT *pText,
 
 LOCDATA CommData;
 int cur_comm;
-UNICODE shared_phrase_buf[256];
+UNICODE shared_phrase_buf[2048];
 volatile BOOLEAN summary = FALSE;
 
 typedef struct response_entry
@@ -126,7 +135,15 @@ static int subtitle_state = DONE_SUBTITLE;
 static Mutex subtitle_mutex;
 
 static const UNICODE * volatile last_subtitle;
-static TFB_Image *subtitle_cache;
+
+CONTEXT TextCacheContext;
+FRAME TextCacheFrame;
+
+RECT CommWndRect = {
+	// default values; actually inited by HailAlien()
+	{SIS_ORG_X, SIS_ORG_Y},
+	{0, 0}
+};
 
 /* _count_lines - sees how many lines a given input string would take to
  * display given the line wrapping information
@@ -166,28 +183,29 @@ add_text (int status, PTEXT pTextIn)
 	int num_lines = 0;
 	static COORD last_baseline;
 	BOOLEAN eol;
+	CONTEXT OldContext;
 	
 	BatchGraphics ();
 
 	maxchars = (COUNT)~0;
 	if (status == 1)
 	{
-		RECT r;
-		GetContextClipRect (&r);
-
 		if (last_subtitle == pTextIn->pStr)
 		{
 			// draws cached subtitle
-			TFB_DrawScreen_Image (subtitle_cache, r.corner.x, r.corner.y, 0, 0, TFB_SCREEN_MAIN);
+			STAMP s;
+
+			s.origin.x = s.origin.y = 0;
+			s.frame = TextCacheFrame;
+			DrawStamp (&s);
 			UnbatchGraphics ();
 			return last_baseline;
 		}
 		else
 		{
-			// saves background to extra screen
-			TFB_DrawScreen_Copy (&r, TFB_SCREEN_MAIN, TFB_SCREEN_EXTRA);
-			// fills screen with transparent color
-			TFB_DrawScreen_Rect (&r, 0, 0, 128, TFB_SCREEN_MAIN);
+			// draw to subtitle cache; prepare first
+			OldContext = SetContext (TextCacheContext);
+			ClearDrawable ();
 
 			last_subtitle = pTextIn->pStr;
 		}
@@ -302,16 +320,13 @@ add_text (int status, PTEXT pTextIn)
 
 	if (status == 1)
 	{
-		RECT r;
-		GetContextClipRect (&r);
+		STAMP s;
 		
-		// copies subtitle to cache
-		TFB_DrawScreen_CopyToImage (subtitle_cache, &r, TFB_SCREEN_MAIN);
-		// restores background
-		TFB_DrawScreen_Copy (&r, TFB_SCREEN_EXTRA, TFB_SCREEN_MAIN);
-		// draws cached subtitle
-		TFB_DrawScreen_Image (subtitle_cache, r.corner.x, r.corner.y, 0, 0,
-				TFB_SCREEN_MAIN);
+		// we were drawing to cache -- flush to screen
+		SetContext (OldContext);
+		s.origin.x = s.origin.y = 0;
+		s.frame = TextCacheFrame;
+		DrawStamp (&s);
 		
 		last_baseline = pText->baseline.y;
 	}
@@ -496,182 +511,21 @@ DrawAlienFrame (FRAME aframe, PSEQUENCE pSeq)
 	UnbatchGraphics ();
 }
 
-typedef struct xform_control
-{
-	COLORMAPPTR CMapPtr;
-	SIZE Ticks, TTotal, TOrig;
-	UBYTE OldCMap[PLUT_BYTE_SIZE];
-} XFORM_CONTROL;
-
-#define MAX_XFORMS 32
-static struct {
-	XFORM_CONTROL TaskControl[MAX_XFORMS];
-	volatile int XFormCurrent, XFormInsertPoint;
-	volatile BOOLEAN XFormsPending;
-	Mutex XFormLock;
-} XFormControl;
-
-static void
-init_xform_control (void)
-{
-	XFormControl.XFormCurrent = XFormControl.XFormInsertPoint = 0;
-	XFormControl.XFormsPending = FALSE;
-	XFormControl.XFormLock = CreateMutex ("Transform Lock", SYNC_CLASS_TOPLEVEL | SYNC_CLASS_VIDEO);
-}
-
-static void
-uninit_xform_control (void)
-{
-	DestroyMutex (XFormControl.XFormLock);
-}
-
-static void
-xform_complete (void)
-{
-	LockMutex (XFormControl.XFormLock);
-	if (XFormControl.XFormsPending)
-	{
-		SetColorMap (XFormControl.TaskControl[XFormControl.XFormCurrent].CMapPtr);
-		if (++XFormControl.XFormCurrent >= MAX_XFORMS)
-		{
-			XFormControl.XFormCurrent = 0;
-		}
-		if (XFormControl.XFormCurrent == XFormControl.XFormInsertPoint)
-		{
-			XFormControl.XFormsPending = FALSE;
-		}
-	}
-	UnlockMutex (XFormControl.XFormLock);
-}
-
 void
 init_communication (void)
 {
-	TFB_Canvas canvas;
-
 	subtitle_mutex = CreateMutex ("Subtitle Lock", SYNC_CLASS_TOPLEVEL | SYNC_CLASS_VIDEO);
-	init_xform_control ();
-
-	canvas = TFB_DrawCanvas_New_TrueColor (SIS_SCREEN_WIDTH,
-		SIS_SCREEN_HEIGHT - SLIDER_Y - SLIDER_HEIGHT + 2, FALSE);
-	subtitle_cache = TFB_DrawImage_New (canvas);
-	TFB_DrawCanvas_SetTransparentColor (subtitle_cache->NormalImg, 0, 0, 128, TRUE);
 }
 
 void
 uninit_communication (void)
 {
 	DestroyMutex (subtitle_mutex);
-	uninit_xform_control ();
-	TFB_DrawImage_Delete (subtitle_cache);
-	subtitle_cache = NULL;
 }
 
-static volatile BOOLEAN ColorChange;
 static volatile BOOLEAN SummaryChange;
 static volatile BOOLEAN ClearSubtitle;
 
-/* Only one thread should ever be allowed to be calling this at any time */
-static void
-xform_PLUT_step (SIZE TDelta)
-{
-	XFORM_CONTROL *control;
-	COLORMAPPTR ColorMapPtr;
-	int i;
-
-	if (!XFormControl.XFormsPending)
-		return;
-
-	control = &XFormControl.TaskControl[XFormControl.XFormCurrent];
-
-	ColorMapPtr = control->CMapPtr;
-
-	if (TDelta > control->TTotal)
-		TDelta = control->TTotal;
-
-	if (_varPLUTs && control->TOrig != 0)
-	{
-#define XFORM_SCALE 0x10000
-		UBYTE *pCurCMap, *pOldCMap, *pNewCMap;
-		int frac;
-
-		pCurCMap = GET_VAR_PLUT (*ColorMapPtr);
-		pOldCMap = control->OldCMap;
-		pNewCMap = (UBYTE*)ColorMapPtr + 2;
-
-		frac = (int)(control->TOrig - control->TTotal) * XFORM_SCALE
-				/ control->TOrig;
-
-		for (i = 0; i < PLUT_BYTE_SIZE; i++)
-		{
-			*pCurCMap = (UBYTE)(*pOldCMap + ((int)*pNewCMap - *pOldCMap)
-						* frac / XFORM_SCALE);
-			pOldCMap++;
-			pCurCMap++;
-			pNewCMap++;
-		}
-		ColorChange = TRUE;
-	}
-	control->TTotal -= TDelta;
-	if (!control->TTotal)
-	{
-		xform_complete ();
-	}
-}
-
-/* This should be thread-safe without locking the XFormControl because
- * only one thread should be Flushing at any given time, constant
- * writes are atomic anyway, and Flush is the only routine that writes
- * XFormFlush. */
-
-static void
-FlushPLUTXForms (void)
-{
-	while (XFormControl.XFormsPending)
-	{
-		xform_complete ();
-	}
-}
-
-DWORD
-XFormPLUT (COLORMAPPTR ColorMapPtr, SIZE TimeInterval)
-{
-	if (ColorMapPtr)
-	{
-		XFORM_CONTROL *control;
-
-		// FlushPLUTXForms ();
-
-		LockMutex (XFormControl.XFormLock);
-		while (XFormControl.XFormsPending
-				&& (XFormControl.XFormInsertPoint == XFormControl.XFormCurrent))
-		{
-			UnlockMutex (XFormControl.XFormLock);
-			FlushPLUTXForms ();
-			LockMutex (XFormControl.XFormLock);
-		}
-		
-		control = &XFormControl.TaskControl[XFormControl.XFormInsertPoint];
-
-		memcpy (control->OldCMap, GET_VAR_PLUT (*ColorMapPtr), PLUT_BYTE_SIZE);
-
-		control->CMapPtr = ColorMapPtr;
-		if ((control->Ticks = TimeInterval) <= 0)
-			control->Ticks = 1; /* prevent divide by zero and negative fade */
-		control->TTotal = control->TOrig = TimeInterval;
-
-		if (++XFormControl.XFormInsertPoint >= MAX_XFORMS)
-			XFormControl.XFormInsertPoint = 0;
-
-		XFormControl.XFormsPending = TRUE;
-
-		UnlockMutex (XFormControl.XFormLock);		
-
-	}
-
-	return (0);
-}
-
 static void
 RefreshResponses (PENCOUNTER_STATE pES)
 {
@@ -859,6 +713,7 @@ ambient_anim_task (void *data)
 	BOOLEAN TransitionDone = FALSE;
 	BOOLEAN TalkFrameChanged = FALSE;
 	BOOLEAN FrameChanged[MAX_ANIMATIONS];
+	BOOLEAN ColorChange = FALSE;
 
 	while ((CommFrame = CommData.AlienFrame) == 0 && !Task_ReadState (task, TASK_EXIT))
 		TaskSwitch ();
@@ -893,7 +748,7 @@ ambient_anim_task (void *data)
 		BOOLEAN Change, CanTalk;
 		DWORD CurTime, ElapsedTicks;
 
-		SleepThreadUntil (LastTime + ONE_SECOND / 120);
+		SleepThreadUntil (LastTime + ONE_SECOND / AMBIENT_ANIM_RATE);
 
 		LockMutex (GraphicsLock);
 		BatchGraphics ();
@@ -955,7 +810,7 @@ ambient_anim_task (void *data)
 
 				if (pSeq->AnimType == COLOR_ANIM)
 				{
-					XFormPLUT (
+					XFormColorMap (
 							GetColorMapAddress (pSeq->AnimObj.CurCMap),
 							(COUNT) (pSeq->Alarm - 1)
 							);
@@ -1200,7 +1055,7 @@ ambient_anim_task (void *data)
 		if (!summary)
 		{
 			CONTEXT OldContext;
-			BOOLEAN CheckSub = 0;
+			BOOLEAN CheckSub = FALSE;
 			BOOLEAN ClearSub;
 			int sub_state;
 
@@ -1220,8 +1075,8 @@ ambient_anim_task (void *data)
 				CommData.AlienFrame = CommFrame;
 				DrawAlienFrame (TalkFrame, &Sequencer[CommData.NumAnimations - 1]);
 				CommData.AlienFrame = F;
-				CheckSub = 1;
-				ClearSub = SummaryChange ? TRUE : FALSE;
+				CheckSub = TRUE;
+				ClearSub = SummaryChange;
 				ColorChange = SummaryChange = FALSE;
 			}
 			if (Change || ClearSub)
@@ -1262,7 +1117,7 @@ ambient_anim_task (void *data)
 					TalkFrameChanged = FALSE;
 				}
 				Change = FALSE;
-				CheckSub = 1;
+				CheckSub = TRUE;
 			}
 
 			if (optSubtitles && CheckSub && sub_state >= SPACE_SUBTITLE)
@@ -1275,14 +1130,14 @@ ambient_anim_task (void *data)
 
 			SetContext (OldContext);
 		}
-		if (LastOscillTime + (ONE_SECOND / 32) < CurTime)
+		if (LastOscillTime + (ONE_SECOND / OSCILLOSCOPE_RATE) < CurTime)
 		{
 			LastOscillTime = CurTime;
 			UpdateSpeechGraphics (FALSE);
 		}
 		UnbatchGraphics ();
 		UnlockMutex (GraphicsLock);
-		xform_PLUT_step(ElapsedTicks);
+		ColorChange = XFormColorMap_step ();
 	}
 	FinishTask (task);
 	return(0);
@@ -1424,18 +1279,78 @@ Rewind:
 	CommData.AlienFrame = F;
 	do_subtitles ((void *)~0);
 
-	if (wait_track == (COUNT)~0)
+	if (!which_track || wait_track == (COUNT)~0)
+	{	// reached the end
 		SetSliderImage (SetAbsFrameIndex (ActivityFrame, 8));
+		return (FALSE);
+	}
+	
 	return (passed);
 }
 
+static BOOLEAN
+DoTalkSegue (COUNT wait_track)
+{
+	BOOLEAN done;
+
+	// Transition animation to talking state, if necessary
+	if (CommData.AlienTalkDesc.NumFrames)
+	{
+		if (!(CommData.AlienTransitionDesc.AnimFlags & TALK_INTRO))
+		{
+			CommData.AlienTransitionDesc.AnimFlags |= TALK_INTRO;
+			if (CommData.AlienTransitionDesc.NumFrames)
+				CommData.AlienTalkDesc.AnimFlags |= TALK_INTRO;
+		}
+					
+		CommData.AlienTransitionDesc.AnimFlags &= ~PAUSE_TALKING;
+		if (CommData.AlienTalkDesc.NumFrames)
+			CommData.AlienTalkDesc.AnimFlags |= WAIT_TALKING;
+		while (CommData.AlienTalkDesc.AnimFlags & TALK_INTRO)
+		{	// wait until the trasition finishes
+			UnlockMutex (GraphicsLock);
+			TaskSwitch ();
+			LockMutex (GraphicsLock);
+		}
+	}
+
+	done = !SpewPhrases (wait_track);
+
+	// transition back to silent, if necessary
+	if (CommData.AlienTalkDesc.NumFrames)
+	{
+		// must set the TALK_DONE flag so that the animation task
+		// releases WAIT_TALKING from AlienTalkDesc
+		CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
+		if ((CommData.AlienTalkDesc.AnimFlags & WAIT_TALKING))
+			CommData.AlienTalkDesc.AnimFlags |= PAUSE_TALKING;
+	}
+
+	return done;
+}
+
+static void
+FlushTalkSegue (void)
+{
+	FlushInput ();
+	while (AnyButtonPress (TRUE))
+		TaskSwitch ();
+
+	do
+		TaskSwitch ();
+	while (CommData.AlienTalkDesc.AnimFlags & PAUSE_TALKING);
+}
+
 void
 AlienTalkSegue (COUNT wait_track)
 {
-	BOOLEAN abort;
+	BOOLEAN done;
+
+	// this skips any talk segues that follow an aborted one
 	if ((GLOBAL (CurrentActivity) & CHECK_ABORT)
-			|| (CommData.AlienTransitionDesc.AnimFlags & TALK_INTRO))
+			|| (CommData.AlienTransitionDesc.AnimFlags & TALK_DONE))
 		return;
+
 	LockMutex (GraphicsLock);
 
 	if (!pCurInputState->Initialized)
@@ -1464,11 +1379,7 @@ AlienTalkSegue (COUNT wait_track)
 			}
 			else
 			{
-				r.corner.x = 0;
-				r.corner.y = 0;
-				r.extent.width = SCREEN_WIDTH;
-				r.extent.height = SCREEN_HEIGHT;
-				ScreenTransition (3, &r);
+				ScreenTransition (3, &CommWndRect);
 			}
 			UnbatchGraphics ();
 		}
@@ -1505,46 +1416,24 @@ AlienTalkSegue (COUNT wait_track)
 
 		LastActivity &= ~CHECK_LOAD;
 	}
-	if (wait_track == (COUNT)~0 || CommData.AlienTalkDesc.NumFrames)
-	{
-		if (!(CommData.AlienTransitionDesc.AnimFlags & TALK_INTRO))
-		{
-			CommData.AlienTransitionDesc.AnimFlags |= TALK_INTRO;
-			if (CommData.AlienTransitionDesc.NumFrames)
-				CommData.AlienTalkDesc.AnimFlags |= TALK_INTRO;
-		}
-					
-		CommData.AlienTransitionDesc.AnimFlags &= ~PAUSE_TALKING;
-		if (CommData.AlienTalkDesc.NumFrames)
-			CommData.AlienTalkDesc.AnimFlags |= WAIT_TALKING;
-		while (CommData.AlienTalkDesc.AnimFlags & TALK_INTRO)
-		{
-			UnlockMutex (GraphicsLock);
-			TaskSwitch ();
-			LockMutex (GraphicsLock);
-		}
-	}
-
-	if (!(abort = SpewPhrases (wait_track)) || wait_track == (COUNT)~0)
+	
+	done = DoTalkSegue (wait_track);
+	if (done || wait_track == (COUNT)~0)
 		FadeMusic (FOREGROUND_VOL, ONE_SECOND);
-	else
-		CommData.AlienTransitionDesc.AnimFlags &= ~TALK_INTRO;
-
-	if (wait_track == (COUNT)~0 || ! abort || CommData.AlienTalkDesc.NumFrames)
-	{
-		CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
-		if ((CommData.AlienTalkDesc.AnimFlags & WAIT_TALKING))
-			CommData.AlienTalkDesc.AnimFlags |= PAUSE_TALKING;
-	}
 
 	UnlockMutex (GraphicsLock);
-	FlushInput ();
-	while (AnyButtonPress (TRUE))
-		TaskSwitch ();
+	FlushTalkSegue ();
 
-	do
-		TaskSwitch ();
-	while (CommData.AlienTalkDesc.AnimFlags & PAUSE_TALKING);
+	if (done || wait_track == (COUNT)~0)
+	{	// all done talking here
+		CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
+	}
+	else
+	{	// there is more to come
+		CommData.AlienTransitionDesc.AnimFlags &= ~TALK_DONE;
+		// allow a transition to talking state again later
+		CommData.AlienTransitionDesc.AnimFlags &= ~TALK_INTRO;
+	}
 }
 
 static BOOLEAN
@@ -1552,7 +1441,7 @@ DoCommunication (PENCOUNTER_STATE pES)
 {
 	SetMenuSounds (MENU_SOUND_UP | MENU_SOUND_DOWN, MENU_SOUND_SELECT);
 
-	if (!(CommData.AlienTransitionDesc.AnimFlags & (TALK_INTRO | TALK_DONE)))
+	if (!(CommData.AlienTransitionDesc.AnimFlags & TALK_DONE))
 	{
 		AlienTalkSegue ((COUNT)~0);
 	}
@@ -1575,43 +1464,13 @@ DoCommunication (PENCOUNTER_STATE pES)
 			{
 				FadeMusic (BACKGROUND_VOL, ONE_SECOND);
 				LockMutex (GraphicsLock);
+				// reset transition state
 				CommData.AlienTransitionDesc.AnimFlags &= ~(TALK_INTRO | TALK_DONE);
-				if (CommData.AlienTalkDesc.NumFrames)
-				{
-					if (!(CommData.AlienTransitionDesc.AnimFlags & TALK_INTRO))
-					{
-						CommData.AlienTransitionDesc.AnimFlags |= TALK_INTRO;
-						if (CommData.AlienTransitionDesc.NumFrames)
-							CommData.AlienTalkDesc.AnimFlags |= TALK_INTRO;
-					}
-					
-					CommData.AlienTransitionDesc.AnimFlags &= ~PAUSE_TALKING;
-					if (CommData.AlienTalkDesc.NumFrames)
-						CommData.AlienTalkDesc.AnimFlags |= WAIT_TALKING;
-					while (CommData.AlienTalkDesc.AnimFlags & TALK_INTRO)
-					{
-						UnlockMutex (GraphicsLock);
-						TaskSwitch ();
-						LockMutex (GraphicsLock);
-					}
-				}
-				
-				SpewPhrases (0);
-				
-				CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
-				if (CommData.AlienTalkDesc.NumFrames)
-				{
-					if ((CommData.AlienTalkDesc.AnimFlags & WAIT_TALKING))
-						CommData.AlienTalkDesc.AnimFlags |= PAUSE_TALKING;
-				}
-
+				DoTalkSegue (0);
 				UnlockMutex (GraphicsLock);
-				FlushInput ();
-				while (AnyButtonPress (TRUE))
-					TaskSwitch ();
-				do
-					TaskSwitch ();
-				while (CommData.AlienTalkDesc.AnimFlags & PAUSE_TALKING);
+				FlushTalkSegue ();
+				// done one way or the other
+				CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
 
 				if (GLOBAL (CurrentActivity) & CHECK_ABORT)
 					break;
@@ -1665,9 +1524,8 @@ DoCommunication (PENCOUNTER_STATE pES)
 			TEXT t;
 #define DELTA_Y_SUMMARY 8
 #define SUMMARY_CHARS (SIS_SCREEN_WIDTH - 34) / 4
-#define MAX_SUMMARY_CHARS 52
 #define MAX_COLS ((SIS_SCREEN_HEIGHT - SLIDER_Y - SLIDER_HEIGHT - DELTA_Y_SUMMARY) / 8) - 1
-			UNICODE buffer[MAX_SUMMARY_CHARS];
+			UNICODE buffer[320]; // SUMMARY_CHARS * 6
 			UNICODE *temp;
 			int i;
 			int col = 0;
@@ -1704,13 +1562,14 @@ DoCommunication (PENCOUNTER_STATE pES)
 				temp = curr->text;
 				if (temp == NULL)
 					continue;
-				// fprintf (stderr, "%s\n", temp);
-				while (wstrlen (temp) > (unsigned int) SUMMARY_CHARS
+				while (utf8StringCount (temp) > (unsigned int) SUMMARY_CHARS
 						&& !(GLOBAL (CurrentActivity) & CHECK_ABORT))
 				{
-					int space_index = SUMMARY_CHARS;
+					UNICODE *pend = skipUTF8Chars (temp, SUMMARY_CHARS);
+					int space_index = pend - temp;
+
 					// find last space before it goes over the max chars per line
-					for (i = SUMMARY_CHARS - 1; i > 0; i--)
+					for (i = space_index; i > 0; i--)
 					{
 						if (temp[i] == ' ')
 						{
@@ -1718,12 +1577,16 @@ DoCommunication (PENCOUNTER_STATE pES)
 							break;
 						}
 					}
-					for (i = 0; i < space_index; i++, temp++)
+					if ((unsigned)space_index >= sizeof (buffer))
 					{
-						buffer[i] = *temp;
+						fprintf (stderr, "DoCommunication() BUG: buffer[%u] "
+								"too small to fit %d bytes\n",
+								sizeof (buffer), space_index);
+						abort ();
 					}
-					buffer[i] = '\0';
-					temp++;
+					strncpy (buffer, temp, space_index);
+					buffer[space_index] = '\0';
+					temp += space_index + 1;
 					t.pStr = buffer;
 					LockMutex (GraphicsLock);
 					font_DrawText (&t);
@@ -1734,7 +1597,11 @@ DoCommunication (PENCOUNTER_STATE pES)
 					{
 						t.baseline.x = SIS_SCREEN_WIDTH >> 1;
 						t.align = ALIGN_CENTER;
-						t.pStr = "_MORE_";
+						snprintf (buffer, sizeof (buffer), "%s%s%s", // "MORE"
+								  STR_MIDDLE_DOT,
+								  GAME_STRING (FEEDBACK_STRING_BASE + 1),
+								  STR_MIDDLE_DOT);
+						t.pStr = buffer;
 						SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x17, 0x00), 0x01));
 						LockMutex (GraphicsLock);
 						font_DrawText (&t);
@@ -1765,10 +1632,13 @@ DoCommunication (PENCOUNTER_STATE pES)
 				col++;
 				if (col > MAX_COLS && curr->next != NULL)
 				{
-					
 					t.baseline.x = SIS_SCREEN_WIDTH >> 1;
 					t.align = ALIGN_CENTER;
-					t.pStr = "_MORE_";
+					snprintf (buffer, sizeof (buffer), "%s%s%s", // "MORE"
+							  STR_MIDDLE_DOT,
+							  GAME_STRING (FEEDBACK_STRING_BASE + 1),
+							  STR_MIDDLE_DOT);
+					t.pStr = buffer;
 					SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x17, 0x00), 0x01));
 					LockMutex (GraphicsLock);
 					font_DrawText (&t);
@@ -1810,48 +1680,21 @@ DoCommunication (PENCOUNTER_STATE pES)
 				FadeMusic (BACKGROUND_VOL, ONE_SECOND);
 				LockMutex (GraphicsLock);
 				FeedbackPlayerPhrase (pES->phrase_buf);
-
+				// reset transition state
 				CommData.AlienTransitionDesc.AnimFlags &= ~(TALK_INTRO | TALK_DONE);
-				if (CommData.AlienTalkDesc.NumFrames)
-				{
-					if (!(CommData.AlienTransitionDesc.AnimFlags & TALK_INTRO))
-					{
-						CommData.AlienTransitionDesc.AnimFlags |= TALK_INTRO;
-						if (CommData.AlienTransitionDesc.NumFrames)
-							CommData.AlienTalkDesc.AnimFlags |= TALK_INTRO;
-					}
-					
-					CommData.AlienTransitionDesc.AnimFlags &= ~PAUSE_TALKING;
-					if (CommData.AlienTalkDesc.NumFrames)
-						CommData.AlienTalkDesc.AnimFlags |= WAIT_TALKING;
-					while (CommData.AlienTalkDesc.AnimFlags & TALK_INTRO)
-					{
-						UnlockMutex (GraphicsLock);
-						TaskSwitch ();
-						LockMutex (GraphicsLock);
-					}
-				}
+				DoTalkSegue (0);
 
-				SpewPhrases (0);
-
-				CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
-				if (CommData.AlienTalkDesc.NumFrames)
-				{
-					if ((CommData.AlienTalkDesc.AnimFlags & WAIT_TALKING))
-						CommData.AlienTalkDesc.AnimFlags |= PAUSE_TALKING;
-				}
 				if (!(GLOBAL (CurrentActivity) & CHECK_ABORT))
 				{
 					RefreshResponses (pES);
 					FadeMusic (FOREGROUND_VOL, ONE_SECOND);
 				}
+				
 				UnlockMutex (GraphicsLock);
-				FlushInput ();
-				while (AnyButtonPress (TRUE))
-					TaskSwitch ();
-				do
-					TaskSwitch ();
-				while (CommData.AlienTalkDesc.AnimFlags & PAUSE_TALKING);
+				FlushTalkSegue ();
+				// done one way or the other
+				CommData.AlienTransitionDesc.AnimFlags |= TALK_DONE;
+
 			}
 			else if (PulsedInputState.key[KEY_MENU_UP])
 				response = (BYTE)((response + (BYTE)(pES->num_responses - 1))
@@ -1906,11 +1749,9 @@ DoCommunication (PENCOUNTER_STATE pES)
 
 	UnlockMutex (GraphicsLock);
 
-	FlushPLUTXForms ();
-	ColorChange = FALSE;
+	FlushColorXForms ();
 	ClearSubtitle = FALSE;
 
-	FlushColorXForms ();
 	StopMusic ();
 	StopSound ();
 	StopTrack ();
@@ -1967,6 +1808,7 @@ HailAlien (void)
 	ENCOUNTER_STATE ES;
 	FONT PlayerFont, OldFont;
 	MUSIC_REF SongRef = 0;
+	COLOR TextBack;
 
 	pCurInputState = &ES;
 	memset (pCurInputState, 0, sizeof (*pCurInputState));
@@ -1987,7 +1829,7 @@ HailAlien (void)
 			);
 	if ((CommData.AlienSongFlags & LDASF_USE_ALTERNATE)
 			&& CommData.AlienAltSong)
-		SongRef = LoadMusicFile (CommData.AlienAltSong);
+		SongRef = LoadMusicInstance ((RESOURCE)CommData.AlienAltSong);
 	if (SongRef)
 		CommData.AlienSong = SongRef;
 	else
@@ -1997,6 +1839,18 @@ HailAlien (void)
 			LoadStringTableInstance ((RESOURCE)CommData.ConversationPhrases)
 			);
 
+	// init subtitle cache context
+	TextCacheContext = CaptureContext (CreateContext ());
+	TextCacheFrame = CaptureDrawable (CreateDrawable (WANT_PIXMAP,
+		SIS_SCREEN_WIDTH, SIS_SCREEN_HEIGHT - SLIDER_Y - SLIDER_HEIGHT + 2,
+		1));
+	SetContext (TextCacheContext);
+	SetContextFGFrame (TextCacheFrame);
+	TextBack = BUILD_COLOR (MAKE_RGB15 (0, 0, 0x10), 1);
+	SetContextBackGroundColor (TextBack);
+	ClearDrawable ();
+	SetFrameTransparentColor (TextCacheFrame, TextBack);
+
 	ES.phrase_buf_index = 1;
 	ES.phrase_buf[0] = '\0';
 
@@ -2010,20 +1864,22 @@ HailAlien (void)
 		SetContext (TaskContext);
 		SetContextFGFrame (Screen);
 		GetFrameRect (CommData.AlienFrame, &r);
-		r.corner.y = SIS_ORG_Y;
 		r.extent.width = SIS_SCREEN_WIDTH;
-
+		CommWndRect.extent = r.extent;
+		
 		SetTransitionSource (NULL);
 		BatchGraphics ();
 		if (LOBYTE (GLOBAL (CurrentActivity)) == WON_LAST_BATTLE)
 		{
-			r.corner.x = (SCREEN_WIDTH - SIS_SCREEN_WIDTH) >> 1;
+			r.corner = CommWndRect.corner;
 			SetContextClipRect (&r);
 		}
 		else
 		{
 			r.corner.x = SIS_ORG_X;
+			r.corner.y = SIS_ORG_Y;
 			SetContextClipRect (&r);
+			CommWndRect.corner = r.corner;
 
 			if (pMenuState == 0)
 			{
@@ -2034,9 +1890,7 @@ HailAlien (void)
 			}
 			else /* in starbase */
 			{
-				UnlockMutex (GraphicsLock);
 				DrawSISFrame ();
-				LockMutex (GraphicsLock);
 				if (GET_GAME_STATE (STARBASE_AVAILABLE))
 				{
 					DrawSISMessage (GAME_STRING (STARBASE_STRING_BASE + 1));
@@ -2070,6 +1924,9 @@ HailAlien (void)
 	DestroyFont (ReleaseFont (CommData.AlienFont));
 	DestroyDrawable (ReleaseDrawable (CommData.AlienFrame));
 
+	DestroyContext (ReleaseContext (TextCacheContext));
+	DestroyDrawable (ReleaseDrawable (TextCacheFrame));
+
 	SetContext (SpaceContext);
 	SetContextFont (OldFont);
 	DestroyFont (ReleaseFont (PlayerFont));
@@ -2085,6 +1942,11 @@ InitCommunication (RESOURCE which_comm)
 	MEM_HANDLE hOldIndex, hIndex;
 	LOCDATAPTR LocDataPtr;
 
+#ifdef DEBUG
+	if (disableInteractivity)
+		return 0;
+#endif
+	
 	last_subtitle = NULL;
 
 	LockMutex (GraphicsLock);
@@ -2096,9 +1958,7 @@ InitCommunication (RESOURCE which_comm)
 		{
 			if (LOBYTE (LastActivity) == 0)
 			{
-				UnlockMutex (GraphicsLock);
 				DrawSISFrame ();
-				LockMutex (GraphicsLock);
 			}
 			else
 			{
@@ -2233,7 +2093,6 @@ RaceCommunication (void)
 	{
 		RACE_COMMUNICATION
 	};
-	extern ACTIVITY NextActivity;
 
 	if (LOBYTE (GLOBAL (CurrentActivity)) == IN_LAST_BATTLE)
 	{
