@@ -30,13 +30,13 @@ static LOCDATA blackurq_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* SIS_TEXT_WIDTH - 16, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)BLACKURQ_COLOR_MAP, /* AlienColorMap */
 	BLACKURQ_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
 	BLACKURQ_CONVERSATION_PHRASES, /* PlayerPhrases */
 	8, /* NumAnimations */
-	{
+	{ /* AlienAmbientArray (ambient animations) */
 		{
 			7, /* StartIndex */
 			6, /* NumFrames */
@@ -103,7 +103,7 @@ static LOCDATA blackurq_desc =
 			0, /* BlockMask */
 		},
 	},
-	{
+	{ /* AlienTransitionDesc */
 		1, /* StartIndex */
 		2, /* NumFrames */
 		0, /* AnimFlags */
@@ -111,7 +111,7 @@ static LOCDATA blackurq_desc =
 		0, 0, /* RestartRate */
 		0, /* BlockMask */
 	},
-	{
+	{ /* AlienTalkDesc */
 		2, /* StartIndex */
 		5, /* NumFrames */
 		0, /* AnimFlags */
@@ -442,7 +442,7 @@ Intro (void)
 		NPCPhrase (OUT_TAKES);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	if (GET_GAME_STATE (KOHR_AH_KILLED_ALL))
@@ -450,7 +450,7 @@ Intro (void)
 		NPCPhrase (GAME_OVER_DUDE);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	if (!GET_GAME_STATE (KOHR_AH_SENSES_EVIL)
@@ -524,8 +524,6 @@ Intro (void)
 		}
 		SET_GAME_STATE (KOHR_AH_VISITS, NumVisits);
 	}
-ExitIntro:
-	;
 }
 
 static COUNT
