@@ -588,7 +588,7 @@ GiveRadios (RESPONSE_REF R)
 		CommData.AlienAmbientArray[2].AnimFlags |= ANIM_DISABLED;
 		UnlockMutex (GraphicsLock);
 
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 0)
 				), ONE_SECOND / 2);
 
@@ -694,8 +694,10 @@ init_commander_comm ()
 		commander_desc.AlienSongFlags &= ~LDASF_USE_ALTERNATE;
 	}
 	else
-	{	// use alternate 'low-power' track if available
-		commander_desc.AlienAltSong = "comm/comandr/comlowpw.mod";
+	{	
+		commander_desc.AlienAmbientArray[2].AnimFlags &= ~ANIM_DISABLED;
+		// use alternate 'low-power' track if available
+		commander_desc.AlienAltSong = COMMANDER_LOWPOW_MUSIC;
 		commander_desc.AlienSongFlags |= LDASF_USE_ALTERNATE;
 	}
 
