@@ -22,16 +22,11 @@
 
 #include "gameev.h"
 #include "setup.h"
+#include "shipcont.h"
 #include "libs/inplib.h"
 #include "libs/mathlib.h"
 
 
-//Added by Chris
-
-void DrawCargoStrings (BYTE OldElement, BYTE NewElement);
-
-//End Added by Chris
-
 #define NUM_HISTORY_ITEMS 9
 #define NUM_EVENT_ITEMS 8
 #define NUM_ALIEN_RACE_ITEMS 16
@@ -226,10 +221,9 @@ ShipWorth (void)
 
 		which_module = GLOBAL_SIS (ModuleSlots[i]);
 		if (which_module < BOMB_MODULE_0
-				|| which_module != CREW_POD
-				|| ++crew_pods > 0)
+				&& (which_module != CREW_POD || ++crew_pods > 0))
 		{
-			worth += GLOBAL (ModuleCost[i]);
+			worth += GLOBAL (ModuleCost[which_module]);
 		}
 	}
 
@@ -368,7 +362,8 @@ StripShip (COUNT fuel_required)
 					break;
 				case CREW_POD:
 					i = HIBYTE (LOWORD (rand_val)) % NUM_MODULE_SLOTS;
-					if ((which_module = SIS_copy.ModuleSlots[i]) >= EMPTY_SLOT
+					which_module = SIS_copy.ModuleSlots[i];
+					if (which_module >= BOMB_MODULE_0
 							|| which_module == FUEL_TANK
 							|| which_module == HIGHEFF_FUELSYS
 							|| (which_module == STORAGE_BAY
@@ -1342,7 +1337,7 @@ NatureOfConversation (RESPONSE_REF R)
 				/* Melnorme reports any news and turns purple */
 			NPCPhrase (BUY_OR_SELL);
 			AlienTalkSegue(1);
-			XFormPLUT (GetColorMapAddress (
+			XFormColorMap (GetColorMapAddress (
 					SetAbsColorMapIndex (CommData.AlienColorMap, 1)
 					), ONE_SECOND / 2);
 			AlienTalkSegue((COUNT)~0);
@@ -1425,11 +1420,14 @@ NatureOfConversation (RESPONSE_REF R)
 static void
 DoBluster (RESPONSE_REF R)
 {
+	// BUG: these should really be GAME_STATE vars
+	//  currently, you can reload a game and skip some responses
+	//  that you've said before
 	static BYTE local_stack0 = 0, local_stack1 = 0;
 
 	if (PLAYER_SAID (R, trade_is_for_the_weak))
 	{
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 2)
 				), ONE_SECOND / 2);
 
@@ -1499,7 +1497,7 @@ yack0_respond (void)
 	{
 		case 0:
 		{
-			UNICODE buf[80];
+			UNICODE buf[ALLIANCE_NAME_BUFSIZE];
 
 			GetAllianceName (buf, name_1);
 			construct_response (
@@ -1626,7 +1624,7 @@ DoFirstMeeting (RESPONSE_REF R)
 	}
 	else if (PLAYER_SAID (R, yes_really_testing))
 	{
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 0)
 				), ONE_SECOND / 2);
 
@@ -1635,7 +1633,7 @@ DoFirstMeeting (RESPONSE_REF R)
 	else if (PLAYER_SAID (R, we_apologize))
 	{
 		SET_GAME_STATE (MELNORME_ANGER, 0);
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 0)
 				), ONE_SECOND / 2);
 
@@ -1674,7 +1672,7 @@ DoMelnormeMiffed (RESPONSE_REF R)
 		}
 		SET_GAME_STATE (MELNORME_MIFFED_COUNT, miffed_count);
 
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 2)
 				), ONE_SECOND / 2);
 	}
@@ -1746,7 +1744,7 @@ DoMelnormePissed (RESPONSE_REF R)
 		}
 		SET_GAME_STATE (MELNORME_PISSED_COUNT, pissed_count);
 
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 2)
 				), ONE_SECOND / 2);
 	}
@@ -1801,7 +1799,7 @@ DoMelnormeHate (RESPONSE_REF R)
 	}
 	SET_GAME_STATE (MELNORME_HATE_COUNT, hate_count);
 
-	XFormPLUT (GetColorMapAddress (
+	XFormColorMap (GetColorMapAddress (
 			SetAbsColorMapIndex (CommData.AlienColorMap, 2)
 			), ONE_SECOND / 2);
 
