@@ -228,7 +228,7 @@ ExitConversation (RESPONSE_REF R)
 		if (PLAYER_SAID (R, about_andro_3))
 			ActivateStarShip (ORZ_SHIP, -1);
 
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 1)
 				), ONE_SECOND / 2);
 	}
@@ -263,6 +263,7 @@ ExitConversation (RESPONSE_REF R)
 static void
 TaaloWorld (RESPONSE_REF R)
 {
+	// We can only get here when ORZ_MANNER != HOSTILE (2)
 	BYTE Manner;
 
 	Manner = GET_GAME_STATE (ORZ_MANNER);
@@ -316,7 +317,7 @@ TaaloWorld (RESPONSE_REF R)
 				) & GOOD_GUY))
 			Response (may_we_land, ExitConversation);
 		else
-				Response (may_we_land, TaaloWorld);
+			Response (may_we_land, TaaloWorld);
 	}
 	else if (PHRASE_ENABLED (make_alliance))
 		Response (make_alliance, TaaloWorld);
@@ -504,21 +505,18 @@ OrzNeutral (RESPONSE_REF R)
 	else if (PLAYER_SAID (R, where_androsyn))
 	{
 		WhereAndrosyn (R);
-
-		goto ExitNeutral;
+		return;
 	}
 	else if (PLAYER_SAID (R, talk_about_alliance)
 			|| PLAYER_SAID (R, seem_like_nice_guys))
 	{
 		OfferAlliance (R);
-
-		goto ExitNeutral;
+		return;
 	}
 	else if (PLAYER_SAID (R, hostile_2))
 	{
 		ExitConversation (R);
-
-		goto ExitNeutral;
+		return;
 	}
 
 	if (GET_GAME_STATE (ORZ_ANDRO_STATE) == 0)
@@ -568,8 +566,6 @@ OrzNeutral (RESPONSE_REF R)
 		}
 	}
 	Response (bye_neutral, ExitConversation);
-ExitNeutral:
-	;
 }
 
 static void
@@ -640,7 +636,7 @@ Intro (void)
 		NPCPhrase (OUT_TAKES);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	if (!GET_GAME_STATE (MET_ORZ_BEFORE))
@@ -670,7 +666,7 @@ Intro (void)
 	else if (GET_GAME_STATE (GLOBAL_FLAGS_AND_DATA) & (1 << 6))
 	{
 		NumVisits = GET_GAME_STATE (TAALO_VISITS);
-		if (Manner == 0)
+		if (Manner != 1)
 		{
 			switch (NumVisits++)
 			{
@@ -843,9 +839,6 @@ Intro (void)
 		AlienTalkSegue (1);
 		CommData.AlienTalkDesc.NumFrames = N;
 	}
-
-ExitIntro:
-	;
 }
 
 static COUNT
