@@ -34,7 +34,7 @@ static LOCDATA pkunk_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* SIS_TEXT_WIDTH - 16, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)PKUNK_COLOR_MAP, /* AlienColorMap */
 	PKUNK_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
@@ -297,7 +297,7 @@ DiscussConquer (RESPONSE_REF R)
 	if (PHRASE_ENABLED (conquer_because_1))
 	{
 #if 0
-		UNICODE buf[80];
+		UNICODE buf[ALLIANCE_NAME_BUFSIZE];
 
 		GetAllianceName (buf, name_1);
 		construct_response (
@@ -849,7 +849,7 @@ Intro (void)
 		NPCPhrase (OUT_TAKES);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	Manner = GET_GAME_STATE (PKUNK_MANNER);
@@ -1085,8 +1085,6 @@ Intro (void)
 
 		PkunkMigrate ((RESPONSE_REF)0);
 	}
-ExitIntro:
-	;
 }
 
 // Called after combat or communications
