@@ -33,7 +33,7 @@ static LOCDATA shofixti_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* SIS_TEXT_WIDTH, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)SHOFIXTI_COLOR_MAP, /* AlienColorMap */
 	SHOFIXTI_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
@@ -339,7 +339,7 @@ RealizeMistake (RESPONSE_REF R)
 	SET_GAME_STATE (SHOFIXTI_STACK2, 3);
 
 	{
-		UNICODE buf[80];
+		UNICODE buf[ALLIANCE_NAME_BUFSIZE];
 
 		GetAllianceName (buf, name_1);
 		construct_response (
@@ -546,7 +546,7 @@ Intro (void)
 		NPCPhrase (OUT_TAKES);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	GetShofixtiName ();
@@ -616,8 +616,6 @@ Intro (void)
 
 		Hostile ((RESPONSE_REF)0);
 	}
-ExitIntro:
-	;
 }
 
 static COUNT
