@@ -575,7 +575,7 @@ AllianceOffer (RESPONSE_REF R)
 	if (PLAYER_SAID (R, misunderstanding))
 	{
 		NPCPhrase (JUST_MISUNDERSTANDING);
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 1)
 				), ONE_SECOND / 4);
 
@@ -727,7 +727,7 @@ SpathiParty (RESPONSE_REF R)
 			Response (fellowship, SpathiParty);
 		Response (do_as_we_say, ExitConversation);
 
-		goto ExitParty;
+		return;
 	}
 	switch (GET_GAME_STATE (SPATHI_HOME_VISITS) - 1)
 	{
@@ -741,8 +741,6 @@ SpathiParty (RESPONSE_REF R)
 			Response (bye_from_party_3, ExitConversation);
 			break;
 	}
-ExitParty:
-	;
 }
 
 static void
@@ -753,7 +751,7 @@ SpathiCouncil (RESPONSE_REF R)
 	else if (PLAYER_SAID (R, good_password))
 	{
 		NPCPhrase (YES_GOOD_PASSWORD);
-		XFormPLUT (GetColorMapAddress (
+		XFormColorMap (GetColorMapAddress (
 				SetAbsColorMapIndex (CommData.AlienColorMap, 1)
 				), ONE_SECOND / 4);
 
@@ -998,7 +996,7 @@ init_spahome_comm ()
 	spahome_desc.AlienTextWidth = SIS_TEXT_WIDTH - 16;
 
 	// use alternate "Safe Ones" track if available
-	spahome_desc.AlienAltSong = "comm/spahome/spahome.mod";
+	spahome_desc.AlienAltSong = SPAHOME_MUSIC;
 	spahome_desc.AlienSongFlags |= LDASF_USE_ALTERNATE;
 
 	if (GET_GAME_STATE (SPATHI_MANNER) == 3)
