@@ -33,7 +33,7 @@ static LOCDATA spathi_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* SIS_TEXT_WIDTH - 16, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)SPATHI_COLOR_MAP, /* AlienColorMap */
 	SPATHI_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
@@ -803,7 +803,7 @@ init_spathi_comm (void)
 
 	if (GET_GAME_STATE (FOUND_PLUTO_SPATHI) == 1)
 	{	// use alternate Fwiffo track if available
-		spathi_desc.AlienAltSong = "comm/spathi/spafwiff.mod";
+		spathi_desc.AlienAltSong = FWIFFO_MUSIC;
 		spathi_desc.AlienSongFlags |= LDASF_USE_ALTERNATE;
 	}
 	else
