@@ -22,6 +22,7 @@
 
 #include "build.h"
 #include "setup.h"
+#include "shipcont.h"
 #include "libs/graphics/gfx_common.h"
 #include "libs/inplib.h"
 #include "libs/mathlib.h"
@@ -29,14 +30,6 @@
 #include "libs/sound/sound.h"
 
 
-//Added by Chris
-
-void ShowRemainingCapacity (void);
-
-void DrawCargoStrings (BYTE OldElement, BYTE NewElement);
-
-//End Added by Chris
-
 static void TellMission (RESPONSE_REF R);
 static void SellMinerals (RESPONSE_REF R);
 
@@ -1983,7 +1976,7 @@ init_starbase_comm ()
 	commander_desc.AlienTextTemplate.valign = VALIGN_MIDDLE;
 
 	// use alternate Starbase track if available
-	commander_desc.AlienAltSong = "comm/starbas/starbas.mod";
+	commander_desc.AlienAltSong = STARBASE_ALT_MUSIC;
 	commander_desc.AlienSongFlags |= LDASF_USE_ALTERNATE;
 
 	CurBulletinMask = 0;
