@@ -34,7 +34,7 @@ static LOCDATA thradd_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* SIS_TEXT_WIDTH - 16, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)THRADD_COLOR_MAP, /* AlienColorMap */
 	THRADD_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
@@ -693,7 +693,7 @@ Intro (void)
 		NPCPhrase (OUT_TAKES);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	if (GET_GAME_STATE (AQUA_HELIX))
@@ -904,8 +904,6 @@ Intro (void)
 			ThraddHostile ((RESPONSE_REF)0);
 		}
 	}
-ExitIntro:
-	;
 }
 
 static COUNT
