@@ -33,7 +33,7 @@ static LOCDATA umgah_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* SIS_TEXT_WIDTH - 16, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)UMGAH_COLOR_MAP, /* AlienColorMap */
 	UMGAH_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
@@ -341,7 +341,7 @@ Zombies (RESPONSE_REF R)
 			NPCPhrase (NOT_GIVE_UP);
 
 			SET_GAME_STATE (BATTLE_SEGUE, 1);
-			goto ExitZombies;
+			return;
 		}
 		else if (PLAYER_SAID (R, arilou_told_us))
 		{
@@ -350,7 +350,7 @@ Zombies (RESPONSE_REF R)
 			SET_GAME_STATE (BATTLE_SEGUE, 1);
 			SET_GAME_STATE (KNOW_UMGAH_ZOMBIES, 1);
 			SET_GAME_STATE (UMGAH_VISITS, 0);
-			goto ExitZombies;
+			return;
 		}
 
 		if (PHRASE_ENABLED (evil_blobbies))
@@ -402,8 +402,6 @@ Zombies (RESPONSE_REF R)
 			}
 		}
 		Response (bye_zombie, CombatIsInevitable);
-ExitZombies:
-		;
 	}
 }
 
