@@ -35,14 +35,14 @@ static LOCDATA yehat_desc =
 	WHITE_COLOR, /* AlienTextFColor */
 	BLACK_COLOR, /* AlienTextBColor */
 	0, /* (SIS_TEXT_WIDTH - 16) * 2 / 3, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)YEHAT_COLOR_MAP, /* AlienColorMap */
 	YEHAT_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
 	YEHAT_CONVERSATION_PHRASES, /* PlayerPhrases */
 	15, /* NumAnimations */
-	{
-		{
+	{ /* AlienAmbientArray (ambient animations) */
+		{ /* right hand-wing tapping keyboard; front guy */
 			4, /* StartIndex */
 			3, /* NumFrames */
 			YOYO_ANIM
@@ -51,7 +51,7 @@ static LOCDATA yehat_desc =
 			ONE_SECOND / 4, ONE_SECOND / 2,/* RestartRate */
 			(1 << 6) | (1 << 7),
 		},
-		{
+		{ /* left hand-wing tapping keyboard; front guy */
 			7, /* StartIndex */
 			3, /* NumFrames */
 			YOYO_ANIM
@@ -92,7 +92,7 @@ static LOCDATA yehat_desc =
 			ONE_SECOND * 6, ONE_SECOND * 3,/* RestartRate */
 			(1 << 3),
 		},
-		{
+		{ /* right arm-wing rising; front guy */
 			26, /* StartIndex */
 			2, /* NumFrames */
 			YOYO_ANIM | WAIT_TALKING, /* AnimFlags */
@@ -100,7 +100,7 @@ static LOCDATA yehat_desc =
 			ONE_SECOND * 6, ONE_SECOND * 3,/* RestartRate */
 			(1 << 0) | (1 << 1),
 		},
-		{
+		{ /* left arm-wing rising; front guy */
 			28, /* StartIndex */
 			2, /* NumFrames */
 			YOYO_ANIM | WAIT_TALKING, /* AnimFlags */
@@ -165,7 +165,7 @@ static LOCDATA yehat_desc =
 			(1 << 2) | (1 << 4),
 		},
 	},
-	{
+	{ /* AlienTransitionDesc - empty */
 		0, /* StartIndex */
 		0, /* NumFrames */
 		0, /* AnimFlags */
@@ -173,7 +173,7 @@ static LOCDATA yehat_desc =
 		0, 0, /* RestartRate */
 		0, /* BlockMask */
 	},
-	{
+	{ /* AlienTalkDesc */
 		1, /* StartIndex */
 		3, /* NumFrames */
 		0, /* AnimFlags */
@@ -367,7 +367,7 @@ YehatHome (RESPONSE_REF R)
 		Response (give_info, YehatHome);
 	if (!GET_GAME_STATE (NO_YEHAT_ALLY_HOME))
 	{
-		UNICODE buf[80];
+		UNICODE buf[ALLIANCE_NAME_BUFSIZE];
 
 		GetAllianceName (buf, name_1);
 		construct_response (
@@ -437,7 +437,7 @@ YehatSpace (RESPONSE_REF R)
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
 		SET_GAME_STATE (NO_YEHAT_ALLY_SPACE, 2);
 
-		goto ExitYehat;
+		return;
 	}
 	else if (PLAYER_SAID (R, at_least_help_us_space))
 	{
@@ -494,7 +494,7 @@ YehatSpace (RESPONSE_REF R)
 	{
 		case 0:
 		{
-			UNICODE buf[80];
+			UNICODE buf[ALLIANCE_NAME_BUFSIZE];
 
 			GetAllianceName (buf, name_1);
 			construct_response (
@@ -550,8 +550,6 @@ YehatSpace (RESPONSE_REF R)
 		}
 	}
 	Response (bye_space, ExitConversation);
-ExitYehat:
-	;
 }
 
 static void
@@ -564,7 +562,7 @@ Intro (void)
 		NPCPhrase (OUT_TAKES);
 
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	if (GET_GAME_STATE (YEHAT_CIVIL_WAR))
@@ -642,8 +640,6 @@ Intro (void)
 
 		YehatSpace ((RESPONSE_REF)0);
 	}
-ExitIntro:
-	;
 }
 
 static COUNT
