@@ -50,7 +50,7 @@ static LOCDATA zoqfot_desc =
 	0, /* AlienTextFColor */
 	0, /* AlienTextBColor */
 	0, /* SIS_SCREEN_WIDTH, */ /* AlienTextWidth */
-	0, /* AlienColorMap */
+	(COLORMAP)ZOQFOTPIK_COLOR_MAP, /* AlienColorMap */
 	ZOQFOTPIK_MUSIC, /* AlienSong */
 	0, /* AlienAltSong */
 	0, /* AlienSongFlags */
@@ -403,7 +403,7 @@ AquaintZoqFot (RESPONSE_REF R)
 
 	if (PHRASE_ENABLED (we_are_vindicator0))
 	{
-		UNICODE buf[80];
+		UNICODE buf[ALLIANCE_NAME_BUFSIZE];
 
 		GetAllianceName (buf, name_1);
 		construct_response (
@@ -763,7 +763,7 @@ Intro (void)
 		NPCPhrase_cb (OUT_TAKES13, &SelectAlienPIK);
 		ZFPTalkSegue ((COUNT)~0);
 		SET_GAME_STATE (BATTLE_SEGUE, 0);
-		goto ExitIntro;
+		return;
 	}
 
 	if (GET_GAME_STATE (ZOQFOT_HOSTILE))
@@ -918,8 +918,6 @@ Intro (void)
 
 		ZoqFotHome (0);
 	}
-ExitIntro:
-	;
 }
 
 static COUNT
