@@ -23,6 +23,7 @@
 #include "settings.h"
 #include "setup.h"
 #include "sounds.h"
+#include "gamestr.h"
 #include "libs/graphics/widgets.h"
 #include "libs/inplib.h"
 #include "libs/sound/trackplayer.h"
@@ -39,7 +40,7 @@ DrawConfirmationWindow (BOOLEAN answer)
 	COLOR oldfg = SetContextForeGroundColor (MENU_TEXT_COLOR);
 	COLOR dark, medium;
 	FONT  oldfont = SetContextFont (StarConFont);
-	FONTEFFECT oldFontEffect = SetContextFontEffect (0, 0, 0);
+	FRAME oldFontEffect = SetContextFontEffect (NULL);
 	RECT r;
 	TEXT t;
 
@@ -55,24 +56,24 @@ DrawConfirmationWindow (BOOLEAN answer)
 
 	t.baseline.x = r.corner.x + (r.extent.width >> 1);
 	t.baseline.y = r.corner.y + 8;
-	t.pStr = "Really Quit?";
+	t.pStr = GAME_STRING (QUITMENU_STRING_BASE); // "Really Quit?"
 	t.align = ALIGN_CENTER;
 	t.valign = VALIGN_BOTTOM;
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += 10;
 	t.baseline.x = r.corner.x + (r.extent.width >> 2);
-	t.pStr = "Yes";
+	t.pStr = GAME_STRING (QUITMENU_STRING_BASE + 1); // "Yes"
 	SetContextForeGroundColor (answer ? MENU_HIGHLIGHT_COLOR : MENU_TEXT_COLOR);
 	font_DrawText (&t);
 	t.baseline.x += (r.extent.width >> 1);
-	t.pStr = "No";
+	t.pStr = GAME_STRING (QUITMENU_STRING_BASE + 2); // "No"
 	SetContextForeGroundColor (answer ? MENU_TEXT_COLOR : MENU_HIGHLIGHT_COLOR);	
 	font_DrawText (&t);
 
 	UnbatchGraphics ();
 
-	SetContextFontEffect (oldFontEffect.type, oldFontEffect.from, oldFontEffect.to);
+	SetContextFontEffect (oldFontEffect);
 	SetContextFont (oldfont);
 	SetContextForeGroundColor (oldfg);
 }
@@ -87,7 +88,8 @@ DoConfirmExit (void)
 	static BOOLEAN in_confirm = FALSE;
 	fprintf (stderr, "Confirming Exit!\n");
 	if (LOBYTE (GLOBAL (CurrentActivity)) != SUPER_MELEE &&
-			LOBYTE (GLOBAL (CurrentActivity)) != WON_LAST_BATTLE)
+			LOBYTE (GLOBAL (CurrentActivity)) != WON_LAST_BATTLE &&
+			!(LastActivity & CHECK_RESTART))
 		SuspendGameClock ();
 	if (CommData.ConversationPhrases && PlayingTrack ())
 		PauseTrack ();
@@ -180,7 +182,8 @@ DoConfirmExit (void)
 	UnlockMutex (GraphicsLock);
 
 	if (LOBYTE (GLOBAL (CurrentActivity)) != SUPER_MELEE &&
-			LOBYTE (GLOBAL (CurrentActivity)) != WON_LAST_BATTLE)
+			LOBYTE (GLOBAL (CurrentActivity)) != WON_LAST_BATTLE &&
+			!(LastActivity & CHECK_RESTART))
 		ResumeGameClock ();
 	if (CommData.ConversationPhrases && PlayingTrack ())
 	{
