@@ -20,6 +20,7 @@
 #define _CONTROLS_H_
 
 #include "libs/compiler.h"
+#include "libs/strlib.h"
 
 
 // Enumerated type for controls
@@ -55,9 +56,16 @@ enum {
 	KEY_MENU_SPECIAL,
 	KEY_MENU_PAGE_UP,
 	KEY_MENU_PAGE_DOWN,
+	KEY_MENU_HOME,
+	KEY_MENU_END,
 	KEY_MENU_ZOOM_IN,
 	KEY_MENU_ZOOM_OUT,
 	KEY_MENU_DELETE,
+	KEY_MENU_BACKSPACE,
+	KEY_MENU_EDIT_CANCEL,
+	KEY_MENU_SEARCH,
+	KEY_MENU_NEXT,
+	KEY_CHARACTER, /* abstract char key */
 	NUM_KEYS
 };
 
@@ -91,6 +99,7 @@ BOOLEAN PauseGame (void);
 BOOLEAN DoConfirmExit (void);
 void TFB_Abort (void);
 BOOLEAN WaitAnyButtonOrQuit (BOOLEAN CheckSpecial);
+extern void WaitForNoInput (SIZE Duration);
 extern BOOLEAN ConfirmExit (void);
 extern void DoInput (PVOID pInputState, BOOLEAN resetInput);
 
@@ -99,6 +108,44 @@ BATTLE_INPUT_STATE p2_combat_summary (void);
 
 extern volatile BOOLEAN GamePaused, ExitRequested;
 
+typedef struct joy_char joy_char_t;
+
+typedef struct textentry_state
+{
+	// standard state required by DoInput
+	BOOLEAN (*InputFunc) (struct textentry_state *pTES);
+	COUNT MenuRepeatDelay;
+
+	// these are semi-private read-only
+	BOOLEAN Initialized;
+	BOOLEAN Success;   // edit confirmed or canceled
+	UNICODE *CacheStr; // cached copy to revert immediate changes
+	STRING JoyAlphaString; // joystick alphabet definition
+	BOOLEAN JoystickMode;  // TRUE when doing joystick input
+	BOOLEAN UpperRegister; // TRUE when entering Caps
+	joy_char_t *JoyAlpha;  // joystick alphabet
+	int JoyAlphaLength;
+	joy_char_t *JoyUpper;  // joystick upper register
+	joy_char_t *JoyLower;  // joystick lower register
+	int JoyRegLength;
+	UNICODE *InsPt;        // set to current pos of insertion point
+	// these are public and must be set before calling DoTextEntry
+	UNICODE *BaseStr;  // set to string to edit
+	int CursorPos;     // set to current cursor pos in chars
+	int MaxSize;       // set to max size of edited string
+
+	BOOLEAN (*ChangeCallback) (struct textentry_state *pTES);
+			// returns TRUE if last change is OK
+	BOOLEAN (*FrameCallback) (struct textentry_state *pTES);
+			// called on every input frame; do whatever;
+			// returns TRUE to continue processing
+	void *CbParam;     // callback parameter, use as you like
+	
+} TEXTENTRY_STATE;
+typedef TEXTENTRY_STATE *PTEXTENTRY_STATE;
+
+BOOLEAN DoTextEntry (PTEXTENTRY_STATE pTES);
+
 #endif
 
 
