@@ -21,6 +21,7 @@
 
 
 extern void Logo (void);
+extern void SplashScreen (void (* DoProcessing)(DWORD TimeOut));
 extern void Introduction (void);
 extern void Victory (void);
 
@@ -29,7 +30,7 @@ extern void DoShipSpin (COUNT index, MUSIC_REF hMusic);
 
 extern BOOLEAN DoFMV (const char *name, const char *loopname,
 		BOOLEAN uninit);
-extern BOOLEAN ShowPresentation (const char *name);
+extern BOOLEAN ShowPresentation (STRING PresStr);
 
 
 #endif  /* _FMV_H */
