@@ -23,11 +23,13 @@
 #include "commglue.h"
 #include "controls.h"
 #include "encount.h"
+#include "planets/lander.h"
 #include "gamestr.h"
 #include "inplib.h"
 #include "load.h"
 #include "options.h"
 #include "save.h"
+#include "starbase.h"
 #include "settings.h"
 #include "setup.h"
 #include "sounds.h"
@@ -41,7 +43,6 @@
 #define MAX_SAVED_GAMES 50
 #define SUMMARY_X_OFFS 14
 #define SUMMARY_SIDE_OFFS 7
-#define MAX_NAME_CHARS 15
 #define SAVES_PER_PAGE 5
 
 static BOOLEAN DoSettings (PMENU_STATE pMS);
@@ -130,48 +131,56 @@ enum
 static void
 FeedbackSetting (BYTE which_setting)
 {
-	UNICODE buf[20];
-	char tmpstr[3];
+	UNICODE buf[128];
+	const char *tmpstr;
 
 	buf[0] = '\0';
+	// pre-terminate buffer in case snprintf() overflows
+	buf[sizeof (buf) - 1] = '\0';
+
 	switch (which_setting)
 	{
 		case SOUND_ON_SETTING:
 		case SOUND_OFF_SETTING:
-			wsprintf (buf, "%s %s",
+			snprintf (buf, sizeof (buf) - 1, "%s %s",
 					GAME_STRING (OPTION_STRING_BASE + 0),
 					GLOBAL (glob_flags) & SOUND_DISABLED
-					? GAME_STRING (OPTION_STRING_BASE + 3) : GAME_STRING (OPTION_STRING_BASE + 4));
+					? GAME_STRING (OPTION_STRING_BASE + 3) :
+					GAME_STRING (OPTION_STRING_BASE + 4));
 			break;
 		case MUSIC_ON_SETTING:
 		case MUSIC_OFF_SETTING:
-			wsprintf (buf, "%s %s",
+			snprintf (buf, sizeof (buf) - 1, "%s %s",
 					GAME_STRING (OPTION_STRING_BASE + 1),
 					GLOBAL (glob_flags) & MUSIC_DISABLED
-					? GAME_STRING (OPTION_STRING_BASE + 3) : GAME_STRING (OPTION_STRING_BASE + 4));
+					? GAME_STRING (OPTION_STRING_BASE + 3) :
+					GAME_STRING (OPTION_STRING_BASE + 4));
 			break;
 		case CYBORG_OFF_SETTING:
 		case CYBORG_NORMAL_SETTING:
 		case CYBORG_DOUBLE_SETTING:
 		case CYBORG_SUPER_SETTING:
-			if (optWhichMenu == OPT_PC && which_setting > CYBORG_NORMAL_SETTING)
+			if (optWhichMenu == OPT_PC &&
+					which_setting > CYBORG_NORMAL_SETTING)
 			{
 				if (which_setting == CYBORG_DOUBLE_SETTING)
-					strcpy (tmpstr, "+");
+					tmpstr = "+";
 				else
-					strcpy (tmpstr, "++");
+					tmpstr = "++";
 			}
 			else
-				tmpstr[0] = 0;
-			wsprintf (buf, "%s %s%s",
+				tmpstr = "";
+			snprintf (buf, sizeof (buf) - 1, "%s %s%s",
 					GAME_STRING (OPTION_STRING_BASE + 2),
 					!(GLOBAL (glob_flags) & CYBORG_ENABLED)
-					? GAME_STRING (OPTION_STRING_BASE + 3) : GAME_STRING (OPTION_STRING_BASE + 4),
+					? GAME_STRING (OPTION_STRING_BASE + 3) :
+					GAME_STRING (OPTION_STRING_BASE + 4),
 					tmpstr);
 			break;
 		case CHANGE_CAPTAIN_SETTING:
 		case CHANGE_SHIP_SETTING:
-			wstrcpy (buf, GAME_STRING (NAMING_STRING_BASE + 0));
+			utf8StringCopy (buf, sizeof (buf),
+					GAME_STRING (NAMING_STRING_BASE + 0));
 			break;
 	}
 
@@ -183,15 +192,15 @@ FeedbackSetting (BYTE which_setting)
 static void
 FeedbackQuit (BYTE which_setting)
 {
-	UNICODE buf[20];
-	buf[0] = '\0';
+	const UNICODE *buf = "";
+
 	switch (which_setting)
 	{
 		case NO_QUIT_MENU:
-			wsprintf (buf, "Don't Quit");
+			buf = GAME_STRING (QUITMENU_STRING_BASE + 3); // "Don't Quit"
 			break;
 		case YES_QUIT_MENU:
-			wsprintf (buf, "Quit Game");
+			buf = GAME_STRING (QUITMENU_STRING_BASE + 4); // "Quit Game"
 			break;
 	}
 
@@ -200,8 +209,12 @@ FeedbackQuit (BYTE which_setting)
 	UnlockMutex (GraphicsLock);
 }
 
+#define DDSHS_NORMAL   0
+#define DDSHS_EDIT     1
+#define DDSHS_BLOCKCUR 2
+
 static BOOLEAN
-DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
+DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, COUNT state)
 {
 	COUNT rel_index;
 	RECT r;
@@ -219,7 +232,7 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 		r.extent.height = SHIP_NAME_HEIGHT;
 
 		SetContext (StatusContext);
-		if (pMS->delta_item == CHANGE_CAPTAIN_SETTING)
+		if (pMS->CurState == CHANGE_CAPTAIN_SETTING)
 		{
 			Font = TinyFont;
 			r.corner.y = 10;
@@ -245,14 +258,18 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 	}
 
 	SetContextFont (Font);
+	// XXX: nasty hack; CurString may not be large enough to
+	//   contain a pointer on some platforms
 	lf.pStr = ((GAME_DESC *)pMS->CurString)[rel_index];
 	lf.CharCount = (COUNT)~0;
 
-	if (state <= 0)
-	{
+	if (!(state & DDSHS_EDIT))
+	{	// normal state
+		SetFlashRect ((PRECT)~0L, (FRAME)0);
+
 		if (pMS->InputFunc == DoNaming)
 		{
-			if (pMS->delta_item == CHANGE_CAPTAIN_SETTING)
+			if (pMS->CurState == CHANGE_CAPTAIN_SETTING)
 				DrawCaptainsName ();
 			else
 			{
@@ -262,7 +279,9 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 			}
 		}
 		else
-		{
+		{	// XXX: remnants of DOS? this function is never actually
+			//   called outside DoNaming nowadays, which makes this
+			//   code utterly dead
 			if (state == 0)
 			{
 				COLOR OldColor;
@@ -273,11 +292,9 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 			}
 			font_DrawText (&lf);
 		}
-		SetFlashRect (&r, (FRAME)0);
-		SetFlashRect ((PRECT)~0L, (FRAME)0);
 	}
 	else
-	{
+	{	// editing state
 		COUNT i;
 		RECT text_r;
 		BYTE char_deltas[MAX_DESC_CHARS];
@@ -285,8 +302,10 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 
 		TextRect (&lf, &text_r, char_deltas);
 		if ((text_r.extent.width + 2) >= r.extent.width)
-		{
+		{	// the text does not fit the input box size and so
+			// will not fit when displayed later
 			UnlockMutex (GraphicsLock);
+			// disallow the change
 			return (FALSE);
 		}
 
@@ -298,17 +317,27 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 			text_r.corner.x += (SIZE)*pchar_deltas++;
 		if ((COUNT)pMS->first_item.x < lf.CharCount) /* end of line */
 			--text_r.corner.x;
-		text_r.extent.width = 1;
-#if 0
-		/* This is code that's a remnant of non-keyboard systems */
-		else
-		{
-			if ((COUNT)pMS->first_item.x == lf.CharCount) /* end of line */
+		
+		if (state & DDSHS_BLOCKCUR)
+		{	// Use block cursor for keyboardless systems
+			if ((COUNT)pMS->first_item.x == lf.CharCount)
+			{	// cursor at end-line -- use insertion point
 				text_r.extent.width = 1;
+			}
+			else if ((COUNT)pMS->first_item.x + 1 == lf.CharCount)
+			{	// extra pixel for last char margin
+				text_r.extent.width = (SIZE)*pchar_deltas + 2;
+			}
 			else
-				text_r.extent.width = (SIZE)*pchar_deltas;
+			{	// normal mid-line char
+				text_r.extent.width = (SIZE)*pchar_deltas + 1;
+			}
 		}
-#endif
+		else
+		{	// Insertion point cursor
+			text_r.extent.width = 1;
+		}
+		
 		text_r.corner.y = r.corner.y;
 		text_r.extent.height = r.extent.height;
 		SetContextForeGroundColor (BLACK_COLOR);
@@ -324,184 +353,79 @@ DrawDescriptionString (PMENU_STATE pMS, COUNT which_string, SIZE state)
 	return (TRUE);
 }
 
-static UWORD
-DoTextEntry (PMENU_STATE pMS)
+static BOOLEAN
+OnNameChange (PTEXTENTRY_STATE pTES)
 {
-	UWORD ch;
-	UNICODE *pStr, *pBaseStr;
-	COUNT len;
-	BOOLEAN left = FALSE, right = FALSE;
+	PMENU_STATE pMS = (PMENU_STATE) pTES->CbParam;
+	COUNT hl = DDSHS_EDIT;
 
-	pBaseStr = ((GAME_DESC *)pMS->CurString)[pMS->CurState - pMS->first_item.y];
-	pStr = &pBaseStr[pMS->first_item.x];
-	len = wstrlen (pStr);
+	pMS->first_item.x = pTES->CursorPos;
+	if (pTES->JoystickMode)
+		hl |= DDSHS_BLOCKCUR;
 
-	ch = GetCharacter ();
-
-#if 0
-	/* This code goes away, but is listed here anyway just in case someone decides
-	   to port this to a keyboardless platform later */
-	   
-	if (SerialInput)
-	{
-		ch = GetInputUNICODE (GetInputState (SerialInput));
-	}
-	else
-	{
-		extern UWORD GetJoystickChar (INPUT_STATE InputState);
-
-		ch = GetJoystickChar ();
-	}
-#endif
-
-	switch (ch)
-	{
-	case SK_DELETE:
-		if (len)
-		{
-			memmove (pStr, pStr + 1, len * sizeof (*pStr));
-			len = (COUNT)~0;
-		}
-		break;
-	case '\b':
-		if (pMS->first_item.x)
-		{
-			memmove (pStr - 1, pStr, (len + 1) * sizeof (*pStr));
-			--pMS->first_item.x;
-			
-			len = (COUNT)~0;
-		}
-		break;
-	case SK_LF_ARROW:
-		left = TRUE;
-		break;
-	case SK_RT_ARROW:
-		right = TRUE;
-		break;
-	default:
-		if (isprint (ch) && (len + (pStr - pBaseStr) < MAX_NAME_CHARS))
-		{
-			memmove (pStr + 1, pStr, (len + 1) * sizeof (*pStr));
-			if (len == 0)
-				*(pStr + 1) = '\0';
-			*pStr++ = ch;
-			++pMS->first_item.x;
-#if 0
-			/* Joystick letter-entry mode */
-				*pStr = ch;
-				if (len == 0)
-					*(pStr + 1) = '\0';
-#endif			
-			len = (COUNT)~0;
-		}
-		break;
-	}
-
-	if (len == (COUNT)~0)
-	{
-		if (!DrawDescriptionString (pMS, pMS->CurState, 1))
-		{
-			len = wstrlen (pStr);
-			memmove (pStr - 1, pStr, (len + 1) * sizeof (*pStr));
-			--pMS->first_item.x;
-		}
-	}
-	else if (left)
-	{
-		if (pMS->first_item.x)
-		{
-			--pMS->first_item.x;
-			DrawDescriptionString (pMS, pMS->CurState, 1);
-		}
-	}
-	else if (right)
-	{
-		if (len)
-		{
-			++pMS->first_item.x;
-			DrawDescriptionString (pMS, pMS->CurState, 1);
-		}
-	}
-
-	return (ch);
+	return DrawDescriptionString (pMS, 0, hl);
 }
 
 static BOOLEAN
 DoNaming (PMENU_STATE pMS)
 {
-	if (GLOBAL (CurrentActivity) & CHECK_ABORT)
-		return (FALSE);
-	
-	if (!pMS->Initialized)
+	GAME_DESC buf;
+	TEXTENTRY_STATE tes;
+	UNICODE *Setting;
+
+	pMS->Initialized = TRUE;
+	pMS->InputFunc = DoNaming;
+
+	buf[0] = '\0';
+	// XXX: this code abuses MENU_STATE struct members to store
+	//  some values:
+	//   first_item.x - current cursor position
+	//   first_item.y - must be set to 0; DrawDescriptionString()
+	//     treats it as base index into array of strings
+	//     supplied in CurString
+	pMS->first_item.x = 0;
+	pMS->first_item.y = 0;
+	// XXX: nasty hack; CurString may not be large enough to
+	//   contain a pointer on some platforms
+	pMS->CurString = (STRING)buf;
+	DrawDescriptionString (pMS, 0, DDSHS_EDIT);
+
+	LockMutex (GraphicsLock);
+	DrawStatusMessage (GAME_STRING (NAMING_STRING_BASE + 0));
+	UnlockMutex (GraphicsLock);
+
+	if (pMS->CurState == CHANGE_CAPTAIN_SETTING)
 	{
-		GAME_DESC GD[1];
-
-		pMS->Initialized = 1;
-		pMS->InputFunc = DoNaming;
-
-		GD[0][0] = '\0';
-		pMS->delta_item = pMS->CurState;
-		pMS->first_item.x = pMS->first_item.y = 0;
-		pMS->CurState = 0;
-		pMS->CurString = (STRING)&GD[0];
-		DrawDescriptionString (pMS, pMS->CurState, 1);
-
-		LockMutex (GraphicsLock);
-		DrawStatusMessage (GAME_STRING (NAMING_STRING_BASE + 0));
-		UnlockMutex (GraphicsLock);
-
-		EnableCharacterMode ();
-		DoInput (pMS, TRUE);
-		DisableCharacterMode ();
-
-		SetMenuSounds (MENU_SOUND_ARROWS, MENU_SOUND_SELECT);
-
-		pMS->InputFunc = DoSettings;
-		pMS->CurState = (BYTE)pMS->delta_item;
-		pMS->delta_item = 0;
-		if (!(GLOBAL (CurrentActivity) & CHECK_ABORT))
-			FeedbackSetting (pMS->CurState);
+		Setting = GLOBAL_SIS (CommanderName);
+		tes.MaxSize = sizeof (GLOBAL_SIS (CommanderName));
 	}
 	else
 	{
-		UWORD ch;
-
-		if (pMS->Initialized == 1)
-		{
-			FlushInput ();
-			pMS->Initialized = 2;
-			return (TRUE);
-		}
-
-		ch = DoTextEntry (pMS);
-
-		if (ch == '\n' || ch == '\r' || ch == 0x1B)
-		{
-			if (ch == '\n' || ch == '\r')
-			{
-				if (pMS->delta_item == CHANGE_CAPTAIN_SETTING)
-					wstrcpy (GLOBAL_SIS (CommanderName),
-							(const UNICODE *)((GAME_DESC *)pMS->CurString)[0]);
-				else
-					wstrcpy (GLOBAL_SIS (ShipName),
-							(const UNICODE *)((GAME_DESC *)pMS->CurString)[0]);
-			}
-			else
-			{
-				if (pMS->delta_item == CHANGE_CAPTAIN_SETTING)
-					wstrcpy ((UNICODE *)((GAME_DESC *)pMS->CurString)[0],
-							GLOBAL_SIS (CommanderName));
-				else
-					wstrcpy ((UNICODE *)((GAME_DESC *)pMS->CurString)[0],
-							GLOBAL_SIS (ShipName));
-			}
-
-			DrawDescriptionString (pMS, pMS->CurState, 0);
-
-			return (FALSE);
-		}
+		Setting = GLOBAL_SIS (ShipName);
+		tes.MaxSize = sizeof (GLOBAL_SIS (ShipName));
 	}
 
+	// text entry setup
+	tes.Initialized = FALSE;
+	tes.MenuRepeatDelay = 0;
+	tes.BaseStr = buf;
+	tes.CursorPos = 0;
+	tes.CbParam = pMS;
+	tes.ChangeCallback = OnNameChange;
+	tes.FrameCallback = 0;
+
+	if (DoTextEntry (&tes))
+		utf8StringCopy (Setting, tes.MaxSize, buf);
+	else
+		utf8StringCopy (buf, sizeof (buf), Setting);
+	DrawDescriptionString (pMS, 0, DDSHS_NORMAL);
+
+	SetMenuSounds (MENU_SOUND_ARROWS, MENU_SOUND_SELECT);
+
+	pMS->InputFunc = DoSettings;
+	if (!(GLOBAL (CurrentActivity) & CHECK_ABORT))
+		FeedbackSetting (pMS->CurState);
+
 	return (TRUE);
 }
 
@@ -629,7 +553,6 @@ DrawCargo (COUNT redraw_state)
 {
 	BYTE i;
 	RECT r;
-	extern FRAME misc_data;
 
 	SetContext (SpaceContext);
 	if (redraw_state)
@@ -679,7 +602,7 @@ DrawCargo (COUNT redraw_state)
 		}
 
 		s.frame = SetAbsFrameIndex (
-				misc_data,
+				MiscDataFrame,
 				(NUM_SCANDOT_TRANSITIONS << 1) + 3
 				);
 		if (redraw_state == 2
@@ -709,7 +632,7 @@ DrawCargo (COUNT redraw_state)
 	else
 	{
 		TEXT t;
-		UNICODE buf[10];
+		UNICODE buf[40];
 		COLOR cargo_color[] =
 		{
 			BUILD_COLOR (MAKE_RGB15 (2, 14, 19), 0x00),
@@ -742,7 +665,7 @@ DrawCargo (COUNT redraw_state)
 			r.corner.y = t.baseline.y - r.extent.height + 1;
 			DrawFilledRectangle (&r);
 			SetContextForeGroundColor (cargo_color[i]);
-			wsprintf (buf, "%u", GLOBAL_SIS (ElementAmounts[i]));
+			sprintf (buf, "%u", GLOBAL_SIS (ElementAmounts[i]));
 			t.CharCount = (COUNT)~0;
 			font_DrawText (&t);
 			t.baseline.y += 12;
@@ -754,7 +677,7 @@ DrawCargo (COUNT redraw_state)
 		r.corner.y = t.baseline.y - r.extent.height + 1;
 		DrawFilledRectangle (&r);
 		SetContextForeGroundColor (cargo_color[i]);
-		wsprintf (buf, "%u", GLOBAL_SIS (TotalBioMass));
+		sprintf (buf, "%u", GLOBAL_SIS (TotalBioMass));
 		t.CharCount = (COUNT)~0;
 		font_DrawText (&t);
 	}
@@ -789,7 +712,7 @@ ShowSummary (SUMMARY_DESC *pSD)
 		QUEUE player_q;
 		CONTEXT OldContext;
 		SIS_STATE SaveSS;
-		UNICODE buf[80];
+		UNICODE buf[256];
 
 		SaveSS = GlobData.SIS_state;
 		player_q = GLOBAL (built_ship_q);
@@ -810,7 +733,8 @@ ShowSummary (SUMMARY_DESC *pSD)
 				MAX_BUILT_SHIPS, sizeof (SHIP_FRAGMENT));
 		for (i = 0; i < pSD->NumShips; ++i)
 			CloneShipFragment (pSD->ShipList[i], &GLOBAL (built_ship_q), 0);
-		DateToString (buf, pSD->month_index, pSD->day_index, pSD->year_index),
+		DateToString (buf, sizeof buf,
+				pSD->month_index, pSD->day_index, pSD->year_index),
 		ClearSISRect (DRAW_SIS_DISPLAY);
 		DrawStatusMessage (buf);
 		UninitQueue (&GLOBAL (built_ship_q));
@@ -836,10 +760,8 @@ ShowSummary (SUMMARY_DESC *pSD)
 				}
 				else
 				{
-					extern FRAME misc_data;
-
 					s.frame = SetAbsFrameIndex (
-							misc_data, 77 + pSD->DeviceList[(i << 2) + j]
+							MiscDataFrame, 77 + pSD->DeviceList[(i << 2) + j]
 							);
 					DrawStamp (&s);
 				}
@@ -879,7 +801,7 @@ ShowSummary (SUMMARY_DESC *pSD)
 			SetContextClipRect (&OldRect);
 			SetContext (SpaceContext);
 
-			wsprintf (buf, "%lu", GLOBAL_SIS (ResUnits));
+			sprintf (buf, "%lu", GLOBAL_SIS (ResUnits));
 			t.baseline.y = 102;
 			r.extent.width = 76;
 			r.extent.height = SHIP_NAME_HEIGHT;
@@ -892,7 +814,7 @@ ShowSummary (SUMMARY_DESC *pSD)
 			t.CharCount = (COUNT)~0;
 		}
 		t.baseline.y = 126;
-		wsprintf (buf, "%u", MAKE_WORD (pSD->MCreditLo, pSD->MCreditHi));
+		sprintf (buf, "%u", MAKE_WORD (pSD->MCreditLo, pSD->MCreditHi));
 		r.extent.width = 30;
 		r.extent.height = SHIP_NAME_HEIGHT;
 		r.corner.x = t.baseline.x - (r.extent.width >> 1);
@@ -939,10 +861,12 @@ ShowSummary (SUMMARY_DESC *pSD)
 				buf[0] = '\0';
 				break;
 			case IN_HYPERSPACE:
-				wstrcpy (buf, GAME_STRING (NAVIGATION_STRING_BASE + 0));
+				utf8StringCopy (buf, sizeof (buf),
+						GAME_STRING (NAVIGATION_STRING_BASE + 0));
 				break;
 			case IN_QUASISPACE:
-				wstrcpy (buf, GAME_STRING (NAVIGATION_STRING_BASE + 1));
+				utf8StringCopy (buf, sizeof (buf),
+						GAME_STRING (NAVIGATION_STRING_BASE + 1));
 				break;
 		}
 
@@ -953,11 +877,12 @@ ShowSummary (SUMMARY_DESC *pSD)
 		t.align = ALIGN_CENTER;
 		t.baseline.x = SIS_SCREEN_WIDTH - 57 - 3 + (SIS_TITLE_WIDTH >> 1);
 		if (pSD->Activity == IN_STARBASE)
-			wstrcpy (buf, GAME_STRING (STARBASE_STRING_BASE));
+			utf8StringCopy (buf, sizeof (buf),
+					GAME_STRING (STARBASE_STRING_BASE));
 		else if (pSD->Activity == IN_PLANET_ORBIT)
-			wstrcpy (buf, GLOBAL_SIS (PlanetName));
+			utf8StringCopy (buf, sizeof (buf), GLOBAL_SIS (PlanetName));
 		else
-			wsprintf (buf, "%03u.%01u : %03u.%01u",
+			sprintf (buf, "%03u.%01u : %03u.%01u",
 					r.corner.x / 10, r.corner.x % 10,
 					r.corner.y / 10, r.corner.y % 10);
 		t.CharCount = (COUNT)~0;
@@ -1146,7 +1071,8 @@ Restart:
 			RECT r;
 			TEXT t;
 			BYTE i, SHIFT;
-			UNICODE buf[80],buf2[15];
+			UNICODE buf[256];
+			UNICODE buf2[80];
 			LockMutex (GraphicsLock);
 
 			BatchGraphics ();
@@ -1210,9 +1136,9 @@ ChangeGameSelection:
 
 				t.baseline.x = r.corner.x + 3;
 				t.baseline.y = r.corner.y + 8;
-				wsprintf (buf, "%02i", NewState - SHIFT + i);
+				sprintf (buf, "%02i", NewState - SHIFT + i);
 				if (MAX_SAVED_GAMES > 99)
-					wsprintf (buf, "%03i", NewState - SHIFT + i);
+					sprintf (buf, "%03i", NewState - SHIFT + i);
 				font_DrawText (&t);
 
 				r.extent.width = 204 - SAFE_X;
@@ -1221,14 +1147,14 @@ ChangeGameSelection:
 
 				t.baseline.x = r.corner.x + 3;
 				if (((SUMMARY_DESC *)pMS->CurString)[NewState - SHIFT + i].year_index == 0)
-					wsprintf (buf, "Empty Slot");
+					sprintf (buf, GAME_STRING (SAVEGAME_STRING_BASE + 3)); // "Empty Slot"
 				else
 				{
-					DateToString (buf2,
+					DateToString (buf2, sizeof buf2,
 							((SUMMARY_DESC *)pMS->CurString)[NewState - SHIFT + i].month_index,
 							((SUMMARY_DESC *)pMS->CurString)[NewState - SHIFT + i].day_index,
 							((SUMMARY_DESC *)pMS->CurString)[NewState - SHIFT + i].year_index);
-					wsprintf (buf, "Saved Game - Date: %s",buf2);
+					sprintf (buf, "%s %s", GAME_STRING (SAVEGAME_STRING_BASE + 4), buf2); // "Saved Game - Date:"
 				}
 				font_DrawText (&t);
 			}
@@ -1340,14 +1266,10 @@ PickGame (PMENU_STATE pMS)
 			{
 				if (pSolarSysState->MenuState.Initialized < 3)
 				{
-					extern MUSIC_REF SpaceMusic;
-						
 					PlayMusic (SpaceMusic, TRUE, 1);
 				}
 				else
 				{
-					extern MUSIC_REF LanderMusic;
-						
 					PlayMusic (LanderMusic, TRUE, 1);
 				}
 			}
