@@ -40,7 +40,6 @@ FRAME PlayFrame;
 
 GLOBDATA GlobData;
 
-extern FRAME flagship_status, misc_data;
 BOOLEAN initedSIS = 0;
 
 
@@ -102,22 +101,25 @@ CreateRadar (void)
 BOOLEAN
 LoadSC2Data (void)
 {
-	if (flagship_status == 0)
+	if (FlagStatFrame == 0)
 	{
 		MEM_HANDLE hOldIndex;
 
 		hOldIndex = SetResourceIndex (hResIndex);
 
-		flagship_status = CaptureDrawable (
+		FlagStatFrame = CaptureDrawable (
 				LoadGraphic (FLAGSTAT_MASK_PMAP_ANIM));
-		if (flagship_status == NULL)
+		if (FlagStatFrame == NULL)
 			return FALSE;
 
-		misc_data = CaptureDrawable (
+		MiscDataFrame = CaptureDrawable (
 				LoadGraphic (MISCDATA_MASK_PMAP_ANIM));
-		if (misc_data == NULL)
+		if (MiscDataFrame == NULL)
 			return FALSE;
 
+		FontGradFrame = CaptureDrawable (
+				LoadGraphic (FONTGRAD_PMAP_ANIM));
+
 		SetResourceIndex (hOldIndex);
 	}
 
@@ -282,8 +284,11 @@ InitSIS (void)
 
 	GLOBAL_SIS (NumLanders) = 1;
 
-	wstrcpy (GLOBAL_SIS (ShipName), GAME_STRING (NAMING_STRING_BASE + 2));
-	wstrcpy (GLOBAL_SIS (CommanderName), GAME_STRING (NAMING_STRING_BASE + 3));
+	utf8StringCopy (GLOBAL_SIS (ShipName), sizeof (GLOBAL_SIS (ShipName)),
+			GAME_STRING (NAMING_STRING_BASE + 2));
+	utf8StringCopy (GLOBAL_SIS (CommanderName),
+			sizeof (GLOBAL_SIS (CommanderName)),
+			GAME_STRING (NAMING_STRING_BASE + 3));
 
 	ActivateStarShip (HUMAN_SHIP, 0);
 	CloneShipFragment (HUMAN_SHIP, &GLOBAL (built_ship_q), 0);
@@ -312,10 +317,12 @@ FreeSC2Data (void)
 {
 	DestroyContext (ReleaseContext (RadarContext));
 	RadarContext = 0;
-	DestroyDrawable (ReleaseDrawable (misc_data));
-	misc_data = 0;
-	DestroyDrawable (ReleaseDrawable (flagship_status));
-	flagship_status = 0;
+	DestroyDrawable (ReleaseDrawable (FontGradFrame));
+	FontGradFrame = 0;
+	DestroyDrawable (ReleaseDrawable (MiscDataFrame));
+	MiscDataFrame = 0;
+	DestroyDrawable (ReleaseDrawable (FlagStatFrame));
+	FlagStatFrame = 0;
 }
 
 void
