@@ -130,7 +130,7 @@ typedef struct
 	COUNT AlienTextWidth;
 	COLORMAP AlienColorMap;
 	DWORD AlienSong;
-	PVOID AlienAltSong;
+	DWORD AlienAltSong;
 	LDAS_FLAGS AlienSongFlags;
 
 	STRING ConversationPhrases;
@@ -441,6 +441,9 @@ START_GAME_STATE
 	ADD_GAME_STATE (MYCON_HOME_VISITS, 3)
 	ADD_GAME_STATE (MYCON_AMBUSH, 1)
 	ADD_GAME_STATE (MYCON_FELL_FOR_AMBUSH, 1)
+			/* Set to 1 when the Mycon have been told about Organon
+			 * and are moving towards it.
+			 */
 
 	ADD_GAME_STATE (GLOBAL_FLAGS_AND_DATA, 8)
 			/* This state seems to be used to distinguish between different
@@ -472,10 +475,10 @@ START_GAME_STATE
 	ADD_GAME_STATE (BOMB_VISITS, 3)
 	ADD_GAME_STATE (ULTRON_CONDITION, 3)
 			/* 0 if the Supox still have the Ultron
-			 * 1 if the player has the Ultron, completely broken
-			 * 2 if the player has the Ultron, with 1 fix
-			 * 3 if the player has the Ultron, with 2 fixes
-			 * 4 if the player has the Ultron, completely restored
+			 * 1 if the Captain has the Ultron, completely broken
+			 * 2 if the Captain has the Ultron, with 1 fix
+			 * 3 if the Captain has the Ultron, with 2 fixes
+			 * 4 if the Captain has the Ultron, completely restored
 			 * 5 if the Ultron has been returned to the Utwig
 			 */
 	ADD_GAME_STATE (UTWIG_HAVE_ULTRON, 1)
@@ -486,7 +489,9 @@ START_GAME_STATE
 	ADD_GAME_STATE (TALKING_PET_VISITS, 3)
 	ADD_GAME_STATE (TALKING_PET_HOME_VISITS, 3)
 	ADD_GAME_STATE (UMGAH_ZOMBIE_BLOBBIES, 1)
+			/* The Umgah have come under the influence of the Talking Pet */
 	ADD_GAME_STATE (KNOW_UMGAH_ZOMBIES, 1)
+			/* The Captain is aware that something is up with the Umgah */
 
 	ADD_GAME_STATE (ARILOU_VISITS, 3)
 	ADD_GAME_STATE (ARILOU_HOME_VISITS, 3)
@@ -679,6 +684,9 @@ START_GAME_STATE
 			 */
 	ADD_GAME_STATE (MYCON_INSULTS, 3)
 	ADD_GAME_STATE (MYCON_KNOW_AMBUSH, 1)
+			/* Set to 1 when the Mycon have been butchered at Organon,
+			 * just before the remaining Mycon head back home.
+			 */
 
 	ADD_GAME_STATE (SYREEN_INFO, 2)
 	ADD_GAME_STATE (KNOW_SYREEN_WORLD_SHATTERED, 1)
