@@ -86,13 +86,6 @@ DoFMV (const char *name, const char *loopname, BOOLEAN uninit)
 	return TRUE;
 }
 
-static void
-CopyTextString (char *Buffer, COUNT BufSize, const char *Src)
-{
-	strncpy (Buffer, Src, BufSize);
-	Buffer[BufSize - 1] = '\0';
-}
-
 static BOOLEAN
 ParseColorString (const char *Src, COLOR* pColor)
 {
@@ -141,13 +134,13 @@ static COUNT
 ParseTextLines (TEXT *Lines, COUNT MaxLines, char* Buffer)
 {
 	COUNT i;
-	const char* pEnd = Buffer + strlen(Buffer);
+	const char* pEnd = Buffer + strlen (Buffer);
 
 	for (i = 0; i < MaxLines && Buffer < pEnd; ++i, ++Lines)
 	{
-		char* pTerm = strchr(Buffer, '\n');
+		char* pTerm = strchr (Buffer, '\n');
 		if (!pTerm)
-			pTerm = Buffer + strlen(Buffer);
+			pTerm = Buffer + strlen (Buffer);
 		*pTerm = '\0'; /* terminate string */
 		Lines->pStr = Buffer;
 		Lines->CharCount = ~0;
@@ -196,25 +189,24 @@ Present_GenerateSIS (PRESENTATION_INPUT_STATE* pPIS)
 	HOT_SPOT hs;
 	int slot;
 	COUNT piece;
+	COLOR SisBack;
 
 	LockMutex (GraphicsLock);
 	OldContext = SetContext (OffScreenContext);
 
-	SkelFrame = CaptureDrawable (LoadCelFile ("slides/ending/sis_skel.ani"));
+	SkelFrame = CaptureDrawable (LoadGraphic (SISSKEL_MASK_PMAP_ANIM));
 	ModuleFrame = CaptureDrawable (LoadGraphic (SISMODS_MASK_PMAP_ANIM));
-	/* TODO: fix this eventually;
-	 * we need to load *all* gfx resources from this package
-	 * otherwise we will leave the package hanging, literally
-	 */
-	DestroyDrawable (LoadGraphic (OUTFIT_PMAP_ANIM));
 
 	GetFrameRect (SkelFrame, &r);
 	SisFrame = CaptureDrawable (CreateDrawable (
 			WANT_PIXMAP, r.extent.width, r.extent.height, 1
 			));
 	SetContextFGFrame (SisFrame);
-	SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (1, 1, 1), 7));
-	DrawFilledRectangle (&r);
+	SetContextClipRect (NULL_PTR);
+	SisBack = BUILD_COLOR (MAKE_RGB15 (1, 1, 1), 7);
+	SetContextBackGroundColor (SisBack);
+	ClearDrawable ();
+	SetFrameTransparentColor (SisFrame, SisBack);
 
 	s.frame = SetAbsFrameIndex (SkelFrame, 0);
 	s.origin.x = 0;
@@ -265,11 +257,6 @@ Present_GenerateSIS (PRESENTATION_INPUT_STATE* pPIS)
 	hs.y = r.extent.height / 2;
 	SetFrameHot (SisFrame, hs);
 
-	/* TODO: this is a hack to get it to work
-	 * anyone know how to do this better? */
-	TFB_DrawCanvas_SetTransparentColor (
-			((PFRAME_DESC)SisFrame)->image->NormalImg, 8, 8, 8, TRUE);
-
 	SetContext (OldContext);
 	FlushGraphics ();
 	UnlockMutex (GraphicsLock);
@@ -277,6 +264,13 @@ Present_GenerateSIS (PRESENTATION_INPUT_STATE* pPIS)
 	pPIS->SisFrame = SisFrame;
 }
 
+BOOLEAN
+ShowPresentationFile (const char *name)
+{
+	return ShowPresentation (CaptureStringTable (
+			LoadStringTableFile (contentDir, name)));
+}
+
 static BOOLEAN
 DoPresentation (PVOID pIS)
 {
@@ -319,10 +313,10 @@ DoPresentation (PVOID pIS)
 			continue;
 		if (1 != sscanf (pStr, "%15s", Opcode))
 			continue;
-		pStr += strlen(Opcode);
+		pStr += strlen (Opcode);
 		if (*pStr != '\0')
 			++pStr;
-		strupr(Opcode);
+		strupr (Opcode);
 
 		if (strcmp (Opcode, "DIMS") == 0)
 		{	/* set dimensions */
@@ -341,7 +335,7 @@ DoPresentation (PVOID pIS)
 		}
 		else if (strcmp (Opcode, "FONT") == 0)
 		{	/* set font */
-			CopyTextString (pPIS->Buffer, sizeof(pPIS->Buffer), pStr);
+			utf8StringCopy (pPIS->Buffer, sizeof (pPIS->Buffer), pStr);
 			if (pPIS->Font)
 				DestroyFont (ReleaseFont (pPIS->Font));
 			pPIS->Font = CaptureFont ((FONT_REF) LoadFontFile (pPIS->Buffer));
@@ -354,14 +348,14 @@ DoPresentation (PVOID pIS)
 		}
 		else if (strcmp (Opcode, "ANI") == 0)
 		{	/* set ani */
-			CopyTextString (pPIS->Buffer, sizeof(pPIS->Buffer), pStr);
+			utf8StringCopy (pPIS->Buffer, sizeof (pPIS->Buffer), pStr);
 			if (pPIS->Frame)
 				DestroyDrawable (ReleaseDrawable (pPIS->Frame));
 			pPIS->Frame = CaptureDrawable (LoadCelFile (pPIS->Buffer));
 		}
 		else if (strcmp (Opcode, "MUSIC") == 0)
 		{	/* set music */
-			CopyTextString (pPIS->Buffer, sizeof(pPIS->Buffer), pStr);
+			utf8StringCopy (pPIS->Buffer, sizeof (pPIS->Buffer), pStr);
 			if (pPIS->MusicRef)
 			{
 				StopMusic ();
@@ -433,7 +427,7 @@ DoPresentation (PVOID pIS)
 			COUNT i;
 			COORD y;
 			
-			CopyTextString (pPIS->Buffer, sizeof(pPIS->Buffer), pStr);
+			utf8StringCopy (pPIS->Buffer, sizeof (pPIS->Buffer), pStr);
 			pPIS->LinesCount = ParseTextLines (pPIS->TextLines,
 					MAX_TEXT_LINES, pPIS->Buffer);
 			
@@ -477,7 +471,7 @@ DoPresentation (PVOID pIS)
 			COUNT i;
 			COORD y;
 			
-			CopyTextString (pPIS->Buffer, sizeof(pPIS->Buffer), pStr);
+			utf8StringCopy (pPIS->Buffer, sizeof (pPIS->Buffer), pStr);
 			pPIS->LinesCount = ParseTextLines (pPIS->TextLines,
 					MAX_TEXT_LINES, pPIS->Buffer);
 			
@@ -673,8 +667,8 @@ DoPresentation (PVOID pIS)
 		{	/* call another script */
 			Present_UnbatchGraphics (pPIS, TRUE);
 
-			CopyTextString (pPIS->Buffer, sizeof(pPIS->Buffer), pStr);
-			ShowPresentation (pPIS->Buffer);
+			utf8StringCopy (pPIS->Buffer, sizeof (pPIS->Buffer), pStr);
+			ShowPresentationFile (pPIS->Buffer);
 		}
 		else if (strcmp (Opcode, "NOOP") == 0)
 		{	/* no operation - must be a comment in script */
@@ -686,16 +680,14 @@ DoPresentation (PVOID pIS)
 }
 
 BOOLEAN
-ShowPresentation (const char *name)
+ShowPresentation (STRING PresStr)
 {
 	CONTEXT OldContext;
 	FONT OldFont;
 	RECT OldRect;
 	PRESENTATION_INPUT_STATE pis;
-	RECT r = {{0, 0}, {SCREEN_WIDTH, SCREEN_HEIGHT}};
 
-	pis.SlideShow = CaptureStringTable (
-			LoadStringTableFile (contentDir, name));
+	pis.SlideShow = PresStr;
 	if (!pis.SlideShow)
 		return FALSE;
 	pis.SlideShow = SetAbsStringTableIndex (pis.SlideShow, 0);
@@ -706,9 +698,9 @@ ShowPresentation (const char *name)
 	GetContextClipRect (&OldRect);
 	OldFont = SetContextFont (NULL);
 	/* paint black rect over screen	*/
-	SetContextForeGroundColor (BUILD_COLOR (
+	SetContextBackGroundColor (BUILD_COLOR (
 			MAKE_RGB15 (0x0, 0x0, 0x0), 0x00));
-	DrawFilledRectangle (&r);
+	ClearDrawable ();
 	UnlockMutex (GraphicsLock);
 
 	FlushInput ();
