@@ -37,6 +37,7 @@ typedef SDWORD          *PSDWORD;
 typedef SBYTE           *PSTR;
 
 typedef void            *PVOID;
+typedef const void     *PCVOID;
 
 typedef UWORD             COUNT;
 typedef COUNT           *PCOUNT;
@@ -44,8 +45,6 @@ typedef SWORD              SIZE;
 typedef SIZE             *PSIZE;
 
 typedef unsigned char   UNICODE;
-#include "strtemp.h"
-		// XXX: this include should be removed in the future.
 
 #define NULL_PTR 0L
 
