@@ -52,6 +52,7 @@ typedef BYTE CREATE_FLAGS;
 #define WANT_MASK (CREATE_FLAGS)(1 << 0)
 #define WANT_PIXMAP (CREATE_FLAGS)(1 << 1)
 #define MAPPED_TO_DISPLAY (CREATE_FLAGS)(1 << 2)
+#define WANT_ALPHA (CREATE_FLAGS)(1 << 3)
 
 typedef struct extent
 {
@@ -161,14 +162,6 @@ extern INTERSECT_CODE BoxIntersect (PRECT pr1, PRECT pr2, PRECT
 		printer);
 extern void BoxUnion (PRECT pr1, PRECT pr2, PRECT punion);
 
-typedef struct
-{
-	BOOLEAN Use;
-	DWORD from;
-	DWORD to;
-	BYTE type;
-} FONTEFFECT;
-
 enum
 {
 	FadeAllToWhite = 250,
@@ -231,13 +224,14 @@ extern DWORD LoadFontFile (PVOID pStr);
 extern DWORD LoadGraphicInstance (DWORD res);
 extern DWORD LoadGraphic (DWORD res);
 extern DRAWABLE LoadDisplayPixmap (PRECT area, FRAME frame);
-extern FONTEFFECT SetContextFontEffect (BYTE type, DWORD from, DWORD to);
+extern FRAME SetContextFontEffect (FRAME EffectFrame);
 extern FONT SetContextFont (FONT Font);
 extern BOOLEAN DestroyFont (FONT_REF FontRef);
 extern FONT CaptureFont (FONT_REF FontRef);
 extern FONT_REF ReleaseFont (FONT Font);
 extern BOOLEAN TextRect (PTEXT pText, PRECT pRect, PBYTE pdelta);
 extern BOOLEAN GetContextFontLeading (PSIZE pheight);
+extern BOOLEAN GetContextFontLeadingWidth (PSIZE pwidth);
 extern COUNT GetFrameCount (FRAME Frame);
 extern COUNT GetFrameIndex (FRAME Frame);
 extern FRAME SetAbsFrameIndex (FRAME Frame, COUNT FrameIndex);
@@ -246,6 +240,7 @@ extern FRAME SetEquFrameIndex (FRAME DstFrame, FRAME SrcFrame);
 extern FRAME IncFrameIndex (FRAME Frame);
 extern FRAME DecFrameIndex (FRAME Frame);
 extern DRAWABLE RotateFrame (FRAME Frame, COUNT angle);
+extern void SetFrameTransparentColor (FRAME Frame, COLOR c32k);
 
 extern FRAME CaptureDrawable (DRAWABLE Drawable);
 extern DRAWABLE ReleaseDrawable (FRAME Frame);
@@ -266,13 +261,10 @@ extern void FlushColorXForms (void);
 #define GetColorMapIndex GetStringTableIndex
 #define SetAbsColorMapIndex SetAbsStringTableIndex
 #define SetRelColorMapIndex SetRelStringTableIndex
-#define GetColorMapLength GetStringLength
+#define GetColorMapLength GetStringLengthBin
 #define GetColorMapAddress GetStringAddress
 #define GetColorMapContents GetStringContents
 
-// Font effect defines
-#define GRADIENT_EFFECT 0
-#define ALTERNATE_EFFECT 1
 
 #endif /* _GFX_PROTOS */
 
