@@ -21,6 +21,7 @@
 #include "tfb_draw.h"
 #include "units.h"
 #include "libs/mathlib.h"
+#include "gfxother.h"
 
 FRAMEPTR _CurFramePtr;
 
@@ -122,7 +123,8 @@ CreateDrawable (CREATE_FLAGS CreateFlags, SIZE width, SIZE height, COUNT
 
 	Drawable = _request_drawable (
 			(COUNT)num_frames, (DRAWABLE_TYPE)RAM_DRAWABLE,
-			(CREATE_FLAGS)(CreateFlags & (WANT_MASK | WANT_PIXMAP | MAPPED_TO_DISPLAY)),
+			(CREATE_FLAGS)(CreateFlags & (WANT_MASK | WANT_PIXMAP
+				| WANT_ALPHA | MAPPED_TO_DISPLAY)),
 			(SIZE)width, (SIZE)height
 			);
 	if (Drawable)
@@ -245,3 +247,13 @@ RotateFrame (FRAMEPTR Frame, COUNT angle)
 
 	return Drawable;
 }
+
+void
+SetFrameTransparentColor (FRAMEPTR Frame, COLOR c32k)
+{
+	TFB_Palette color;
+	
+	COLORtoPalette (c32k, &color);
+	TFB_DrawCanvas_SetTransparentColor (Frame->image->NormalImg,
+			color.r, color.g, color.b, FALSE);
+}
