@@ -54,7 +54,7 @@ process_image (FRAMEPTR FramePtr, SDL_Surface *img[], AniData *ani, int cel_ct)
 	// handle transparency cases
 	if (img[cel_ct]->format->palette)
 	{	// indexed color image
-		if (ani[cel_ct].transparent_color != -1)
+		if (ani[cel_ct].transparent_color >= 0)
 		    SDL_SetColorKey (img[cel_ct], SDL_SRCCOLORKEY,
 					ani[cel_ct].transparent_color);
 	}
@@ -63,7 +63,7 @@ process_image (FRAMEPTR FramePtr, SDL_Surface *img[], AniData *ani, int cel_ct)
 		if (ani[cel_ct].transparent_color == 0)
 			// make RGB=0,0,0 transparent
 		    SDL_SetColorKey (img[cel_ct], SDL_SRCCOLORKEY,
-					SDL_MapRGB (img[cel_ct]->format, 0, 0, 0));
+					SDL_MapRGBA (img[cel_ct]->format, 0, 0, 0, 0));
 	}
 	if (ani[cel_ct].transparent_color == -1)
 	{	// enforce -1 to mean 'no transparency'
@@ -106,68 +106,61 @@ process_image (FRAMEPTR FramePtr, SDL_Surface *img[], AniData *ani, int cel_ct)
 }
 
 static void
-processFontChar (FRAMEPTR FramePtr, SDL_Surface *surf, int charInd)
+processFontChar (TFB_Char* CharPtr, SDL_Surface *surf)
 {
 	int x,y;
 	Uint8 r,g,b,a;
 	Uint32 p;
-	SDL_Color colors[256];
-	SDL_Surface *new_surf;				
+	SDL_PixelFormat* srcfmt = surf->format;
 	GetPixelFn getpix;
-	PutPixelFn putpix;
+	BYTE* newdata;
+	Uint32 dpitch;
 
-	TYPE_SET (FramePtr->TypeIndexAndFlags, WANT_PIXMAP << FTYPE_SHIFT);
-	INDEX_SET (FramePtr->TypeIndexAndFlags, charInd);
-			// XXX: Is this still relevant?
+	// Currently, each font char has its own separate data
+	//  but that can change to common mem area
+	newdata = HMalloc (surf->w * surf->h * sizeof(BYTE));
+	dpitch = surf->w;
 
 	SDL_LockSurface (surf);
 
-	// convert 32-bit png font to indexed
-
-	new_surf = SDL_CreateRGBSurface (SDL_SWSURFACE, surf->w, surf->h,
-			8, 0, 0, 0, 0);
-
 	getpix = getpixel_for (surf);
-	putpix = putpixel_for (new_surf);
 
+	// produce an alpha-only image in internal BYTE[] format
+	//  from the SDL surface
 	for (y = 0; y < surf->h; ++y)
 	{
-		for (x = 0; x < surf->w; ++x)
+		BYTE* dst = newdata + dpitch * y;
+
+		for (x = 0; x < surf->w; ++x, ++dst)
 		{
 			p = getpix (surf, x, y);
-			SDL_GetRGBA (p, surf->format, &r, &g, &b, &a);
+			SDL_GetRGBA (p, srcfmt, &r, &g, &b, &a);
 
-			if (r == 0 && g == 0 && b == 0)
-				putpix (new_surf, x, y, 0);
-			else
-				putpix (new_surf, x, y, 1);
+			if (!srcfmt->Amask)
+			{	// produce alpha from intensity (Y component)
+				// using a fast approximation
+				// contributions to Y are: R=2, G=4, B=1
+				a = (((int)r << 1) + ((int)g << 2) + b) / 7;
+			}
+			
+			*dst = a;
 		}
 	}
 
-	colors[0].r = 0;
-	colors[0].g = 0;
-	colors[0].b = 0;
-	for (x = 1; x < 256; ++x)
-	{
-		colors[x].r = 255;
-		colors[x].g = 255;
-		colors[x].b = 255;
-	}
-
-	SDL_SetColors (new_surf, colors, 0, 256);
-	SDL_SetColorKey (new_surf, SDL_SRCCOLORKEY, 0);
-
 	SDL_UnlockSurface (surf);
-	SDL_FreeSurface (surf);
 
-	FramePtr->image = TFB_DrawImage_New (new_surf);
-	surf = FramePtr->image->NormalImg;
-	
-	SetFrameBounds (FramePtr, surf->w + 1, surf->h + 1);
+	CharPtr->data = newdata;
+	CharPtr->pitch = dpitch;
+	CharPtr->extent.width = surf->w;
+	CharPtr->extent.height = surf->h;
+	CharPtr->disp.width = surf->w + 1;
+	CharPtr->disp.height = surf->h + 1;
 			// XXX: why the +1?
 			// I brought it into this function from the only calling
 			// function, but I don't know why it was there in the first
 			// place.
+			// XXX: the +1 appears to be for character and line spacing
+			//  text_blt just adds the frame width to move to the next char
 	
 	{
 		// This tunes the font positioning to be about what it should
@@ -175,14 +168,15 @@ processFontChar (FRAMEPTR FramePtr, SDL_Surface *surf, int charInd)
 
 		int tune_amount = 0;
 
-		if (surf->h == 8)
+		if (CharPtr->extent.height == 8)
 			tune_amount = -1;
-		else if (surf->h == 9)
+		else if (CharPtr->extent.height == 9)
 			tune_amount = -2;
-		else if (surf->h > 9)
+		else if (CharPtr->extent.height > 9)
 			tune_amount = -3;
 
-		FramePtr->HotSpot = MAKE_HOT_SPOT (0, surf->h + tune_amount);
+		CharPtr->HotSpot = MAKE_HOT_SPOT (0,
+				CharPtr->extent.height + tune_amount);
 	}
 }
 
@@ -193,14 +187,15 @@ processFontChar (FRAMEPTR FramePtr, SDL_Surface *surf, int charInd)
 FRAMEPTR stretch_frame (FRAMEPTR FramePtr, int neww, int newh, int destroy)
 {
 	FRAMEPTR NewFrame;
-	UBYTE type;
+	CREATE_FLAGS flags;
 	TFB_Image *tfbImg;
 	TFB_Canvas src, dst;
 	EXTENT ext;
-	type = (UBYTE)TYPE_GET (GetFrameParentDrawable (FramePtr)
+
+	flags = TYPE_GET (GetFrameParentDrawable (FramePtr)
 			->FlagsAndIndex) >> FTYPE_SHIFT;
 	NewFrame = CaptureDrawable (
-				CreateDrawable (type, (SIZE)neww, (SIZE)newh, 1));
+				CreateDrawable (flags, (SIZE)neww, (SIZE)newh, 1));
 	tfbImg = FramePtr->image;
 	LockMutex (tfbImg->mutex);
 	src = tfbImg->NormalImg;
@@ -221,11 +216,6 @@ void process_rgb_bmp (FRAMEPTR FramePtr, Uint32 *rgba, int maxx, int maxy)
 	SDL_Surface *img;
 	PutPixelFn putpix;
 
-//	TYPE_SET (FramePtr->TypeIndexAndFlags, WANT_PIXMAP << FTYPE_SHIFT);
-//	INDEX_SET (FramePtr->TypeIndexAndFlags,  1);
-
-
-	// convert 32-bit png font to indexed
 	tfbImg = FramePtr->image;
 	LockMutex (tfbImg->mutex);
 	img = (SDL_Surface *)tfbImg->NormalImg;
@@ -265,7 +255,8 @@ void fill_frame_rgb (FRAMEPTR FramePtr, Uint32 color, int x0, int y0,
 	UnlockMutex (tfbImg->mutex);
 }
 
-void arith_frame_blit (FRAMEPTR srcFrame, RECT *rsrc, FRAMEPTR dstFrame, RECT *rdst, int num,int denom)
+void arith_frame_blit (FRAMEPTR srcFrame, RECT *rsrc, FRAMEPTR dstFrame,
+		RECT *rdst, int num, int denom)
 {
 	TFB_Image *srcImg, *dstImg;
 	SDL_Surface *src, *dst;
@@ -315,134 +306,65 @@ void arith_frame_blit (FRAMEPTR srcFrame, RECT *rsrc, FRAMEPTR dstFrame, RECT *r
 }
 
 // Generate an array of all pixels in FramePtr
-// The pixel format is :
-//  bits 25-32 : red
-//  bits 17-24 : green
-//  bits 9-16  : blue
-//  bits 1-8   : alpha
-void getpixelarray(Uint32 *map, FRAMEPTR FramePtr, int width, int height)
+// The 32bpp pixel format is :
+//  bits 24-31 : red
+//  bits 16-23 : green
+//  bits 8-15  : blue
+//  bits 0-7   : alpha
+// The 8bpp pixel format is 1 index per pixel
+void getpixelarray (void *map, int Bpp, FRAMEPTR FramePtr,
+		int width, int height)
 {
 	Uint8 r,g,b,a;
 	Uint32 p, pos, row;
 	TFB_Image *tfbImg;
 	SDL_Surface *img;
 	GetPixelFn getpix;
-	int x,y;
+	int x, y, w, h;
 
 	tfbImg = FramePtr->image;
 	LockMutex (tfbImg->mutex);
 	img = (SDL_Surface *)tfbImg->NormalImg;
-	SDL_LockSurface (img);
 	getpix = getpixel_for (img);
-	for (y = 0, row = 0; y < height; y++, row += width)
+
+	w = width < img->w ? width : img->w;
+	h = height < img->h ? height : img->h;
+	
+	SDL_LockSurface (img);
+
+	if (Bpp == 4)
 	{
-		if(y >= img->h)
-			continue;
-		for(x = 0, pos = row; x < img->w; x++, pos++)
+		Uint32 *dp = (Uint32 *)map;
+
+		for (y = 0, row = 0; y < h; y++, row += width)
 		{
+			for (x = 0, pos = row; x < w; x++, pos++)
+			{
 				p = getpix (img, x, y);
-				SDL_GetRGBA (p,img->format, &r, &g, &b, &a);
-				map[pos] = r << 24 | g << 16 | b << 8 | a;
+				SDL_GetRGBA (p, img->format, &r, &g, &b, &a);
+				dp[pos] = r << 24 | g << 16 | b << 8 | a;
+			}
 		}
 	}
+	else if (Bpp == 1)
+	{
+		Uint8 *dp = (Uint8 *)map;
+
+		for (y = 0, row = 0; y < h; y++, row += width)
+		{
+			for (x = 0, pos = row; x < w; x++, pos++)
+			{
+				p = getpix (img, x, y);
+				dp[pos] = p;
+			}
+		}
+	}
+
 	SDL_UnlockSurface (img);
 	UnlockMutex (tfbImg->mutex);
 }
 
-FRAMEPTR Build_Font_Effect (FRAMEPTR FramePtr, Uint32 from, Uint32 to, BYTE type)
-{
-	FRAMEPTR NewFrame;
-	int x, y;
-	int width, height;
-	Uint32 color, clear;
-	BYTE from_r, from_g, from_b, from_a;
-	BYTE to_r, to_g, to_b, to_a;
-	TFB_Image *tfbImg, *tfbOrigImg;
-	SDL_Surface *img, *OrigImg;
-	PutPixelFn putpix;
-	GetPixelFn getpix;
 
-	width = GetFrameWidth (FramePtr);
-	height = GetFrameHeight (FramePtr);
-	NewFrame = CaptureDrawable (CreateDrawable ((CREATE_FLAGS)RAM_DRAWABLE, 
-			(SIZE)width, (SIZE)height, 1));
-	tfbOrigImg = FramePtr->image;
-	OrigImg = (SDL_Surface *)tfbOrigImg->NormalImg;
-	SDL_LockSurface (OrigImg);
-
-	tfbImg = NewFrame->image;
-	img = (SDL_Surface *)tfbImg->NormalImg;
-	SDL_LockSurface (img);
-
-	putpix = putpixel_for (img);
-	getpix = getpixel_for (OrigImg);
-
-	from_r = (from >> 24);
-	from_g = (from >> 16) & 0xFF;
-	from_b = (from >> 8) & 0xFF;
-	from_a = from & 0xFF;
-
-	to_r = (to >> 24);
-	to_g = (to >> 16) & 0xFF;
-	to_b = (to >> 8) & 0xFF;
-	to_a = to & 0xFF;
-
-	clear = SDL_MapRGBA (img->format, 0, 0, 0, 0);
-	for (y = 0; y < 2; y++)
-		for (x = 0; x < width; x++)
-			putpix (img, x, y, clear);
-
-	width--;
-	if (type == GRADIENT_EFFECT)
-	{
-		int clrstep_r, clrstep_g, clrstep_b, clrstep_a;
-		clrstep_r = (to_r - from_r) /  (height - 5);
-		clrstep_g = (to_g - from_g) /  (height - 5);
-		clrstep_b = (to_b - from_b) /  (height - 5);
-		clrstep_a = (to_a - from_a) /  (height - 5);
-		for (; y < height - 1; y++)
-		{
-			color = SDL_MapRGBA (img->format, from_r, from_g, from_b, from_a);
-			from_r += clrstep_r;
-			from_g += clrstep_g;
-			from_b += clrstep_b;
-			from_a += clrstep_a;
-			for (x = 0; x < width; x++)
-				if (getpix (OrigImg, x, y) == 1)
-					putpix (img, x, y, color);
-				else
-					putpix (img, x, y, clear);
-			putpix (img, x, y, clear);
-		}
-	}
-	else if (type == ALTERNATE_EFFECT)
-	{
-		Uint32 color1, color2;
-		color1 = SDL_MapRGBA (img->format, from_r, from_g, from_b, from_a);
-		color2 = SDL_MapRGBA (img->format, to_r, to_g, to_b, to_a);
-		for (; y < height - 1; y++)
-		{
-			for (x = 0; x < width; x++)
-				if (getpix (OrigImg, x, y) == 1)
-				{
-					color = ((y & 0x01) ^ (x & 0x01)) ? color2 : color1;
-					putpix (img, x, y, color);
-				}
-				else
-					putpix (img, x, y, clear);
-			putpix (img, x, y, clear);
-		}
-	}
-
-	width++;
-	for (x = 0; x < width; x++)
-		putpix (img, x, y, clear);
-	SDL_UnlockSurface (img);
-	SDL_UnlockSurface (OrigImg);
-	NewFrame->HotSpot = FramePtr->HotSpot;
-	return (NewFrame);
-
-}
 // Generate a pixel (in the correct format to be applied to FramePtr) from the
 // r,g,b,a values supplied
 Uint32 frame_mapRGBA (FRAMEPTR FramePtr,Uint8 r, Uint8 g,  Uint8 b, Uint8 a)
@@ -678,6 +600,7 @@ _GetFontData (uio_Stream *fp, DWORD length)
 	
 	fontPtr->FontRef = fontRef;
 	fontPtr->Leading = 0;
+	fontPtr->LeadingWidth = 0;
 
 	{
 		size_t startBCD = 0;
@@ -709,10 +632,10 @@ _GetFontData (uio_Stream *fp, DWORD length)
 				{
 					// Process one character.
 					BuildCharDesc *bcd = &bcds[bcdI];
-					FRAME_DESC *destFrame =
+					TFB_Char *destChar =
 							&page->charDesc[bcd->index - page->firstChar];
 				
-					if (destFrame->image != NULL)
+					if (destChar->data != NULL)
 					{
 						// There's already an image for this character.
 #ifdef DEBUG
@@ -724,14 +647,13 @@ _GetFontData (uio_Stream *fp, DWORD length)
 						continue;
 					}
 					
-					processFontChar (destFrame, bcd->surface,
-							bcd->index - page->firstChar);
-					// bcd->surface is handed over to destFrame.
-					// Don't access it through bcd->surface any more.
-					// It may be freed from within ProcessFontChar().
+					processFontChar (destChar, bcd->surface);
+					SDL_FreeSurface (bcd->surface);
 
-					if (GetFrameHeight (destFrame) > fontPtr->Leading)
-						fontPtr->Leading = GetFrameHeight (destFrame);
+					if (destChar->disp.height > fontPtr->Leading)
+						fontPtr->Leading = destChar->disp.height;
+					if (destChar->disp.width > fontPtr->LeadingWidth)
+						fontPtr->LeadingWidth = destChar->disp.width;
 				}
 			}
 
@@ -785,12 +707,14 @@ _ReleaseFontData (MEM_HANDLE handle)
 			size_t charI;
 			for (charI = 0; charI < page->numChars; charI++)
 			{
-				FRAME_DESC *frame = &page->charDesc[charI];
+				TFB_Char *c = &page->charDesc[charI];
 				
-				if (frame->image == NULL)
+				if (c->data == NULL)
 					continue;
 				
-				TFB_DrawScreen_DeleteImage (frame->image);
+				// XXX: fix this if fonts get per-page data
+				//  rather than per-char
+				TFB_DrawScreen_DeleteData (c->data);
 			}
 		
 			nextPage = page->next;
@@ -842,7 +766,8 @@ _request_drawable (COUNT NumFrames, DRAWABLE_TYPE DrawableType,
 				TFB_Image *Image;
 
 				if (DrawableType == RAM_DRAWABLE && imgw > 0 && imgh > 0
-						&& (Image = TFB_DrawImage_New (TFB_DrawCanvas_New_TrueColor (imgw, imgh, FALSE))))
+						&& (Image = TFB_DrawImage_New (TFB_DrawCanvas_New_TrueColor (
+							imgw, imgh, (flags & WANT_ALPHA) ? TRUE : FALSE))))
 				{
 					FramePtr->image = Image;
 				}
