@@ -20,18 +20,18 @@
 
 #include "libs/graphics/sdl/opengl.h"
 #include "bbox.h"
-#include "2xscalers.h"
+#include "scalers.h"
 
-static SDL_Surface *format_conv_surf = NULL;
 static SDL_Surface *scaled_display = NULL;
 static SDL_Surface *scaled_transition = NULL;
 
 static int ScreenFilterMode;
 static GLuint DisplayTexture;
 static GLuint TransitionTexture;
-static BOOLEAN scanlines;
 static BOOLEAN upload_transitiontexture = FALSE;
 
+static TFB_ScaleFunc scaler = NULL;
+
 #if SDL_BYTEORDER == SDL_BIG_ENDIAN
 #define R_MASK 0xff000000
 #define G_MASK 0x00ff0000
@@ -46,23 +46,33 @@ static BOOLEAN upload_transitiontexture = FALSE;
 
 
 static SDL_Surface *
-Create_Screen (void)
+Create_Screen (SDL_Surface *template, int w, int h)
 {
-	SDL_Surface *result = SDL_CreateRGBSurface(SDL_SWSURFACE, ScreenWidth, ScreenHeight, 32,
-		R_MASK, G_MASK, B_MASK, 0x00000000);
-	if (result == NULL)
-	{
-		fprintf (stderr, "Couldn't create screen buffer: %s\n", SDL_GetError());
-		exit (-1);
+	SDL_Surface *newsurf = SDL_CreateRGBSurface(SDL_SWSURFACE, w, h,
+			template->format->BitsPerPixel,
+			template->format->Rmask, template->format->Gmask,
+			template->format->Bmask, 0);
+	if (newsurf == 0) {
+		fprintf (stderr, "Couldn't create screen buffers: %s\n",
+				SDL_GetError());
 	}
-	return result;
+	return newsurf;
 }
 
-int
-TFB_GL_ConfigureVideo (int driver, int flags, int width, int height, int bpp)
+static int
+ReInit_Screen (SDL_Surface **screen, SDL_Surface *template, int w, int h)
 {
-	int i, videomode_flags, texture_width, texture_height;
-	GraphicsDriver = driver;
+	if (*screen)
+		SDL_FreeSurface (*screen);
+	*screen = Create_Screen (template, w, h);
+	
+	return *screen == 0 ? -1 : 0;
+}
+
+static int
+AttemptColorDepth (int flags, int width, int height, int bpp)
+{
+	int videomode_flags;
 	ScreenColorDepth = bpp;
 	ScreenWidthActual = width;
 	ScreenHeightActual = height;
@@ -95,7 +105,7 @@ TFB_GL_ConfigureVideo (int driver, int flags, int width, int height, int bpp)
 			break;
 	}
 
-	SDL_GL_SetAttribute (SDL_GL_DEPTH_SIZE, bpp);
+	SDL_GL_SetAttribute (SDL_GL_DEPTH_SIZE, 0);
 	SDL_GL_SetAttribute (SDL_GL_DOUBLEBUFFER, 1);
 
 	videomode_flags = SDL_OPENGL;
@@ -114,87 +124,81 @@ TFB_GL_ConfigureVideo (int driver, int flags, int width, int height, int bpp)
 	}
 	else
 	{
-		fprintf (stderr, "Set the resolution to: %ix%ix%i\n",
+		fprintf (stderr, "Set the resolution to: %ix%ix%i (surface reports %ix%ix%i)\n",
+				width, height, bpp,			 
 				SDL_GetVideoSurface()->w, SDL_GetVideoSurface()->h,
 				SDL_GetVideoSurface()->format->BitsPerPixel);
 
 		fprintf (stderr, "OpenGL renderer: %s version: %s\n",
 				glGetString (GL_RENDERER), glGetString (GL_VERSION));
 	}
+	return 0;
+}
 
-	if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPT ||
-		GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPTADV ||
-		GfxFlags & TFB_GFXFLAGS_SCALE_TRISCAN)
+int
+TFB_GL_ConfigureVideo (int driver, int flags, int width, int height)
+{
+	int i, texture_width, texture_height;
+	GraphicsDriver = driver;
+
+	if (AttemptColorDepth (flags, width, height, 32) &&
+			AttemptColorDepth (flags, width, height, 24) &&
+			AttemptColorDepth (flags, width, height, 16))
 	{
-		if (scaled_display)
-		{
-			SDL_FreeSurface (scaled_display);
-			scaled_display = NULL;
-		}
-		scaled_display = SDL_CreateRGBSurface(SDL_SWSURFACE, ScreenWidth * 2,
-			ScreenHeight * 2, 32, R_MASK, G_MASK, B_MASK, 0x00000000);
-		if (scaled_display == NULL)
-		{
-			fprintf (stderr, "Couldn't create scaled_display: %s\n", SDL_GetError());
+		fprintf (stderr, "Couldn't set any OpenGL %ix%i video mode!\n",
+			 width, height);
+		return -1;
+	}		
+
+	if (format_conv_surf)
+		SDL_FreeSurface (format_conv_surf);
+	format_conv_surf = SDL_CreateRGBSurface (SDL_SWSURFACE, 0, 0, 32,
+		R_MASK, G_MASK, B_MASK, A_MASK);
+	if (format_conv_surf == NULL)
+	{
+		fprintf (stderr, "Couldn't create format_conv_surf: %s\n",
+				SDL_GetError());
+		return -1;
+	}
+
+	for (i = 0; i < TFB_GFX_NUMSCREENS; i++)
+	{
+		if (0 != ReInit_Screen (&SDL_Screens[i], format_conv_surf,
+				ScreenWidth, ScreenHeight))
 			return -1;
-		}
-		if (scaled_transition)
-		{
-			SDL_FreeSurface (scaled_transition);
-			scaled_transition = NULL;
-		}
-		scaled_transition = SDL_CreateRGBSurface(SDL_SWSURFACE, ScreenWidth * 2,
-			ScreenHeight * 2, 32, R_MASK, G_MASK, B_MASK, 0x00000000);
-		if (scaled_transition == NULL)
-		{
-			fprintf (stderr, "Couldn't create scaled_transition: %s\n", SDL_GetError());
+	}
+
+	SDL_Screen = SDL_Screens[0];
+	TransitionScreen = SDL_Screens[2];
+
+	if (GfxFlags & TFB_GFXFLAGS_SCALE_SOFT_ONLY)
+	{
+		if (0 != ReInit_Screen (&scaled_display, format_conv_surf,
+				ScreenWidth * 2, ScreenHeight * 2))
+			return -1;
+
+		if (0 != ReInit_Screen (&scaled_transition, format_conv_surf,
+				ScreenWidth * 2, ScreenHeight * 2))
 			return -1;
-		}
 
 		texture_width = 1024;
 		texture_height = 512;
+
+		scaler = Scale_PrepPlatform (flags, SDL_Screen->format);
 	}
 	else
 	{
 		texture_width = 512;
 		texture_height = 256;
+
+		scaler = NULL;
 	}
 
-	if (format_conv_surf)
-	{
-		SDL_FreeSurface (format_conv_surf);
-		format_conv_surf = NULL;
-	}
-	format_conv_surf = SDL_CreateRGBSurface(SDL_SWSURFACE, 0, 0, 32,
-		R_MASK, G_MASK, B_MASK, A_MASK);
-	if (format_conv_surf == NULL)
-	{
-		fprintf (stderr, "Couldn't create format_conv_surf: %s\n", SDL_GetError());
-		return -1;
-	}
-
-	if (GfxFlags & TFB_GFXFLAGS_SCALE_BILINEAR ||
-		GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPT ||
-		GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPTADV ||
-		GfxFlags & TFB_GFXFLAGS_SCALE_TRISCAN)
+	if (GfxFlags & TFB_GFXFLAGS_SCALE_ANY)
 		ScreenFilterMode = GL_LINEAR;
 	else
 		ScreenFilterMode = GL_NEAREST;
 
-	if (flags & TFB_GFXFLAGS_SCANLINES)
-		scanlines = TRUE;
-	else
-		scanlines = FALSE;
-
-	/* TODO: This leaks */
-	for (i = 0; i < TFB_GFX_NUMSCREENS; i++)
-	{
-		SDL_Screens[i] = Create_Screen ();
-	}
-
-	SDL_Screen = SDL_Screens[0];
-	TransitionScreen = SDL_Screens[2];
-
 	glViewport (0, 0, ScreenWidthActual, ScreenHeightActual);
 	glClearColor (0,0,0,0);
 	glClear (GL_COLOR_BUFFER_BIT|GL_DEPTH_BUFFER_BIT);
@@ -208,20 +212,22 @@ TFB_GL_ConfigureVideo (int driver, int flags, int width, int height, int bpp)
 	glPixelStorei (GL_UNPACK_ALIGNMENT, 1);
 	glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
 	glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
-	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGB, texture_width, texture_height, 0, GL_RGBA, GL_UNSIGNED_BYTE, 0);
+	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGB, texture_width, texture_height,
+			0, GL_RGBA, GL_UNSIGNED_BYTE, 0);
 
 	glGenTextures (1, &TransitionTexture);
 	glBindTexture (GL_TEXTURE_2D, TransitionTexture);
 	glPixelStorei (GL_UNPACK_ALIGNMENT, 1);
 	glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP);
 	glTexParameterf (GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP);
-	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGB, texture_width, texture_height, 0, GL_RGBA, GL_UNSIGNED_BYTE, 0);
+	glTexImage2D (GL_TEXTURE_2D, 0, GL_RGB, texture_width, texture_height,
+			0, GL_RGBA, GL_UNSIGNED_BYTE, 0);
 
 	return 0;
 }
 
 int
-TFB_GL_InitGraphics (int driver, int flags, int width, int height, int bpp)
+TFB_GL_InitGraphics (int driver, int flags, int width, int height)
 {
 	char VideoName[256];
 
@@ -235,14 +241,15 @@ TFB_GL_InitGraphics (int driver, int flags, int width, int height, int bpp)
 	ScreenWidth = 320;
 	ScreenHeight = 240;
 
-	if (TFB_GL_ConfigureVideo (driver, flags, width, height, bpp))
+	if (TFB_GL_ConfigureVideo (driver, flags, width, height))
 	{
-		fprintf (stderr, "Could not initialize video: no fallback at start of program!\n");
+		fprintf (stderr, "Could not initialize video: "
+				"no fallback at start of program!\n");
 		exit (-1);
 	}	 
 
-	// pre-compute the RGB->YUV transformations
-	Scale_PrepYUV();
+	// Initialize scalers (let them precompute whatever)
+	Scale_Init ();
 
 	return 0;
 }
@@ -295,7 +302,7 @@ TFB_GL_DrawQuad (void)
 	glEnd ();
 }
 
-void 
+void
 TFB_GL_SwapBuffers (int force_full_redraw)
 {
 	int fade_amount = FadeAmount;
@@ -327,23 +334,17 @@ TFB_GL_SwapBuffers (int force_full_redraw)
 		updated.w = TFB_BBox.region.extent.width;
 		updated.h = TFB_BBox.region.extent.height;
 
-		if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPT ||
-			GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPTADV ||
-			GfxFlags & TFB_GFXFLAGS_SCALE_TRISCAN)
+		if (scaler)
 		{
-			if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPT)
-				Scale_BiAdaptFilter (SDL_Screen, scaled_display, &updated);
-			else if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPTADV)
-				Scale_BiAdaptAdvFilter (SDL_Screen, scaled_display, &updated);
-			else if (GfxFlags & TFB_GFXFLAGS_SCALE_TRISCAN)
-				Scale_TriScanFilter (SDL_Screen, scaled_display, &updated);
+			scaler (SDL_Screen, scaled_display, &updated);
 
 			glPixelStorei (GL_UNPACK_ROW_LENGTH, ScreenWidth * 2);
 			glPixelStorei (GL_UNPACK_SKIP_ROWS, updated.y * 2);
 			glPixelStorei (GL_UNPACK_SKIP_PIXELS, updated.x * 2);
 			SDL_LockSurface (scaled_display);
-			glTexSubImage2D (GL_TEXTURE_2D, 0, updated.x * 2, updated.y * 2, updated.w * 2, updated.h * 2,
-				GL_RGBA, GL_UNSIGNED_BYTE, scaled_display->pixels);
+			glTexSubImage2D (GL_TEXTURE_2D, 0, updated.x * 2, updated.y * 2,
+					updated.w * 2, updated.h * 2, GL_RGBA, GL_UNSIGNED_BYTE,
+					scaled_display->pixels);
 			SDL_UnlockSurface (scaled_display);
 		}
 		else
@@ -352,8 +353,9 @@ TFB_GL_SwapBuffers (int force_full_redraw)
 			glPixelStorei (GL_UNPACK_SKIP_ROWS, updated.y);
 			glPixelStorei (GL_UNPACK_SKIP_PIXELS, updated.x);
 			SDL_LockSurface (SDL_Screen);
-			glTexSubImage2D (GL_TEXTURE_2D, 0, updated.x, updated.y, updated.w, updated.h,
-				GL_RGBA, GL_UNSIGNED_BYTE, SDL_Screen->pixels);
+			glTexSubImage2D (GL_TEXTURE_2D, 0, updated.x, updated.y,
+					updated.w, updated.h, GL_RGBA, GL_UNSIGNED_BYTE,
+					SDL_Screen->pixels);
 			SDL_UnlockSurface (SDL_Screen);
 		}
 	}
@@ -369,27 +371,22 @@ TFB_GL_SwapBuffers (int force_full_redraw)
 		
 		if (upload_transitiontexture) 
 		{
-			if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPT ||
-				GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPTADV ||
-				GfxFlags & TFB_GFXFLAGS_SCALE_TRISCAN)
+			if (scaler)
 			{
 				SDL_Rect r;
 				r.x = r.y = 0;
 				r.w = ScreenWidth;
 				r.h = ScreenHeight;
-				if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPT)
-					Scale_BiAdaptFilter (TransitionScreen, scaled_transition, &r);
-				else if (GfxFlags & TFB_GFXFLAGS_SCALE_BIADAPTADV)
-					Scale_BiAdaptAdvFilter (TransitionScreen, scaled_transition, &r);
-				else if (GfxFlags & TFB_GFXFLAGS_SCALE_TRISCAN)
-					Scale_TriScanFilter (TransitionScreen, scaled_transition, &r);
+				
+				scaler (TransitionScreen, scaled_transition, &r); 
 
 				glPixelStorei (GL_UNPACK_ROW_LENGTH, ScreenWidth * 2);
 				glPixelStorei (GL_UNPACK_SKIP_ROWS, 0);
 				glPixelStorei (GL_UNPACK_SKIP_PIXELS, 0);
 				SDL_LockSurface (scaled_transition);
-				glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, ScreenWidth * 2, ScreenHeight * 2,
-					GL_RGBA, GL_UNSIGNED_BYTE, scaled_transition->pixels);
+				glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, ScreenWidth * 2,
+						ScreenHeight * 2, GL_RGBA, GL_UNSIGNED_BYTE,
+						scaled_transition->pixels);
 				SDL_UnlockSurface (scaled_transition);
 			}
 			else
@@ -398,22 +395,26 @@ TFB_GL_SwapBuffers (int force_full_redraw)
 				glPixelStorei (GL_UNPACK_SKIP_ROWS, 0);
 				glPixelStorei (GL_UNPACK_SKIP_PIXELS, 0);
 				SDL_LockSurface (TransitionScreen);
-				glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, ScreenWidth, ScreenHeight,
-					GL_RGBA, GL_UNSIGNED_BYTE, TransitionScreen->pixels);
+				glTexSubImage2D (GL_TEXTURE_2D, 0, 0, 0, ScreenWidth,
+						ScreenHeight, GL_RGBA, GL_UNSIGNED_BYTE,
+						TransitionScreen->pixels);
 				SDL_UnlockSurface (TransitionScreen);
 			}
 
 			upload_transitiontexture = FALSE;
 		}
 
-		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, ScreenFilterMode);
-		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, ScreenFilterMode);
+		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER,
+				ScreenFilterMode);
+		glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER,
+				ScreenFilterMode);
 		glEnable (GL_BLEND);
 		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 		glColor4f (1, 1, 1, (255 - transition_amount) / 255.0f);		
 		glScissor (
 			(GLint) (TransitionClipRect.x * scale_x),
-			(GLint) ((ScreenHeight - (TransitionClipRect.y + TransitionClipRect.h)) * scale_y),
+			(GLint) ((ScreenHeight - (TransitionClipRect.y +
+				TransitionClipRect.h)) * scale_y),
 			(GLsizei) (TransitionClipRect.w * scale_x),
 			(GLsizei) (TransitionClipRect.h * scale_y)
 		);		
@@ -428,18 +429,18 @@ TFB_GL_SwapBuffers (int force_full_redraw)
 
 		if (fade_amount < 255)
 		{
-			c = fade_amount / 255.0f;
-			glBlendFunc (GL_DST_COLOR, GL_ZERO);
+			c = (255 - fade_amount) / 255.0f;
+			glColor4f (0, 0, 0, c);
 		}
 		else
 		{
 			c = (fade_amount - 255) / 255.0f;
-			glBlendFunc (GL_ONE, GL_ONE);
+			glColor4f (1, 1, 1, c);
 		}
 
 		glDisable (GL_TEXTURE_2D);
+		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 		glEnable (GL_BLEND);
-		glColor4f (c, c, c, 1);
 
 		TFB_GL_DrawQuad ();
 	}
@@ -450,20 +451,4 @@ TFB_GL_SwapBuffers (int force_full_redraw)
 	SDL_GL_SwapBuffers ();
 }
 
-SDL_Surface* 
-TFB_GL_DisplayFormatAlpha (SDL_Surface *surface)
-{
-	SDL_Surface* newsurf;
-	
-	newsurf = SDL_ConvertSurface (surface, format_conv_surf->format, surface->flags);
-	// SDL_SRCCOLORKEY and SDL_SRCALPHA cannot work at the same time,
-	// so we need to disable one of them
-	if ((surface->flags & SDL_SRCCOLORKEY) && newsurf
-			&& (newsurf->flags & SDL_SRCCOLORKEY)
-			&& (newsurf->flags & SDL_SRCALPHA))
-		SDL_SetAlpha (newsurf, 0, 255);
-
-	return newsurf;
-}
-
 #endif
