@@ -21,11 +21,10 @@
 
 #include "libs/graphics/sdl/sdl_common.h"
 
-int TFB_GL_InitGraphics (int driver, int flags, int width, int height, int bpp);
-int TFB_GL_ConfigureVideo (int driver, int flags, int width, int height, int bpp);
+int TFB_GL_InitGraphics (int driver, int flags, int width, int height);
+int TFB_GL_ConfigureVideo (int driver, int flags, int width, int height);
 void TFB_GL_UploadTransitionScreen (void);
 void TFB_GL_SwapBuffers (int force_full_redraw);
-SDL_Surface* TFB_GL_DisplayFormatAlpha (SDL_Surface *surface);
 
 
 #ifdef HAVE_OPENGL
