@@ -41,6 +41,8 @@ SDL_Surface *TransitionScreen;
 
 SDL_Surface *SDL_Screens[TFB_GFX_NUMSCREENS];
 
+SDL_Surface *format_conv_surf = NULL;
+
 volatile int TransitionAmount = 255;
 SDL_Rect TransitionClipRect;
 static volatile BOOLEAN abortFlag = FALSE;
@@ -74,7 +76,7 @@ TFB_PreInit (void)
 }
 
 int
-TFB_ReInitGraphics (int driver, int flags, int width, int height, int bpp)
+TFB_ReInitGraphics (int driver, int flags, int width, int height)
 {
 	int result;
 	char caption[200];
@@ -84,17 +86,17 @@ TFB_ReInitGraphics (int driver, int flags, int width, int height, int bpp)
 	if (driver == TFB_GFXDRIVER_SDL_OPENGL)
 	{
 #ifdef HAVE_OPENGL
-		result = TFB_GL_ConfigureVideo (driver, flags, width, height, bpp);
+		result = TFB_GL_ConfigureVideo (driver, flags, width, height);
 #else
 		driver = TFB_GFXDRIVER_SDL_PURE;
 		fprintf (stderr, "OpenGL support not compiled in, so using pure "
 				"sdl driver\n");
-		result = TFB_Pure_ConfigureVideo (driver, flags, width, height, bpp);
+		result = TFB_Pure_ConfigureVideo (driver, flags, width, height);
 #endif
 	}
 	else
 	{
-		result = TFB_Pure_ConfigureVideo (driver, flags, width, height, bpp);
+		result = TFB_Pure_ConfigureVideo (driver, flags, width, height);
 	}
 
 	sprintf (caption, "The Ur-Quan Masters v%d.%d.%d%s",
@@ -111,33 +113,27 @@ TFB_ReInitGraphics (int driver, int flags, int width, int height, int bpp)
 }
 
 int
-TFB_InitGraphics (int driver, int flags, int width, int height, int bpp)
+TFB_InitGraphics (int driver, int flags, int width, int height)
 {
 	int result;
 	char caption[200];
 
-	if (bpp != 15 && bpp != 16 && bpp != 24 && bpp != 32)
-	{
-		fprintf(stderr, "Fatal error: bpp of %d not supported\n", bpp);
-		exit(-1);
-	}
-
 	GfxFlags = flags;
 
 	if (driver == TFB_GFXDRIVER_SDL_OPENGL)
 	{
 #ifdef HAVE_OPENGL
-		result = TFB_GL_InitGraphics (driver, flags, width, height, bpp);
+		result = TFB_GL_InitGraphics (driver, flags, width, height);
 #else
 		driver = TFB_GFXDRIVER_SDL_PURE;
 		fprintf (stderr, "OpenGL support not compiled in, so using pure "
 				"sdl driver\n");
-		result = TFB_Pure_InitGraphics (driver, flags, width, height, bpp);
+		result = TFB_Pure_InitGraphics (driver, flags, width, height);
 #endif
 	}
 	else
 	{
-		result = TFB_Pure_InitGraphics (driver, flags, width, height, bpp);
+		result = TFB_Pure_InitGraphics (driver, flags, width, height);
 	}
 
 	sprintf (caption, "The Ur-Quan Masters v%d.%d.%d%s", 
@@ -150,7 +146,6 @@ TFB_InitGraphics (int driver, int flags, int width, int height, int bpp)
 
 	Init_DrawCommandQueue ();
 
-	TFB_FlushPaletteCache ();
 	TFB_DrawCanvas_Initialize ();
 
 	RenderingCond = CreateCondVar ("DCQ empty",
@@ -197,7 +192,7 @@ TFB_ProcessEvents ()
 	}
 	if (ImmediateInputState.key[KEY_ABORT] || abortFlag)
 		exit (0);
-#ifdef DEBUG
+#if defined(DEBUG) || defined(USE_DEBUG_KEY)
 	if (ImmediateInputState.key[KEY_DEBUG])
 	{
 		FlushInput ();
@@ -223,14 +218,32 @@ TFB_SwapBuffers (int force_full_redraw)
 SDL_Surface* 
 TFB_DisplayFormatAlpha (SDL_Surface *surface)
 {
-#ifdef HAVE_OPENGL
-	if (GraphicsDriver == TFB_GFXDRIVER_SDL_OPENGL)
-	{
-		return TFB_GL_DisplayFormatAlpha (surface);
-	}
-#endif
+	SDL_Surface* newsurf;
+	SDL_PixelFormat* dstfmt;
+	const SDL_PixelFormat* srcfmt = surface->format;
+	
+	// figure out what format to use (alpha/no alpha)
+	if (surface->format->Amask)
+		dstfmt = format_conv_surf->format;
+	else
+		dstfmt = SDL_Screen->format;
 
-	return SDL_DisplayFormatAlpha (surface);
+	if (srcfmt->BytesPerPixel == dstfmt->BytesPerPixel && 
+			srcfmt->Rmask == dstfmt->Rmask &&
+			srcfmt->Gmask == dstfmt->Gmask &&
+			srcfmt->Bmask == dstfmt->Bmask &&
+			srcfmt->Amask == dstfmt->Amask)
+		return surface; // no conversion needed
+
+	newsurf = SDL_ConvertSurface (surface, dstfmt, surface->flags);
+	// SDL_SRCCOLORKEY and SDL_SRCALPHA cannot work at the same time,
+	// so we need to disable one of them
+	if ((surface->flags & SDL_SRCCOLORKEY) && newsurf
+			&& (newsurf->flags & SDL_SRCCOLORKEY)
+			&& (newsurf->flags & SDL_SRCALPHA))
+		SDL_SetAlpha (newsurf, 0, 255);
+
+	return newsurf;
 }
 
 void TFB_BlitSurface (SDL_Surface *src, SDL_Rect *srcrect, SDL_Surface *dst,
@@ -587,31 +600,32 @@ TFB_FlushGraphics () // Only call from main thread!!
 		case TFB_DRAWCOMMANDTYPE_SETMIPMAP:
 			LockMutex (DC.data.setmipmap.image->mutex);
 			DC.data.setmipmap.image->MipmapImg = DC.data.setmipmap.mipmap;
+			DC.data.setmipmap.image->MipmapHs.x = DC.data.setmipmap.hotx;
+			DC.data.setmipmap.image->MipmapHs.y = DC.data.setmipmap.hoty;
 			UnlockMutex (DC.data.setmipmap.image->mutex);
 			break;
 		case TFB_DRAWCOMMANDTYPE_IMAGE:
 			{
 				TFB_Image *DC_image = DC.data.image.image;
-				TFB_Palette *pal;
+				TFB_ColorMap *cmap = DC.data.image.colormap;
 				int x = DC.data.image.x;
 				int y = DC.data.image.y;
 
-				if (DC.data.image.UsePalette)
-					pal = palette;
-				else
-					pal = 0;
-
 				TFB_DrawCanvas_Image (DC_image, x, y,
-						DC.data.image.scale, pal,
+						DC.data.image.scale, cmap,
 						SDL_Screens[DC.data.image.destBuffer]);
 
 				if (DC.data.image.destBuffer == 0)
 				{
 					LockMutex (DC_image->mutex);
 					if (DC.data.image.scale)
-						TFB_BBox_RegisterCanvas (DC_image->ScaledImg, x, y);
+						TFB_BBox_RegisterCanvas (DC_image->ScaledImg,
+								x - DC_image->last_scale_hs.x,
+								y - DC_image->last_scale_hs.y);
 					else
-						TFB_BBox_RegisterCanvas (DC_image->NormalImg, x, y);
+						TFB_BBox_RegisterCanvas (DC_image->NormalImg,
+								x - DC_image->NormalHs.x,
+								y - DC_image->NormalHs.y);
 					UnlockMutex (DC_image->mutex);
 				}
 
@@ -633,12 +647,41 @@ TFB_FlushGraphics () // Only call from main thread!!
 				{
 					LockMutex (DC_image->mutex);
 					if (DC.data.filledimage.scale)
-						TFB_BBox_RegisterCanvas (DC_image->ScaledImg, x, y);
+						TFB_BBox_RegisterCanvas (DC_image->ScaledImg,
+								x - DC_image->last_scale_hs.x,
+								y - DC_image->last_scale_hs.y);
 					else
-						TFB_BBox_RegisterCanvas (DC_image->NormalImg, x, y);
+						TFB_BBox_RegisterCanvas (DC_image->NormalImg,
+								x - DC_image->NormalHs.x,
+								y - DC_image->NormalHs.y);
 					UnlockMutex (DC_image->mutex);
 				}
 
+				break;
+			}
+		case TFB_DRAWCOMMANDTYPE_FONTCHAR:
+			{
+				TFB_Char *DC_char = DC.data.fontchar.fontchar;
+				int x = DC.data.fontchar.x;
+				int y = DC.data.fontchar.y;
+
+				TFB_DrawCanvas_FontChar (DC.data.fontchar.fontchar,
+						DC.data.fontchar.backing,
+						DC.data.fontchar.x, DC.data.fontchar.y,
+						SDL_Screens[DC.data.fontchar.destBuffer]);
+
+				if (DC.data.fontchar.destBuffer == 0)
+				{
+					RECT r;
+					
+					r.corner.x = x - DC_char->HotSpot.x;
+					r.corner.y = y - DC_char->HotSpot.y;
+					r.extent.width = DC_char->extent.width;
+					r.extent.height = DC_char->extent.height;
+
+					TFB_BBox_RegisterRect (&r);
+				}
+
 				break;
 			}
 		case TFB_DRAWCOMMANDTYPE_LINE:
@@ -730,21 +773,24 @@ TFB_FlushGraphics () // Only call from main thread!!
 				TFB_DrawImage_Delete(DC_image);
 				break;
 			}
+		case TFB_DRAWCOMMANDTYPE_DELETEDATA:
+			{
+				void *data = DC.data.deletedata.data;
+				HFree (data);
+				break;
+			}
 		case TFB_DRAWCOMMANDTYPE_SENDSIGNAL:
 			ClearSemaphore (DC.data.sendsignal.sem);
 			break;
 		case TFB_DRAWCOMMANDTYPE_REINITVIDEO:
 			{
 				int oldDriver = GraphicsDriver;
-				int oldBpp = ScreenColorDepth;
 				if (TFB_ReInitGraphics (DC.data.reinitvideo.driver, DC.data.reinitvideo.flags, 
-							DC.data.reinitvideo.width, DC.data.reinitvideo.height, 
-							DC.data.reinitvideo.bpp))
+							DC.data.reinitvideo.width, DC.data.reinitvideo.height))
 				{
-					fprintf (stderr, "Could not provide requested mode: reverting to last known driver and bpp.\n");
+					fprintf (stderr, "Could not provide requested mode: reverting to last known driver.\n");
 					if (TFB_ReInitGraphics (oldDriver, DC.data.reinitvideo.flags,
-								DC.data.reinitvideo.width, DC.data.reinitvideo.height, 
-								oldBpp))
+								DC.data.reinitvideo.width, DC.data.reinitvideo.height))
 					{
 						fprintf (stderr, "Couldn't reinit at that point either.  Your video has been somehow tied in knots.\n");
 						exit (-1);
