@@ -19,6 +19,7 @@
 #include "drawcmd.h"
 #include "units.h"
 
+static const HOT_SPOT NullHs = {0, 0};
 
 void
 TFB_DrawScreen_Line (int x1, int y1, int x2, int y2, int r, int g, int b,
@@ -77,67 +78,21 @@ TFB_DrawScreen_SetPalette (int paletteIndex, int r, int g, int b)
 	TFB_EnqueueDrawCommand (&DC);
 }
 
-/* This value is protected by the DCQ's lock. */
-static int _localpal[256][3];
-
-void
-TFB_FlushPaletteCache ()
-{
-	int i;
-	Lock_DCQ (-1);
-	for (i = 0; i < 256; i++)
-	{
-		_localpal[i][0] = -1;
-		_localpal[i][1] = -1;
-		_localpal[i][2] = -1;
-	}
-	Unlock_DCQ ();
-}
-
 void
 TFB_DrawScreen_Image (TFB_Image *img, int x, int y, int scale,
-		TFB_Palette *palette, SCREEN dest)
+		TFB_ColorMap *cmap, SCREEN dest)
 {
 	TFB_DrawCommand DC;
 	
 	DC.Type = TFB_DRAWCOMMANDTYPE_IMAGE;
 	DC.data.image.image = img;
+	DC.data.image.colormap = cmap;
 	DC.data.image.x = x;
 	DC.data.image.y = y;
 	DC.data.image.scale = (scale == GSCALE_IDENTITY) ? 0 : scale;
-
-	if (palette != NULL)
-	{
-		int i, changed;
-		Lock_DCQ(257);
-		changed = 0;
-		for (i = 0; i < 256; i++)
-		{
-			if ((_localpal[i][0] != palette[i].r) ||
-			    (_localpal[i][1] != palette[i].g) ||
-			    (_localpal[i][2] != palette[i].b))
-			{
-				changed++;
-				_localpal[i][0] = palette[i].r;
-				_localpal[i][1] = palette[i].g;
-				_localpal[i][2] = palette[i].b;
-				TFB_DrawScreen_SetPalette (i, palette[i].r, palette[i].g,
-						palette[i].b);
-			}
-		}
-		// if (changed) { fprintf (stderr, "Actually changing palette! "); }
-		DC.data.image.UsePalette = TRUE;
-	}
-	else
-	{
-		Lock_DCQ (1);
-		DC.data.image.UsePalette = FALSE;
-	}
-
 	DC.data.image.destBuffer = dest;
 
 	TFB_EnqueueDrawCommand (&DC);
-	Unlock_DCQ ();
 }
 
 void
@@ -159,6 +114,22 @@ TFB_DrawScreen_FilledImage (TFB_Image *img, int x, int y, int scale,
 	TFB_EnqueueDrawCommand (&DC);
 }
 
+void
+TFB_DrawScreen_FontChar (TFB_Char *fontChar, TFB_Image *backing,
+		int x, int y, SCREEN dest)
+{
+	TFB_DrawCommand DC;
+	
+	DC.Type = TFB_DRAWCOMMANDTYPE_FONTCHAR;
+	DC.data.fontchar.fontchar = fontChar;
+	DC.data.fontchar.backing = backing;
+	DC.data.fontchar.x = x;
+	DC.data.fontchar.y = y;
+	DC.data.fontchar.destBuffer = dest;
+
+	TFB_EnqueueDrawCommand (&DC);
+}
+
 void
 TFB_DrawScreen_CopyToImage (TFB_Image *img, PRECT lpRect, SCREEN src)
 {
@@ -214,6 +185,21 @@ TFB_DrawScreen_DeleteImage (TFB_Image *img)
 	}
 }
 
+void
+TFB_DrawScreen_DeleteData (void *data)
+		// data must be a result of HXalloc() call
+{
+	if (data)
+	{
+		TFB_DrawCommand DC;
+
+		DC.Type = TFB_DRAWCOMMANDTYPE_DELETEDATA;
+		DC.data.deletedata.data = data;
+
+		TFB_EnqueueDrawCommand (&DC);
+	}
+}
+
 void
 TFB_DrawScreen_WaitForSignal (void)
 {
@@ -230,8 +216,7 @@ TFB_DrawScreen_WaitForSignal (void)
 }
 
 void
-TFB_DrawScreen_ReinitVideo (int driver, int flags, int width, int height,
-		int bpp)
+TFB_DrawScreen_ReinitVideo (int driver, int flags, int width, int height)
 {
 	TFB_DrawCommand DrawCommand;
 	DrawCommand.Type = TFB_DRAWCOMMANDTYPE_REINITVIDEO;
@@ -239,7 +224,6 @@ TFB_DrawScreen_ReinitVideo (int driver, int flags, int width, int height,
 	DrawCommand.data.reinitvideo.flags = flags;
 	DrawCommand.data.reinitvideo.width = width;
 	DrawCommand.data.reinitvideo.height = height;
-	DrawCommand.data.reinitvideo.bpp = bpp;
 	TFB_EnqueueDrawCommand(&DrawCommand);
 }
 
@@ -264,10 +248,10 @@ TFB_DrawImage_Rect (PRECT rect, int r, int g, int b, TFB_Image *image)
 
 void
 TFB_DrawImage_Image (TFB_Image *img, int x, int y, int scale,
-		TFB_Palette *palette, TFB_Image *target)
+		TFB_ColorMap *cmap, TFB_Image *target)
 {
 	LockMutex (target->mutex);
-	TFB_DrawCanvas_Image (img, x, y, scale, palette, target->NormalImg);
+	TFB_DrawCanvas_Image (img, x, y, scale, cmap, target->NormalImg);
 	target->dirty = TRUE;
 	UnlockMutex (target->mutex);
 }
@@ -282,6 +266,17 @@ TFB_DrawImage_FilledImage (TFB_Image *img, int x, int y, int scale,
 	UnlockMutex (target->mutex);
 }
 
+void
+TFB_DrawImage_FontChar (TFB_Char *fontChar, TFB_Image *backing,
+		int x, int y, TFB_Image *target)
+{
+	LockMutex (target->mutex);
+	TFB_DrawCanvas_FontChar (fontChar, backing, x, y, target->NormalImg);
+	target->dirty = TRUE;
+	UnlockMutex (target->mutex);
+}
+
+
 TFB_Image *
 TFB_DrawImage_New (TFB_Canvas canvas)
 {
@@ -289,7 +284,12 @@ TFB_DrawImage_New (TFB_Canvas canvas)
 	img->mutex = CreateMutex ("image lock", SYNC_CLASS_VIDEO);
 	img->ScaledImg = NULL;
 	img->MipmapImg = NULL;
+	img->FilledImg = NULL;
 	img->colormap_index = -1;
+	img->colormap_version = 0;
+	img->NormalHs = NullHs;
+	img->MipmapHs = NullHs;
+	img->last_scale_hs = NullHs;
 	img->last_scale_type = -1;
 	TFB_DrawCanvas_GetExtent (canvas, &img->extent);
 
@@ -314,7 +314,12 @@ TFB_DrawImage_CreateForScreen (int w, int h, BOOLEAN withalpha)
 	img->mutex = CreateMutex ("image lock", SYNC_CLASS_VIDEO);
 	img->ScaledImg = NULL;
 	img->MipmapImg = NULL;
+	img->FilledImg = NULL;
 	img->colormap_index = -1;
+	img->colormap_version = 0;
+	img->NormalHs = NullHs;
+	img->MipmapHs = NullHs;
+	img->last_scale_hs = NullHs;
 	img->last_scale_type = -1;
 	img->Palette = NULL;
 	img->extent.width = w;
@@ -384,12 +389,16 @@ void
 TFB_DrawImage_FixScaling (TFB_Image *image, int target, int type)
 {
 	EXTENT old = image->extent;
-	TFB_DrawCanvas_GetScaledExtent (image->NormalImg, image->MipmapImg,
-			target, &image->extent);
+	HOT_SPOT oldhs = image->last_scale_hs;
+	TFB_DrawCanvas_GetScaledExtent (image->NormalImg, image->NormalHs,
+			image->MipmapImg, image->MipmapHs, target,
+			&image->extent, &image->last_scale_hs);
 
 	if ((old.width != image->extent.width) ||
 			(old.height != image->extent.height) || image->dirty ||
-			!image->ScaledImg || type != image->last_scale_type)
+			!image->ScaledImg || type != image->last_scale_type ||
+			(oldhs.x != image->last_scale_hs.x) ||
+			(oldhs.y != image->last_scale_hs.y))
 	{
 		image->dirty = FALSE;
 		image->ScaledImg = TFB_DrawCanvas_New_ScaleTarget (image->NormalImg,
