@@ -119,8 +119,7 @@ TFB_Prim_Stamp (PSTAMP stmp)
 	int x, y;
 	PFRAME_DESC SrcFramePtr;
 	TFB_Image *img;
-	BOOLEAN paletted;
-	TFB_Palette palette[256];
+	TFB_ColorMap *cmap = NULL;
 	int gscale;
 
 	SrcFramePtr = (PFRAME_DESC)stmp->frame;
@@ -140,35 +139,25 @@ TFB_Prim_Stamp (PSTAMP stmp)
 
 	LockMutex (img->mutex);
 
-	x = stmp->origin.x - _CurFramePtr->HotSpot.x - SrcFramePtr->HotSpot.x;
-	y = stmp->origin.y - _CurFramePtr->HotSpot.y - SrcFramePtr->HotSpot.y;
-	paletted = FALSE;
-
-	if (gscale != GSCALE_IDENTITY)
-	{	// rounding error correction here
-		x += (SrcFramePtr->HotSpot.x * (GSCALE_IDENTITY - gscale)
-				+ (GSCALE_IDENTITY >> 1)) / GSCALE_IDENTITY;
-		y += (SrcFramePtr->HotSpot.y * (GSCALE_IDENTITY - gscale)
-				+ (GSCALE_IDENTITY >> 1)) / GSCALE_IDENTITY;
-	}
+	img->NormalHs = SrcFramePtr->HotSpot;
+	x = stmp->origin.x - _CurFramePtr->HotSpot.x;
+	y = stmp->origin.y - _CurFramePtr->HotSpot.y;
 
 	if (TFB_DrawCanvas_IsPaletted(img->NormalImg) && img->colormap_index != -1)
 	{
-		TFB_ColorMapToRGB (palette, img->colormap_index);
-		paletted = TRUE;
+		// returned cmap is addrefed, must release later
+		cmap = TFB_GetColorMap (img->colormap_index);
 	}
 
 	UnlockMutex (img->mutex);
 
 	if (TYPE_GET (_CurFramePtr->TypeIndexAndFlags) == SCREEN_DRAWABLE)
 	{
-		TFB_DrawScreen_Image (img, x, y, gscale, (paletted ? palette : NULL),
-				      TFB_SCREEN_MAIN);
+		TFB_DrawScreen_Image (img, x, y, gscale, cmap, TFB_SCREEN_MAIN);
 	}
 	else
 	{
-		TFB_DrawImage_Image (img, x, y, gscale, (paletted ? palette : NULL),
-				     _CurFramePtr->image);
+		TFB_DrawImage_Image (img, x, y, gscale, cmap, _CurFramePtr->image);
 	}
 }
 
@@ -198,20 +187,14 @@ TFB_Prim_StampFill (PSTAMP stmp, TFB_Palette *color)
 
 	LockMutex (img->mutex);
 
-	x = stmp->origin.x - _CurFramePtr->HotSpot.x - SrcFramePtr->HotSpot.x;
-	y = stmp->origin.y - _CurFramePtr->HotSpot.y - SrcFramePtr->HotSpot.y;
+	img->NormalHs = SrcFramePtr->HotSpot;
+	x = stmp->origin.x - _CurFramePtr->HotSpot.x;
+	y = stmp->origin.y - _CurFramePtr->HotSpot.y;
+
 	r = color->r;
 	g = color->g;
 	b = color->b;
 
-	if (gscale != GSCALE_IDENTITY)
-	{	// rounding error correction here
-		x += (SrcFramePtr->HotSpot.x * (GSCALE_IDENTITY - gscale)
-				+ (GSCALE_IDENTITY >> 1)) / GSCALE_IDENTITY;
-		y += (SrcFramePtr->HotSpot.y * (GSCALE_IDENTITY - gscale)
-				+ (GSCALE_IDENTITY >> 1)) / GSCALE_IDENTITY;
-	}
-
 	UnlockMutex (img->mutex);
 
 	if (TYPE_GET (_CurFramePtr->TypeIndexAndFlags) == SCREEN_DRAWABLE)
@@ -226,4 +209,24 @@ TFB_Prim_StampFill (PSTAMP stmp, TFB_Palette *color)
 	}
 }
 
+void
+TFB_Prim_FontChar (PPOINT origin, TFB_Char *fontChar, TFB_Image *backing)
+{
+	int x, y;
+
+	x = origin->x - _CurFramePtr->HotSpot.x;
+	y = origin->y - _CurFramePtr->HotSpot.y;
+
+	if (TYPE_GET (_CurFramePtr->TypeIndexAndFlags) == SCREEN_DRAWABLE)
+	{
+		TFB_DrawScreen_FontChar (fontChar, backing, x, y,
+					    TFB_SCREEN_MAIN);
+	}
+	else
+	{
+		TFB_DrawImage_FontChar (fontChar, backing, x, y,
+					   _CurFramePtr->image);
+	}
+}
+
 // Text rendering is in font.c, under the name _text_blt
