@@ -30,14 +30,15 @@
 
 #define KBDBUFSIZE (1 << 8)
 static int kbdhead=0, kbdtail=0;
-static UNICODE kbdbuf[KBDBUFSIZE];
+static wchar_t kbdbuf[KBDBUFSIZE];
+static wchar_t lastchar;
+static int kbdstate[SDLK_LAST];
 
 static BOOLEAN InputInitialized = FALSE;
-UWORD UNICODEToKBD (UNICODE which_key);
 
 static BOOLEAN _in_character_mode = FALSE;
 
-#define VCONTROL_VERSION 1
+#define VCONTROL_VERSION 2
 
 static VControl_NameBinding control_names[] = {
 	{ "Menu-Up", (int *)&ImmediateInputState.key[KEY_MENU_UP] },
@@ -49,9 +50,15 @@ static VControl_NameBinding control_names[] = {
 	{ "Menu-Special", (int *)&ImmediateInputState.key[KEY_MENU_SPECIAL] },
 	{ "Menu-Page-Up", (int *)&ImmediateInputState.key[KEY_MENU_PAGE_UP] },
 	{ "Menu-Page-Down", (int *)&ImmediateInputState.key[KEY_MENU_PAGE_DOWN] },
+	{ "Menu-Home", (int *)&ImmediateInputState.key[KEY_MENU_HOME] },
+	{ "Menu-End", (int *)&ImmediateInputState.key[KEY_MENU_END] },
 	{ "Menu-Zoom-In", (int *)&ImmediateInputState.key[KEY_MENU_ZOOM_IN] },
 	{ "Menu-Zoom-Out", (int *)&ImmediateInputState.key[KEY_MENU_ZOOM_OUT] },
 	{ "Menu-Delete", (int *)&ImmediateInputState.key[KEY_MENU_DELETE] },
+	{ "Menu-Backspace", (int *)&ImmediateInputState.key[KEY_MENU_BACKSPACE] },
+	{ "Menu-Edit-Cancel", (int *)&ImmediateInputState.key[KEY_MENU_EDIT_CANCEL] },
+	{ "Menu-Search", (int *)&ImmediateInputState.key[KEY_MENU_SEARCH] },
+	{ "Menu-Next", (int *)&ImmediateInputState.key[KEY_MENU_NEXT] },
 	{ "Player-1-Thrust", (int *)&ImmediateInputState.key[KEY_P1_THRUST] },
 	{ "Player-1-Left", (int *)&ImmediateInputState.key[KEY_P1_LEFT] },
 	{ "Player-1-Right", (int *)&ImmediateInputState.key[KEY_P1_RIGHT] },
@@ -152,6 +159,13 @@ initKeyConfig(void) {
 	exit (EXIT_FAILURE);
 }
 
+static void
+resetKeyboardState (void)
+{
+	memset (kbdstate, 0, sizeof (kbdstate));
+	ImmediateInputState.key[KEY_CHARACTER] = 0;
+}
+
 int 
 TFB_InitInput (int driver, int flags)
 {
@@ -184,6 +198,7 @@ TFB_InitInput (int driver, int flags)
 	}
 
 	_in_character_mode = FALSE;
+	resetKeyboardState ();
 
 	/* Prepare the Virtual Controller system. */
 	VControl_Init ();
@@ -204,34 +219,43 @@ TFB_UninitInput (void)
 	VControl_Uninit ();
 }
 
+// XXX: not currently used -- character mode is always on
 void
 EnableCharacterMode (void)
 {
 	kbdhead = kbdtail = 0;
+	lastchar = 0;
 	_in_character_mode = TRUE;
 	VControl_ResetInput ();
-	
 }
 
+// XXX: not currently used -- character mode is always on
 void
 DisableCharacterMode (void)
 {
 	VControl_ResetInput ();
 	_in_character_mode = FALSE;
 	kbdhead = kbdtail = 0;
+	lastchar = 0;
 }
 
-UNICODE
-GetCharacter (void)
+wchar_t
+GetNextCharacter (void)
 {
-	UNICODE result;
-	while (kbdhead == kbdtail)
-		TaskSwitch ();
+	wchar_t result;
+	if (kbdhead == kbdtail)
+		return 0;
 	result = kbdbuf[kbdhead];
 	kbdhead = (kbdhead + 1) & (KBDBUFSIZE - 1);
 	return result;
 }	
 
+wchar_t
+GetLastCharacter (void)
+{
+	return lastchar;
+}	
+
 volatile int MouseButtonDown = 0;
 
 void
@@ -252,34 +276,47 @@ ProcessMouseEvent (const SDL_Event *e)
 
 
 void
-ProcessInputEvent(const SDL_Event *Event)
+ProcessInputEvent (const SDL_Event *Event)
 {
 	if (!InputInitialized)
 		return;
-	ProcessMouseEvent (Event);
-	if (!_in_character_mode)
-	{
-		VControl_HandleEvent (Event);
-	}
-	else
-	{
-		SDLKey k = Event->key.keysym.sym;
-		UNICODE map_key;
-		if (Event->type != SDL_KEYDOWN)
-			return;
-		if (!Event->key.keysym.unicode &&
-				(k == SDLK_CAPSLOCK ||
-				k == SDLK_NUMLOCK))
-			return;
-		if (Event->key.keysym.unicode != 0)
-			map_key = (UNICODE) Event->key.keysym.unicode;
-		else
-			map_key = KBDToUNICODE(k);
 	
-		kbdbuf[kbdtail] = map_key;
-		kbdtail = (kbdtail + 1) & (KBDBUFSIZE - 1);
-		if (kbdtail == kbdhead)
-			kbdhead = (kbdhead + 1) & (KBDBUFSIZE - 1);
+	ProcessMouseEvent (Event);
+	VControl_HandleEvent (Event);
+
+	{	// process character input event, if any
+		SDLKey k = Event->key.keysym.sym;
+		wchar_t map_key = Event->key.keysym.unicode;
+
+		if (Event->type == SDL_KEYDOWN)
+		{
+			// dont care about the non-printable, non-char
+			if (!map_key)
+				return;
+
+			kbdstate[k]++;
+			ImmediateInputState.key[KEY_CHARACTER]++;
+			
+			lastchar = map_key;
+			kbdbuf[kbdtail] = map_key;
+			kbdtail = (kbdtail + 1) & (KBDBUFSIZE - 1);
+			if (kbdtail == kbdhead)
+				kbdhead = (kbdhead + 1) & (KBDBUFSIZE - 1);
+		}
+		else if (Event->type == SDL_KEYUP)
+		{
+			if (kbdstate[k] == 0)
+			{	// something is fishy -- better to reset the
+				// repeatable state to avoid big problems
+				ImmediateInputState.key[KEY_CHARACTER] = 0;
+			}
+			else
+			{
+				kbdstate[k]--;
+				if (ImmediateInputState.key[KEY_CHARACTER] > 0)
+					ImmediateInputState.key[KEY_CHARACTER]--;
+			}
+		}
 	}
 }
 
@@ -287,6 +324,10 @@ void
 TFB_ResetControls (void)
 {
 	VControl_ResetInput ();
+	resetKeyboardState ();
+	// flush character buffer
+	kbdhead = kbdtail = 0;
+	lastchar = 0;
 }
 
 void
@@ -296,140 +337,4 @@ FlushInput (void)
 	FlushInputState ();
 }
 
-// Translates from SDLKeys to values defined in inplib.h
-UNICODE
-KBDToUNICODE (UWORD SK_in)
-{
-	switch (SK_in)
-	{
-		case SDLK_KP_ENTER:
-		case SDLK_RETURN:
-			return '\n';
-		case SDLK_KP4:
-		case SDLK_LEFT:
-			return (SK_LF_ARROW);
-		case SDLK_KP6:
-		case SDLK_RIGHT:
-			return (SK_RT_ARROW);
-		case SDLK_KP8:
-		case SDLK_UP:
-			return (SK_UP_ARROW);
-		case SDLK_KP2:
-		case SDLK_DOWN:
-			return (SK_DN_ARROW);
-		case SDLK_KP7:
-		case SDLK_HOME:
-			return (SK_HOME);
-		case SDLK_KP9:
-		case SDLK_PAGEUP:
-			return (SK_PAGE_UP);
-		case SDLK_KP1:
-		case SDLK_END:
-			return (SK_END);
-		case SDLK_KP3:
-		case SDLK_PAGEDOWN:
-			return (SK_PAGE_DOWN);
-		case SDLK_KP0:
-		case SDLK_INSERT:
-			return (SK_INSERT);
-		case SDLK_KP_PERIOD:
-		case SDLK_DELETE:
-			return (SK_DELETE);
-		case SDLK_KP_PLUS:
-			return (SK_KEYPAD_PLUS);
-		case SDLK_KP_MINUS:
-			return (SK_KEYPAD_MINUS);
-		case SDLK_LSHIFT:
-			return (SK_LF_SHIFT);
-		case SDLK_RSHIFT:
-			return (SK_RT_SHIFT);
-		case SDLK_LCTRL:
-			return (SK_LF_CTL);
-		case SDLK_RCTRL:
-			return (SK_RT_CTL);
-		case SDLK_LALT:
-			return (SK_LF_ALT);
-		case SDLK_RALT:
-			return (SK_RT_ALT);
-		case SDLK_F1:
-		case SDLK_F2:
-		case SDLK_F3:
-		case SDLK_F4:
-		case SDLK_F5:
-		case SDLK_F6:
-		case SDLK_F7:
-		case SDLK_F8:
-		case SDLK_F9:
-		case SDLK_F10:
-		case SDLK_F11:
-		case SDLK_F12:
-			return ((UNICODE) ((SK_in - SDLK_F1) + SK_F1));
-		default:
-			return (UNICODE)SK_in;
-	}
-}
-
-// Translates from values defined in inplib.h to SDLKey values
-UWORD
-UNICODEToKBD (UNICODE which_key)
-{
-	switch (which_key)
-	{
-		case '\r':
-		case '\n':
-			return SDLK_RETURN;
-		case SK_LF_ARROW:
-			return SDLK_LEFT;
-		case SK_RT_ARROW:
-			return SDLK_RIGHT;
-		case SK_UP_ARROW:
-			return SDLK_UP;
-		case SK_DN_ARROW:
-			return SDLK_DOWN;
-		case SK_HOME:
-			return SDLK_HOME;
-		case SK_PAGE_UP:
-			return SDLK_PAGEUP;
-		case SK_END:
-			return SDLK_END;
-		case SK_PAGE_DOWN:
-			return SDLK_PAGEDOWN;
-		case SK_INSERT:
-			return SDLK_INSERT;
-		case SK_DELETE:
-			return SDLK_DELETE;
-		case SK_KEYPAD_PLUS:
-			return SDLK_KP_PLUS;
-		case SK_KEYPAD_MINUS:
-			return SDLK_KP_MINUS;
-		case SK_LF_SHIFT:
-			return SDLK_LSHIFT;
-		case SK_RT_SHIFT:
-			return SDLK_RSHIFT;
-		case SK_LF_CTL:
-			return SDLK_LCTRL;
-		case SK_RT_CTL:
-			return SDLK_RCTRL;
-		case SK_LF_ALT:
-			return SDLK_LALT;
-		case SK_RT_ALT:
-			return SDLK_RALT;
-		case SK_F1:
-		case SK_F2:
-		case SK_F3:
-		case SK_F4:
-		case SK_F5:
-		case SK_F6:
-		case SK_F7:
-		case SK_F8:
-		case SK_F9:
-		case SK_F10:
-		case SK_F11:
-		case SK_F12:
-			return (which_key - SK_F1) + SDLK_F1;
-		default:
-			return which_key;
-	}
-}
-
 #endif
