@@ -18,23 +18,17 @@
  * API is heavily influenced by SDL_sound.
  */
 
-#ifdef WIN32
-#include <io.h>
-#include <fcntl.h>
-#endif
-
 #include <string.h>
 #include <stdlib.h>
 #include "port.h"
 #include "libs/misc.h"
+#include "libs/file.h"
 #include "decoder.h"
 #include "wav.h"
 #include "dukaud.h"
 #include "modaud.h"
 #include "oggaud.h"
 
-extern bool fileExists2(uio_DirHandle *dir, const char *fileName);
-		// Can't '#include "libs/file.h"' due to some type conflicts.
 
 #define MAX_REG_DECODERS 31
 
