@@ -20,7 +20,7 @@
 
 /*==============================================================================
 
-  $Id: mikmod.h,v 1.3 2005/04/23 23:57:17 meep-eep Exp $
+  $Id: mikmod.h,v 1.4 2005/11/07 04:55:03 avolkov Exp $
 
   MikMod sound library include file
 
@@ -31,8 +31,6 @@
 
 #include <stdio.h>
 #include <stdlib.h>
-#include "port.h"
-#include "libs/uio.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -326,8 +324,8 @@ typedef struct SAMPLE {
 
 /* Sample functions */
 
-MIKMODAPI extern SAMPLE *Sample_Load(uio_DirHandle*,CHAR*);
-MIKMODAPI extern SAMPLE *Sample_LoadFP(uio_Stream*);
+MIKMODAPI extern SAMPLE *Sample_Load(CHAR*);
+MIKMODAPI extern SAMPLE *Sample_LoadFP(FILE*);
 MIKMODAPI extern SAMPLE *Sample_LoadGeneric(MREADER*);
 MIKMODAPI extern void   Sample_Free(SAMPLE*);
 MIKMODAPI extern SBYTE  Sample_Play(SAMPLE*,ULONG,UBYTE);
@@ -523,17 +521,10 @@ MIKMODAPI extern struct MLOADER load_xm;  /* FastTracker 2 (by Triton) */
  *	========== Module player
  */
 
-/* SDL_RWops compatability */
-#ifdef USE_RWOPS
-#include "port.h"
-#include SDL_INCLUDE(SDL_rwops.h)
-MIKMODAPI extern MODULE* Player_LoadRW(SDL_RWops*,int,BOOL);
-#endif /* USE_RWOPS */
-/* End SDL_RWops compatability */
-MIKMODAPI extern MODULE* Player_Load(uio_DirHandle *, CHAR*,int,BOOL);
-MIKMODAPI extern MODULE* Player_LoadFP(uio_Stream*,int,BOOL);
+MIKMODAPI extern MODULE* Player_Load(CHAR*,int,BOOL);
+MIKMODAPI extern MODULE* Player_LoadFP(FILE*,int,BOOL);
 MIKMODAPI extern MODULE* Player_LoadGeneric(MREADER*,int,BOOL);
-MIKMODAPI extern CHAR*   Player_LoadTitle(uio_DirHandle*,CHAR*);
+MIKMODAPI extern CHAR*   Player_LoadTitle(CHAR*);
 MIKMODAPI extern void    Player_Free(MODULE*);
 MIKMODAPI extern void    Player_Start(MODULE*);
 MIKMODAPI extern BOOL    Player_Active(void);
