@@ -25,10 +25,14 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include <time.h>
+#ifdef __unix__
+#	include <sys/wait.h>
+#endif
 
 #include "debug.h"
 #include "uioport.h"
 #include "io.h"
+#include "utils.h"
 #include "types.h"
 #include "mem.h"
 #include "uioutils.h"
@@ -58,6 +62,7 @@ void unInitRepository(void);
 
 static int debugCmdCat(DebugContext *debugContext, int argc, char *argv[]);
 static int debugCmdCd(DebugContext *debugContext, int argc, char *argv[]);
+static int debugCmdExec(DebugContext *debugContext, int argc, char *argv[]);
 static int debugCmdExit(DebugContext *debugContext, int argc, char *argv[]);
 static int debugCmdLs(DebugContext *debugContext, int argc, char *argv[]);
 static int debugCmdMem(DebugContext *debugContext, int argc, char *argv[]);
@@ -87,6 +92,7 @@ debugMountOne(uio_Repository *destRep, const char *mountPoint,
 DebugCommand debugCommands[] = {
 	{ "cat", debugCmdCat },
 	{ "cd", debugCmdCd },
+	{ "exec", debugCmdExec },
 	{ "exit", debugCmdExit },
 	{ "fwritetest", debugCmdFwriteTest },
 	{ "ls", debugCmdLs },
@@ -129,11 +135,11 @@ debugMountOne(uio_Repository *destRep, const char *mountPoint,
 	mountHandle = uio_mountDir(destRep, mountPoint, fsType, sourceDir,
 			sourcePath, inPath, autoMount, flags, relative);
 	if (mountHandle == NULL) {
-		int saveErrno = errno;
+		int savedErrno = errno;
 		fprintf(stderr, "Could not mount '%s' and graft '%s' from that "
 				"into the repository at '%s': %s\n",
 				sourcePath, inPath, mountPoint, strerror(errno));
-		errno = saveErrno;
+		errno = savedErrno;
 	}
 	return mountHandle;
 }
@@ -208,9 +214,15 @@ initRepository(void) {
 			uio_closeDir(rootDir);
 		}
 	}
+	mountHandles[8] = debugMountOne(repository, "/tmp/",
+			uio_FSTYPE_STDIO, NULL, NULL, "/tmp/", autoMount,
+			uio_MOUNT_TOP, NULL);
+
+#if 1
 	mountHandles[8] = debugMountOne(repository, "/root/root/",
 			uio_FSTYPE_STDIO, NULL, NULL, "/", autoMount,
 			uio_MOUNT_TOP | uio_MOUNT_RDONLY, NULL);
+#endif
 
 }
 
@@ -293,27 +305,27 @@ makeArgs(char *lineBuf, int *argc, char ***argv) {
 
 	numArg = 0;
 	ptr = lineBuf;
-	while(1) {
-		while (isspace(*ptr))
+	while(true) {
+		while (isspace((int) *ptr))
 			ptr++;
 		if (*ptr == '\0')
 			break;
 		numArg++;
-		while (!isspace(*ptr))
+		while (!isspace((int) *ptr))
 			ptr++;
 	}
 
 	args = uio_malloc((numArg + 1) * sizeof (char *));
 	numArg = 0;
 	ptr = lineBuf;
-	while(1) {
-		while (isspace(*ptr))
+	while(true) {
+		while (isspace((int) *ptr))
 			ptr++;
 		if (*ptr == '\0')
 			break;
 		args[numArg] = ptr;
 		numArg++;
-		while (!isspace(*ptr))
+		while (!isspace((int) *ptr))
 			ptr++;
 		if (*ptr == '\0')
 			break;
@@ -424,6 +436,131 @@ debugCmdCd(DebugContext *debugContext, int argc, char *argv[]) {
 	return 0;
 }
 
+static int
+debugCmdExec(DebugContext *debugContext, int argc, char *argv[]) {
+	int i;
+	const char **newArgs;
+	int errCode = 0;
+	uio_StdioAccessHandle **handles;
+	uio_DirHandle *tempDir;
+
+	if (argc < 2) {
+		fprintf(debugContext->err, "Invalid number of arguments.\n");
+		return 1;
+	}
+
+	tempDir = uio_openDirRelative(debugContext->cwd, "/tmp", 0);
+	if (tempDir == 0) {
+		fprintf(debugContext->err, "Could not open temp dir: %s.\n",
+				strerror(errno));
+		return 1;
+	}
+
+	newArgs = uio_malloc(argc * sizeof (char *));
+	newArgs[0] = argv[1];
+	handles = uio_malloc(argc * sizeof (uio_StdioAccessHandle *));
+	handles[0] = NULL;
+	
+	for (i = 2; i < argc; i++) {
+#if 0
+		if (argv[i][0] == '-') {
+			// Don't try to parse arguments that start with '-'.
+			// They are probably option flags.
+			newArgs[i - 1] = argv[i];
+		}
+#endif
+		handles[i - 1] = uio_getStdioAccess(debugContext->cwd, argv[i],
+				O_RDONLY, tempDir);
+		if (handles[i - 1] == NULL) {
+			if (errno == ENOENT) {
+				// No match; we keep what's typed litterally.
+				newArgs[i - 1] = argv[i];
+				continue;
+			}
+
+			// error
+			fprintf(debugContext->err,
+					"Cannot execute: Cannot get stdio access to %s: %s.\n",
+					argv[i], strerror(errno));
+			errCode = 1;
+			argc = i + 1;
+			goto err;
+		}
+
+		newArgs[i - 1] = uio_StdioAccessHandle_getPath(handles[i - 1]);
+	}
+	newArgs[argc - 1] = NULL;
+
+	fprintf(debugContext->err, "Executing: %s", newArgs[0]);
+	for (i = 1; i < argc - 1; i++)
+		fprintf(debugContext->err, " %s", newArgs[i]);
+	fprintf(debugContext->err, "\n");
+
+#ifdef __unix__
+	{
+		pid_t pid;
+		
+		pid = fork();
+		switch (pid) {
+			case -1:
+				fprintf(debugContext->err, "Error: fork() failed: %s.\n",
+						strerror(errno));
+				break;
+			case 0:
+				// child
+				execvp(newArgs[0], (char * const *) newArgs);
+				fprintf(debugContext->err, "Error: execvp() failed: %s.\n",
+						strerror(errno));
+				_exit(EXIT_FAILURE);
+				break;
+			default: {
+				// parent
+				int status;
+				pid_t retVal;
+
+				while (1) {
+					retVal = waitpid(pid, &status, 0);
+					if (retVal != -1)
+						break;
+					if (errno != EINTR) {
+						fprintf(debugContext->err, "Error: waitpid() "
+								"failed: %s\n", strerror(errno));
+						break;
+					}
+				}
+				if (retVal == -1)
+					break;
+
+				if (WIFEXITED(status)) {
+					fprintf(debugContext->err, "Exit status: %d\n",
+							WEXITSTATUS(status));
+				} else if (WIFSIGNALED(status)) {
+					fprintf(debugContext->err, "Terminated on signal %d.\n",
+							WTERMSIG(status));
+				} else {
+					fprintf(debugContext->err, "Error: weird exit status.\n");
+				}
+				break;
+			}
+		}
+	}
+#else
+	fprintf(debugContext->err, "Cannot execute: not supported on this "
+			"platform.\n");
+#endif
+
+err:
+	for (i = 1; i < argc - 1; i++) {
+		if (handles[i] != NULL)
+			uio_releaseStdioAccess(handles[i]);
+	}
+	uio_free(handles);
+	uio_free((void *) newArgs);
+	uio_closeDir(tempDir);
+
+	return errCode;
+}
+
 static int
 debugCmdExit(DebugContext *debugContext, int argc, char *argv[]) {
 	debugContext->exit = true;
@@ -709,11 +846,11 @@ debugCmdStat(DebugContext *debugContext, int argc, char *argv[]) {
 	
 	if (uio_stat(debugContext->cwd, argv[1], &statBuf) == -1) {
 		// errno is set
-		int saveErrno;
-		saveErrno = errno;
+		int savedErrno;
+		savedErrno = errno;
 		fprintf(debugContext->err, "Could not stat file: %s\n",
 				strerror(errno));
-		errno = saveErrno;
+		errno = savedErrno;
 		return 1;
 	}
 
