@@ -117,6 +117,9 @@ uio_closeRepository(uio_Repository *repository) {
  *                inPath - the location relative to the root of the newly
  *                		mounted fileSystem, pointing to the directory
  *                      that is to be grafted.
+ *                      Note: If fsType is uio_FSTYPE_STDIO, inPath is
+ *                      relative to the root of the filesystem, NOT to
+ *                      the current working dir.
  *                autoMount - array of automount options in function
  *                		in this mountPoint.
  *                flags - one of uio_MOUNT_TOP, uio_MOUNT_BOTTOM,
@@ -372,6 +375,8 @@ uio_rename(uio_DirHandle *oldDir, const char *oldPath,
 	}
 
 	if (uio_mountInfoIsReadOnly(oldReadMountInfo)) {
+		// XXX: Doesn't uio_getPhysicalAccess already handle this?
+		//      It doesn't return EROFS though; perhaps it should.
 		uio_PDirHandle_unref(oldPReadDir);
 		uio_PDirHandle_unref(newPReadDir);
 		uio_PDirHandle_unref(newPWriteDir);
@@ -391,7 +396,7 @@ uio_rename(uio_DirHandle *oldDir, const char *oldPath,
 		return -1;
 	}
 	retVal = (oldReadMountInfo->pDirHandle->pRoot->handler->rename)(
-			oldPReadDir, oldName, newPReadDir, newName);
+			oldPReadDir, oldName, newPWriteDir, newName);
 	if (retVal == -1) {
 		int savedErrno = errno;
 		uio_PDirHandle_unref(oldPReadDir);
