@@ -32,6 +32,7 @@
 #include "resinst.h"
 #include "save.h"
 #include "settings.h"
+#include "gameopt.h"
 #include "setup.h"
 #include "sounds.h"
 #include "util.h"
@@ -46,11 +47,6 @@
 #include <string.h>
 
 
-//Added by Chris
-
-void ConfirmSaveLoad (STAMP *MsgStamp);
-
-//End Added by Chris
 static void DrawMeleeShipStrings (PMELEE_STATE pMS, BYTE NewStarShip);
 
 
@@ -142,10 +138,19 @@ PMELEE_STATE volatile pMeleeState;
 static BOOLEAN DoMelee (PMELEE_STATE pMS);
 static BOOLEAN DoEdit (PMELEE_STATE pMS);
 static BOOLEAN DoPickShip (PMELEE_STATE pMS);
-static void DrawTeamString (PMELEE_STATE pMS, COUNT HiLiteState);
+
+#define DTSHS_NORMAL   0
+#define DTSHS_EDIT     1
+#define DTSHS_SELECTED 2
+#define DTSHS_REPAIR   4
+#define DTSHS_BLOCKCUR 8
+
+static BOOLEAN DrawTeamString (PMELEE_STATE pMS, COUNT HiLiteState);
+
 static BOOLEAN DoLoadTeam (PMELEE_STATE pMS);
 static void DrawFileStrings (PMELEE_STATE pMS, int HiLiteState);
 
+
 static void
 DrawMeleeIcon (COUNT which_icon)
 {
@@ -314,7 +319,7 @@ RepairMeleeFrame (PRECT pRect)
 					DrawShipBox (pMeleeState, FALSE);
 			}
 
-			DrawTeamString (pMeleeState, 0);
+			DrawTeamString (pMeleeState, DTSHS_NORMAL);
 		}
 		pMeleeState->side = old_side;
 		pMeleeState->row = old_row;
@@ -330,7 +335,7 @@ RepairMeleeFrame (PRECT pRect)
 	SetContext (OldContext);
 }
 
-static void
+static BOOLEAN
 DrawTeamString (PMELEE_STATE pMS, COUNT HiLiteState)
 {
 	RECT r;
@@ -341,15 +346,12 @@ DrawTeamString (PMELEE_STATE pMS, COUNT HiLiteState)
 			+ ((MELEE_BOX_HEIGHT + MELEE_BOX_SPACE) * NUM_MELEE_ROWS + 2));
 	r.extent.width = NUM_MELEE_COLUMNS * (MELEE_BOX_WIDTH + MELEE_BOX_SPACE);
 	r.extent.height = 13;
-	if (HiLiteState == 4)
+	if (HiLiteState == DTSHS_REPAIR)
 	{
 		RepairMeleeFrame (&r);
-		return;
+		return (TRUE);
 	}
 		
-	if (HiLiteState & 1)
-		r.extent.width -= 29;
-
 	SetContextFont (MicroFont);
 
 	lfText.pStr = pMS->TeamImage[pMS->side].TeamName;
@@ -357,55 +359,75 @@ DrawTeamString (PMELEE_STATE pMS, COUNT HiLiteState)
 
 	lfText.baseline.x = r.corner.x + 1;
 	lfText.align = ALIGN_LEFT;
-	lfText.CharCount = wstrlen (lfText.pStr); // (COUNT)~0;
+	lfText.CharCount = strlen (lfText.pStr);
 
 	BatchGraphics ();
-	if (!(HiLiteState & 1))
-	{
+	if (!(HiLiteState & DTSHS_EDIT))
+	{	// normal or selected state
 		TEXT rtText;
-		UNICODE buf[10];
+		UNICODE buf[30];
 
-		wsprintf (buf, "%d", pMS->star_bucks[pMS->side]);
+		sprintf (buf, "%d", pMS->star_bucks[pMS->side]);
 		rtText.pStr = buf;
 		rtText.align = ALIGN_RIGHT;
 		rtText.CharCount = (COUNT)~0;
 		rtText.baseline.y = lfText.baseline.y;
 		rtText.baseline.x = lfText.baseline.x + r.extent.width - 1;
 
-		SetContextForeGroundColor (HiLiteState == 0
+		SetContextForeGroundColor (!(HiLiteState & DTSHS_SELECTED)
 				? TEAM_NAME_TEXT_COLOR : TEAM_NAME_EDIT_TEXT_COLOR);
 		font_DrawText (&lfText);
 		font_DrawText (&rtText);
 	}
 	else
-	{
+	{	// editing state
 		COUNT i;
 		RECT text_r;
 		BYTE char_deltas[MAX_TEAM_CHARS];
 		PBYTE pchar_deltas;
 
+		// not drawing team bucks
+		r.extent.width -= 29;
+
 		TextRect (&lfText, &text_r, char_deltas);
+		if ((text_r.extent.width + 2) >= r.extent.width)
+		{	// the text does not fit the input box size and so
+			// will not fit when displayed later
+			UnbatchGraphics ();
+			// disallow the change
+			return (FALSE);
+		}
 
 		text_r = r;
 		SetContextForeGroundColor (TEAM_NAME_EDIT_RECT_COLOR);
 		DrawFilledRectangle (&text_r);
 
+		// calculate the cursor position and draw it
 		pchar_deltas = char_deltas;
 		for (i = pMS->CurIndex; i > 0; --i)
 			text_r.corner.x += (SIZE)*pchar_deltas++;
-		if (pMS->CurIndex < lfText.CharCount) /* end of line */
+		if (pMS->CurIndex < lfText.CharCount) /* cursor mid-line */
 			--text_r.corner.x;
-		text_r.extent.width = 1;
-#if 0
-		/* Code for keyboardless systems */
-		else
-		{
-			if (pMS->CurIndex == lfText.CharCount) /* end of line */
+		if (HiLiteState & DTSHS_BLOCKCUR)
+		{	// Use block cursor for keyboardless systems
+			if (pMS->CurIndex == lfText.CharCount)
+			{	// cursor at end-line -- use insertion point
 				text_r.extent.width = 1;
+			}
+			else if (pMS->CurIndex + 1 == lfText.CharCount)
+			{	// extra pixel for last char margin
+				text_r.extent.width = (SIZE)*pchar_deltas + 2;
+			}
 			else
-				text_r.extent.width = (SIZE)*pchar_deltas;
+			{	// normal mid-line char
+				text_r.extent.width = (SIZE)*pchar_deltas + 1;
+			}
 		}
-#endif
+		else
+		{	// Insertion point cursor
+			text_r.extent.width = 1;
+		}
+		// position cursor within input field rect
 		++text_r.corner.x;
 		++text_r.corner.y;
 		text_r.extent.height -= 2;
@@ -416,6 +438,8 @@ DrawTeamString (PMELEE_STATE pMS, COUNT HiLiteState)
 		font_DrawText (&lfText);
 	}
 	UnbatchGraphics ();
+
+	return (TRUE);
 }
 
 static void
@@ -484,7 +508,7 @@ Deselect (BYTE opt)
 				if (pMeleeState->row < NUM_MELEE_ROWS)
 					DrawShipBox (pMeleeState, FALSE);
 				else if (pMeleeState->CurIndex == (BYTE)~0)
-					DrawTeamString (pMeleeState, 0);
+					DrawTeamString (pMeleeState, DTSHS_NORMAL);
 			}
 			else if (pMeleeState->InputFunc == DoPickShip)
 			{
@@ -530,7 +554,7 @@ Select (BYTE opt)
 				if (pMeleeState->row < NUM_MELEE_ROWS)
 					DrawShipBox (pMeleeState, TRUE);
 				else if (pMeleeState->CurIndex == (BYTE)~0)
-					DrawTeamString (pMeleeState, 2);
+					DrawTeamString (pMeleeState, DTSHS_SELECTED);
 			}
 			else if (pMeleeState->InputFunc == DoPickShip)
 			{
@@ -789,7 +813,7 @@ DrawFileStrings (PMELEE_STATE pMS, int HiLiteState)
 		font_DrawText (&Text);
 
 		rtText.baseline.y = Text.baseline.y;
-		wsprintf (buf, "%d", GetTeamValue (&pMS->FileList[bot]));
+		sprintf (buf, "%d", GetTeamValue (&pMS->FileList[bot]));
 		rtText.CharCount = (COUNT)~0;
 		font_DrawText (&rtText);
 	}
@@ -831,7 +855,7 @@ DrawFileStrings (PMELEE_STATE pMS, int HiLiteState)
 					font_DrawText (&Text);
 
 					rtText.baseline.y = Text.baseline.y;
-					wsprintf (buf, "%d", GetTeamValue (&pMS->FileList[bot - top]));
+					sprintf (buf, "%d", GetTeamValue (&pMS->FileList[bot - top]));
 					rtText.CharCount = (COUNT)~0;
 					font_DrawText (&rtText);
 				}
@@ -992,88 +1016,6 @@ DoLoadTeam (PMELEE_STATE pMS)
 	return (TRUE);
 }
 
-// XXX: TODO: to be merged with DoTextEntry in gameopt.c
-static UWORD
-DoTextEntry (PMELEE_STATE pMS)
-{
-	UWORD ch;
-	UNICODE *pStr, *pBaseStr;
-	COUNT len, max_chars;
-	BOOLEAN left = FALSE, right = FALSE;
-
-	if (pMS->MeleeOption == EDIT_MELEE)
-	{
-		pBaseStr = pMS->TeamImage[pMS->side].TeamName;
-		max_chars = MAX_TEAM_CHARS;
-	}
-	else
-	{
-		// Should not happen. Satisfying compiler.
-		return 0;
-	}
-
-	ch = GetCharacter ();
-
-	pStr = &pBaseStr[pMS->CurIndex];
-	len = wstrlen (pStr);
-	switch (ch)
-	{
-	case SK_DELETE:
-		if (len)
-		{
-			memmove (pStr, pStr + 1, len * sizeof (*pStr));
-			len = (COUNT)~0;
-		}
-		break;
-	case '\b':
-		if (pMS->CurIndex)
-		{
-			memmove (pStr - 1, pStr, (len + 1) * sizeof (*pStr));
-			--pMS->CurIndex;
-			
-			len = (COUNT)~0;
-		}
-		break;
-	case SK_LF_ARROW:
-		left = TRUE;
-		break;
-	case SK_RT_ARROW:
-		right = TRUE;
-		break;
-	default:
-		if (isprint (ch) && (len + pStr - pBaseStr < (int)(max_chars)))
-		{
-			memmove (pStr + 1, pStr, (len + 1) * sizeof (*pStr));
-			*pStr++ = ch;
-			++pMS->CurIndex;
-			
-			len = (COUNT)~0;
-		}
-		break;
-	}
-
-	if (len == (COUNT)~0)
-		DrawTeamString (pMS, 1);
-	else if (left)
-	{
-		if (pMS->CurIndex)
-		{
-			--pMS->CurIndex;
-			DrawTeamString (pMS, 1);
-		}
-	}
-	else if (right)
-	{
-		if (len)
-		{
-			++pMS->CurIndex;
-			DrawTeamString (pMS, 1);
-		}
-	}
-
-	return (ch);
-}
-
 static int
 WriteTeamImage (TEAM_IMAGE *pTI, uio_Stream *save_fp)
 {
@@ -1102,11 +1044,21 @@ GetNewList:
 
 		if (status == -1)
 		{
-			DeleteResFile (meleeDir, file);
+			BOOLEAN deleteStatus;
+
+			fprintf (stderr, "Could not load '%s'\n", file);
+
+			deleteStatus = DeleteResFile (meleeDir, file);
+			if (deleteStatus == FALSE)
+			{
+				// XXX: see bug #823
+				fprintf (stderr, "FATAL: Could not delete '%s'\n", file);
+				abort ();
+			}
 			goto GetNewList;
 		}
 
-		if (pbuf && wstricmp (file, pbuf) == 0)
+		if (pbuf && stricmp (file, pbuf) == 0)
 		{
 			pMS->CurIndex = GetDirEntryTableIndex (pMS->TeamDE) + NUM_PREBUILT;
 			pbuf = 0;
@@ -1189,7 +1141,7 @@ DeleteCurrentShip (PMELEE_STATE pMS)
 	GetShipBox (&r, pMS->side, pMS->row, pMS->col);
 	RepairMeleeFrame (&r);
 
-	DrawTeamString (pMS, 4);
+	DrawTeamString (pMS, DTSHS_REPAIR);
 	UnlockMutex (GraphicsLock);
 
 }
@@ -1209,6 +1161,24 @@ AdvanceCursor (PMELEE_STATE pMS)
 	}
 }
 
+static BOOLEAN
+OnTeamNameChange (PTEXTENTRY_STATE pTES)
+{
+	PMELEE_STATE pMS = (PMELEE_STATE) pTES->CbParam;
+	BOOLEAN ret;
+	COUNT hl = DTSHS_EDIT;
+
+	pMS->CurIndex = pTES->CursorPos;
+	if (pTES->JoystickMode)
+		hl |= DTSHS_BLOCKCUR;
+
+	LockMutex (GraphicsLock);
+	ret = DrawTeamString (pMS, hl);
+	UnlockMutex (GraphicsLock);
+
+	return ret;
+}
+
 static BOOLEAN
 DoEdit (PMELEE_STATE pMS)
 {
@@ -1261,32 +1231,34 @@ DoEdit (PMELEE_STATE pMS)
 
 		if (row == NUM_MELEE_ROWS)
 		{
-			if (pMS->CurIndex != (BYTE)~0)
-			{
-				UNICODE ch;
-				LockMutex (GraphicsLock);
-				if (pMS->Initialized == 1)
-				{
-					FlushInput ();
-					pMS->Initialized = 2;
-				}
-				else if (((ch = DoTextEntry (pMS)) == '\n') || (ch == '\r'))
-				{
-					pMS->CurIndex = (BYTE)~0;
-					DrawTeamString (pMS, 4);
-					pMS->Initialized = 1;
-					DisableCharacterMode ();
-				}
-				UnlockMutex (GraphicsLock);
-				return (TRUE);
-			}
-			else if (PulsedInputState.key[KEY_MENU_SELECT])
+			if (PulsedInputState.key[KEY_MENU_SELECT])
 			{
+				TEXTENTRY_STATE tes;
+
+				// going to enter text
+				// XXX: CurIndex is abused here; DrawTeamString expects
+				//   CurIndex to contain the current cursor position
 				pMS->CurIndex = 0;
 				LockMutex (GraphicsLock);
-				DrawTeamString (pMS, 1);
+				DrawTeamString (pMS, DTSHS_EDIT);
 				UnlockMutex (GraphicsLock);
-				EnableCharacterMode ();
+
+				tes.Initialized = FALSE;
+				tes.MenuRepeatDelay = 0;
+				tes.BaseStr = pMS->TeamImage[pMS->side].TeamName;
+				tes.CursorPos = 0;
+				tes.MaxSize = MAX_TEAM_CHARS + 1;
+				tes.CbParam = pMS;
+				tes.ChangeCallback = OnTeamNameChange;
+				tes.FrameCallback = 0;
+				DoTextEntry (&tes);
+				
+				// done entering
+				pMS->CurIndex = (BYTE)~0;
+				LockMutex (GraphicsLock);
+				DrawTeamString (pMS, DTSHS_REPAIR);
+				UnlockMutex (GraphicsLock);
+				
 				return (TRUE);
 			}
 		}
@@ -1407,7 +1379,7 @@ DoPickShip (PMELEE_STATE pMS)
 
 			pMS->TeamImage[pMS->side].ShipList[pMS->row][pMS->col] = pMS->CurIndex;
 			LockMutex (GraphicsLock);
-			DrawTeamString (pMS, 4);
+			DrawTeamString (pMS, DTSHS_REPAIR);
 			DrawShipBox (pMS, FALSE);
 			UnlockMutex (GraphicsLock);
 			AdvanceCursor (pMS);
@@ -1564,7 +1536,7 @@ BuildAndDrawShipList (PMELEE_STATE pMS)
 		RECT r;
 		TEXT t;
 		STAMP s;
-		UNICODE buf[10];
+		UNICODE buf[30];
 
 		side = !i;
 
@@ -1593,7 +1565,7 @@ BuildAndDrawShipList (PMELEE_STATE pMS)
 				MAKE_RGB15 (0xA, 0xA, 0x1F), 0x9));
 		font_DrawText (&t);
 
-		wsprintf (buf, "%d", pMS->star_bucks[i]);
+		sprintf (buf, "%d", pMS->star_bucks[i]);
 		t.baseline.x = 4;
 		t.baseline.y = 7;
 		t.align = ALIGN_LEFT;
@@ -1662,7 +1634,7 @@ DoMelee (PMELEE_STATE pMS)
 			DestroyMusic (pMS->hMusic);
 			pMS->hMusic = 0;
 		}
-		pMS->hMusic = LoadMusicFile ("melee/melemenu.ogg");
+		pMS->hMusic = LoadMusicInstance (MELEE_MUSIC);
 		pMS->Initialized = TRUE;
 		
 		pMS->MeleeOption = START_MELEE;
@@ -1841,7 +1813,9 @@ DoMelee (PMELEE_STATE pMS)
 static void
 InitPreBuilt (PMELEE_STATE pMS)
 {
-	wstrcpy (pMS->PreBuiltList[0].TeamName, GAME_STRING (MELEE_STRING_BASE + 4));
+	utf8StringCopy (pMS->PreBuiltList[0].TeamName,
+			sizeof (pMS->PreBuiltList[0].TeamName),
+			GAME_STRING (MELEE_STRING_BASE + 4));
 	pMS->PreBuiltList[0].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[0].ShipList[0][1] = MELEE_CHMMR;
 	pMS->PreBuiltList[0].ShipList[0][2] = MELEE_DRUUGE;
@@ -1857,7 +1831,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[0].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[0].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[1].TeamName, GAME_STRING (MELEE_STRING_BASE + 5));
+	utf8StringCopy (pMS->PreBuiltList[1].TeamName,
+			sizeof (pMS->PreBuiltList[1].TeamName),
+			GAME_STRING (MELEE_STRING_BASE + 5));
 	pMS->PreBuiltList[1].ShipList[0][0] = MELEE_ARILOU;
 	pMS->PreBuiltList[1].ShipList[0][1] = MELEE_CHENJESU;
 	pMS->PreBuiltList[1].ShipList[0][2] = MELEE_EARTHLING;
@@ -1873,7 +1849,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[1].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[1].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[2].TeamName, GAME_STRING (MELEE_STRING_BASE + 6));
+	utf8StringCopy (pMS->PreBuiltList[2].TeamName,
+			sizeof (pMS->PreBuiltList[2].TeamName),
+			GAME_STRING (MELEE_STRING_BASE + 6));
 	pMS->PreBuiltList[2].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[2].ShipList[0][1] = MELEE_CHMMR;
 	pMS->PreBuiltList[2].ShipList[0][2] = MELEE_DRUUGE;
@@ -1889,7 +1867,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[2].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[2].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[3].TeamName, GAME_STRING (MELEE_STRING_BASE + 7));
+	utf8StringCopy (pMS->PreBuiltList[3].TeamName,
+			sizeof (pMS->PreBuiltList[3].TeamName),
+			GAME_STRING (MELEE_STRING_BASE + 7));
 	pMS->PreBuiltList[3].ShipList[0][0] = MELEE_CHENJESU;
 	pMS->PreBuiltList[3].ShipList[0][1] = MELEE_CHENJESU;
 	pMS->PreBuiltList[3].ShipList[0][2] = MELEE_CHMMR;
@@ -1905,7 +1885,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[3].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[3].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[4].TeamName, GAME_STRING (MELEE_STRING_BASE + 8));
+	utf8StringCopy (pMS->PreBuiltList[4].TeamName,
+			sizeof (pMS->PreBuiltList[4].TeamName),
+			GAME_STRING (MELEE_STRING_BASE + 8));
 	pMS->PreBuiltList[4].ShipList[0][0] = MELEE_URQUAN;
 	pMS->PreBuiltList[4].ShipList[0][1] = MELEE_CHENJESU;
 	pMS->PreBuiltList[4].ShipList[0][2] = MELEE_MYCON;
@@ -1921,7 +1903,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[4].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[4].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[5].TeamName, "Ford's Fighters");
+	utf8StringCopy (pMS->PreBuiltList[5].TeamName,
+			sizeof (pMS->PreBuiltList[5].TeamName),
+			"Ford's Fighters");
 	pMS->PreBuiltList[5].ShipList[0][0] = MELEE_CHMMR;
 	pMS->PreBuiltList[5].ShipList[0][1] = MELEE_ZOQFOTPIK;
 	pMS->PreBuiltList[5].ShipList[0][2] = MELEE_MELNORME;
@@ -1937,7 +1921,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[5].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[5].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[6].TeamName, "Leyland's Lashers");
+	utf8StringCopy (pMS->PreBuiltList[6].TeamName,
+			sizeof (pMS->PreBuiltList[6].TeamName),
+			"Leyland's Lashers");
 	pMS->PreBuiltList[6].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[6].ShipList[0][1] = MELEE_EARTHLING;
 	pMS->PreBuiltList[6].ShipList[0][2] = MELEE_MYCON;
@@ -1953,7 +1939,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[6].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[6].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[7].TeamName, "The Gregorizers 200");
+	utf8StringCopy (pMS->PreBuiltList[7].TeamName,
+			sizeof (pMS->PreBuiltList[7].TeamName),
+			"The Gregorizers 200");
 	pMS->PreBuiltList[7].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[7].ShipList[0][1] = MELEE_CHMMR;
 	pMS->PreBuiltList[7].ShipList[0][2] = MELEE_DRUUGE;
@@ -1969,7 +1957,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[7].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[7].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[8].TeamName, "300 point Armada!");
+	utf8StringCopy (pMS->PreBuiltList[8].TeamName,
+			sizeof (pMS->PreBuiltList[8].TeamName),
+			"300 point Armada!");
 	pMS->PreBuiltList[8].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[8].ShipList[0][1] = MELEE_CHMMR;
 	pMS->PreBuiltList[8].ShipList[0][2] = MELEE_CHENJESU;
@@ -1985,7 +1975,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[8].ShipList[1][5] = MELEE_URQUAN;
 	pMS->PreBuiltList[8].ShipList[1][6] = MELEE_YEHAT;
 
-	wstrcpy (pMS->PreBuiltList[9].TeamName, "Little Dudes with Attitudes");
+	utf8StringCopy (pMS->PreBuiltList[9].TeamName,
+			sizeof (pMS->PreBuiltList[9].TeamName),
+			"Little Dudes with Attitudes");
 	pMS->PreBuiltList[9].ShipList[0][0] = MELEE_UMGAH;
 	pMS->PreBuiltList[9].ShipList[0][1] = MELEE_THRADDASH;
 	pMS->PreBuiltList[9].ShipList[0][2] = MELEE_SHOFIXTI;
@@ -2001,7 +1993,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[9].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[9].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[10].TeamName, "New Alliance Ships");
+	utf8StringCopy (pMS->PreBuiltList[10].TeamName,
+			sizeof (pMS->PreBuiltList[10].TeamName),
+			"New Alliance Ships");
 	pMS->PreBuiltList[10].ShipList[0][0] = MELEE_ARILOU;
 	pMS->PreBuiltList[10].ShipList[0][1] = MELEE_CHMMR;
 	pMS->PreBuiltList[10].ShipList[0][2] = MELEE_EARTHLING;
@@ -2017,7 +2011,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[10].ShipList[1][5] = MELEE_THRADDASH;
 	pMS->PreBuiltList[10].ShipList[1][6] = MELEE_SPATHI;
 
-	wstrcpy (pMS->PreBuiltList[11].TeamName, "Old Alliance Ships");
+	utf8StringCopy (pMS->PreBuiltList[11].TeamName,
+			sizeof (pMS->PreBuiltList[11].TeamName),
+			"Old Alliance Ships");
 	pMS->PreBuiltList[11].ShipList[0][0] = MELEE_ARILOU;
 	pMS->PreBuiltList[11].ShipList[0][1] = MELEE_CHENJESU;
 	pMS->PreBuiltList[11].ShipList[0][2] = MELEE_EARTHLING;
@@ -2033,7 +2029,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[11].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[11].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[12].TeamName, "Old Hierarchy Ships");
+	utf8StringCopy (pMS->PreBuiltList[12].TeamName,
+			sizeof (pMS->PreBuiltList[12].TeamName),
+			"Old Hierarchy Ships");
 	pMS->PreBuiltList[12].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[12].ShipList[0][1] = MELEE_ILWRATH;
 	pMS->PreBuiltList[12].ShipList[0][2] = MELEE_MYCON;
@@ -2049,7 +2047,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[12].ShipList[1][5] = (BYTE)~0;
 	pMS->PreBuiltList[12].ShipList[1][6] = (BYTE)~0;
 
-	wstrcpy (pMS->PreBuiltList[13].TeamName, "Star Control 1");
+	utf8StringCopy (pMS->PreBuiltList[13].TeamName,
+			sizeof (pMS->PreBuiltList[13].TeamName),
+			"Star Control 1");
 	pMS->PreBuiltList[13].ShipList[0][0] = MELEE_ANDROSYNTH;
 	pMS->PreBuiltList[13].ShipList[0][1] = MELEE_ARILOU;
 	pMS->PreBuiltList[13].ShipList[0][2] = MELEE_CHENJESU;
@@ -2065,7 +2065,9 @@ InitPreBuilt (PMELEE_STATE pMS)
 	pMS->PreBuiltList[13].ShipList[1][5] = MELEE_VUX;
 	pMS->PreBuiltList[13].ShipList[1][6] = MELEE_YEHAT;
 
-	wstrcpy (pMS->PreBuiltList[14].TeamName, "Star Control 2");
+	utf8StringCopy (pMS->PreBuiltList[14].TeamName,
+			sizeof (pMS->PreBuiltList[14].TeamName),
+			"Star Control 2");
 	pMS->PreBuiltList[14].ShipList[0][0] = MELEE_CHMMR;
 	pMS->PreBuiltList[14].ShipList[0][1] = MELEE_DRUUGE;
 	pMS->PreBuiltList[14].ShipList[0][2] = MELEE_KOHR_AH;
