@@ -20,6 +20,7 @@
 #include "controls.h"
 #include "options.h"
 #include "setup.h"
+#include "gamestr.h"
 #include "libs/graphics/gfx_common.h"
 #include "libs/tasklib.h"
 
@@ -57,76 +58,8 @@ DrawPCMenuFrame (RECT *r)
 #define ALT_MANIFEST 0x80
 #define ALT_EXIT_MENU0 0x81
 
-/* Define all menu text.  There is 1 item for each PM_* enum*/
-static char menu_string[][11]  = {
-		"scan",
-		"starmap",
-		"devices",
-		"cargo",
-		"roster",
-		"game",
-		"navigate",
-
-		"mineral",
-		"energy",
-		"biological",
-		"exit menu",
-		"autoscan",
-		"dispatch",
-
-		"save game",
-		"load game",
-		"quit game",
-		"settings",
-		"exit menu",
-
-		"converse",
-		"attack!",
-		"game",
-
-		"fuel",
-		"module",
-		"game",
-		"exit menu",
-
-		"crew",
-		"game",
-		"exit menu",
-
-		"sound",
-		"music",
-		"cyborg",
-		"captain",
-		"flagship",
-		"exit menu",
-		"",
-		"",
-		"",
-		"",
-		"",
-//PM_QUIT
-		"no, play!",
-		"yes, quit!",
-//PM_ALTSCAN
-		"scan",
-		"starmap",
-		"manifest",
-		"game",
-		"navigate",
-//PM_ALTERNATE_2
-		"cargo",
-		"devices",
-		"roster",
-		"exit menu",
-//PM_ALTERNATE3 replaces PM_MIN_SCAN
-		"mineral",
-		"energy",
-		"biological",
-		"autoscan",
-		"dispatch",
-		"exit menu"
-
-	};
+static UNICODE pm_crew_str[128];
+static UNICODE pm_fuel_str[128];
 
 /* Actually display the menu text */
 static void
@@ -138,7 +71,8 @@ DrawPCMenu (BYTE beg_index, BYTE end_index, BYTE NewState, BYTE hilite, RECT *r)
 	int num_items;
 	FONT OldFont;
 	TEXT t;
-	UNICODE buf[40];
+	UNICODE buf[256];
+
 	pos = beg_index + NewState;
 	num_items = 1 + end_index - beg_index;
 	r->corner.x -= 1;
@@ -161,7 +95,10 @@ DrawPCMenu (BYTE beg_index, BYTE end_index, BYTE NewState, BYTE hilite, RECT *r)
 	SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x15, 0x15), 0x08));
 	for (i = beg_index; i <= end_index; i++)
 	{
-		wsprintf (buf, menu_string[i]);
+		utf8StringCopy (buf, sizeof (buf),
+						(i == PM_FUEL) ? pm_fuel_str :
+						(i == PM_CREW) ? pm_crew_str :
+						GAME_STRING (MAINMENU_STRING_BASE + i));
 		if (hilite && pos == i)
 		{
 			SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x0A, 0x0A, 0x1F), 0x08));
@@ -539,9 +476,13 @@ DrawMenuStateStrings (BYTE beg_index, SWORD NewState)
 	if (s.frame && optWhichMenu == OPT_PC)
 	{
 		if (beg_index == PM_CREW)
-			sprintf (menu_string[PM_CREW], "crew(%d)", GLOBAL (CrewCost));
+			sprintf (pm_crew_str, "%s(%d)",
+					 GAME_STRING (MAINMENU_STRING_BASE + PM_CREW),
+					 GLOBAL (CrewCost));
 		if (beg_index == PM_FUEL)
-			sprintf (menu_string[PM_FUEL], "fuel(%d)", GLOBAL (FuelCost));
+			sprintf (pm_fuel_str, "%s(%d)",
+					 GAME_STRING (MAINMENU_STRING_BASE + PM_FUEL),
+					 GLOBAL (FuelCost));
 		if (beg_index == PM_SOUND_ON)
 		{
 			end_index = beg_index + 5;
@@ -607,7 +548,7 @@ DrawMenuStateStrings (BYTE beg_index, SWORD NewState)
 		switch (beg_index + NewState)
 		{
 			TEXT t;
-			UNICODE buf[4];
+			UNICODE buf[20];
 
 			case PM_CREW:
 				t.baseline.x = s.origin.x + RADAR_WIDTH - 2;
@@ -615,7 +556,7 @@ DrawMenuStateStrings (BYTE beg_index, SWORD NewState)
 				t.align = ALIGN_RIGHT;
 				t.CharCount = (COUNT)~0;
 				t.pStr = buf;
-				wsprintf (buf, "%u", GLOBAL (CrewCost));
+				sprintf (buf, "%u", GLOBAL (CrewCost));
 				SetContextFont (TinyFont);
 				SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x1F, 0x00), 0x02));
 				font_DrawText (&t);
@@ -626,7 +567,7 @@ DrawMenuStateStrings (BYTE beg_index, SWORD NewState)
 				t.align = ALIGN_RIGHT;
 				t.CharCount = (COUNT)~0;
 				t.pStr = buf;
-				wsprintf (buf, "%u", GLOBAL (FuelCost));
+				sprintf (buf, "%u", GLOBAL (FuelCost));
 				SetContextFont (TinyFont);
 				SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x1F, 0x00), 0x02));
 				font_DrawText (&t);
