@@ -212,7 +212,7 @@ GetMeleeStarShip (STARSHIPPTR LastStarShipPtr, COUNT which_player)
 {
 	COUNT ships_left;
 	TEXT t;
-	UNICODE buf[10];
+	UNICODE buf[40];
 	STAMP s;
 	CONTEXT OldContext;
 	GETMELEE_STATE gmstate;
@@ -237,8 +237,6 @@ GetMeleeStarShip (STARSHIPPTR LastStarShipPtr, COUNT which_player)
 			StarShipPtr = LockStarShip (&race_q[which_player], hBattleShip);
 			if (StarShipPtr == LastStarShipPtr)
 			{
-				extern FRAME status;
-
 				LastStarShipPtr->RaceResIndex = 0;
 
 				gmstate.col = LastStarShipPtr->ShipFacing;
@@ -246,7 +244,7 @@ GetMeleeStarShip (STARSHIPPTR LastStarShipPtr, COUNT which_player)
 					+ ((ICON_WIDTH + 2) * (gmstate.col % NUM_MELEE_COLS_ORIG));
 				s.origin.y = 9
 					+ ((ICON_HEIGHT + 2) * (gmstate.col / NUM_MELEE_COLS_ORIG));
-				s.frame = SetAbsFrameIndex (status, 3);
+				s.frame = SetAbsFrameIndex (StatusFrame, 3);
 				DrawStamp (&s);
 				s.frame = SetAbsFrameIndex (PickMeleeFrame, which_player);
 			}
@@ -268,7 +266,7 @@ GetMeleeStarShip (STARSHIPPTR LastStarShipPtr, COUNT which_player)
 		SetContextForeGroundColor (PICK_BG_COLOR);
 		DrawFilledRectangle (&gmstate.flash_rect);
 
-		wsprintf (buf, "%d", cur_bucks);
+		sprintf (buf, "%d", cur_bucks);
 		t.baseline.y = 7;
 		t.align = ALIGN_RIGHT;
 		t.pStr = buf;
@@ -301,18 +299,19 @@ GetMeleeStarShip (STARSHIPPTR LastStarShipPtr, COUNT which_player)
 		SetContext (OldContext);
 		UnlockMutex (GraphicsLock);
 
-		PressState = AnyButtonPress (TRUE);
+		PressState = PulsedInputState.key[KEY_MENU_SELECT] || PulsedInputState.key[KEY_MENU_CANCEL];
 		do
 		{
-			ButtonState = AnyButtonPress (TRUE);
+			UpdateInputState ();
+			ButtonState = PulsedInputState.key[KEY_MENU_SELECT] || PulsedInputState.key[KEY_MENU_CANCEL];
 			if (PressState)
 			{
 				PressState = ButtonState;
 				ButtonState = FALSE;
 			}
-		} while (!ButtonState
+		} while (!(GLOBAL (CurrentActivity) & CHECK_ABORT) && (!ButtonState
 				&& (!(PlayerControl[0] & PlayerControl[1] & PSYTRON_CONTROL)
-				|| (TaskSwitch (), GetTimeCounter ()) < TimeOut));
+				|| (TaskSwitch (), GetTimeCounter ()) < TimeOut)));
 
 		LockMutex (GraphicsLock);
 
@@ -344,7 +343,7 @@ GetMeleeStarShip (STARSHIPPTR LastStarShipPtr, COUNT which_player)
 
 	UnlockMutex (GraphicsLock);
 	ResetKeyRepeat ();
-	DoInput ((PVOID)&gmstate, TRUE);
+	DoInput ((PVOID)&gmstate, FALSE);
 
 	LockMutex (GraphicsLock);
 	SetFlashRect (NULL_PTR, (FRAME)0);
