@@ -218,15 +218,15 @@ ChangeSelection:
 
 			if (crew_level)
 			{
-				char buf[20];
+				char buf[80];
 
 				t.baseline.x = r.corner.x + (r.extent.width >> 1);
 				t.pStr = buf;
 				t.CharCount = (COUNT)~0;
 				if (crew_level >= max_crew)
-					wsprintf (buf, "%u", crew_level);
+					sprintf (buf, "%u", crew_level);
 				else
-					wsprintf (buf, "%u/%u", crew_level, max_crew);
+					sprintf (buf, "%u/%u", crew_level, max_crew);
 				SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x14, 0x00), 0x02));
 				font_DrawText (&t);
 			}
@@ -272,7 +272,7 @@ OldContext = SetContext (SpaceContext);
 		UnlockMutex (GraphicsLock);
 		pMenuState = &MenuState;
 		SetMenuSounds (MENU_SOUND_ARROWS, MENU_SOUND_SELECT);
-		DoInput ((PVOID)&MenuState, TRUE);
+		DoInput ((PVOID)&MenuState, FALSE);
 		pMenuState = 0;
 		LockMutex (GraphicsLock);
 
@@ -507,11 +507,9 @@ SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x12, 0x12, 0x12), 0x17));
 				DrawStamp (&s);
 				if (StarShipPtr->RaceResIndex == 0)
 				{
-					extern FRAME status;
-					
 					/* Dead ship - mark with an X. */
 					s.origin.x -= 1;
-					s.frame = SetAbsFrameIndex (status, 3);
+					s.frame = SetAbsFrameIndex (StatusFrame, 3);
 					DrawStamp (&s);
 				}
 			}
