@@ -19,25 +19,24 @@
 #include "colors.h"
 #include "controls.h"
 #include "gamestr.h"
+#include "shipcont.h"
 #include "setup.h"
 #include "sounds.h"
 #include "util.h"
 
 
-void DrawCargoStrings (BYTE OldElement, BYTE NewElement);
-
 void
 ShowRemainingCapacity (void)
 {
 	RECT r;
 	TEXT rt;
 	CONTEXT OldContext;
-	UNICODE rt_amount_buf[10];
+	UNICODE rt_amount_buf[40];
 
 	OldContext = SetContext (StatusContext);
 	SetContextFont (TinyFont);
 
-	wsprintf (rt_amount_buf, "%u",
+	sprintf (rt_amount_buf, "%u",
 			GetSBayCapacity (NULL_PTR)
 			- GLOBAL_SIS (TotalElementMass));
 	rt.baseline.x = 59;
@@ -68,7 +67,7 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 	TEXT rt;
 	RECT r;
 	CONTEXT OldContext;
-	UNICODE rt_amount_buf[10];
+	UNICODE rt_amount_buf[40];
 
 	LockMutex (GraphicsLock);
 
@@ -84,7 +83,6 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 	if (OldElement > NUM_ELEMENT_CATEGORIES)
 	{
 		STAMP s;
-		extern FRAME misc_data;
 
 		r.corner.x = 2;
 		r.extent.width = FIELD_WIDTH + 1;
@@ -118,7 +116,7 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 
 		s.origin.x = r.corner.x + (r.extent.width >> 1);
 		s.frame = SetAbsFrameIndex (
-				misc_data,
+				MiscDataFrame,
 				(NUM_SCANDOT_TRANSITIONS << 1) + 3
 				);
 		cy = y;
@@ -152,14 +150,14 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 
 				SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0xA, 0xA, 0x1F), 0x09));
 				rt.baseline.x = 32;
-				wsprintf (rt_amount_buf, "%u",
+				sprintf (rt_amount_buf, "%u",
 						GLOBAL (ElementWorth[OldElement]));
 				rt.CharCount = (COUNT)~0;
 				font_DrawText (&rt);
 
 				SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x14, 0x14), 0x03));
 				rt.baseline.x = 58;
-				wsprintf (rt_amount_buf, "%u",
+				sprintf (rt_amount_buf, "%u",
 						GLOBAL_SIS (ElementAmounts[OldElement]));
 				rt.CharCount = (COUNT)~0;
 				font_DrawText (&rt);
@@ -182,7 +180,7 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 
 		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x14, 0x14), 0x03));
 		rt.baseline.x = 58;
-		wsprintf (rt_amount_buf, "%u", GLOBAL_SIS (TotalBioMass));
+		sprintf (rt_amount_buf, "%u", GLOBAL_SIS (TotalBioMass));
 		rt.CharCount = (COUNT)~0;
 		font_DrawText (&rt);
 
@@ -224,15 +222,15 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 		rt.baseline.y = cy;
 
 		if (OldElement == NUM_ELEMENT_CATEGORIES)
-			wsprintf (rt_amount_buf, "%u", GLOBAL_SIS (TotalBioMass));
+			sprintf (rt_amount_buf, "%u", GLOBAL_SIS (TotalBioMass));
 		else
 		{
 			SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0xA, 0xA, 0x1F), 0x09));
 			rt.baseline.x = 32;
-			wsprintf (rt_amount_buf, "%u", GLOBAL (ElementWorth[OldElement]));
+			sprintf (rt_amount_buf, "%u", GLOBAL (ElementWorth[OldElement]));
 			rt.CharCount = (COUNT)~0;
 			font_DrawText (&rt);
-			wsprintf (rt_amount_buf, "%u", GLOBAL_SIS (ElementAmounts[OldElement]));
+			sprintf (rt_amount_buf, "%u", GLOBAL_SIS (ElementAmounts[OldElement]));
 		}
 
 		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x14, 0x14), 0x03));
@@ -254,15 +252,15 @@ DrawCargoStrings (BYTE OldElement, BYTE NewElement)
 		rt.baseline.y = cy;
 
 		if (NewElement == NUM_ELEMENT_CATEGORIES)
-			wsprintf (rt_amount_buf, "%u", GLOBAL_SIS (TotalBioMass));
+			sprintf (rt_amount_buf, "%u", GLOBAL_SIS (TotalBioMass));
 		else
 		{
 			SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x14, 0x14), 0x03));
 			rt.baseline.x = 32;
-			wsprintf (rt_amount_buf, "%u", GLOBAL (ElementWorth[NewElement]));
+			sprintf (rt_amount_buf, "%u", GLOBAL (ElementWorth[NewElement]));
 			rt.CharCount = (COUNT)~0;
 			font_DrawText (&rt);
-			wsprintf (rt_amount_buf, "%u", GLOBAL_SIS (ElementAmounts[NewElement]));
+			sprintf (rt_amount_buf, "%u", GLOBAL_SIS (ElementAmounts[NewElement]));
 		}
 
 		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0xA, 0x1F, 0x1F), 0x0B));
