@@ -21,10 +21,13 @@
 #include "gamestr.h"
 #include "controls.h"
 #include "settings.h"
+#include "shipcont.h"
+#include "load.h"
 #include "setup.h"
 #include "state.h"
 #include "sounds.h"
 #include "util.h"
+#include "strlib.h"
 
 
 // If DEBUG_DEVICES is defined, the device list shown in the game will
@@ -32,18 +35,6 @@
 // devices the player actually possesses.
 //#define DEBUG_DEVICES
 
-static COUNT
-lpstrchr (const UNICODE *pStr, UNICODE ch)
-{
-	COUNT skip_chars;
-
-	skip_chars = 0;
-	while (*pStr++ != ch)
-		++skip_chars;
-
-	return (skip_chars);
-}
-
 static void
 DrawDevices (PMENU_STATE pMS, BYTE OldDevice, BYTE NewDevice)
 {
@@ -70,7 +61,6 @@ DrawDevices (PMENU_STATE pMS, BYTE OldDevice, BYTE NewDevice)
 			|| NewDevice >= (BYTE)(pMS->first_item.y + MAX_VIS_DEVICES))))
 	{
 		STAMP s;
-		extern FRAME misc_data;
 
 		r.corner.x = 2;
 		r.extent.width = FIELD_WIDTH + 1;
@@ -124,7 +114,7 @@ DrawDevices (PMENU_STATE pMS, BYTE OldDevice, BYTE NewDevice)
 				++OldDevice)
 		{
 			s.frame = SetAbsFrameIndex (
-					misc_data, 77 + pDeviceMap[OldDevice]
+					MiscDataFrame, 77 + pDeviceMap[OldDevice]
 					);
 			DrawStamp (&s);
 
@@ -133,10 +123,10 @@ DrawDevices (PMENU_STATE pMS, BYTE OldDevice, BYTE NewDevice)
 				t.baseline.y = cy;
 				t.pStr = GAME_STRING (pDeviceMap[OldDevice] +
 						DEVICE_STRING_BASE + 1);
-				t.CharCount = lpstrchr (t.pStr, ' ');
+				t.CharCount = utf8StringPos (t.pStr, ' ');
 				font_DrawText (&t);
 				t.baseline.y += 7;
-				t.pStr += t.CharCount + 1;
+				t.pStr = skipUTF8Chars (t.pStr, t.CharCount + 1);
 				t.CharCount = (COUNT)~0;
 				font_DrawText (&t);
 			}
@@ -162,10 +152,10 @@ DrawDevices (PMENU_STATE pMS, BYTE OldDevice, BYTE NewDevice)
 		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x14, 0x14), 0x03));
 		t.baseline.y = cy;
 		t.pStr = GAME_STRING (pDeviceMap[OldDevice] + DEVICE_STRING_BASE + 1);
-		t.CharCount = lpstrchr (t.pStr, ' ');
+		t.CharCount = utf8StringPos (t.pStr, ' ');
 		font_DrawText (&t);
 		t.baseline.y += 7;
-		t.pStr += t.CharCount + 1;
+		t.pStr = skipUTF8Chars (t.pStr, t.CharCount + 1);
 		t.CharCount = (COUNT)~0;
 		font_DrawText (&t);
 	}
@@ -180,10 +170,10 @@ DrawDevices (PMENU_STATE pMS, BYTE OldDevice, BYTE NewDevice)
 		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0xA, 0x1F, 0x1F), 0x0B));
 		t.baseline.y = cy;
 		t.pStr = GAME_STRING (pDeviceMap[NewDevice] + DEVICE_STRING_BASE + 1);
-		t.CharCount = lpstrchr (t.pStr, ' ');
+		t.CharCount = utf8StringPos (t.pStr, ' ');
 		font_DrawText (&t);
 		t.baseline.y += 7;
-		t.pStr += t.CharCount + 1;
+		t.pStr = skipUTF8Chars (t.pStr, t.CharCount + 1);
 		t.CharCount = (COUNT)~0;
 		font_DrawText (&t);
 	}
@@ -195,7 +185,6 @@ static UWORD
 DeviceFailed (BYTE which_device)
 {
 	BYTE val;
-	extern ACTIVITY NextActivity;
 
 	switch (which_device)
 	{
