@@ -230,10 +230,7 @@ GenerateTalkingPet (BYTE control)
 
 			if (pSolarSysState->pOrbitalDesc == &pSolarSysState->PlanetDesc[0])
 			{
-				pSolarSysState->SysInfo.PlanetInfo.LanderFont =
-						CaptureFont (
-								LoadGraphic (LANDER_FONT)
-								);
+				LoadStdLanderFont (&pSolarSysState->SysInfo.PlanetInfo);
 				pSolarSysState->PlanetSideFrame[1] =
 						CaptureDrawable (
 						LoadGraphic (RUINS_MASK_PMAP_ANIM)
