@@ -221,7 +221,8 @@ generate_orbital (void)
 				pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature = 165;
 				break;
 			case 1: /* VENUS */
-				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 9000;
+				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 90 *
+						EARTH_ATMOSPHERE;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetDensity = 95;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius = 95;
 				pSolarSysState->SysInfo.PlanetInfo.AxialTilt = 177;
@@ -241,6 +242,7 @@ generate_orbital (void)
 				pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature = 22;
 				break;
 			case 3: /* MARS */
+				// XXX: Mars atmo should actually be 1/2 in current units
 				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 1;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetDensity = 72;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius = 53;
@@ -251,7 +253,7 @@ generate_orbital (void)
 				pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature = -53;
 				break;
 			case 4: /* JUPITER */
-				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 0xFFFF;
+				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = GAS_GIANT_ATMOSPHERE;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetDensity = 24;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius = 1120;
 				pSolarSysState->SysInfo.PlanetInfo.AxialTilt = 3;
@@ -262,7 +264,7 @@ generate_orbital (void)
 				pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist = EARTH_RADIUS * 520L / 100;
 				break;
 			case 5: /* SATURN */
-				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 0xFFFF;
+				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = GAS_GIANT_ATMOSPHERE;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetDensity = 13;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius = 945;
 				pSolarSysState->SysInfo.PlanetInfo.AxialTilt = 27;
@@ -273,7 +275,7 @@ generate_orbital (void)
 				pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist = EARTH_RADIUS * 952L / 100;
 				break;
 			case 6: /* URANUS */
-				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 0xFFFF;
+				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = GAS_GIANT_ATMOSPHERE;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetDensity = 21;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius = 411;
 				pSolarSysState->SysInfo.PlanetInfo.AxialTilt = 98;
@@ -284,7 +286,7 @@ generate_orbital (void)
 				pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist = EARTH_RADIUS * 1916L / 100;
 				break;
 			case 7: /* NEPTUNE */
-				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = 0xFFFF;
+				pSolarSysState->SysInfo.PlanetInfo.AtmoDensity = GAS_GIANT_ATMOSPHERE;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetDensity = 28;
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius = 396;
 				pSolarSysState->SysInfo.PlanetInfo.AxialTilt = 30;
@@ -297,10 +299,7 @@ generate_orbital (void)
 			case 8: /* PLUTO */
 				if (!GET_GAME_STATE (FOUND_PLUTO_SPATHI))
 				{
-					pSolarSysState->SysInfo.PlanetInfo.LanderFont =
-							CaptureFont (
-									LoadGraphic (LANDER_FONT)
-									);
+					LoadStdLanderFont (&pSolarSysState->SysInfo.PlanetInfo);
 					pSolarSysState->PlanetSideFrame[1] =
 							CaptureDrawable (
 							LoadGraphic (SPAPLUTO_MASK_PMAP_ANIM)
@@ -326,7 +325,8 @@ generate_orbital (void)
 		pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity =
 				CalcGravity (pSolarSysState->SysInfo.PlanetInfo.PlanetDensity,
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius);
-		LoadPlanet (i == 2);
+		LoadPlanet (i == 2 ? CaptureDrawable (LoadGraphic (EARTH_MASK_ANIM))
+				: NULL);
 	}
 	else
 	{
@@ -342,10 +342,7 @@ generate_orbital (void)
 
 				if (!GET_GAME_STATE (MOONBASE_DESTROYED))
 				{
-					pSolarSysState->SysInfo.PlanetInfo.LanderFont =
-							CaptureFont (
-									LoadGraphic (LANDER_FONT)
-									);
+					LoadStdLanderFont (&pSolarSysState->SysInfo.PlanetInfo);
 					pSolarSysState->PlanetSideFrame[1] =
 							CaptureDrawable (
 							LoadGraphic (MOONBASE_MASK_PMAP_ANIM)
@@ -421,7 +418,7 @@ generate_orbital (void)
 		pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity =
 				CalcGravity (pSolarSysState->SysInfo.PlanetInfo.PlanetDensity,
 				pSolarSysState->SysInfo.PlanetInfo.PlanetRadius);
-		LoadPlanet (FALSE);
+		LoadPlanet (NULL);
 	}
 }
 
@@ -467,7 +464,9 @@ GenerateSOL (BYTE control)
 			break;
 		case GENERATE_NAME:
 			i = pSolarSysState->pBaseDesc - pSolarSysState->PlanetDesc;
-			wstrcpy (GLOBAL_SIS (PlanetName), GAME_STRING (PLANET_NUMBER_BASE + i));
+			utf8StringCopy (GLOBAL_SIS (PlanetName),
+					sizeof (GLOBAL_SIS (PlanetName)),
+					GAME_STRING (PLANET_NUMBER_BASE + i));
 			SET_GAME_STATE (BATTLE_PLANET,
 					pSolarSysState->PlanetDesc[i].data_index);
 			break;
