@@ -77,7 +77,9 @@ GenerateSpathi (BYTE control)
 			if (pSolarSysState->pBaseDesc == &pSolarSysState->PlanetDesc[0])
 			{
 #ifdef NOTYET
-				wstrcpy (GLOBAL_SIS (PlanetName), "Spathiwa");
+				utf8StringCopy (GLOBAL_SIS (PlanetName),
+						sizeof (GLOBAL_SIS (PlanetName)),
+						"Spathiwa");
 #endif /* NOTYET */
 
 				pSolarSysState->MoonDesc[0].data_index = PELLUCID_WORLD;
@@ -94,7 +96,9 @@ GenerateSpathi (BYTE control)
 			PPLANET_DESC pMinPlanet;
 
 			pMinPlanet = &pSolarSysState->PlanetDesc[0];
-			FillOrbits (pSolarSysState->SunDesc[0].NumPlanets = 1, pMinPlanet, FALSE);
+			FillOrbits (pSolarSysState,
+					pSolarSysState->SunDesc[0].NumPlanets = 1, pMinPlanet,
+					FALSE);
 
 			pMinPlanet->radius = EARTH_RADIUS * 1150L / 100;
 			angle = ARCTAN (pMinPlanet->location.x, pMinPlanet->location.y);
@@ -194,10 +198,7 @@ GenerateSpathi (BYTE control)
 				pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature = 28;
 				if (!GET_GAME_STATE (UMGAH_BROADCASTERS))
 				{
-					pSolarSysState->SysInfo.PlanetInfo.LanderFont =
-							CaptureFont (
-									LoadGraphic (LANDER_FONT)
-									);
+					LoadStdLanderFont (&pSolarSysState->SysInfo.PlanetInfo);
 					pSolarSysState->PlanetSideFrame[1] =
 							CaptureDrawable (
 							LoadGraphic (UMGAH_BCS_MASK_PMAP_ANIM)
@@ -207,7 +208,7 @@ GenerateSpathi (BYTE control)
 									LoadStringTable (UMGAH_BCS_STRTAB)
 									);
 				}
-				LoadPlanet (FALSE);
+				LoadPlanet (NULL);
 				break;
 			}
 			else if (pSolarSysState->pOrbitalDesc == &pSolarSysState->PlanetDesc[0])
@@ -231,7 +232,7 @@ GenerateSpathi (BYTE control)
 				pSolarSysState->SysInfo.PlanetInfo.Tectonics = 0;
 				pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature = 31;
 
-				LoadPlanet (FALSE);
+				LoadPlanet (NULL);
 				break;
 			}
 		default:
