@@ -57,38 +57,38 @@ BlueDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* ULTRAMARINE_WORLD */
 		PLANET_ALWAYS, /* NOBLE_WORLD */
 		PLANET_ALWAYS, /* AZURE_WORLD */
-		PLANET_NEVER, /* CHONDRITE_WORLD */
-		PLANET_NEVER, /* PURPLE_WORLD */
-		PLANET_NEVER, /* SUPER_DENSE_WORLD */
-		PLANET_NEVER, /* PELLUCID_WORLD */
-		PLANET_NEVER, /* DUST_WORLD */
-		PLANET_NEVER, /* CRIMSON_WORLD */
-		PLANET_NEVER, /* CIMMERIAN_WORLD */
-		PLANET_NEVER, /* INFRARED_WORLD */
+		PLANET_NEVER,  /* CHONDRITE_WORLD */
+		PLANET_NEVER,  /* PURPLE_WORLD */
+		PLANET_NEVER,  /* SUPER_DENSE_WORLD */
+		PLANET_NEVER,  /* PELLUCID_WORLD */
+		PLANET_NEVER,  /* DUST_WORLD */
+		PLANET_NEVER,  /* CRIMSON_WORLD */
+		PLANET_NEVER,  /* CIMMERIAN_WORLD */
+		PLANET_NEVER,  /* INFRARED_WORLD */
 		PLANET_ALWAYS, /* SELENIC_WORLD */
 		PLANET_ALWAYS, /* AURIC_WORLD */
 
 		PLANET_ALWAYS, /* FLUORESCENT_WORLD */
 		PLANET_ALWAYS, /* ULTRAVIOLET_WORLD */
 		PLANET_ALWAYS, /* PLUTONIC_WORLD */
-		PLANET_NEVER, /* RAINBOW_WORLD */
-		PLANET_NEVER, /* CRACKED_WORLD */
+		PLANET_NEVER,  /* RAINBOW_WORLD */
+		PLANET_NEVER,  /* CRACKED_WORLD */
 		PLANET_ALWAYS, /* SAPPHIRE_WORLD */
 		PLANET_ALWAYS, /* ORGANIC_WORLD */
 		PLANET_ALWAYS, /* XENOLITHIC_WORLD */
 		PLANET_ALWAYS, /* REDUX_WORLD */
 		PLANET_ALWAYS, /* PRIMORDIAL_WORLD */
-		PLANET_NEVER, /* EMERALD_WORLD */
+		PLANET_NEVER,  /* EMERALD_WORLD */
 		PLANET_ALWAYS, /* CHLORINE_WORLD */
 		PLANET_ALWAYS, /* MAGNETIC_WORLD */
 		PLANET_ALWAYS, /* WATER_WORLD */
 		PLANET_ALWAYS, /* TELLURIC_WORLD */
-		PLANET_NEVER, /* HYDROCARBON_WORLD */
-		PLANET_NEVER, /* IODINE_WORLD */
-		PLANET_NEVER, /* VINYLOGOUS_WORLD */
-		PLANET_NEVER, /* RUBY_WORLD */
-		PLANET_NEVER, /* MAGMA_WORLD */
-		PLANET_NEVER, /* MAROON_WORLD */
+		PLANET_NEVER,  /* HYDROCARBON_WORLD */
+		PLANET_NEVER,  /* IODINE_WORLD */
+		PLANET_NEVER,  /* VINYLOGOUS_WORLD */
+		PLANET_NEVER,  /* RUBY_WORLD */
+		PLANET_NEVER,  /* MAGMA_WORLD */
+		PLANET_NEVER,  /* MAROON_WORLD */
 
 		PLANET_ALWAYS, /* BLU_GAS_GIANT */
 		PLANET_ALWAYS, /* CYA_GAS_GIANT */
@@ -109,8 +109,8 @@ GreenDistribution (BYTE which_world)
 {
 	BYTE PlanetDistribution[NUMBER_OF_PLANET_TYPES] =
 	{
-		PLANET_NEVER, /* OOLITE_WORLD */
-		PLANET_NEVER, /* YTTRIC_WORLD */
+		PLANET_NEVER,  /* OOLITE_WORLD */
+		PLANET_NEVER,  /* YTTRIC_WORLD */
 		PLANET_ALWAYS, /* QUASI_DEGENERATE_WORLD */
 		PLANET_ALWAYS, /* LANTHANIDE_WORLD */
 		PLANET_ALWAYS, /* TREASURE_WORLD */
@@ -132,19 +132,19 @@ GreenDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* PURPLE_WORLD */
 		PLANET_ALWAYS, /* SUPER_DENSE_WORLD */
 		PLANET_ALWAYS, /* PELLUCID_WORLD */
-		PLANET_NEVER, /* DUST_WORLD */
-		PLANET_NEVER, /* CRIMSON_WORLD */
-		PLANET_NEVER, /* CIMMERIAN_WORLD */
-		PLANET_NEVER, /* INFRARED_WORLD */
+		PLANET_NEVER,  /* DUST_WORLD */
+		PLANET_NEVER,  /* CRIMSON_WORLD */
+		PLANET_NEVER,  /* CIMMERIAN_WORLD */
+		PLANET_NEVER,  /* INFRARED_WORLD */
 		PLANET_ALWAYS, /* SELENIC_WORLD */
 		PLANET_ALWAYS, /* AURIC_WORLD */
 
 		PLANET_ALWAYS, /* FLUORESCENT_WORLD */
 		PLANET_ALWAYS, /* ULTRAVIOLET_WORLD */
 		PLANET_ALWAYS, /* PLUTONIC_WORLD */
-		PLANET_NEVER, /* RAINBOW_WORLD */
-		PLANET_NEVER, /* CRACKED_WORLD */
-		PLANET_NEVER, /* SAPPHIRE_WORLD */
+		PLANET_NEVER,  /* RAINBOW_WORLD */
+		PLANET_NEVER,  /* CRACKED_WORLD */
+		PLANET_NEVER,  /* SAPPHIRE_WORLD */
 		PLANET_ALWAYS, /* ORGANIC_WORLD */
 		PLANET_ALWAYS, /* XENOLITHIC_WORLD */
 		PLANET_ALWAYS, /* REDUX_WORLD */
@@ -156,10 +156,10 @@ GreenDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* TELLURIC_WORLD */
 		PLANET_ALWAYS, /* HYDROCARBON_WORLD */
 		PLANET_ALWAYS, /* IODINE_WORLD */
-		PLANET_NEVER, /* VINYLOGOUS_WORLD */
-		PLANET_NEVER, /* RUBY_WORLD */
-		PLANET_NEVER, /* MAGMA_WORLD */
-		PLANET_NEVER, /* MAROON_WORLD */
+		PLANET_NEVER,  /* VINYLOGOUS_WORLD */
+		PLANET_NEVER,  /* RUBY_WORLD */
+		PLANET_NEVER,  /* MAGMA_WORLD */
+		PLANET_NEVER,  /* MAROON_WORLD */
 
 		PLANET_ALWAYS, /* BLU_GAS_GIANT */
 		PLANET_ALWAYS, /* CYA_GAS_GIANT */
@@ -180,16 +180,16 @@ OrangeDistribution (BYTE which_world)
 {
 	BYTE PlanetDistribution[NUMBER_OF_PLANET_TYPES] =
 	{
-		PLANET_NEVER, /* OOLITE_WORLD */
-		PLANET_NEVER, /* YTTRIC_WORLD */
-		PLANET_NEVER, /* QUASI_DEGENERATE_WORLD */
-		PLANET_NEVER, /* LANTHANIDE_WORLD */
-		PLANET_NEVER, /* TREASURE_WORLD */
+		PLANET_NEVER,  /* OOLITE_WORLD */
+		PLANET_NEVER,  /* YTTRIC_WORLD */
+		PLANET_NEVER,  /* QUASI_DEGENERATE_WORLD */
+		PLANET_NEVER,  /* LANTHANIDE_WORLD */
+		PLANET_NEVER,  /* TREASURE_WORLD */
 		PLANET_ALWAYS, /* UREA_WORLD */
-		PLANET_NEVER, /* METAL_WORLD */
+		PLANET_NEVER,  /* METAL_WORLD */
 		PLANET_ALWAYS, /* RADIOACTIVE_WORLD */
-		PLANET_NEVER, /* OPALESCENT_WORLD */
-		PLANET_NEVER, /* CYANIC_WORLD */
+		PLANET_NEVER,  /* OPALESCENT_WORLD */
+		PLANET_NEVER,  /* CYANIC_WORLD */
 		PLANET_ALWAYS, /* ACID_WORLD */
 		PLANET_ALWAYS, /* ALKALI_WORLD */
 		PLANET_ALWAYS, /* HALIDE_WORLD */
@@ -208,19 +208,19 @@ OrangeDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* CIMMERIAN_WORLD */
 		PLANET_ALWAYS, /* INFRARED_WORLD */
 		PLANET_ALWAYS, /* SELENIC_WORLD */
-		PLANET_NEVER, /* AURIC_WORLD */
+		PLANET_NEVER,  /* AURIC_WORLD */
 
-		PLANET_NEVER, /* FLUORESCENT_WORLD */
-		PLANET_NEVER, /* ULTRAVIOLET_WORLD */
-		PLANET_NEVER, /* PLUTONIC_WORLD */
-		PLANET_NEVER, /* RAINBOW_WORLD */
-		PLANET_NEVER, /* CRACKED_WORLD */
-		PLANET_NEVER, /* SAPPHIRE_WORLD */
-		PLANET_NEVER, /* ORGANIC_WORLD */
-		PLANET_NEVER, /* XENOLITHIC_WORLD */
-		PLANET_NEVER, /* REDUX_WORLD */
-		PLANET_NEVER, /* PRIMORDIAL_WORLD */
-		PLANET_NEVER, /* EMERALD_WORLD */
+		PLANET_NEVER,  /* FLUORESCENT_WORLD */
+		PLANET_NEVER,  /* ULTRAVIOLET_WORLD */
+		PLANET_NEVER,  /* PLUTONIC_WORLD */
+		PLANET_NEVER,  /* RAINBOW_WORLD */
+		PLANET_NEVER,  /* CRACKED_WORLD */
+		PLANET_NEVER,  /* SAPPHIRE_WORLD */
+		PLANET_NEVER,  /* ORGANIC_WORLD */
+		PLANET_NEVER,  /* XENOLITHIC_WORLD */
+		PLANET_NEVER,  /* REDUX_WORLD */
+		PLANET_NEVER,  /* PRIMORDIAL_WORLD */
+		PLANET_NEVER,  /* EMERALD_WORLD */
 		PLANET_ALWAYS, /* CHLORINE_WORLD */
 		PLANET_ALWAYS, /* MAGNETIC_WORLD */
 		PLANET_ALWAYS, /* WATER_WORLD */
@@ -228,7 +228,7 @@ OrangeDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* HYDROCARBON_WORLD */
 		PLANET_ALWAYS, /* IODINE_WORLD */
 		PLANET_ALWAYS, /* VINYLOGOUS_WORLD */
-		PLANET_NEVER, /* RUBY_WORLD */
+		PLANET_NEVER,  /* RUBY_WORLD */
 		PLANET_ALWAYS, /* MAGMA_WORLD */
 		PLANET_ALWAYS, /* MAROON_WORLD */
 
@@ -251,22 +251,22 @@ RedDistribution (BYTE which_world)
 {
 	BYTE PlanetDistribution[NUMBER_OF_PLANET_TYPES] =
 	{
-		PLANET_NEVER, /* OOLITE_WORLD */
-		PLANET_NEVER, /* YTTRIC_WORLD */
-		PLANET_NEVER, /* QUASI_DEGENERATE_WORLD */
-		PLANET_NEVER, /* LANTHANIDE_WORLD */
-		PLANET_NEVER, /* TREASURE_WORLD */
+		PLANET_NEVER,  /* OOLITE_WORLD */
+		PLANET_NEVER,  /* YTTRIC_WORLD */
+		PLANET_NEVER,  /* QUASI_DEGENERATE_WORLD */
+		PLANET_NEVER,  /* LANTHANIDE_WORLD */
+		PLANET_NEVER,  /* TREASURE_WORLD */
 		PLANET_ALWAYS, /* UREA_WORLD */
 		PLANET_ALWAYS, /* METAL_WORLD */
-		PLANET_NEVER, /* RADIOACTIVE_WORLD */
-		PLANET_NEVER, /* OPALESCENT_WORLD */
-		PLANET_NEVER, /* CYANIC_WORLD */
-		PLANET_NEVER, /* ACID_WORLD */
-		PLANET_NEVER, /* ALKALI_WORLD */
-		PLANET_NEVER, /* HALIDE_WORLD */
-		PLANET_NEVER, /* GREEN_WORLD */
-		PLANET_NEVER, /* COPPER_WORLD */
-		PLANET_NEVER, /* CARBIDE_WORLD */
+		PLANET_NEVER,  /* RADIOACTIVE_WORLD */
+		PLANET_NEVER,  /* OPALESCENT_WORLD */
+		PLANET_NEVER,  /* CYANIC_WORLD */
+		PLANET_NEVER,  /* ACID_WORLD */
+		PLANET_NEVER,  /* ALKALI_WORLD */
+		PLANET_NEVER,  /* HALIDE_WORLD */
+		PLANET_NEVER,  /* GREEN_WORLD */
+		PLANET_NEVER,  /* COPPER_WORLD */
+		PLANET_NEVER,  /* CARBIDE_WORLD */
 		PLANET_ALWAYS, /* ULTRAMARINE_WORLD */
 		PLANET_ALWAYS, /* NOBLE_WORLD */
 		PLANET_ALWAYS, /* AZURE_WORLD */
@@ -279,20 +279,20 @@ RedDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* CIMMERIAN_WORLD */
 		PLANET_ALWAYS, /* INFRARED_WORLD */
 		PLANET_ALWAYS, /* SELENIC_WORLD */
-		PLANET_NEVER, /* AURIC_WORLD */
+		PLANET_NEVER,  /* AURIC_WORLD */
 
-		PLANET_NEVER, /* FLUORESCENT_WORLD */
-		PLANET_NEVER, /* ULTRAVIOLET_WORLD */
-		PLANET_NEVER, /* PLUTONIC_WORLD */
-		PLANET_NEVER, /* RAINBOW_WORLD */
-		PLANET_NEVER, /* CRACKED_WORLD */
-		PLANET_NEVER, /* SAPPHIRE_WORLD */
-		PLANET_NEVER, /* ORGANIC_WORLD */
-		PLANET_NEVER, /* XENOLITHIC_WORLD */
-		PLANET_NEVER, /* REDUX_WORLD */
-		PLANET_NEVER, /* PRIMORDIAL_WORLD */
-		PLANET_NEVER, /* EMERALD_WORLD */
-		PLANET_NEVER, /* CHLORINE_WORLD */
+		PLANET_NEVER,  /* FLUORESCENT_WORLD */
+		PLANET_NEVER,  /* ULTRAVIOLET_WORLD */
+		PLANET_NEVER,  /* PLUTONIC_WORLD */
+		PLANET_NEVER,  /* RAINBOW_WORLD */
+		PLANET_NEVER,  /* CRACKED_WORLD */
+		PLANET_NEVER,  /* SAPPHIRE_WORLD */
+		PLANET_NEVER,  /* ORGANIC_WORLD */
+		PLANET_NEVER,  /* XENOLITHIC_WORLD */
+		PLANET_NEVER,  /* REDUX_WORLD */
+		PLANET_NEVER,  /* PRIMORDIAL_WORLD */
+		PLANET_NEVER,  /* EMERALD_WORLD */
+		PLANET_NEVER,  /* CHLORINE_WORLD */
 		PLANET_ALWAYS, /* MAGNETIC_WORLD */
 		PLANET_ALWAYS, /* WATER_WORLD */
 		PLANET_ALWAYS, /* TELLURIC_WORLD */
@@ -335,44 +335,44 @@ WhiteDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* ACID_WORLD */
 		PLANET_ALWAYS, /* ALKALI_WORLD */
 		PLANET_ALWAYS, /* HALIDE_WORLD */
-		PLANET_NEVER, /* GREEN_WORLD */
-		PLANET_NEVER, /* COPPER_WORLD */
-		PLANET_NEVER, /* CARBIDE_WORLD */
-		PLANET_NEVER, /* ULTRAMARINE_WORLD */
-		PLANET_NEVER, /* NOBLE_WORLD */
-		PLANET_NEVER, /* AZURE_WORLD */
-		PLANET_NEVER, /* CHONDRITE_WORLD */
-		PLANET_NEVER, /* PURPLE_WORLD */
-		PLANET_NEVER, /* SUPER_DENSE_WORLD */
-		PLANET_NEVER, /* PELLUCID_WORLD */
-		PLANET_NEVER, /* DUST_WORLD */
-		PLANET_NEVER, /* CRIMSON_WORLD */
-		PLANET_NEVER, /* CIMMERIAN_WORLD */
-		PLANET_NEVER, /* INFRARED_WORLD */
+		PLANET_NEVER,  /* GREEN_WORLD */
+		PLANET_NEVER,  /* COPPER_WORLD */
+		PLANET_NEVER,  /* CARBIDE_WORLD */
+		PLANET_NEVER,  /* ULTRAMARINE_WORLD */
+		PLANET_NEVER,  /* NOBLE_WORLD */
+		PLANET_NEVER,  /* AZURE_WORLD */
+		PLANET_NEVER,  /* CHONDRITE_WORLD */
+		PLANET_NEVER,  /* PURPLE_WORLD */
+		PLANET_NEVER,  /* SUPER_DENSE_WORLD */
+		PLANET_NEVER,  /* PELLUCID_WORLD */
+		PLANET_NEVER,  /* DUST_WORLD */
+		PLANET_NEVER,  /* CRIMSON_WORLD */
+		PLANET_NEVER,  /* CIMMERIAN_WORLD */
+		PLANET_NEVER,  /* INFRARED_WORLD */
 		PLANET_ALWAYS, /* SELENIC_WORLD */
 		PLANET_ALWAYS, /* AURIC_WORLD */
 
 		PLANET_ALWAYS, /* FLUORESCENT_WORLD */
 		PLANET_ALWAYS, /* ULTRAVIOLET_WORLD */
 		PLANET_ALWAYS, /* PLUTONIC_WORLD */
-		PLANET_NEVER, /* RAINBOW_WORLD */
-		PLANET_NEVER, /* CRACKED_WORLD */
+		PLANET_NEVER,  /* RAINBOW_WORLD */
+		PLANET_NEVER,  /* CRACKED_WORLD */
 		PLANET_ALWAYS, /* SAPPHIRE_WORLD */
 		PLANET_ALWAYS, /* ORGANIC_WORLD */
 		PLANET_ALWAYS, /* XENOLITHIC_WORLD */
 		PLANET_ALWAYS, /* REDUX_WORLD */
 		PLANET_ALWAYS, /* PRIMORDIAL_WORLD */
 		PLANET_ALWAYS, /* EMERALD_WORLD */
-		PLANET_NEVER, /* CHLORINE_WORLD */
-		PLANET_NEVER, /* MAGNETIC_WORLD */
-		PLANET_NEVER, /* WATER_WORLD */
-		PLANET_NEVER, /* TELLURIC_WORLD */
-		PLANET_NEVER, /* HYDROCARBON_WORLD */
-		PLANET_NEVER, /* IODINE_WORLD */
+		PLANET_NEVER,  /* CHLORINE_WORLD */
+		PLANET_NEVER,  /* MAGNETIC_WORLD */
+		PLANET_NEVER,  /* WATER_WORLD */
+		PLANET_NEVER,  /* TELLURIC_WORLD */
+		PLANET_NEVER,  /* HYDROCARBON_WORLD */
+		PLANET_NEVER,  /* IODINE_WORLD */
 		PLANET_ALWAYS, /* VINYLOGOUS_WORLD */
 		PLANET_ALWAYS, /* RUBY_WORLD */
-		PLANET_NEVER, /* MAGMA_WORLD */
-		PLANET_NEVER, /* MAROON_WORLD */
+		PLANET_NEVER,  /* MAGMA_WORLD */
+		PLANET_NEVER,  /* MAROON_WORLD */
 
 		PLANET_ALWAYS, /* BLU_GAS_GIANT */
 		PLANET_ALWAYS, /* CYA_GAS_GIANT */
@@ -393,10 +393,10 @@ YellowDistribution (BYTE which_world)
 {
 	BYTE PlanetDistribution[NUMBER_OF_PLANET_TYPES] =
 	{
-		PLANET_NEVER, /* OOLITE_WORLD */
-		PLANET_NEVER, /* YTTRIC_WORLD */
-		PLANET_NEVER, /* QUASI_DEGENERATE_WORLD */
-		PLANET_NEVER, /* LANTHANIDE_WORLD */
+		PLANET_NEVER,  /* OOLITE_WORLD */
+		PLANET_NEVER,  /* YTTRIC_WORLD */
+		PLANET_NEVER,  /* QUASI_DEGENERATE_WORLD */
+		PLANET_NEVER,  /* LANTHANIDE_WORLD */
 		PLANET_ALWAYS, /* TREASURE_WORLD */
 		PLANET_ALWAYS, /* UREA_WORLD */
 		PLANET_ALWAYS, /* METAL_WORLD */
@@ -423,17 +423,17 @@ YellowDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* SELENIC_WORLD */
 		PLANET_ALWAYS, /* AURIC_WORLD */
 
-		PLANET_NEVER, /* FLUORESCENT_WORLD */
-		PLANET_NEVER, /* ULTRAVIOLET_WORLD */
-		PLANET_NEVER, /* PLUTONIC_WORLD */
-		PLANET_NEVER, /* RAINBOW_WORLD */
-		PLANET_NEVER, /* CRACKED_WORLD */
-		PLANET_NEVER, /* SAPPHIRE_WORLD */
+		PLANET_NEVER,  /* FLUORESCENT_WORLD */
+		PLANET_NEVER,  /* ULTRAVIOLET_WORLD */
+		PLANET_NEVER,  /* PLUTONIC_WORLD */
+		PLANET_NEVER,  /* RAINBOW_WORLD */
+		PLANET_NEVER,  /* CRACKED_WORLD */
+		PLANET_NEVER,  /* SAPPHIRE_WORLD */
 		PLANET_ALWAYS, /* ORGANIC_WORLD */
 		PLANET_ALWAYS, /* XENOLITHIC_WORLD */
 		PLANET_ALWAYS, /* REDUX_WORLD */
 		PLANET_ALWAYS, /* PRIMORDIAL_WORLD */
-		PLANET_NEVER, /* EMERALD_WORLD */
+		PLANET_NEVER,  /* EMERALD_WORLD */
 		PLANET_ALWAYS, /* CHLORINE_WORLD */
 		PLANET_ALWAYS, /* MAGNETIC_WORLD */
 		PLANET_ALWAYS, /* WATER_WORLD */
@@ -441,7 +441,7 @@ YellowDistribution (BYTE which_world)
 		PLANET_ALWAYS, /* HYDROCARBON_WORLD */
 		PLANET_ALWAYS, /* IODINE_WORLD */
 		PLANET_ALWAYS, /* VINYLOGOUS_WORLD */
-		PLANET_NEVER, /* RUBY_WORLD */
+		PLANET_NEVER,  /* RUBY_WORLD */
 		PLANET_ALWAYS, /* MAGMA_WORLD */
 		PLANET_ALWAYS, /* MAROON_WORLD */
 
@@ -469,8 +469,8 @@ YellowDistribution (BYTE which_world)
 #define SUPERGIANT_GASG_DIST SCALE_RADIUS (33)
 
 void
-FillOrbits (BYTE NumPlanets, PPLANET_DESC pBaseDesc, BOOLEAN
-		TypesDefined)
+FillOrbits (PSOLARSYS_STATE system,
+		BYTE NumPlanets, PPLANET_DESC pBaseDesc, BOOLEAN TypesDefined)
 { /* Generate Planets in orbit around star */
 	BYTE StarColor, PlanetCount, MaxPlanet;
 	BOOLEAN GeneratingMoons;
@@ -486,13 +486,13 @@ FillOrbits (BYTE NumPlanets, PPLANET_DESC pBaseDesc, BOOLEAN
 		{SUPERGIANT_ROCK_DIST, SUPERGIANT_GASG_DIST},
 	};
 #ifdef DEBUG_ORBITS
-UNICODE buf[40];
+UNICODE buf[256];
 char stype[] = {'D', 'G', 'S'};
 char scolor[] = {'B', 'G', 'O', 'R', 'W', 'Y'};
 #endif /* DEBUG_ORBITS */
 
 	pPD = pBaseDesc;
-	StarSize = pSolarSysState->SunDesc[0].data_index;
+	StarSize = system->SunDesc[0].data_index;
 	StarColor = STAR_COLOR (CurStarDescPtr->Type);
 
 	if (NumPlanets == (BYTE)~0)
@@ -501,7 +501,7 @@ char scolor[] = {'B', 'G', 'O', 'R', 'W', 'Y'};
 		while ((NumPlanets = (BYTE)(LOWORD (TFB_Random())
 				% MAX_GENERATED_PLANETS)) == 0)
 			;
-		pSolarSysState->SunDesc[0].NumPlanets = NumPlanets;
+		system->SunDesc[0].NumPlanets = NumPlanets;
 	}
 
 #ifdef DEBUG_ORBITS
@@ -510,7 +510,7 @@ char scolor[] = {'B', 'G', 'O', 'R', 'W', 'Y'};
 			scolor[STAR_COLOR (CurStarDescPtr->Type)],
 			stype[STAR_TYPE (CurStarDescPtr->Type)]);
 #endif /* DEBUG_ORBITS */
-	GeneratingMoons = (BOOLEAN) (pBaseDesc == pSolarSysState->MoonDesc);
+	GeneratingMoons = (BOOLEAN) (pBaseDesc == system->MoonDesc);
 	if (GeneratingMoons)
 		MaxPlanet = FIRST_LARGE_ROCKY_WORLD;
 	else
@@ -530,10 +530,8 @@ char scolor[] = {'B', 'G', 'O', 'R', 'W', 'Y'};
 			if (TypesDefined)
 				rand_val = 0;
 			else
-				pPD->data_index = (BYTE)(
-						HIBYTE (LOWORD (rand_val))
-						% MaxPlanet
-						);
+				pPD->data_index =
+						(BYTE)(HIBYTE (LOWORD (rand_val)) % MaxPlanet);
 
 			chance = PLANET_NEVER;
 			switch (StarColor)
@@ -578,8 +576,8 @@ RelocatePlanet:
 		}
 		else
 		{
-			pPD->radius =  (LOWORD (rand_val)
-					% (MAX_PLANET_RADIUS - min_radius))
+			pPD->radius =
+					(LOWORD (rand_val) % (MAX_PLANET_RADIUS - min_radius))
 					+ min_radius;
 			for (pLocPD = pPD - 1; pLocPD >= pBaseDesc; --pLocPD)
 			{
@@ -594,14 +592,9 @@ RelocatePlanet:
 
 		rand_val = TFB_Random ();
 		angle = NORMALIZE_ANGLE (LOWORD (rand_val));
-		pPD->location.x =
-				COSINE (angle, pPD->radius);
-		pPD->location.y =
-				SINE (angle, pPD->radius);
-		pPD->rand_seed = MAKE_DWORD (
-				pPD->location.x,
-				pPD->location.y
-				);
+		pPD->location.x = COSINE (angle, pPD->radius);
+		pPD->location.y = SINE (angle, pPD->radius);
+		pPD->rand_seed = MAKE_DWORD (pPD->location.x, pPD->location.y);
 
 		++pPD;
 	}
