@@ -18,19 +18,16 @@
 
 #include "element.h"
 #include "scan.h"
+#include "lander.h"
 #include "settings.h"
 #include "setup.h"
+#include "uqmdebug.h"
 #include "libs/graphics/gfx_common.h"
+#include "resinst.h"
 
 
-//Added by Chris
+extern int rotate_planet_task (PVOID data);
 
-void
-DrawPlanet(int x, int y, int dy, unsigned int rgb);
-
-//End Added by Chris
-
-extern int rotate_planet_task (PVOID Blah);
 
 void
 DrawScannedObjects (BOOLEAN Reversed)
@@ -60,21 +57,97 @@ DrawScannedObjects (BOOLEAN Reversed)
 	}
 }
 
-void
-LoadPlanet (BOOLEAN IsDefined)
+typedef enum
 {
-	STAMP s;
-	LockMutex (GraphicsLock);
+	DRAW_ORBITAL_FULL,
+	DRAW_ORBITAL_WAIT,
+	DRAW_ORBITAL_UPDATE,
+
+} DRAW_ORBITAL_MODE;
+
+static void
+DrawOrbitalDisplay (DRAW_ORBITAL_MODE Mode)
+{
+	RECT r = { { SIS_ORG_X, SIS_ORG_Y }, 
+				{ SIS_SCREEN_WIDTH, SIS_SCREEN_HEIGHT } };
 
 	BatchGraphics ();
-	SetTransitionSource (NULL);
-	if (!(LastActivity & CHECK_LOAD))
+	
+	if (Mode != DRAW_ORBITAL_UPDATE)
+	{
+		SetTransitionSource (NULL);
+
+		DrawSISFrame ();
+		DrawSISMessage (NULL_PTR);
+		DrawSISTitle (GLOBAL_SIS (PlanetName));
 		DrawStarBackGround (TRUE);
+	}
+
+	SetContext (SpaceContext);
+	
+	if (Mode == DRAW_ORBITAL_WAIT)
+	{
+		STAMP s;
+
+		s.frame = CaptureDrawable (
+				LoadGraphic (ORBENTER_PMAP_ANIM));
+		s.origin.x = -SAFE_X;
+		s.origin.y = SIS_SCREEN_HEIGHT - MAP_HEIGHT;
+		DrawStamp (&s);
+		DestroyDrawable (ReleaseDrawable (s.frame));
+	}
+	else
+	{
+		DrawPlanet (SIS_SCREEN_WIDTH - MAP_WIDTH,
+				SIS_SCREEN_HEIGHT - MAP_HEIGHT, 0, 0);
+	}
+
+	if (Mode != DRAW_ORBITAL_UPDATE)
+	{
+		ScreenTransition (3, &r);
+	}
+
+	UnbatchGraphics ();
+
+	if (Mode != DRAW_ORBITAL_WAIT)
+	{
+		LoadIntoExtraScreen (&r);
+	}
+}
+
+// Initialise the surface graphics, and start the planet music.
+// Called from the GENERATE_ORBITAL case of an IP generation function
+// (when orbit is entered; either from IP, or from loading a saved game)
+// and when "starmap" is selected from orbit and then cancelled;
+// also after in-orbit comm and after defeating planet guards in combat.
+// SurfDefFrame contains surface definition images when a planet comes
+// with its own bitmap (currently only for Earth)
+void
+LoadPlanet (FRAME SurfDefFrame)
+{
+	BOOLEAN WaitMode;
+
+#ifdef DEBUG
+	if (disableInteractivity)
+		return;
+#endif
+
+	WaitMode = !(LastActivity & CHECK_LOAD) &&
+			(pSolarSysState->MenuState.Initialized <= 2);
+
+	if (WaitMode)
+	{
+		LockMutex (GraphicsLock);
+		DrawOrbitalDisplay (DRAW_ORBITAL_WAIT);
+		UnlockMutex (GraphicsLock);
+	}
 
 	if (pSolarSysState->MenuState.flash_task == 0)
 	{
+		// The "rotate planets" task is not initialised yet.
+		// This means the call to LoadPlanet is made from a
+		// GENERATE_ORBITAL case of an IP generation function.
 		PPLANET_DESC pPlanetDesc;
-		extern void GeneratePlanetSide (void);
 
 		StopMusic ();
 
@@ -92,12 +165,8 @@ LoadPlanet (BOOLEAN IsDefined)
 			LoadLanderData ();
 		*/
 
-		{
-			extern void GeneratePlanetMask (PPLANET_DESC
-					pPlanetDesc, BOOLEAN IsEarth);
-
-			GeneratePlanetMask (pPlanetDesc, IsDefined);
-		}
+		GeneratePlanetMask (pPlanetDesc, SurfDefFrame);
+		SetPlanetMusic ((UBYTE)(pPlanetDesc->data_index & ~PLANET_SHIELDED));
 
 		if (pPlanetDesc->pPrevDesc != &pSolarSysState->SunDesc[0])
 			pPlanetDesc = pPlanetDesc->pPrevDesc;
@@ -105,25 +174,11 @@ LoadPlanet (BOOLEAN IsDefined)
 		GeneratePlanetSide ();
 	}
 
-	if (LastActivity & CHECK_LOAD)
-	{
-		if (LOBYTE (LastActivity) == 0)
-		{
-			UnlockMutex (GraphicsLock);
-			DrawSISFrame ();
-			LockMutex (GraphicsLock);
-		}
-		else
-		{
-			ClearSISRect (DRAW_SIS_DISPLAY);
-			RepairSISBorder ();
-		}
-		DrawSISMessage (NULL_PTR);
-		DrawSISTitle (GLOBAL_SIS (PlanetName));
-	}
-
+	LockMutex (GraphicsLock);
+	DrawOrbitalDisplay (WaitMode ? DRAW_ORBITAL_UPDATE : DRAW_ORBITAL_FULL);
+#if 0
+	// this used to draw the static slave shield graphic
 	SetContext (SpaceContext);
-
 	s.frame = pSolarSysState->PlanetSideFrame[2];
 	if (s.frame)
 	{
@@ -131,62 +186,20 @@ LoadPlanet (BOOLEAN IsDefined)
 		s.origin.y = ((116 - SIS_ORG_Y) >> 1) + 2;
 		DrawStamp (&s);
 	}
-
-	if (!(LastActivity & CHECK_LOAD))
-	{
-		RECT r;
-
-		BatchGraphics ();
-		DrawPlanet (SIS_SCREEN_WIDTH - MAP_WIDTH, SIS_SCREEN_HEIGHT - MAP_HEIGHT, 0, 0);
-		UnbatchGraphics ();
-
-		r.corner.x = SIS_ORG_X;
-		r.corner.y = SIS_ORG_Y;
-		r.extent.width = SIS_SCREEN_WIDTH;
-		r.extent.height = SIS_SCREEN_HEIGHT;
-		ScreenTransition (3, &r);
-		UnbatchGraphics ();
-		LoadIntoExtraScreen (&r);
-	}
-	
+#endif
 	UnlockMutex (GraphicsLock);
 
 	if (!PLRPlaying ((MUSIC_REF)~0))
-	{
-		extern MUSIC_REF LanderMusic;
-			
 		PlayMusic (LanderMusic, TRUE, 1);
-		if (pSolarSysState->MenuState.flash_task == 0)
-		{
-			pSolarSysState->MenuState.flash_task =
-					AssignTask (rotate_planet_task, 4096,
-					"rotate planets");
 
-			while (pSolarSysState->MenuState.Initialized == 2)
-				TaskSwitch ();
-		}
-	}
-
-	if (LastActivity & CHECK_LOAD)
+	if (pSolarSysState->MenuState.flash_task == 0)
 	{
-		RECT r;
-		CONTEXT oldContext;
+		pSolarSysState->MenuState.flash_task =
+				AssignTask (rotate_planet_task, 4096,
+				"rotate planets");
 
-		r.corner.x = SIS_ORG_X;
-		r.corner.y = SIS_ORG_Y;
-		r.extent.width = SIS_SCREEN_WIDTH;
-		r.extent.height = SIS_SCREEN_HEIGHT;
-		LockMutex (GraphicsLock);
-		oldContext = SetContext (SpaceContext);
-		DrawStarBackGround (TRUE);
-		SetContext (oldContext);
-		BatchGraphics();
-		DrawPlanet (SIS_SCREEN_WIDTH - MAP_WIDTH, SIS_SCREEN_HEIGHT - MAP_HEIGHT, 0, 0);
-		UnbatchGraphics();
-		ScreenTransition (3, &r);  // How does this work?
-		UnbatchGraphics ();
-		LoadIntoExtraScreen (&r);
-		UnlockMutex (GraphicsLock);
+		while (pSolarSysState->MenuState.Initialized == 2)
+			TaskSwitch ();
 	}
 }
 
@@ -234,28 +247,49 @@ FreePlanet (void)
 	DestroyDrawable (ReleaseDrawable (Orbit->TintFrame));
 	Orbit->TintFrame = 0;
 	pSolarSysState->Tint_rgb = 0;
-	DestroyDrawable (ReleaseDrawable (Orbit->ShieldFrame));
-	Orbit->ShieldFrame = 0;
 
-	if (Orbit->lpTopoMap!=0)
+	DestroyDrawable (ReleaseDrawable (Orbit->ObjectFrame));
+	Orbit->ObjectFrame = 0;
+	DestroyDrawable (ReleaseDrawable (Orbit->WorkFrame));
+	Orbit->WorkFrame = 0;
+
+	if (Orbit->lpTopoMap != 0)
 	{
 		HFree (Orbit->lpTopoMap);
 		Orbit->lpTopoMap = 0;
 	}
+	if (Orbit->ScratchArray != 0)
+	{
+		HFree (Orbit->ScratchArray);
+		Orbit->ScratchArray = 0;
+	}
 
 	DestroyContext (ReleaseContext (TaskContext));
 	TaskContext = 0;
-
+	
 	DestroyStringTable (ReleaseStringTable (
 			pSolarSysState->SysInfo.PlanetInfo.DiscoveryString
 			));
 	pSolarSysState->SysInfo.PlanetInfo.DiscoveryString = 0;
-	DestroyFont (ReleaseFont (
-			pSolarSysState->SysInfo.PlanetInfo.LanderFont
-			));
-	pSolarSysState->SysInfo.PlanetInfo.LanderFont = 0;
+	FreeLanderFont (&pSolarSysState->SysInfo.PlanetInfo);
 	pSolarSysState->PauseRotate = 0;
 
 	UnlockMutex (GraphicsLock);
 }
 
+void
+LoadStdLanderFont (PLANET_INFO *info)
+{
+	info->LanderFont = CaptureFont (LoadGraphic (LANDER_FONT));
+	info->LanderFontEff = CaptureDrawable (
+			LoadGraphic (LANDER_FONTEFF_PMAP_ANIM));
+}
+
+void
+FreeLanderFont (PLANET_INFO *info)
+{
+	DestroyFont (ReleaseFont (info->LanderFont));
+	info->LanderFont = 0;
+	DestroyDrawable (ReleaseDrawable (info->LanderFontEff));
+	info->LanderFontEff = 0;
+}
