@@ -19,7 +19,7 @@
 #ifndef _PLANETS_H
 #define _PLANETS_H
 
-#include "starbase.h"
+#include "menustat.h"
 #include "units.h"
 
 #define END_INTERPLANETARY START_INTERPLANETARY
@@ -144,26 +144,51 @@ typedef void (*PLAN_GEN_FUNC) (BYTE control);
 typedef struct planet_orbit
 {
 	FRAME TopoZoomFrame;
+			// 4x scaled topo image for planet-side
 	PBYTE lpTopoData;
+			// normal topo data; expressed in elevation levels
+			// data is signed for planets other than gas giants
+			// transformed to light variance map for 3d planet
 	FRAME PlanetFrameArray;
+			// cached rotating 3d planet frames
 	BYTE *isPFADefined;
-	FRAME ShieldFrame;
+			// cached frames 'present' flags
+	FRAME ObjectFrame;
+			// any extra planetary object (shield, atmo, rings)
+			// automatically drawn if present
 	FRAME TintFrame;
+			// tinted topo images for current scan type (dynamic)
 	DWORD *lpTopoMap;
+			// RGBA version of topo image; for 3d planet
 	DWORD *ScratchArray;
+			// temp RGBA data for whatever transforms (nuked often)
+	FRAME WorkFrame;
+			// any extra frame workspace (for dynamic objects)
 }  PLANET_ORBIT;
 
+// See doc/devel/generate for information on how this structure is
+// filled.
 typedef struct solarsys_state
 {
 	MENU_STATE MenuState;
 
 	COUNT WaitIntersect;
-	PLANET_DESC SunDesc[MAX_SUNS], PlanetDesc[MAX_PLANETS], MoonDesc[MAX_MOONS];
-	PPLANET_DESC pBaseDesc, pOrbitalDesc;
+	PLANET_DESC SunDesc[MAX_SUNS];
+	PLANET_DESC PlanetDesc[MAX_PLANETS];
+			// Description of the planets in the system.
+			// Only defined after a call to GenFunc with GENERATE_PLANETS
+			// as its argument, and overwritten by subsequent calls.
+	PLANET_DESC MoonDesc[MAX_MOONS];
+			// Description of the moons orbiting the planet pointed to
+			// by pBaseDesc.
+			// Only defined after a call to GenFunc with GENERATE_MOONS
+			// as its argument, and overwritten by subsequent calls.
+	PPLANET_DESC pBaseDesc;
+	PPLANET_DESC pOrbitalDesc;
 	SIZE FirstPlanetIndex, LastPlanetIndex;
 			// The planets get sorted on their image.origin.y value.
 			// PlanetDesc[FirstPlanetIndex] is the planet with the lowest
-			// image.origin.y, and PlanetDesc[FirstPlanetIndex] has the
+			// image.origin.y, and PlanetDesc[LastPlanetIndex] has the
 			// highest image.origin.y.
 			// PlanetDesc[PlanetDesc[i].NextIndex] is the next planet
 			// after PlanetDesc[i] in the ordering.
@@ -179,6 +204,8 @@ typedef struct solarsys_state
 
 	COUNT CurNode;
 	PLAN_GEN_FUNC GenFunc;
+			// Function to call to fill in various parts of this structure.
+			// See doc/devel/generate.
 
 	FRAME PlanetSideFrame[6];
 	UWORD Tint_rgb;
@@ -189,10 +216,13 @@ typedef struct solarsys_state
 typedef SOLARSYS_STATE *PSOLARSYS_STATE;
 
 extern PSOLARSYS_STATE pSolarSysState;
+extern MUSIC_REF SpaceMusic;
 
-extern void LoadPlanet (BOOLEAN IsDefined);
-void DrawPlanet(int x, int y, int dy, unsigned int rgb);
+extern void LoadPlanet (FRAME SurfDefFrame);
+extern void DrawPlanet (int x, int y, int dy, unsigned int rgb);
 extern void FreePlanet (void);
+extern void LoadStdLanderFont (PLANET_INFO *info);
+extern void FreeLanderFont (PLANET_INFO *info);
 
 extern void ExploreSolarSys (void);
 extern void DrawStarBackGround (BOOLEAN ForPlanet);
@@ -203,8 +233,8 @@ extern void DrawSystem (SIZE radius, BOOLEAN IsInnerSystem);
 extern void DrawOval (PRECT pRect, BYTE num_off_pixels);
 extern void DrawFilledOval (PRECT pRect);
 extern void DoMissions (void);
-extern void FillOrbits (BYTE NumPlanets, PPLANET_DESC pBaseDesc, BOOLEAN
-		TypesDefined);
+extern void FillOrbits (PSOLARSYS_STATE system,
+		BYTE NumPlanets, PPLANET_DESC pBaseDesc, BOOLEAN TypesDefined);
 extern void ScanSystem (void);
 extern void ChangeSolarSys (void);
 extern BOOLEAN DoFlagshipCommands (PMENU_STATE pMS);
@@ -215,5 +245,13 @@ extern BOOLEAN ValidateOrbits (void);
 extern void IP_reset (void);
 extern void IP_frame (void);
 
+extern PRECT RotatePlanet (int x, int dx, int dy, COUNT scale_amt,
+		UBYTE zoom_from, PRECT r);
+extern void SetPlanetTilt (int da);
+extern void DrawScannedObjects (BOOLEAN Reversed);
+extern void GeneratePlanetMask (PPLANET_DESC pPlanetDesc, FRAME SurfDefFrame);
+extern void DeltaTopography (COUNT num_iterations, PSBYTE DepthArray,
+		PRECT pRect, SIZE depth_delta);
+
 #endif /* _PLANETS_H */
 
