@@ -23,21 +23,19 @@
 #include "gamestr.h"
 #include "globdata.h"
 #include "options.h"
+#include "scan.h"
+#include "shipcont.h"
 #include "settings.h"
 #include "setup.h"
 #include "sounds.h"
 #include "state.h"
 #include "uqmdebug.h"
 #include "libs/inplib.h"
+#include "libs/strlib.h"
 #include "libs/graphics/gfx_common.h"
 #include "libs/mathlib.h"
 
 
-//Added by Chris
-
-void RepairBackRect (PRECT pRect);
-
-//End Added by Chris
 
 #define UNIVERSE_TO_DISPX(ux) \
 		(COORD)(((((long)(ux) - pMenuState->flash_rect1.corner.x) \
@@ -462,10 +460,10 @@ DrawStarMap (COUNT race_update, PRECT pClipRect)
 
 #ifdef NOTYET
 {
-UNICODE buf[40];
+UNICODE buf[256];
 
 GetClusterName (SDPtr, buf);
-wprintf ("%s\n", buf);
+printf ("%s\n", buf);
 }
 #endif /* NOTYET */
 		s.origin.x = UNIVERSE_TO_DISPX (SDPtr->star_pt.x);
@@ -609,35 +607,624 @@ ZoomStarMap (SIZE dir)
 	}
 }
 
+static void
+UpdateCursorLocation (PMENU_STATE pMS, int sx, int sy, const POINT *newpt)
+{
+	STAMP s;
+	POINT pt;
+
+	pt.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
+	pt.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
+
+	if (newpt)
+	{	// absolute move
+		sx = sy = 0;
+		s.origin.x = UNIVERSE_TO_DISPX (newpt->x);
+		s.origin.y = UNIVERSE_TO_DISPY (newpt->y);
+		pMS->first_item = *newpt;
+	}
+	else
+	{	// incremental move
+		s.origin.x = pt.x + sx;
+		s.origin.y = pt.y + sy;
+	}
+
+	if (sx)
+	{
+		pMS->first_item.x =
+				DISP_TO_UNIVERSEX (s.origin.x) - sx;
+		while (UNIVERSE_TO_DISPX (pMS->first_item.x) == pt.x)
+		{
+			pMS->first_item.x += sx;
+			if (pMS->first_item.x < 0)
+			{
+				pMS->first_item.x = 0;
+				break;
+			}
+			else if (pMS->first_item.x > MAX_X_UNIVERSE)
+			{
+				pMS->first_item.x = MAX_X_UNIVERSE;
+				break;
+			}
+		}
+		s.origin.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
+	}
+
+	if (sy)
+	{
+		pMS->first_item.y =
+				DISP_TO_UNIVERSEY (s.origin.y) + sy;
+		while (UNIVERSE_TO_DISPY (pMS->first_item.y) == pt.y)
+		{
+			pMS->first_item.y -= sy;
+			if (pMS->first_item.y < 0)
+			{
+				pMS->first_item.y = 0;
+				break;
+			}
+			else if (pMS->first_item.y > MAX_Y_UNIVERSE)
+			{
+				pMS->first_item.y = MAX_Y_UNIVERSE;
+				break;
+			}
+		}
+		s.origin.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
+	}
+
+	if (s.origin.x < 0 || s.origin.y < 0
+			|| s.origin.x >= SIS_SCREEN_WIDTH
+			|| s.origin.y >= SIS_SCREEN_HEIGHT)
+	{
+		pMS->flash_rect1.corner = pMS->first_item;
+		DrawStarMap (0, NULL_PTR);
+
+		s.origin.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
+		s.origin.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
+	}
+	else
+	{
+		LockMutex (GraphicsLock);
+		EraseCursor (pt.x, pt.y);
+		// ClearDrawable ();
+		DrawCursor (s.origin.x, s.origin.y);
+		UnlockMutex (GraphicsLock);
+	}
+}
+
+#define CURSOR_INFO_BUFSIZE 256
+
+static void
+UpdateCursorInfo (PMENU_STATE pMS, UNICODE *prevbuf)
+{
+	UNICODE buf[CURSOR_INFO_BUFSIZE] = "";
+	POINT pt;
+	STAR_DESCPTR SDPtr, BestSDPtr;
+
+	pt.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
+	pt.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
+
+	SDPtr = BestSDPtr = 0;
+	while ((SDPtr = FindStar (SDPtr, &pMS->first_item, 75, 75)))
+	{
+		if (UNIVERSE_TO_DISPX (SDPtr->star_pt.x) == pt.x
+				&& UNIVERSE_TO_DISPY (SDPtr->star_pt.y) == pt.y
+				&& (BestSDPtr == 0
+				|| STAR_TYPE (SDPtr->Type) >= STAR_TYPE (BestSDPtr->Type)))
+			BestSDPtr = SDPtr;
+	}
+
+	if (BestSDPtr)
+	{
+		pMS->first_item = BestSDPtr->star_pt;
+		GetClusterName (BestSDPtr, buf);
+	}
+
+	if (GET_GAME_STATE (ARILOU_SPACE))
+	{
+		POINT ari_pt;
+
+		if (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1)
+		{
+			ari_pt.x = ARILOU_SPACE_X;
+			ari_pt.y = ARILOU_SPACE_Y;
+		}
+		else
+		{
+			ari_pt.x = QUASI_SPACE_X;
+			ari_pt.y = QUASI_SPACE_Y;
+		}
+
+		if (UNIVERSE_TO_DISPX (ari_pt.x) == pt.x
+				&& UNIVERSE_TO_DISPY (ari_pt.y) == pt.y)
+		{
+			pMS->first_item = ari_pt;
+			utf8StringCopy (buf, sizeof (buf),
+					GAME_STRING (STAR_STRING_BASE + 132));
+		}
+	}
+
+	LockMutex (GraphicsLock);
+	DrawHyperCoords (pMS->first_item);
+	if (strcmp (buf, prevbuf) != 0)
+	{
+		strcpy (prevbuf, buf);
+		DrawSISMessage (buf);
+	}
+	UnlockMutex (GraphicsLock);
+}
+
+static void
+UpdateFuelRequirement (PMENU_STATE pMS)
+{
+	UNICODE buf[80];
+	COUNT fuel_required;
+	DWORD f;
+	POINT pt;
+
+	if (LOBYTE (GLOBAL (CurrentActivity)) != IN_HYPERSPACE)
+		pt = CurStarDescPtr->star_pt;
+	else
+	{
+		pt.x = LOGX_TO_UNIVERSE (GLOBAL_SIS (log_x));
+		pt.y = LOGY_TO_UNIVERSE (GLOBAL_SIS (log_y));
+	}
+	pt.x -= pMS->first_item.x;
+	pt.y -= pMS->first_item.y;
+
+	f = (DWORD)((long)pt.x * pt.x + (long)pt.y * pt.y);
+	if (f == 0 || GET_GAME_STATE (ARILOU_SPACE_SIDE) > 1)
+		fuel_required = 0;
+	else
+		fuel_required = square_root (f) + (FUEL_TANK_SCALE / 20);
+
+	sprintf (buf, "%s %u.%u",
+			GAME_STRING (NAVIGATION_STRING_BASE + 4),
+			fuel_required / FUEL_TANK_SCALE,
+			(fuel_required % FUEL_TANK_SCALE) / 10);
+
+	LockMutex (GraphicsLock);
+	DrawStatusMessage (buf);
+	UnlockMutex (GraphicsLock);
+}
+
+#define STAR_SEARCH_BUFSIZE 256
+
+typedef struct starsearch_state
+{
+	PMENU_STATE pMS;
+	UNICODE Text[STAR_SEARCH_BUFSIZE];
+	UNICODE LastText[STAR_SEARCH_BUFSIZE];
+	DWORD LastChangeTime;
+	int FirstIndex;
+	int CurIndex;
+	int LastIndex;
+	BOOLEAN SingleClust;
+	BOOLEAN SingleMatch;
+	UNICODE Buffer[STAR_SEARCH_BUFSIZE];
+	const UNICODE *Prefix;
+	const UNICODE *Cluster;
+	int PrefixLen;
+	int ClusterLen;
+	int ClusterPos;
+	int SortedStars[NUM_SOLAR_SYSTEMS];
+} STAR_SEARCH_STATE;
+
+static int
+compStarName (const void *ptr1, const void *ptr2)
+{
+	int index1;
+	int index2;
+
+	index1 = *(const int *) ptr1;
+	index2 = *(const int *) ptr2;
+	if (star_array[index1].Postfix != star_array[index2].Postfix)
+	{
+		return utf8StringCompare (GAME_STRING (star_array[index1].Postfix),
+				GAME_STRING (star_array[index2].Postfix));
+	}
+
+	if (star_array[index1].Prefix < star_array[index2].Prefix)
+		return -1;
+	
+	if (star_array[index1].Prefix > star_array[index2].Prefix)
+		return 1;
+
+	return 0;
+}
+
+static void
+SortStarsOnName (STAR_SEARCH_STATE *pSS)
+{
+	int i;
+	int *sorted = pSS->SortedStars;
+
+	for (i = 0; i < NUM_SOLAR_SYSTEMS; i++)
+		sorted[i] = i;
+
+	qsort (sorted, NUM_SOLAR_SYSTEMS, sizeof (int), compStarName);
+}
+
+static void
+SplitStarName (STAR_SEARCH_STATE *pSS)
+{
+	UNICODE *buf = pSS->Buffer;
+	UNICODE *next;
+	UNICODE *sep;
+
+	pSS->Prefix = 0;
+	pSS->PrefixLen = 0;
+	pSS->Cluster = 0;
+	pSS->ClusterLen = 0;
+	pSS->ClusterPos = 0;
+
+	// skip leading space
+	for (next = buf; *next != '\0' &&
+			getCharFromString ((const UNICODE **)&next) == ' ';
+			buf = next)
+		;
+	if (*buf == '\0')
+	{	// no text
+		return;
+	}
+
+	pSS->Prefix = buf;
+
+	// See if player gave a prefix
+	for (buf = next; *next != '\0' &&
+			getCharFromString ((const UNICODE **)&next) != ' ';
+			buf = next)
+		;
+	if (*buf != '\0')
+	{	// found possibly separating ' '
+		sep = buf;
+		// skip separating space
+		for (buf = next; *next != '\0' &&
+				getCharFromString ((const UNICODE **)&next) == ' ';
+				buf = next)
+			;
+	}
+
+	if (*buf == '\0')
+	{	// reached the end -- cluster only
+		pSS->Cluster = pSS->Prefix;
+		pSS->ClusterLen = utf8StringCount (pSS->Cluster);
+		pSS->ClusterPos = utf8StringCountN (pSS->Buffer, pSS->Cluster);
+		pSS->Prefix = 0;
+		return;
+	}
+
+	// consider the rest cluster name (whatever there is)
+	pSS->Cluster = buf;
+	pSS->ClusterLen = utf8StringCount (pSS->Cluster);
+	pSS->ClusterPos = utf8StringCountN (pSS->Buffer, pSS->Cluster);
+	*sep = '\0'; // split
+	pSS->PrefixLen = utf8StringCount (pSS->Prefix);
+}
+
+static inline int
+SkipStarCluster (int *sortedStars, int istar)
+{
+	int Postfix = star_array[sortedStars[istar]].Postfix;
+
+	for (++istar; istar < NUM_SOLAR_SYSTEMS &&
+			star_array[sortedStars[istar]].Postfix == Postfix;
+			++istar)
+		;
+	return istar;
+}
+
+static int
+FindNextStarIndex (STAR_SEARCH_STATE *pSS, int from, BOOLEAN WithinClust)
+{
+	int i;
+
+	if (!pSS->Cluster)
+		return -1; // nothing to search for
+
+	for (i = from; i < NUM_SOLAR_SYSTEMS; ++i)
+	{
+		STAR_DESCPTR SDPtr = &star_array[pSS->SortedStars[i]];
+		UNICODE FullName[STAR_SEARCH_BUFSIZE];
+		UNICODE *ClusterName = GAME_STRING (SDPtr->Postfix);
+		const UNICODE *sptr;
+		const UNICODE *dptr;
+		int dlen;
+		int c;
+		
+		dlen = utf8StringCount (ClusterName);
+		if (pSS->ClusterLen > dlen)
+		{	// no match, skip the rest of cluster
+			i = SkipStarCluster (pSS->SortedStars, i) - 1;
+			continue;
+		}
+
+		for (c = 0, sptr = pSS->Cluster, dptr = ClusterName;
+				c < pSS->ClusterLen; ++c)
+		{
+			wchar_t sc = getCharFromString (&sptr);
+			wchar_t dc = getCharFromString (&dptr);
+
+			if (toWideUpper (sc) != toWideUpper (dc))
+				break;
+		}
+
+		if (c < pSS->ClusterLen)
+		{	// no match here, skip the rest of cluster
+			i = SkipStarCluster (pSS->SortedStars, i) - 1;
+			continue;
+		}
+
+		if (!SDPtr->Prefix || WithinClust)
+			// singular star - prefix not checked
+			// or searching within clusters
+			break;
+
+		if (!pSS->Prefix)
+		{	// searching for cluster name only
+			// return only the first stars in a cluster
+			if (i == 0 || SDPtr->Postfix !=
+					star_array[pSS->SortedStars[i - 1]].Postfix)
+			{	// found one
+				break;
+			}
+			else
+			{	// another star in the same cluster, skip cluster
+				i = SkipStarCluster (pSS->SortedStars, i) - 1;
+				continue;
+			}
+		}
+
+		// check prefix
+		GetClusterName (SDPtr, FullName);
+		dlen = utf8StringCount (FullName);
+		if (pSS->PrefixLen > dlen)
+			continue;
+
+		for (c = 0, sptr = pSS->Prefix, dptr = FullName;
+				c < pSS->PrefixLen; ++c)
+		{
+			wchar_t sc = getCharFromString (&sptr);
+			wchar_t dc = getCharFromString (&dptr);
+
+			if (toWideUpper (sc) != toWideUpper (dc))
+				break;
+		}
+
+		if (c >= pSS->PrefixLen)
+			break; // found one
+	}
+
+	return (i < NUM_SOLAR_SYSTEMS) ? i : -1;
+}
+
+static void
+DrawMatchedStarName (PTEXTENTRY_STATE pTES)
+{
+	STAR_SEARCH_STATE *pSS = (STAR_SEARCH_STATE *) pTES->CbParam;
+	PMENU_STATE pMS = pSS->pMS;
+	UNICODE buf[STAR_SEARCH_BUFSIZE] = "";
+	SIZE ExPos = 0;
+	SIZE CurPos = -1;
+	STAR_DESCPTR SDPtr = &star_array[pSS->SortedStars[pSS->CurIndex]];
+	COUNT flags;
+
+	if (pSS->SingleClust || pSS->SingleMatch)
+	{	// draw full star name
+		GetClusterName (SDPtr, buf);
+		ExPos = -1;
+		flags = DSME_SETFR;
+	}
+	else
+	{	// draw substring match
+		UNICODE *pstr = buf;
+
+		strcpy (pstr, pSS->Text);
+		ExPos = pSS->ClusterPos;
+		pstr = skipUTF8Chars (pstr, pSS->ClusterPos);
+
+		strcpy (pstr, GAME_STRING (SDPtr->Postfix));
+		ExPos += pSS->ClusterLen;
+		CurPos = pTES->CursorPos;
+
+		flags = DSME_CLEARFR;
+		if (pTES->JoystickMode)
+			flags |= DSME_BLOCKCUR;
+	}
+	
+	LockMutex (GraphicsLock);
+	DrawSISMessageEx (buf, CurPos, ExPos, flags);
+	DrawHyperCoords (pMS->first_item);
+	UnlockMutex (GraphicsLock);
+}
+
+static void
+MatchNextStar (STAR_SEARCH_STATE *pSS, BOOLEAN Reset)
+{
+	if (Reset)
+		pSS->FirstIndex = -1; // reset cache
+	
+	if (pSS->FirstIndex < 0)
+	{	// first time after changes
+		pSS->CurIndex = -1;
+		pSS->LastIndex = -1;
+		pSS->SingleClust = FALSE;
+		pSS->SingleMatch = FALSE;
+		strcpy (pSS->Buffer, pSS->Text);
+		SplitStarName (pSS);
+	}
+
+	pSS->CurIndex = FindNextStarIndex (pSS, pSS->CurIndex + 1,
+			pSS->SingleClust);
+	if (pSS->FirstIndex < 0) // first search
+		pSS->FirstIndex = pSS->CurIndex;
+	
+	if (pSS->CurIndex >= 0)
+	{	// remember as last (searching forward-only)
+		pSS->LastIndex = pSS->CurIndex;
+	}
+	else
+	{	// wrap around
+		pSS->CurIndex = pSS->FirstIndex;
+
+		if (pSS->FirstIndex == pSS->LastIndex && pSS->FirstIndex != -1)
+		{
+			if (!pSS->Prefix)
+			{	// only one cluster matching
+				pSS->SingleClust = TRUE;
+			}
+			else
+			{	// exact match
+				pSS->SingleMatch = TRUE;
+			}
+		}
+	}
+}
+
+static BOOLEAN
+OnStarNameChange (PTEXTENTRY_STATE pTES)
+{
+	STAR_SEARCH_STATE *pSS = (STAR_SEARCH_STATE *) pTES->CbParam;
+	PMENU_STATE pMS = pSS->pMS;
+	COUNT flags;
+	BOOLEAN ret = TRUE;
+
+	if (strcmp (pSS->Text, pSS->LastText) != 0)
+	{	// string changed
+		pSS->LastChangeTime = GetTimeCounter ();
+		strcpy (pSS->LastText, pSS->Text);
+		
+		// reset the search
+		MatchNextStar (pSS, TRUE);
+	}
+
+	if (pSS->CurIndex < 0)
+	{	// nothing found
+		if (pSS->Text[0] == '\0')
+			flags = DSME_SETFR;
+		else
+			flags = DSME_CLEARFR;
+		if (pTES->JoystickMode)
+			flags |= DSME_BLOCKCUR;
+
+		LockMutex (GraphicsLock);
+		ret = DrawSISMessageEx (pSS->Text, pTES->CursorPos, -1, flags);
+		UnlockMutex (GraphicsLock);
+	}
+	else
+	{
+		STAR_DESCPTR SDPtr;
+
+		// move the cursor to the found star
+		SDPtr = &star_array[pSS->SortedStars[pSS->CurIndex]];
+		UpdateCursorLocation (pMS, 0, 0, &SDPtr->star_pt);
+
+		DrawMatchedStarName (pTES);
+		UpdateFuelRequirement (pMS);
+	}
+
+	return ret;
+}
+
+static BOOLEAN
+OnStarNameFrame (PTEXTENTRY_STATE pTES)
+{
+	STAR_SEARCH_STATE *pSS = (STAR_SEARCH_STATE *) pTES->CbParam;
+	PMENU_STATE pMS = pSS->pMS;
+
+	if (PulsedInputState.key[KEY_MENU_NEXT])
+	{	// search for next match
+		STAR_DESCPTR SDPtr;
+
+		MatchNextStar (pSS, FALSE);
+
+		if (pSS->CurIndex < 0)
+		{	// nothing found
+			if (PulsedInputState.key[KEY_MENU_NEXT])
+				PlaySoundEffect (SetAbsSoundIndex (MenuSounds, 2),
+						0, NotPositional (), NULL, 0);
+			return TRUE;
+		}
+
+		// move the cursor to the found star
+		SDPtr = &star_array[pSS->SortedStars[pSS->CurIndex]];
+		UpdateCursorLocation (pMS, 0, 0, &SDPtr->star_pt);
+
+		DrawMatchedStarName (pTES);
+		UpdateFuelRequirement (pMS);
+	}
+	
+	return TRUE;
+}
+
+static BOOLEAN
+DoStarSearch (PMENU_STATE pMS)
+{
+	TEXTENTRY_STATE tes;
+	STAR_SEARCH_STATE *pss;
+	BOOLEAN success;
+
+	pss = HMalloc (sizeof (*pss));
+	if (!pss)
+		return FALSE;
+
+	LockMutex (GraphicsLock);
+	DrawSISMessageEx ("", 0, 0, DSME_SETFR);
+	UnlockMutex (GraphicsLock);
+
+	pss->pMS = pMS;
+	pss->LastChangeTime = 0;
+	pss->Text[0] = '\0';
+	pss->LastText[0] = '\0';
+	pss->FirstIndex = -1;
+	SortStarsOnName (pss);
+
+	// text entry setup
+	tes.Initialized = FALSE;
+	tes.MenuRepeatDelay = 0;
+	tes.BaseStr = pss->Text;
+	tes.MaxSize = sizeof (pss->Text);
+	tes.CursorPos = 0;
+	tes.CbParam = pss;
+	tes.ChangeCallback = OnStarNameChange;
+	tes.FrameCallback = OnStarNameFrame;
+
+	SetMenuSounds (MENU_SOUND_ARROWS, MENU_SOUND_SELECT);
+	success = DoTextEntry (&tes);
+
+	LockMutex (GraphicsLock);
+	DrawSISMessageEx (pss->Text, -1, -1, DSME_CLEARFR);
+	UnlockMutex (GraphicsLock);
+
+	HFree (pss);
+
+	return success;
+} 
+
 static BOOLEAN
 DoMoveCursor (PMENU_STATE pMS)
 {
 #define MIN_ACCEL_DELAY (ONE_SECOND / 60)
 #define MAX_ACCEL_DELAY (ONE_SECOND / 8)
 #define STEP_ACCEL_DELAY (ONE_SECOND / 120)
-	STAMP s;
-	UNICODE buf[30];
-	static UNICODE last_buf;
+	static UNICODE last_buf[CURSOR_INFO_BUFSIZE];
 
 	pMS->MenuRepeatDelay = (COUNT)pMS->CurState;
 	if (!pMS->Initialized)
 	{
-		pMS->Initialized = MAKE_WORD (
-				KBDToUNICODE (SK_INSERT),
-				KBDToUNICODE (SK_DELETE)
-				);
+		pMS->Initialized = TRUE;
 		pMS->InputFunc = DoMoveCursor;
 
+		SetMenuSounds (MENU_SOUND_NONE, MENU_SOUND_NONE);
 		SetMenuRepeatDelay (MIN_ACCEL_DELAY, MAX_ACCEL_DELAY, STEP_ACCEL_DELAY, TRUE);
 
 		pMS->flash_task = AssignTask (flash_cursor_func, 2048,
 				"flash location on star map");
-		s.origin.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
-		s.origin.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
 		
-		last_buf = ~0;
-		buf[0] = '\0';
-		goto UpdateCursorInfo;
+		last_buf[0] = '\0';
+		UpdateCursorInfo (pMS, last_buf);
+		UpdateFuelRequirement (pMS);
+
+		return TRUE;
 	}
 	else if (PulsedInputState.key[KEY_MENU_CANCEL])
 	{
@@ -653,9 +1240,8 @@ DoMoveCursor (PMENU_STATE pMS)
 	{
 		GLOBAL (autopilot) = pMS->first_item;
 #ifdef DEBUG
-		if (instantMove) {
-			GLOBAL_SIS (log_x) = UNIVERSE_TO_LOGX(pMS->first_item.x);
-			GLOBAL_SIS (log_y) = UNIVERSE_TO_LOGY(pMS->first_item.y);
+		if (instantMove)
+		{
 			PlaySoundEffect (SetAbsSoundIndex (MenuSounds, 3), 0,
 					NotPositional (), NULL, GAME_SOUND_PRIORITY);
 			if (pMS->flash_task)
@@ -663,15 +1249,54 @@ DoMoveCursor (PMENU_STATE pMS)
 				ConcludeTask (pMS->flash_task);
 				pMS->flash_task = 0;
 			}
+
+			if (LOBYTE (GLOBAL (CurrentActivity)) == IN_HYPERSPACE)
+			{
+				// Move to the new location immediately.
+				doInstantMove ();
+			}
+			else if (LOBYTE (GLOBAL (CurrentActivity)) == IN_INTERPLANETARY)
+			{
+				// We're in a solar system; exit it.
+				GLOBAL (CurrentActivity) |= END_INTERPLANETARY;
+			
+				// Set a hook to move to the new location:
+				debugHook = doInstantMove;
+			}
+
 			return (FALSE);
 		}
 #endif
 		DrawStarMap (0, NULL_PTR);
 	}
+	else if (PulsedInputState.key[KEY_MENU_SEARCH])
+	{
+		if (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1)
+		{	// HyperSpace search
+			POINT oldpt = pMS->first_item;
+
+			if (!DoStarSearch (pMS))
+			{	// search failed or canceled - return cursor
+				UpdateCursorLocation (pMS, 0, 0, &oldpt);
+			}
+			// make sure cmp fails
+			strcpy (last_buf, "  <random garbage>  ");
+			UpdateCursorInfo (pMS, last_buf);
+			UpdateFuelRequirement (pMS);
+
+			SetMenuRepeatDelay (MIN_ACCEL_DELAY, MAX_ACCEL_DELAY,
+					STEP_ACCEL_DELAY, TRUE);
+			SetMenuSounds (MENU_SOUND_NONE, MENU_SOUND_NONE);
+		}
+		else
+		{	// no search in QuasiSpace
+			PlaySoundEffect (SetAbsSoundIndex (MenuSounds, 2),
+					0, NotPositional (), NULL, 0);
+		}
+	}
 	else
 	{
 		SBYTE sx, sy;
-		POINT pt;
 		SIZE ZoomIn, ZoomOut;
 
 		ZoomIn = ZoomOut = 0;
@@ -688,155 +1313,11 @@ DoMoveCursor (PMENU_STATE pMS)
 		if (PulsedInputState.key[KEY_MENU_UP])      sy =   -1;
 		if (PulsedInputState.key[KEY_MENU_DOWN])    sy =    1;
 
-		if (sx == 0 && sy == 0)
+		if (sx != 0 || sy != 0)
 		{
-		}
-		else
-		{
-			pt.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
-			pt.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
-
-			s.origin.x = pt.x + sx;
-			s.origin.y = pt.y + sy;
-
-			buf[0] = '\0';
-			if (sx)
-			{
-				pMS->first_item.x =
-						DISP_TO_UNIVERSEX (s.origin.x) - sx;
-				while (UNIVERSE_TO_DISPX (pMS->first_item.x) == pt.x)
-				{
-					pMS->first_item.x += sx;
-					if (pMS->first_item.x < 0)
-					{
-						pMS->first_item.x = 0;
-						break;
-					}
-					else if (pMS->first_item.x > MAX_X_UNIVERSE)
-					{
-						pMS->first_item.x = MAX_X_UNIVERSE;
-						break;
-					}
-				}
-				s.origin.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
-			}
-
-			if (sy)
-			{
-				pMS->first_item.y =
-						DISP_TO_UNIVERSEY (s.origin.y) + sy;
-				while (UNIVERSE_TO_DISPY (pMS->first_item.y) == pt.y)
-				{
-					pMS->first_item.y -= sy;
-					if (pMS->first_item.y < 0)
-					{
-						pMS->first_item.y = 0;
-						break;
-					}
-					else if (pMS->first_item.y > MAX_Y_UNIVERSE)
-					{
-						pMS->first_item.y = MAX_Y_UNIVERSE;
-						break;
-					}
-				}
-				s.origin.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
-			}
-
-			if (s.origin.x < 0 || s.origin.y < 0
-					|| s.origin.x >= SIS_SCREEN_WIDTH
-					|| s.origin.y >= SIS_SCREEN_HEIGHT)
-			{
-				pMS->flash_rect1.corner = pMS->first_item;
-				DrawStarMap (0, NULL_PTR);
-
-				s.origin.x = UNIVERSE_TO_DISPX (pMS->first_item.x);
-				s.origin.y = UNIVERSE_TO_DISPY (pMS->first_item.y);
-			}
-			else
-			{
-				LockMutex (GraphicsLock);
-				EraseCursor (pt.x, pt.y);
-				// ClearDrawable ();
-				DrawCursor (s.origin.x, s.origin.y);
-				UnlockMutex (GraphicsLock);
-			}
-
-UpdateCursorInfo:
-			{
-				STAR_DESCPTR SDPtr, BestSDPtr;
-
-				SDPtr = BestSDPtr = 0;
-				while ((SDPtr = FindStar (SDPtr, &pMS->first_item, 75, 75)))
-				{
-					if (UNIVERSE_TO_DISPX (SDPtr->star_pt.x) == s.origin.x
-							&& UNIVERSE_TO_DISPY (SDPtr->star_pt.y) == s.origin.y
-							&& (BestSDPtr == 0
-							|| STAR_TYPE (SDPtr->Type) >= STAR_TYPE (BestSDPtr->Type)))
-						BestSDPtr = SDPtr;
-				}
-
-				if (BestSDPtr)
-				{
-					pMS->first_item = BestSDPtr->star_pt;
-					GetClusterName (BestSDPtr, buf);
-				}
-			}
-
-			if (GET_GAME_STATE (ARILOU_SPACE))
-			{
-				if (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1)
-				{
-					pt.x = ARILOU_SPACE_X;
-					pt.y = ARILOU_SPACE_Y;
-				}
-				else
-				{
-					pt.x = QUASI_SPACE_X;
-					pt.y = QUASI_SPACE_Y;
-				}
-
-				if (UNIVERSE_TO_DISPX (pt.x) == s.origin.x
-						&& UNIVERSE_TO_DISPY (pt.y) == s.origin.y)
-				{
-					pMS->first_item = pt;
-					wstrcpy (buf, GAME_STRING (STAR_STRING_BASE + 132));
-				}
-			}
-
-			{
-				COUNT fuel_required;
-				DWORD f;
-
-				if (LOBYTE (GLOBAL (CurrentActivity)) != IN_HYPERSPACE)
-					pt = CurStarDescPtr->star_pt;
-				else
-				{
-					pt.x = LOGX_TO_UNIVERSE (GLOBAL_SIS (log_x));
-					pt.y = LOGY_TO_UNIVERSE (GLOBAL_SIS (log_y));
-				}
-				pt.x -= pMS->first_item.x;
-				pt.y -= pMS->first_item.y;
-
-				f = (DWORD)((long)pt.x * pt.x + (long)pt.y * pt.y);
-				if (f == 0 || GET_GAME_STATE (ARILOU_SPACE_SIDE) > 1)
-					fuel_required = 0;
-				else
-					fuel_required = square_root (f) + (FUEL_TANK_SCALE / 20);
-				LockMutex (GraphicsLock);
-				DrawHyperCoords (pMenuState->first_item);
-				if (last_buf == (UNICODE) ~0
-						|| (buf[0] && !last_buf) || (!buf[0] && last_buf))
-				{
-					last_buf = buf[0];
-					DrawSISMessage (buf);
-				}
-				wsprintf (buf, "%s %u.%u",
-						GAME_STRING (NAVIGATION_STRING_BASE + 4),
-						fuel_required / FUEL_TANK_SCALE,
-						(fuel_required % FUEL_TANK_SCALE) / 10);
-				DrawStatusMessage (buf);
-				UnlockMutex (GraphicsLock);
-			}
+			UpdateCursorLocation (pMS, sx, sy, NULL_PTR);
+			UpdateCursorInfo (pMS, last_buf);
+			UpdateFuelRequirement (pMS);
 		}
 	}
 
@@ -1107,14 +1588,13 @@ DoStarMap (void)
 	//FRAME OldFrame;
 	RECT clip_r;
 	CONTEXT OldContext;
-	extern FRAME misc_data;
 
 	pMenuState = &MenuState;
 	memset (pMenuState, 0, sizeof (*pMenuState));
 
 	MenuState.flash_rect1.corner.x = MAX_X_UNIVERSE >> 1;
 	MenuState.flash_rect1.corner.y = MAX_Y_UNIVERSE >> 1;
-	MenuState.CurFrame = SetAbsFrameIndex (misc_data, 48);
+	MenuState.CurFrame = SetAbsFrameIndex (MiscDataFrame, 48);
 	MenuState.delta_item = 0;
 
 	if (LOBYTE (GLOBAL (CurrentActivity)) != IN_HYPERSPACE)
@@ -1134,7 +1614,6 @@ DoStarMap (void)
 
 	MenuState.InputFunc = DoMoveCursor;
 	MenuState.Initialized = FALSE;
-	SetMenuRepeatDelay (MIN_ACCEL_DELAY, MAX_ACCEL_DELAY, STEP_ACCEL_DELAY, TRUE);
 
 	transition_pending = TRUE;
 	if (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1)
@@ -1150,14 +1629,13 @@ DoStarMap (void)
 	GetContextClipRect (&clip_r);
 	SetContext (OldContext);
 	LoadIntoExtraScreen (&clip_r);
-			DrawCursor (
-			UNIVERSE_TO_DISPX (pMenuState->first_item.x),
-			UNIVERSE_TO_DISPY (pMenuState->first_item.y)
+	DrawCursor (
+			UNIVERSE_TO_DISPX (MenuState.first_item.x),
+			UNIVERSE_TO_DISPY (MenuState.first_item.y)
 			);
 	UnbatchGraphics ();
 	UnlockMutex (GraphicsLock);
 
-	SetMenuSounds (MENU_SOUND_NONE, MENU_SOUND_NONE);
 	DoInput ((PVOID)&MenuState, FALSE);
 	SetMenuSounds (MENU_SOUND_ARROWS, MENU_SOUND_SELECT);
 
@@ -1240,8 +1718,6 @@ DoFlagshipCommands (PMENU_STATE pMS)
 							break;
 						case EQUIP_DEVICE:
 						{
-							extern BOOLEAN Devices (PMENU_STATE pMS);
-
 							pMenuState = pMS;
 							if (!Devices (pMS))
 								select = FALSE;
@@ -1255,15 +1731,11 @@ DoFlagshipCommands (PMENU_STATE pMS)
 						}
 						case CARGO:
 						{
-							extern void Cargo (PMENU_STATE pMS);
-
 							Cargo (pMS);
 							break;
 						}
 						case ROSTER:
 						{
-							extern BOOLEAN Roster (void);
-
 							if (!Roster ())
 								select = FALSE;
 							break;
@@ -1300,7 +1772,7 @@ DoFlagshipCommands (PMENU_STATE pMS)
 
 							if (!AutoPilotSet && pMS->Initialized >= 3)
 							{
-								LoadPlanet (FALSE);
+								LoadPlanet (NULL);
 								--pMS->Initialized;
 								pSolarSysState->PauseRotate = 0;
 								LockMutex (GraphicsLock);
