@@ -24,6 +24,7 @@
 #include "sounds.h"
 #include "planets/lander.h"
 #include "planets/planets.h"
+#include "uqmdebug.h"
 #include "libs/inplib.h"
 
 #include <ctype.h>
@@ -39,46 +40,45 @@ extern FRAME SpaceJunkFrame;
 static void
 ClearReportArea (void)
 {
-	COUNT i;
+	COUNT x, y;
 	RECT r;
 	STAMP s;
-	PRIMITIVE prim_row[MAX_CELL_COLS];
+	COORD startx;
 
 	if (optWhichFonts == OPT_PC)
 		s.frame = SetAbsFrameIndex (SpaceJunkFrame, 21);
 	else
 		s.frame = SetAbsFrameIndex (SpaceJunkFrame, 18);
 	GetFrameRect (s.frame, &r);
-	s.origin.x = 1 + (r.extent.width >> 1) - 1;
-	s.origin.y = 1;
-	for (i = 0; i < NUM_CELL_COLS; ++i)
-	{
-		prim_row[i].Object.Stamp = s;
-		s.origin.x += r.extent.width + 1;
 
-		SetPrimNextLink (&prim_row[i], i + 1);
-		if (optWhichFonts == OPT_PC)
-			SetPrimType (&prim_row[i], STAMP_PRIM);
-		else
-		{
-			SetPrimType (&prim_row[i], STAMPFILL_PRIM);
-			SetPrimColor (&prim_row[i], BUILD_COLOR (MAKE_RGB15 (0x00, 0x07, 0x00), 0x57));
-		}
-	}
-	SetPrimNextLink (&prim_row[i - 1], END_OF_LIST);
+	BatchGraphics ();
 
 	SetContextBackGroundColor (BLACK_COLOR);
 	ClearDrawable ();
 	SetContextClipping (FALSE);
-	for (i = 0; i < NUM_CELL_ROWS; ++i)
+	SetContextForeGroundColor (BUILD_COLOR (
+			MAKE_RGB15 (0x00, 0x07, 0x00), 0x57));
+	
+	startx = 1 + (r.extent.width >> 1) - 1;
+	s.origin.y = 1;
+	for (y = 0; y < NUM_CELL_ROWS; ++y)
 	{
-		DrawBatch (prim_row, 0, 0);
-		r.corner.y -= r.extent.height + 1;
-		SetFrameHot (s.frame, MAKE_HOT_SPOT (r.corner.x, r.corner.y));
+		s.origin.x = startx;
+		for (x = 0; x < NUM_CELL_COLS; ++x)
+		{
+			if (optWhichFonts == OPT_PC)
+				DrawStamp (&s);
+			else
+				DrawFilledStamp (&s);
+			
+			s.origin.x += r.extent.width + 1;
+		}
+		s.origin.y += r.extent.height + 1;
 	}
+
 	SetContextClipping (TRUE);
-	r.corner.y = 0;
-	SetFrameHot (s.frame, MAKE_HOT_SPOT (r.corner.x, r.corner.y));
+
+	UnbatchGraphics ();
 }
 
 static void
@@ -86,42 +86,44 @@ MakeReport (SOUND ReadOutSounds, UNICODE *pStr, COUNT StrLen)
 {
 	BYTE ButtonState;
 	int end_page_len;
-	UNICODE last_c, end_page_buf[80];
+	UNICODE end_page_buf[200];
+	wchar_t last_c;
 	COUNT row_cells;
 	BOOLEAN Sleepy;
 	RECT r;
 	TEXT t;
 
-	wsprintf (end_page_buf, "%s\n", GAME_STRING (SCAN_STRING_BASE + NUM_SCAN_TYPES));
-	end_page_len = wstrlen (end_page_buf);
+	sprintf (end_page_buf, "%s\n", GAME_STRING (SCAN_STRING_BASE + NUM_SCAN_TYPES));
+	end_page_len = utf8StringCount (end_page_buf);
 
 	GetFrameRect (SetAbsFrameIndex (SpaceJunkFrame, 18), &r);
 
 	t.align = ALIGN_LEFT;
 	t.CharCount = 1;
 	t.pStr = pStr;
-	last_c = *pStr;
 
 	Sleepy = TRUE;
 	UnlockMutex (GraphicsLock);
 
 	FlushInput ();
+	// XXX: this is a pretty ugly goto
 	goto InitPageCell;
+
 	while (StrLen)
 	{
 		COUNT col_cells;
 		const UNICODE *pLastStr;
-		const UNICODE *pTempStr;
+		const UNICODE *pNextStr;
 		COUNT lf_pos;
 
 		pLastStr = t.pStr;
 
 		// scan for LFs in the remaining string
 		// trailing LF will be ignored
-		for (lf_pos = StrLen, pTempStr = t.pStr;
-				lf_pos && *pTempStr != '\n';
-				--lf_pos, ++pTempStr)
-			;
+		for (lf_pos = StrLen, pNextStr = t.pStr;
+				lf_pos && getCharFromString (&pNextStr) != '\n';
+				--lf_pos)
+ 			;
 
 		col_cells = 0;
 		// check if the remaining text fits on current screen
@@ -138,12 +140,14 @@ MakeReport (SOUND ReadOutSounds, UNICODE *pStr, COUNT StrLen)
 		{
 			COUNT word_chars;
 			const UNICODE *pStr;
-
+			wchar_t c;
+ 
 			pStr = t.pStr;
-			while (isgraph (*pStr))
-				++pStr;
+			pNextStr = t.pStr;
+			while (isWideGraphChar (getCharFromString (&pNextStr)))
+				pStr = pNextStr;
 
-			word_chars = (COUNT)(pStr - t.pStr);
+			word_chars = utf8StringCountN (t.pStr, pStr);
 			if ((col_cells += word_chars) <= NUM_CELL_COLS)
 			{
 				DWORD TimeOut;
@@ -153,6 +157,9 @@ MakeReport (SOUND ReadOutSounds, UNICODE *pStr, COUNT StrLen)
 				TimeOut = GetTimeCounter ();
 				while (word_chars--)
 				{
+					pNextStr = t.pStr;
+					c = getCharFromString (&pNextStr);
+					
 					if (!Sleepy || (GLOBAL (CurrentActivity) & CHECK_ABORT))
 						font_DrawText (&t);
 					else
@@ -164,17 +171,16 @@ MakeReport (SOUND ReadOutSounds, UNICODE *pStr, COUNT StrLen)
 						PlaySound (ReadOutSounds, NotPositional (), NULL,
 								GAME_SOUND_PRIORITY);
 
-						if (t.pStr[0] == ',')
+						if (c == ',')
 							TimeOut += ONE_SECOND / 4;
-						if (t.pStr[0] == '.' || t.pStr[0] == '!' ||
-								t.pStr[0] == '?')
+						if (c == '.' || c == '!' || c == '?')
 							TimeOut += ONE_SECOND / 2;
 						else
 							TimeOut += ONE_SECOND / 20;
 						if (word_chars == 0)
 							TimeOut += ONE_SECOND / 20;
 
-						TaskSwitch();
+						TaskSwitch ();
 						while (GetTimeCounter () < TimeOut)
 						{
 							if (ButtonState)
@@ -192,12 +198,12 @@ MakeReport (SOUND ReadOutSounds, UNICODE *pStr, COUNT StrLen)
 							TaskSwitch();
 						}
 					}
-					++t.pStr;
+					t.pStr = pNextStr;
 					t.baseline.x += r.extent.width + 1;
 				}
 
 				++col_cells;
-				last_c = *t.pStr++;
+				last_c = getCharFromString (&t.pStr);
 				t.baseline.x += r.extent.width + 1;
 			}
 		} while (col_cells <= NUM_CELL_COLS && last_c != '\n' && StrLen);
@@ -239,34 +245,39 @@ DoDiscoveryReport (SOUND ReadOutSounds)
 {
 	POINT old_curs;
 	CONTEXT OldContext;
-	extern void DrawScannedObjects (BOOLEAN Reversed);
+
+#ifdef DEBUG
+	if (disableInteractivity)
+		return;
+#endif
 
 	if (pMenuState)
 	{
 		old_curs = pMenuState->flash_rect0.corner;
-		pMenuState->flash_rect0.corner.x = /* disable cursor */
-				pMenuState->flash_rect0.corner.x = -1000;
+		
+		/* Disable cursor: */
+		pMenuState->flash_rect0.corner.x = -1000;
+		pMenuState->flash_rect0.corner.y = -1000;
 	}
 
 	OldContext = SetContext (ScanContext);
 	{
 		FONT OldFont;
+		FRAME OldFontEffect;
 
-		OldFont = SetContextFont (pSolarSysState->SysInfo.PlanetInfo.LanderFont);
+		OldFont = SetContextFont (
+				pSolarSysState->SysInfo.PlanetInfo.LanderFont);
 		if (optWhichFonts == OPT_PC)
-		{
-			SetContextFontEffect (ALTERNATE_EFFECT,
-				BUILD_COLOR_RGBA (0x00, 0x00, 0xD6, 0xFF),
-				BUILD_COLOR_RGBA (0x00, 0x04, 0xFF, 0xFF));
-			MakeReport (ReadOutSounds,
-				(UNICODE *)GetStringAddress (pSolarSysState->SysInfo.PlanetInfo.DiscoveryString),
-				GetStringLength (pSolarSysState->SysInfo.PlanetInfo.DiscoveryString));
-			SetContextFontEffect (0, 0, 0);
-		}
+			OldFontEffect = SetContextFontEffect (
+					pSolarSysState->SysInfo.PlanetInfo.LanderFontEff);
 		else
-			MakeReport (ReadOutSounds,
-				(UNICODE *)GetStringAddress (pSolarSysState->SysInfo.PlanetInfo.DiscoveryString),
-				GetStringLength (pSolarSysState->SysInfo.PlanetInfo.DiscoveryString));
+			OldFontEffect = SetContextFontEffect (NULL);
+
+		MakeReport (ReadOutSounds,
+			(UNICODE *)GetStringAddress (pSolarSysState->SysInfo.PlanetInfo.DiscoveryString),
+			GetStringLength (pSolarSysState->SysInfo.PlanetInfo.DiscoveryString));
+		
+		SetContextFontEffect (OldFontEffect);
 		SetContextFont (OldFont);
 	}
 #ifdef OLD
