@@ -25,6 +25,9 @@
 #include "options.h"
 #include "resinst.h"
 #include "settings.h"
+#include "load.h"
+#include "util.h"
+#include "lander.h"
 #include "setup.h"
 #include "sounds.h"
 #include "state.h"
@@ -33,14 +36,7 @@
 #include "libs/mathlib.h"
 
 
-//Added by Chris
-
-void
-DrawPlanet(int x, int y, int dy, unsigned int rgb);
-
-void WaitForNoInput (SIZE Duration);
-
-//End Added by Chris
+extern FRAME SpaceJunkFrame;
 
 // define SPIN_ON_SCAN to allow the planet to spin 
 // while scaning  is going on
@@ -49,9 +45,6 @@ void WaitForNoInput (SIZE Duration);
 #define FLASH_INDEX 105
 #define FLASH_WIDTH 9
 #define FLASH_HEIGHT 9
-extern FRAME misc_data;
-
-extern void DrawScannedObjects (BOOLEAN Reversed);
 
 CONTEXT ScanContext;
 
@@ -74,19 +67,19 @@ static void
 EraseCoarseScan (void)
 {
 	RECT r, tr;
-	extern FRAME SpaceJunkFrame;
 	const int leftScanWidth   = 80;
 	const int rightScanWidth  = 80;
 	const int leftScanOffset  = 5;
 	const int rightScanOffset = 50;
+	const int nameEraseWidth = SIS_SCREEN_WIDTH - 2;
 
 	LockMutex (GraphicsLock);
 	SetContext (SpaceContext);
 
-	r.corner.x = (SIS_SCREEN_WIDTH >> 1) - (160 >> 1);
-	r.corner.y = 13 - 7;
-	r.extent.width = 160;
-	r.extent.height = 10;
+	r.corner.x = (SIS_SCREEN_WIDTH >> 1) - (nameEraseWidth >> 1);
+	r.corner.y = 13 - 10;
+	r.extent.width = nameEraseWidth;
+	r.extent.height = 14;
 	RepairBackRect (&r);
 
 	GetFrameRect (SetAbsFrameIndex (SpaceJunkFrame, 20), &tr);
@@ -118,65 +111,86 @@ PrintScanTitlePC (TEXT *t, RECT *r, const char *txt, int xpos)
 			BUILD_COLOR (MAKE_RGB15 (0xF, 0x00, 0x19), 0x3B));
 }
 
+static void
+MakeScanValue (UNICODE *buf, long val, const UNICODE *extra)
+{
+	if (val >= 10 * 100)
+	{	// 1 decimal place
+		sprintf (buf, "%ld.%ld%s", val / 100, (val / 10) % 10, extra);
+	}
+	else
+	{	// 2 decimal places
+		sprintf (buf, "%ld.%02ld%s", val / 100, val % 100, extra);
+	}
+}
+
 static void
 PrintCoarseScanPC (void)
 {
 #define SCAN_LEADING_PC 14
-	SIZE temp;
+	SDWORD val;
 	TEXT t;
 	RECT r;
-	UNICODE buf[40];
+	UNICODE buf[200];
 
 	LockMutex (GraphicsLock);
 	SetContext (SpaceContext);
 
 	if (CurStarDescPtr->Index == SOL_DEFINED)
 	{
-		if (pSolarSysState->pOrbitalDesc->pPrevDesc == &pSolarSysState->SunDesc[0])
-			wstrcpy (buf, GLOBAL_SIS (PlanetName));
+		if (pSolarSysState->pOrbitalDesc->pPrevDesc ==
+				&pSolarSysState->SunDesc[0])
+			utf8StringCopy (buf, sizeof (buf), GLOBAL_SIS (PlanetName));
 		else
 		{
 			switch (pSolarSysState->pOrbitalDesc->pPrevDesc
 					- pSolarSysState->PlanetDesc)
 			{
 				case 2: /* EARTH */
-					wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 9));
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (PLANET_NUMBER_BASE + 9));
 					break;
 				case 4: /* JUPITER */
 					switch (pSolarSysState->pOrbitalDesc
 							- pSolarSysState->MoonDesc)
 					{
 						case 0:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 10));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 10));
 							break;
 						case 1:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 11));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 11));
 							break;
 						case 2:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 12));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 12));
 							break;
 						case 3:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 13));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 13));
 							break;
 					}
 					break;
-				case 5:
-					wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 14));
+				case 5: /* SATURN */
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (PLANET_NUMBER_BASE + 14));
 					break;
-				case 7:
-					wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 15));
+				case 7: /* NEPTUNE */
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (PLANET_NUMBER_BASE + 15));
 					break;
 			}
 		}
 	}
 	else
 	{
-		temp = pSolarSysState->pOrbitalDesc->data_index & ~PLANET_SHIELDED;
-		if (temp >= FIRST_GAS_GIANT)
-			wsprintf (buf, "%s", GAME_STRING (SCAN_STRING_BASE + 4 + 51));
+		val = pSolarSysState->pOrbitalDesc->data_index & ~PLANET_SHIELDED;
+		if (val >= FIRST_GAS_GIANT)
+			sprintf (buf, "%s", GAME_STRING (SCAN_STRING_BASE + 4 + 51));
 		else
-			wsprintf (buf, "%s %s",
-					GAME_STRING (SCAN_STRING_BASE + 4 + temp),
+			sprintf (buf, "%s %s",
+					GAME_STRING (SCAN_STRING_BASE + 4 + val),
 					GAME_STRING (SCAN_STRING_BASE + 4 + 50));
 	}
 
@@ -201,13 +215,12 @@ PrintCoarseScanPC (void)
 	t.align = ALIGN_LEFT;
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Orbit: ", LEFT_SIDE_BASELINE_X_PC);
-	temp = (SIZE)((pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist * 100L
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE),
+			LEFT_SIDE_BASELINE_X_PC); // "Orbit: "
+	val = ((pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist * 100L
 			+ (EARTH_RADIUS >> 1)) / EARTH_RADIUS);
-	if (temp >= 10 * 100)
-		wsprintf (buf, "%u.%u a.u.", temp / 100, (temp / 10) % 10);
-	else
-		wsprintf (buf, "%u.%02u a.u.", temp / 100, temp % 100);
+	MakeScanValue (buf, val,
+			GAME_STRING (ORBITSCAN_STRING_BASE + 1)); // " a.u."
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -215,19 +228,20 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Atmo: ", LEFT_SIDE_BASELINE_X_PC);
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 2),
+			LEFT_SIDE_BASELINE_X_PC); // "Atmo: "
 	if (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity == GAS_GIANT_ATMOSPHERE)
-		wsprintf (buf, "Super Thick");
+		utf8StringCopy (buf, sizeof (buf),
+				GAME_STRING (ORBITSCAN_STRING_BASE + 3)); // "Super Thick"
 	else if (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity == 0)
-		wsprintf (buf, "Vacuum");
+		utf8StringCopy (buf, sizeof (buf),
+				GAME_STRING (ORBITSCAN_STRING_BASE + 4)); // "Vacuum"
 	else
 	{
-		temp = (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity * 100
+		val = (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity * 100
 			+ (EARTH_ATMOSPHERE >> 1)) / EARTH_ATMOSPHERE;
-		if (temp >= 10 * 100)
-			wsprintf (buf, "%u.%u atm", temp / 100, (temp / 10) % 10);
-		else
-			wsprintf (buf, "%u.%02u atm", temp / 100, temp % 100);
+		MakeScanValue (buf, val,
+				GAME_STRING (ORBITSCAN_STRING_BASE + 5)); // " atm"
 	}
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
@@ -236,8 +250,9 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Temp: ", LEFT_SIDE_BASELINE_X_PC);
-	wsprintf (buf, "%d^ c",
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 6),
+			LEFT_SIDE_BASELINE_X_PC); // "Temp: "
+	sprintf (buf, "%d" STR_DEGREE_SIGN " c",
 			pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature);
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
@@ -246,12 +261,14 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Weather: ", LEFT_SIDE_BASELINE_X_PC);
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 7),
+			LEFT_SIDE_BASELINE_X_PC); // "Weather: "
 	if (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity == 0)
-		t.pStr = "None";
+		t.pStr = GAME_STRING (ORBITSCAN_STRING_BASE + 8); // "None"
 	else
 	{
-		wsprintf (buf, "Class %u",
+		sprintf (buf, "%s %u",
+				GAME_STRING (ORBITSCAN_STRING_BASE + 9), // "Class"
 				pSolarSysState->SysInfo.PlanetInfo.Weather + 1);
 		t.pStr = buf;
 	}
@@ -261,13 +278,15 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Tectonics: ", LEFT_SIDE_BASELINE_X_PC);
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 10),
+			LEFT_SIDE_BASELINE_X_PC); // "Tectonics: "
 	if (PLANSIZE (pSolarSysState->SysInfo.PlanetInfo.PlanDataPtr->Type) ==
 			GAS_GIANT)
-		t.pStr = "None";
+		t.pStr = GAME_STRING (ORBITSCAN_STRING_BASE + 8); // "None"
 	else
 	{
-		wsprintf (buf, "Class %u",
+		sprintf (buf, "%s %u",
+				GAME_STRING (ORBITSCAN_STRING_BASE + 9), // "Class"
 				pSolarSysState->SysInfo.PlanetInfo.Tectonics + 1);
 		t.pStr = buf;
 	}
@@ -278,21 +297,16 @@ PrintCoarseScanPC (void)
 	t.baseline.y = SCAN_BASELINE_Y_PC;
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Mass: ", RIGHT_SIDE_BASELINE_X_PC);
-	{
-		DWORD tr;
-
-		tr = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
-		tr = (tr * tr * tr / 100L
-				* (DWORD)pSolarSysState->SysInfo.PlanetInfo.PlanetDensity
-				+ (DWORD)((100L * 100L) >> 1)) / (DWORD)(100L * 100L);
-		if (tr == 0)
-			tr = 1;
-		if (tr >= 10 * 100)
-			wsprintf (buf, "%lu.%lu e.s.", tr / 100, (tr / 10) % 10);
-		else
-			wsprintf (buf, "%lu.%02lu e.s.", tr / 100, tr % 100);
-	}
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 11),
+			RIGHT_SIDE_BASELINE_X_PC); // "Mass: "
+	val = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
+	val = (val * val * val / 100L
+			* pSolarSysState->SysInfo.PlanetInfo.PlanetDensity
+			+ ((100L * 100L) >> 1)) / (100L * 100L);
+	if (val == 0)
+		val = 1;
+	MakeScanValue (buf, val,
+			GAME_STRING (ORBITSCAN_STRING_BASE + 12)); // " e.s."
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -300,12 +314,11 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Radius: ", RIGHT_SIDE_BASELINE_X_PC);
-	temp = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
-	if (temp >= 10 * 100)
-		wsprintf (buf, "%u.%u e.s.", temp / 100, (temp / 10) % 10);
-	else
-		wsprintf (buf, "%u.%02u e.s.", temp / 100, temp % 100);
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 13),
+			RIGHT_SIDE_BASELINE_X_PC); // "Radius: "
+	val = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
+	MakeScanValue (buf, val,
+			GAME_STRING (ORBITSCAN_STRING_BASE + 12)); // " e.s."
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -313,16 +326,13 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Gravity: ", RIGHT_SIDE_BASELINE_X_PC);
-	temp = pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity;
-	if (temp >= 10 * 100)
-		wsprintf (buf, "%u.%u g.", temp / 100, (temp / 10) % 10);
-	else
-	{
-		if (temp == 0)
-			temp = 1;
-		wsprintf (buf, "%u.%02u g.", temp / 100, temp % 100);
-	}
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 14),
+			RIGHT_SIDE_BASELINE_X_PC); // "Gravity: "
+	val = pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity;
+	if (val == 0)
+		val = 1;
+	MakeScanValue (buf, val,
+			GAME_STRING (ORBITSCAN_STRING_BASE + 15)); // " g."
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -330,19 +340,12 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Day: ", RIGHT_SIDE_BASELINE_X_PC);
-	if (pSolarSysState->SysInfo.PlanetInfo.RotationPeriod < 240 * 10)
-	{
-		temp = (SIZE)(pSolarSysState->SysInfo.PlanetInfo.RotationPeriod *
-				10 / 24);
-		wsprintf (buf, "%u.%02u days", temp / 100, temp % 100);
-	}
-	else
-	{
-		temp = (SIZE)((pSolarSysState->SysInfo.PlanetInfo.RotationPeriod
-				+ (24 >> 1)) / 24);
-		wsprintf (buf, "%u.%u days", temp / 10, temp % 10);
-	}
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE + 16),
+			RIGHT_SIDE_BASELINE_X_PC); // "Day: "
+	val = (SDWORD)pSolarSysState->SysInfo.PlanetInfo.RotationPeriod
+			* 10 / 24;
+	MakeScanValue (buf, val,
+			GAME_STRING (ORBITSCAN_STRING_BASE + 17)); // " days"
 	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -350,11 +353,13 @@ PrintCoarseScanPC (void)
 	UnlockMutex (GraphicsLock);
 
 	LockMutex (GraphicsLock);
-	PrintScanTitlePC (&t, &r, "Tilt: ", RIGHT_SIDE_BASELINE_X_PC);
-	if ((temp = pSolarSysState->SysInfo.PlanetInfo.AxialTilt) < 0)
-		temp = -temp;
+	PrintScanTitlePC (&t, &r, GAME_STRING (ORBITSCAN_STRING_BASE),
+			RIGHT_SIDE_BASELINE_X_PC); // "Tilt: "
+	val = pSolarSysState->SysInfo.PlanetInfo.AxialTilt;
+	if (val < 0)
+		val = -val;
 	t.pStr = buf;
-	wsprintf (buf, "%u^", temp);
+	sprintf (buf, "%ld" STR_DEGREE_SIGN, val);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	UnlockMutex (GraphicsLock);
@@ -364,11 +369,10 @@ static void
 PrintCoarseScan3DO (void)
 {
 #define SCAN_LEADING 19
-	SIZE temp;
+	SDWORD val;
 	TEXT t;
 	STAMP s;
-	UNICODE buf[40];
-	extern FRAME SpaceJunkFrame;
+	UNICODE buf[200];
 
 	LockMutex (GraphicsLock);
 	SetContext (SpaceContext);
@@ -376,50 +380,57 @@ PrintCoarseScan3DO (void)
 	if (CurStarDescPtr->Index == SOL_DEFINED)
 	{
 		if (pSolarSysState->pOrbitalDesc->pPrevDesc == &pSolarSysState->SunDesc[0])
-			wstrcpy (buf, GLOBAL_SIS (PlanetName));
+			utf8StringCopy (buf, sizeof (buf), GLOBAL_SIS (PlanetName));
 		else
 		{
 			switch (pSolarSysState->pOrbitalDesc->pPrevDesc
 					- pSolarSysState->PlanetDesc)
 			{
 				case 2: /* EARTH */
-					wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 9));
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (PLANET_NUMBER_BASE + 9));
 					break;
 				case 4: /* JUPITER */
 					switch (pSolarSysState->pOrbitalDesc
 							- pSolarSysState->MoonDesc)
 					{
 						case 0:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 10));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 10));
 							break;
 						case 1:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 11));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 11));
 							break;
 						case 2:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 12));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 12));
 							break;
 						case 3:
-							wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 13));
+							utf8StringCopy (buf, sizeof (buf),
+									GAME_STRING (PLANET_NUMBER_BASE + 13));
 							break;
 					}
 					break;
-				case 5:
-					wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 14));
+				case 5: /* SATURN */
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (PLANET_NUMBER_BASE + 14));
 					break;
-				case 7:
-					wstrcpy (buf, GAME_STRING (PLANET_NUMBER_BASE + 15));
+				case 7: /* NEPTUNE */
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (PLANET_NUMBER_BASE + 15));
 					break;
 			}
 		}
 	}
 	else
 	{
-		temp = pSolarSysState->pOrbitalDesc->data_index & ~PLANET_SHIELDED;
-		if (temp >= FIRST_GAS_GIANT)
-			wsprintf (buf, "%s", GAME_STRING (SCAN_STRING_BASE + 4 + 51));
+		val = pSolarSysState->pOrbitalDesc->data_index & ~PLANET_SHIELDED;
+		if (val >= FIRST_GAS_GIANT)
+			sprintf (buf, "%s", GAME_STRING (SCAN_STRING_BASE + 4 + 51));
 		else
-			wsprintf (buf, "%s %s",
-					GAME_STRING (SCAN_STRING_BASE + 4 + temp),
+			sprintf (buf, "%s %s",
+					GAME_STRING (SCAN_STRING_BASE + 4 + val),
 					GAME_STRING (SCAN_STRING_BASE + 4 + 50));
 	}
 
@@ -449,12 +460,9 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	temp = (SIZE)((pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist * 100L
+	val = ((pSolarSysState->SysInfo.PlanetInfo.PlanetToSunDist * 100L
 			+ (EARTH_RADIUS >> 1)) / EARTH_RADIUS);
-	if (temp >= 10 * 100)
-		wsprintf (buf, "%u.%u&", temp / 100, (temp / 10) % 10);
-	else
-		wsprintf (buf, "%u.%02u&", temp / 100, temp % 100);
+	MakeScanValue (buf, val, STR_EARTH_SIGN);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += SCAN_LEADING;
@@ -463,15 +471,12 @@ PrintCoarseScan3DO (void)
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
 	if (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity == GAS_GIANT_ATMOSPHERE)
-		wsprintf (buf, "\x7f");
+		strcpy (buf, STR_INFINITY_SIGN);
 	else
 	{
-		temp = (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity * 100
+		val = (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity * 100
 				+ (EARTH_ATMOSPHERE >> 1)) / EARTH_ATMOSPHERE;
-		if (temp >= 10 * 100)
-			wsprintf (buf, "%u.%u&", temp / 100, (temp / 10) % 10);
-		else
-			wsprintf (buf, "%u.%02u&", temp / 100, temp % 100);
+		MakeScanValue (buf, val, STR_EARTH_SIGN);
 	}
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -480,7 +485,8 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	wsprintf (buf, "%d^", pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature);
+	sprintf (buf, "%d" STR_DEGREE_SIGN,
+			pSolarSysState->SysInfo.PlanetInfo.SurfaceTemperature);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += SCAN_LEADING;
@@ -488,7 +494,7 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	wsprintf (buf, "<%u>", pSolarSysState->SysInfo.PlanetInfo.AtmoDensity == 0
+	sprintf (buf, "<%u>", pSolarSysState->SysInfo.PlanetInfo.AtmoDensity == 0
 			? 0 : (pSolarSysState->SysInfo.PlanetInfo.Weather + 1));
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
@@ -497,7 +503,7 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	wsprintf (buf, "<%u>",
+	sprintf (buf, "<%u>",
 			PLANSIZE (
 			pSolarSysState->SysInfo.PlanetInfo.PlanDataPtr->Type
 			) == GAS_GIANT
@@ -512,20 +518,13 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	{
-		DWORD tr;
-
-		tr = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
-		if ((tr = (tr * tr * tr / 100L
-				* (DWORD)pSolarSysState->SysInfo.PlanetInfo.PlanetDensity
-				+ (DWORD)((100L * 100L) >> 1))
-				/ (DWORD)(100L * 100L)) == 0)
-			tr = 1;
-		if (tr >= 10 * 100)
-			wsprintf (buf, "%lu.%lu&", tr / 100, (tr / 10) % 10);
-		else
-			wsprintf (buf, "%lu.%02lu&", tr / 100, tr % 100);
-	}
+	val = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
+	val = (val * val * val / 100L
+			* pSolarSysState->SysInfo.PlanetInfo.PlanetDensity
+			+ ((100L * 100L) >> 1)) / (100L * 100L);
+	if (val == 0)
+		val = 1;
+	MakeScanValue (buf, val, STR_EARTH_SIGN);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += SCAN_LEADING;
@@ -533,10 +532,9 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	if ((temp = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius) >= 10 * 100)
-		wsprintf (buf, "%u.%u&", temp / 100, (temp / 10) % 10);
-	else
-		wsprintf (buf, "%u.%02u&", temp / 100, temp % 100);
+	val = pSolarSysState->SysInfo.PlanetInfo.PlanetRadius;
+	MakeScanValue (buf, val, STR_EARTH_SIGN);
+
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += SCAN_LEADING;
@@ -544,14 +542,10 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	if ((temp = pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity) >= 10 * 100)
-		wsprintf (buf, "%u.%u&", temp / 100, (temp / 10) % 10);
-	else
-	{
-		if (temp == 0)
-			temp = 1;
-		wsprintf (buf, "%u.%02u&", temp / 100, temp % 100);
-	}
+	val = pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity;
+	if (val == 0)
+		val = 1;
+	MakeScanValue (buf, val, STR_EARTH_SIGN);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += SCAN_LEADING;
@@ -559,9 +553,10 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	if ((temp = pSolarSysState->SysInfo.PlanetInfo.AxialTilt) < 0)
-		temp = -temp;
-	wsprintf (buf, "%u^", temp);
+	val = pSolarSysState->SysInfo.PlanetInfo.AxialTilt;
+	if (val < 0)
+		val = -val;
+	sprintf (buf, "%ld" STR_DEGREE_SIGN, val);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	t.baseline.y += SCAN_LEADING;
@@ -569,17 +564,9 @@ PrintCoarseScan3DO (void)
 
 	LockMutex (GraphicsLock);
 	t.pStr = buf;
-	if (pSolarSysState->SysInfo.PlanetInfo.RotationPeriod < 240 * 10)
-	{
-		temp = (SIZE)(pSolarSysState->SysInfo.PlanetInfo.RotationPeriod * 10 / 24);
-		wsprintf (buf, "%u.%02u&", temp / 100, temp % 100);
-	}
-	else
-	{
-		temp = (SIZE)((pSolarSysState->SysInfo.PlanetInfo.RotationPeriod
-				+ (24 >> 1)) / 24);
-		wsprintf (buf, "%u.%u&", temp / 10, temp % 10);
-	}
+	val = (SDWORD)pSolarSysState->SysInfo.PlanetInfo.RotationPeriod
+			* 10 / 24;
+	MakeScanValue (buf, val, STR_EARTH_SIGN);
 	t.CharCount = (COUNT)~0;
 	font_DrawText (&t);
 	UnlockMutex (GraphicsLock);
@@ -626,7 +613,7 @@ flash_planet_loc_func(void *data)
 	SetPrimNextLink (&p, END_OF_LIST);
 
 	p.Object.Stamp.origin.x = p.Object.Stamp.origin.y = -1;
-	p.Object.Stamp.frame = SetAbsFrameIndex (misc_data, FLASH_INDEX);
+	p.Object.Stamp.frame = SetAbsFrameIndex (MiscDataFrame, FLASH_INDEX);
 	c = 0x00;
 	val = -0x02;
 	TimeIn = 0;
@@ -746,7 +733,6 @@ PickPlanetSide (PMENU_STATE pMS)
 		else
 		{
 			COUNT fuel_required;
-			extern void PlanetSide (PMENU_STATE pMS);
 
 			fuel_required = (COUNT)(
 					pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity << 1
@@ -760,7 +746,7 @@ PickPlanetSide (PMENU_STATE pMS)
 			DeltaSISGauges (0, -(SIZE)fuel_required, 0);
 			SetContext (ScanContext);
 			s.origin = pMenuState->flash_rect0.corner;
-			s.frame = SetAbsFrameIndex (misc_data, FLASH_INDEX);
+			s.frame = SetAbsFrameIndex (MiscDataFrame, FLASH_INDEX);
 			DrawStamp (&s);
 			UnlockMutex (GraphicsLock);
 
@@ -771,7 +757,6 @@ PickPlanetSide (PMENU_STATE pMS)
 			if (GET_GAME_STATE (FOUND_PLUTO_SPATHI) == 1)
 			{
 				HSTARSHIP hStarShip;
-				extern ACTIVITY NextActivity;
 
 				if (pMenuState->flash_task)
 				{
@@ -880,8 +865,7 @@ DrawScannedStuff (COUNT y, BYTE CurState)
 
 	OldColor = SetContextForeGroundColor (0);
 
-	for (hElement = GetHeadElement ();
-			hElement; hElement = hNextElement)
+	for (hElement = GetHeadElement (); hElement; hElement = hNextElement)
 	{
 		ELEMENTPTR ElementPtr;
 		//COLOR OldColor;
@@ -966,6 +950,7 @@ DoScan (PMENU_STATE pMS)
 {
 	DWORD TimeIn, WaitTime;
 	BOOLEAN select, cancel;
+
 	select = PulsedInputState.key[KEY_MENU_SELECT];
 	cancel = PulsedInputState.key[KEY_MENU_CANCEL];
 	if (GLOBAL (CurrentActivity) & CHECK_ABORT)
@@ -999,7 +984,16 @@ DoScan (PMENU_STATE pMS)
 		if (pMS->CurState == DISPATCH_SHUTTLE)
 		{
 			COUNT fuel_required;
-			UNICODE buf[20];
+			UNICODE buf[100];
+
+			if ((pSolarSysState->pOrbitalDesc->data_index & PLANET_SHIELDED)
+					|| (pSolarSysState->SysInfo.PlanetInfo.AtmoDensity ==
+						GAS_GIANT_ATMOSPHERE))
+			{	// cannot dispatch to shielded planets or gas giants
+				PlaySoundEffect (SetAbsSoundIndex (MenuSounds, 2),
+						0, NotPositional (), NULL, GAME_SOUND_PRIORITY);
+				return (TRUE);
+			}
 
 			fuel_required = (COUNT)(
 					pSolarSysState->SysInfo.PlanetInfo.SurfaceGravity << 1
@@ -1016,7 +1010,7 @@ DoScan (PMENU_STATE pMS)
 				return (TRUE);
 			}
 
-			wsprintf (buf, "%s%1.1f",
+			sprintf (buf, "%s%1.1f",
 					GAME_STRING (NAVIGATION_STRING_BASE + 5),
 					(float) fuel_required / FUEL_TANK_SCALE);
 			LockMutex (GraphicsLock);
@@ -1037,117 +1031,125 @@ DoScan (PMENU_STATE pMS)
 			return PickPlanetSide (pMS);
 		}
 
+		// Various scans
+		if (pSolarSysState->pOrbitalDesc->data_index & PLANET_SHIELDED)
+		{	// cannot scan shielded planets
+			PlaySoundEffect (SetAbsSoundIndex (MenuSounds, 2),
+					0, NotPositional (), NULL, GAME_SOUND_PRIORITY);
+			return (TRUE);
+		}
+
 		pSolarSysState->MenuState.Initialized += 4;
 #ifndef SPIN_ON_SCAN
 		pSolarSysState->PauseRotate = 1;
 #endif
-		if ((min_scan = pMS->CurState) != AUTO_SCAN)
+	
+		min_scan = pMS->CurState;
+		if (min_scan != AUTO_SCAN)
 			max_scan = min_scan;
 		else
-			min_scan = MINERAL_SCAN, max_scan = BIOLOGICAL_SCAN;
+		{
+			min_scan = MINERAL_SCAN;
+			max_scan = BIOLOGICAL_SCAN;
+		}
 
 		do
 		{
-		TEXT t;
-		SWORD i;
+			TEXT t;
+			SWORD i;
 
-		t.baseline.x = SIS_SCREEN_WIDTH >> 1;
-		t.baseline.y = SIS_SCREEN_HEIGHT - MAP_HEIGHT - 7;
-		t.align = ALIGN_CENTER;
-		t.CharCount = (COUNT)~0;
+			t.baseline.x = SIS_SCREEN_WIDTH >> 1;
+			t.baseline.y = SIS_SCREEN_HEIGHT - MAP_HEIGHT - 7;
+			t.align = ALIGN_CENTER;
+			t.CharCount = (COUNT)~0;
 
-		pSolarSysState->CurNode = (COUNT)~0;
-		(*pSolarSysState->GenFunc) (
-				(BYTE)(min_scan + GENERATE_MINERAL)
-				);
-		pMS->delta_item = (SIZE)pSolarSysState->CurNode;
-		t.pStr = GAME_STRING (SCAN_STRING_BASE + min_scan);
+			pSolarSysState->CurNode = (COUNT)~0;
+			(*pSolarSysState->GenFunc) ((BYTE)(min_scan + GENERATE_MINERAL));
+			pMS->delta_item = (SIZE)pSolarSysState->CurNode;
+			t.pStr = GAME_STRING (SCAN_STRING_BASE + min_scan);
 
-		LockMutex (GraphicsLock);
-		SetContext (SpaceContext);
-		r.corner.x = 0;
-		r.corner.y = t.baseline.y - 10;
-		r.extent.width = SIS_SCREEN_WIDTH;
-		r.extent.height = t.baseline.y - r.corner.y + 1;
-		RepairBackRect (&r);
-
-		SetContextFont (MicroFont);
-		switch (min_scan)
-		{
-			case MINERAL_SCAN:
-				SetContextForeGroundColor (
-						BUILD_COLOR (MAKE_RGB15 (0x13, 0x00, 0x00), 0x2C)
-						);
-				break;
-			case ENERGY_SCAN:
-				SetContextForeGroundColor (
-						BUILD_COLOR (MAKE_RGB15 (0xC, 0xC, 0xC), 0x1C)
-						);
-				break;
-			case BIOLOGICAL_SCAN:
-				SetContextForeGroundColor (
-						BUILD_COLOR (MAKE_RGB15 (0x00, 0xE, 0x00), 0x6C)
-						);
-				break;
-		}
-		font_DrawText (&t);
-
-		SetContext (ScanContext);
-		UnlockMutex (GraphicsLock);
-
-	{
-		DWORD rgb;
-		
-		switch (min_scan)
-		{
-			case MINERAL_SCAN:
-				rgb = 0x1f << 10;
-				break;
-			case ENERGY_SCAN:
-				rgb = (0x1f << 10) | (0x1f << 5) | 0x1f;
-				break;
-			case BIOLOGICAL_SCAN:
-				rgb = 0x1f << 5;
-				break;
-		}
-
-		LockMutex (GraphicsLock);
-		BatchGraphics ();
-		DrawPlanet (0, 0, 0, 0);
-		UnbatchGraphics ();
-		UnlockMutex (GraphicsLock);
-
-		PressState = AnyButtonPress (TRUE);
-		WaitTime = (ONE_SECOND << 1) / MAP_HEIGHT;
-//		LockMutex (GraphicsLock);
-		TimeIn = GetTimeCounter ();
-		for (i = 0; i < MAP_HEIGHT + NUM_FLASH_COLORS + 1; i++)
-		{
-			ButtonState = AnyButtonPress (TRUE);
-			if (PressState)
-			{
-				PressState = ButtonState;
-				ButtonState = FALSE;
-			}
-			if (ButtonState)
-				i = -i;
 			LockMutex (GraphicsLock);
-			BatchGraphics ();
-			DrawPlanet (0, 0, i, rgb);
-			if (i < 0) 
-				i = MAP_HEIGHT + NUM_FLASH_COLORS;
-			if (pMS->delta_item)
-				DrawScannedStuff (i, min_scan);
-			UnbatchGraphics ();
-			UnlockMutex (GraphicsLock);
-//			FlushGraphics ();
-			SleepThreadUntil (TimeIn + WaitTime);
-			TimeIn = GetTimeCounter ();
-		}
-//		UnlockMutex (GraphicsLock);
-		pSolarSysState->Tint_rgb = 0;
+			SetContext (SpaceContext);
+			r.corner.x = 0;
+			r.corner.y = t.baseline.y - 10;
+			r.extent.width = SIS_SCREEN_WIDTH;
+			r.extent.height = t.baseline.y - r.corner.y + 1;
+			RepairBackRect (&r);
 
-	}
+			SetContextFont (MicroFont);
+			switch (min_scan)
+			{
+				case MINERAL_SCAN:
+					SetContextForeGroundColor (
+							BUILD_COLOR (MAKE_RGB15 (0x13, 0x00, 0x00), 0x2C));
+					break;
+				case ENERGY_SCAN:
+					SetContextForeGroundColor (
+							BUILD_COLOR (MAKE_RGB15 (0xC, 0xC, 0xC), 0x1C));
+					break;
+				case BIOLOGICAL_SCAN:
+					SetContextForeGroundColor (
+							BUILD_COLOR (MAKE_RGB15 (0x00, 0xE, 0x00), 0x6C));
+					break;
+			}
+			font_DrawText (&t);
+
+			SetContext (ScanContext);
+			UnlockMutex (GraphicsLock);
+
+			{
+				DWORD rgb;
+				
+				switch (min_scan)
+				{
+					case MINERAL_SCAN:
+						rgb = MAKE_RGB15 (0x1f, 0x00, 0x00);
+						break;
+					case ENERGY_SCAN:
+						rgb = MAKE_RGB15 (0x1f, 0x1f, 0x1f);
+						break;
+					case BIOLOGICAL_SCAN:
+						rgb = MAKE_RGB15 (0x00, 0x1f, 0x00);
+						break;
+				}
+
+				LockMutex (GraphicsLock);
+				BatchGraphics ();
+				DrawPlanet (0, 0, 0, 0);
+				UnbatchGraphics ();
+				UnlockMutex (GraphicsLock);
+
+				PressState = AnyButtonPress (TRUE);
+				WaitTime = (ONE_SECOND << 1) / MAP_HEIGHT;
+//				LockMutex (GraphicsLock);
+				TimeIn = GetTimeCounter ();
+				for (i = 0; i < MAP_HEIGHT + NUM_FLASH_COLORS + 1; i++)
+				{
+					ButtonState = AnyButtonPress (TRUE);
+					if (PressState)
+					{
+						PressState = ButtonState;
+						ButtonState = FALSE;
+					}
+					if (ButtonState)
+						i = -i;
+					LockMutex (GraphicsLock);
+					BatchGraphics ();
+					DrawPlanet (0, 0, i, rgb);
+					if (i < 0)
+						i = MAP_HEIGHT + NUM_FLASH_COLORS;
+					if (pMS->delta_item)
+						DrawScannedStuff (i, min_scan);
+					UnbatchGraphics ();
+					UnlockMutex (GraphicsLock);
+//					FlushGraphics ();
+					SleepThreadUntil (TimeIn + WaitTime);
+					TimeIn = GetTimeCounter ();
+				}
+//				UnlockMutex (GraphicsLock);
+				pSolarSysState->Tint_rgb = 0;
+
+			}
 
 		} while (++min_scan <= max_scan);
 
@@ -1156,7 +1158,8 @@ DoScan (PMENU_STATE pMS)
 		r.corner.x = 0;
 		r.corner.y = (SIS_SCREEN_HEIGHT - MAP_HEIGHT - 7) - 10;
 		r.extent.width = SIS_SCREEN_WIDTH;
-		r.extent.height = (SIS_SCREEN_HEIGHT - MAP_HEIGHT - 7) - r.corner.y + 1;
+		r.extent.height = (SIS_SCREEN_HEIGHT - MAP_HEIGHT - 7)
+				- r.corner.y + 1;
 		RepairBackRect (&r);
 
 		SetContext (ScanContext);
@@ -1166,7 +1169,8 @@ DoScan (PMENU_STATE pMS)
 			DrawScannedObjects (FALSE);
 			UnlockMutex (GraphicsLock);
 
-			DrawMenuStateStrings (PM_MIN_SCAN, pMS->CurState = DISPATCH_SHUTTLE);
+			pMS->CurState = DISPATCH_SHUTTLE;
+			DrawMenuStateStrings (PM_MIN_SCAN, pMS->CurState);
 		}
 		else
 			UnlockMutex (GraphicsLock);
@@ -1175,9 +1179,10 @@ DoScan (PMENU_STATE pMS)
 		pSolarSysState->PauseRotate = 0;
 		FlushInput ();
 	}
-	else if (!(pSolarSysState->pOrbitalDesc->data_index & PLANET_SHIELDED)
+	else if (optWhichMenu == OPT_PC ||
+			(!(pSolarSysState->pOrbitalDesc->data_index & PLANET_SHIELDED)
 			&& pSolarSysState->SysInfo.PlanetInfo.AtmoDensity !=
-			GAS_GIANT_ATMOSPHERE)
+				GAS_GIANT_ATMOSPHERE))
 		DoMenuChooser (pMS, PM_MIN_SCAN);
 
 	return (TRUE);
@@ -1210,9 +1215,10 @@ ScanSystem (void)
 	}
 }
 
-	if ((pSolarSysState->pOrbitalDesc->data_index & PLANET_SHIELDED)
+	if (optWhichMenu == OPT_3DO &&
+			((pSolarSysState->pOrbitalDesc->data_index & PLANET_SHIELDED)
 			|| pSolarSysState->SysInfo.PlanetInfo.AtmoDensity ==
-			GAS_GIANT_ATMOSPHERE)
+				GAS_GIANT_ATMOSPHERE))
 	{
 		MenuState.CurState = EXIT_SCAN;
 		ScanContext = 0;
@@ -1220,8 +1226,10 @@ ScanSystem (void)
 	else
 	{
 		MenuState.CurState = AUTO_SCAN;
-		pSolarSysState->MenuState.first_item.x = (MAP_WIDTH >> 1) << MAG_SHIFT;
-		pSolarSysState->MenuState.first_item.y = (MAP_HEIGHT >> 1) << MAG_SHIFT;
+		pSolarSysState->MenuState.first_item.x =
+				(MAP_WIDTH >> 1) << MAG_SHIFT;
+		pSolarSysState->MenuState.first_item.y =
+				(MAP_HEIGHT >> 1) << MAG_SHIFT;
 
 		LockMutex (GraphicsLock);
 		ScanContext = CaptureContext (CreateContext ());
@@ -1230,8 +1238,7 @@ ScanSystem (void)
 		MenuState.flash_rect0.extent.height = FLASH_HEIGHT;
 		MenuState.flash_frame0 = CaptureDrawable (
 				CreateDrawable (WANT_PIXMAP | MAPPED_TO_DISPLAY,
-				FLASH_WIDTH, FLASH_HEIGHT, 1)
-				);
+				FLASH_WIDTH, FLASH_HEIGHT, 1));
 		SetContextFGFrame (Screen);
 		r.corner.x = (SIS_ORG_X + SIS_SCREEN_WIDTH) - MAP_WIDTH;
 		r.corner.y = (SIS_ORG_Y + SIS_SCREEN_HEIGHT) - MAP_HEIGHT;
@@ -1281,158 +1288,134 @@ GeneratePlanetSide (void)
 		COUNT num_nodes;
 		FRAME f;
 
-		f = SetAbsFrameIndex (
-				misc_data,
-				NUM_SCANDOT_TRANSITIONS * (scan - ENERGY_SCAN)
-				);
+		f = SetAbsFrameIndex (MiscDataFrame,
+				NUM_SCANDOT_TRANSITIONS * (scan - ENERGY_SCAN));
 
 		pSolarSysState->CurNode = (COUNT)~0;
-		(*pSolarSysState->GenFunc) (
-				(BYTE)(scan + GENERATE_MINERAL)
-				);
+		(*pSolarSysState->GenFunc) ((BYTE)(scan + GENERATE_MINERAL));
+
 		num_nodes = pSolarSysState->CurNode;
-		if (num_nodes)
+		while (num_nodes--)
 		{
-			while (num_nodes--)
+			HELEMENT hNodeElement;
+			ELEMENTPTR NodeElementPtr;
+
+			if (pSolarSysState->SysInfo.PlanetInfo.ScanRetrieveMask[scan]
+					& (1L << num_nodes))
+				continue;
+
+			hNodeElement = AllocElement ();
+			if (!hNodeElement)
+				continue;
+
+			LockElement (hNodeElement, &NodeElementPtr);
+
+			pSolarSysState->CurNode = num_nodes;
+			(*pSolarSysState->GenFunc) ((BYTE)(scan + GENERATE_MINERAL));
+
+			NodeElementPtr->life_span = MAKE_WORD (scan, num_nodes + 1);
+			NodeElementPtr->state_flags = BAD_GUY;
+			NodeElementPtr->current.location.x =
+					pSolarSysState->SysInfo.PlanetInfo.CurPt.x;
+			NodeElementPtr->current.location.y =
+					pSolarSysState->SysInfo.PlanetInfo.CurPt.y;
+
+			SetPrimType (&DisplayArray[NodeElementPtr->PrimIndex], STAMP_PRIM);
+			if (scan == MINERAL_SCAN)
 			{
-				HELEMENT hNodeElement;
+				COUNT EType;
 
-				if (!(pSolarSysState->SysInfo.PlanetInfo.ScanRetrieveMask[scan]
-						& (1L << num_nodes))
-						&& (hNodeElement = AllocElement ()))
+				EType = pSolarSysState->SysInfo.PlanetInfo.CurType;
+				NodeElementPtr->turn_wait = (BYTE)EType;
+				NodeElementPtr->mass_points = HIBYTE (
+						pSolarSysState->SysInfo.PlanetInfo.CurDensity);
+				NodeElementPtr->current.image.frame = SetAbsFrameIndex (
+						MiscDataFrame, (NUM_SCANDOT_TRANSITIONS << 1)
+						+ ElementCategory (EType) * 5);
+				NodeElementPtr->next.image.frame = SetRelFrameIndex (
+						NodeElementPtr->current.image.frame, LOBYTE (
+						pSolarSysState->SysInfo.PlanetInfo.CurDensity) + 1);
+				DisplayArray[NodeElementPtr->PrimIndex].Object.Stamp.frame =
+						IncFrameIndex (NodeElementPtr->next.image.frame);
+			}
+			else
+			{
+				extern void object_animation (PELEMENT ElementPtr);
+
+				NodeElementPtr->current.image.frame = f;
+				NodeElementPtr->next.image.frame = SetRelFrameIndex (
+						f, NUM_SCANDOT_TRANSITIONS - 1);
+				NodeElementPtr->turn_wait = MAKE_BYTE (4, 4);
+				NodeElementPtr->preprocess_func = object_animation;
+				if (scan == ENERGY_SCAN)
 				{
-					ELEMENTPTR NodeElementPtr;
-
-					LockElement (hNodeElement, &NodeElementPtr);
-
-					pSolarSysState->CurNode = num_nodes;
-					(*pSolarSysState->GenFunc) (
-							(BYTE)(scan + GENERATE_MINERAL)
-							);
-
-					NodeElementPtr->life_span = MAKE_WORD (scan, num_nodes + 1);
-					NodeElementPtr->state_flags = BAD_GUY;
-					NodeElementPtr->current.location.x =
-							pSolarSysState->SysInfo.PlanetInfo.CurPt.x;
-					NodeElementPtr->current.location.y =
-							pSolarSysState->SysInfo.PlanetInfo.CurPt.y;
-
-					SetPrimType (&DisplayArray[NodeElementPtr->PrimIndex], STAMP_PRIM);
-					if (scan == MINERAL_SCAN)
-					{
-						COUNT EType;
-
-						EType = pSolarSysState->SysInfo.PlanetInfo.CurType;
-						NodeElementPtr->turn_wait = (BYTE)EType;
-						NodeElementPtr->mass_points =
-								HIBYTE (
-								pSolarSysState->SysInfo.PlanetInfo.CurDensity
-								);
-						NodeElementPtr->current.image.frame =
-								SetAbsFrameIndex (
-								misc_data,
-								(NUM_SCANDOT_TRANSITIONS << 1)
-								+ ElementCategory (EType) * 5
-								);
-						NodeElementPtr->next.image.frame =
-								SetRelFrameIndex (
-								NodeElementPtr->current.image.frame,
-								LOBYTE (
-								pSolarSysState->SysInfo.PlanetInfo.CurDensity
-								) + 1
-								);
-						DisplayArray[NodeElementPtr->PrimIndex].Object.Stamp.frame =
-								IncFrameIndex (
-								NodeElementPtr->next.image.frame
-								);
-					}
+					if (pSolarSysState->SysInfo.PlanetInfo.CurType == 1)
+						NodeElementPtr->mass_points = 0;
+					else if (pSolarSysState->SysInfo.PlanetInfo.CurType == 2)
+						NodeElementPtr->mass_points = 1;
 					else
+						NodeElementPtr->mass_points = MAX_SCROUNGED;
+					DisplayArray[NodeElementPtr->PrimIndex].Object.Stamp.frame =
+							pSolarSysState->PlanetSideFrame[1];
+				}
+				else
+				{
+					COUNT i, which_node;
+
+					which_node = pSolarSysState->SysInfo.PlanetInfo.CurType;
+
+					if (CreatureData[which_node].Attributes & SPEED_MASK)
 					{
-						extern void
-								object_animation
-								(PELEMENT
-								ElementPtr);
-
-						NodeElementPtr->current.image.frame = f;
-						NodeElementPtr->next.image.frame =
-								SetRelFrameIndex (
-								f, NUM_SCANDOT_TRANSITIONS - 1
-								);
-						NodeElementPtr->turn_wait = MAKE_BYTE (4, 4);
-						NodeElementPtr->preprocess_func = object_animation;
-						if (scan == ENERGY_SCAN)
-						{
-							if (pSolarSysState->SysInfo.PlanetInfo.CurType == 1)
-								NodeElementPtr->mass_points = 0;
-							else if (pSolarSysState->SysInfo.PlanetInfo.CurType == 2)
-								NodeElementPtr->mass_points = 1;
-							else
-								NodeElementPtr->mass_points = MAX_SCROUNGED;
-							DisplayArray[NodeElementPtr->PrimIndex].Object.Stamp.frame =
-									pSolarSysState->PlanetSideFrame[1];
-						}
-						else
-						{
-							COUNT i, which_node;
-
-							which_node = pSolarSysState->SysInfo.PlanetInfo.CurType;
-
-							if (CreatureData[which_node].Attributes & SPEED_MASK)
-							{
-								i = (COUNT)TFB_Random ();
-								NodeElementPtr->current.location.x =
-										(LOBYTE (i) % (MAP_WIDTH - (8 << 1))) + 8;
-								NodeElementPtr->current.location.y =
-										(HIBYTE (i) % (MAP_HEIGHT - (8 << 1))) + 8;
-							}
-
-							if (pSolarSysState->PlanetSideFrame[0] == 0)
-								pSolarSysState->PlanetSideFrame[0] =
-										CaptureDrawable (LoadGraphic (
-										CANNISTER_MASK_PMAP_ANIM
-										));
-							for (i = 0; i < MAX_LIFE_VARIATION
-									&& life_init_tab[i] != (BYTE)(which_node + 1);
-									++i)
-							{
-								if (life_init_tab[i] == 0)
-								{
-									life_init_tab[i] = (BYTE)which_node + 1;
-
-									pSolarSysState->PlanetSideFrame[i + 3] =
-											CaptureDrawable (LoadGraphic (
-											MAKE_RESOURCE (
-											GET_PACKAGE (LIFE00_MASK_PMAP_ANIM)
-											+ which_node, GFXRES,
-											GET_INSTANCE (LIFE00_MASK_PMAP_ANIM)
-											+ which_node)));
-
-									break;
-								}
-							}
-
-							NodeElementPtr->mass_points = (BYTE)which_node;
-							NodeElementPtr->hit_points = HINIBBLE (
-									CreatureData[which_node].ValueAndHitPoints
-									);
-							DisplayArray[NodeElementPtr->PrimIndex].Object.Stamp.frame =
-									SetAbsFrameIndex (
-									pSolarSysState->PlanetSideFrame[i + 3],
-									(COUNT)TFB_Random ()
-									);
-						}
+						i = (COUNT)TFB_Random ();
+						NodeElementPtr->current.location.x =
+								(LOBYTE (i) % (MAP_WIDTH - (8 << 1))) + 8;
+						NodeElementPtr->current.location.y =
+								(HIBYTE (i) % (MAP_HEIGHT - (8 << 1))) + 8;
 					}
 
-					NodeElementPtr->next.location.x =
-							NodeElementPtr->current.location.x << MAG_SHIFT;
-					NodeElementPtr->next.location.y =
-							NodeElementPtr->current.location.y << MAG_SHIFT;
-					UnlockElement (hNodeElement);
+					if (pSolarSysState->PlanetSideFrame[0] == 0)
+						pSolarSysState->PlanetSideFrame[0] =
+								CaptureDrawable (LoadGraphic (
+								CANNISTER_MASK_PMAP_ANIM));
+					for (i = 0; i < MAX_LIFE_VARIATION
+							&& life_init_tab[i] != (BYTE)(which_node + 1);
+							++i)
+					{
+						if (life_init_tab[i] != 0)
+							continue;
 
-					PutElement (hNodeElement);
+						life_init_tab[i] = (BYTE)which_node + 1;
+
+						pSolarSysState->PlanetSideFrame[i + 3] =
+								CaptureDrawable (LoadGraphic (
+								MAKE_RESOURCE (
+								GET_PACKAGE (LIFE00_MASK_PMAP_ANIM)
+								+ which_node, GFXRES,
+								GET_INSTANCE (LIFE00_MASK_PMAP_ANIM)
+								+ which_node)));
+
+						break;
+					}
+
+					NodeElementPtr->mass_points = (BYTE)which_node;
+					NodeElementPtr->hit_points = HINIBBLE (
+							CreatureData[which_node].ValueAndHitPoints);
+					DisplayArray[NodeElementPtr->PrimIndex].
+							Object.Stamp.frame = SetAbsFrameIndex (
+							pSolarSysState->PlanetSideFrame[i + 3],
+							(COUNT)TFB_Random ());
 				}
 			}
+
+			NodeElementPtr->next.location.x =
+					NodeElementPtr->current.location.x << MAG_SHIFT;
+			NodeElementPtr->next.location.y =
+					NodeElementPtr->current.location.y << MAG_SHIFT;
+			UnlockElement (hNodeElement);
+
+			PutElement (hNodeElement);
 		}
 	}
 }
 
+
