@@ -25,6 +25,8 @@
 #include "nameref.h"
 #include "resinst.h"
 #include "settings.h"
+#include "lander.h"
+#include "load.h"
 #include "setup.h"
 #include "sounds.h"
 #include "state.h"
@@ -36,17 +38,11 @@
 
 //#define DEBUG_SOLARSYS
 
-//Added by Chris
-
-void LoadLanderData (void);
-
-void RenderTopography (BOOLEAN Reconstruct);
-
-//End Added by Chris
 
 PSOLARSYS_STATE pSolarSysState;
 FRAME SISIPFrame, SunFrame, OrbitalFrame, SpaceJunkFrame;
 COLORMAP OrbitalCMap;
+COLORMAP SunCMap;
 MUSIC_REF SpaceMusic;
 
 #define DRAW_STARS (1 << 0)
@@ -59,11 +55,59 @@ MUSIC_REF SpaceMusic;
 #define GRAB_BKGND (1 << 7)
 
 static SIZE old_radius;
-BYTE draw_sys_flags = DRAW_STARS
-								| DRAW_PLANETS
-								| DRAW_ORBITS
-								| DRAW_HYPER_COORDS
-								| GRAB_BKGND;
+BYTE draw_sys_flags = DRAW_STARS | DRAW_PLANETS | DRAW_ORBITS
+		| DRAW_HYPER_COORDS | GRAB_BKGND;
+
+// NB. This function modifies the RNG state.
+static void
+GeneratePlanets (PSOLARSYS_STATE system)
+{
+	COUNT i;
+	PPLANET_DESC planet;
+
+	for (i = system->SunDesc[0].NumPlanets,
+			planet = &system->PlanetDesc[0]; i; --i, ++planet)
+	{
+		DWORD rand_val;
+		BYTE byte_val;
+		BYTE num_moons;
+		BYTE type;
+
+		rand_val = TFB_Random ();
+		byte_val = LOBYTE (rand_val);
+
+		num_moons = 0;
+		type = PlanData[planet->data_index & ~PLANET_SHIELDED].Type;
+		switch (PLANSIZE (type))
+		{
+			case LARGE_ROCKY_WORLD:
+				if (byte_val < 0x00FF * 25 / 100)
+				{
+					if (byte_val < 0x00FF * 5 / 100)
+						++num_moons;
+					++num_moons;
+				}
+				break;
+			case GAS_GIANT:
+				if (byte_val < 0x00FF * 90 / 100)
+				{
+					if (byte_val < 0x00FF * 75 / 100)
+					{
+						if (byte_val < 0x00FF * 50 / 100)
+						{
+							if (byte_val < 0x00FF * 25 / 100)
+								++num_moons;
+							++num_moons;
+						}
+						++num_moons;
+					}
+					++num_moons;
+				}
+				break;
+		}
+		planet->NumPlanets = num_moons;
+	}
+}
 
 static void
 GenerateMoons (void)
@@ -103,17 +147,17 @@ GenerateMoons (void)
 			pMoonDesc->temp_color = pCurDesc->temp_color;
 
 			data_index = pMoonDesc->data_index;
-					/* Starbase */
 			if (data_index == (BYTE)~0)
 			{
-				pMoonDesc->image.frame = SetAbsFrameIndex (
-						SpaceJunkFrame, 16);
+				/* Starbase */
+				pMoonDesc->image.frame =
+						SetAbsFrameIndex (SpaceJunkFrame, 16);
 			}
-					/* Samatra */
 			else if (data_index == (BYTE)(~0 - 1))
 			{
-				pMoonDesc->image.frame = SetAbsFrameIndex (
-						SpaceJunkFrame, 19);
+				/* Sa-Matra */
+				pMoonDesc->image.frame =
+						SetAbsFrameIndex (SpaceJunkFrame, 19);
 			}
 		}
 	}
@@ -129,6 +173,8 @@ FreeIPData (void)
 	SISIPFrame = 0;
 	DestroyDrawable (ReleaseDrawable (SunFrame));
 	SunFrame = 0;
+	DestroyColorMap (ReleaseColorMap (SunCMap));
+	SunCMap = 0;
 	DestroyColorMap (ReleaseColorMap (OrbitalCMap));
 	OrbitalCMap = 0;
 	DestroyDrawable (ReleaseDrawable (OrbitalFrame));
@@ -151,6 +197,7 @@ LoadIPData (void)
 		OrbitalCMap = CaptureColorMap (LoadColorMap (ORBPLAN_COLOR_MAP));
 		OrbitalFrame = CaptureDrawable (
 				LoadGraphic (ORBPLAN_MASK_PMAP_ANIM));
+		SunCMap = CaptureColorMap (LoadColorMap (IPSUN_COLOR_MAP));
 		SunFrame = CaptureDrawable (LoadGraphic (SUN_MASK_PMAP_ANIM));
 
 		SpaceMusic = LoadMusicInstance (IP_MUSIC);
@@ -166,11 +213,11 @@ LoadSolarSys (void)
 #define NUM_TEMP_RANGES 5
 	COLOR temp_color_array[NUM_TEMP_RANGES] =
 	{
-		BUILD_COLOR (MAKE_RGB15 (0x00, 0x00, 0xE), 0x54),
-		BUILD_COLOR (MAKE_RGB15 (0x00, 0x6, 0x8), 0x62),
-		BUILD_COLOR (MAKE_RGB15 (0x00, 0xB, 0x00), 0x6D),
-		BUILD_COLOR (MAKE_RGB15 (0xF, 0x00, 0x00), 0x2D),
-		BUILD_COLOR (MAKE_RGB15 (0xF, 0x8, 0x00), 0x75),
+		BUILD_COLOR (MAKE_RGB15 (0x00, 0x00, 0x0E), 0x54),
+		BUILD_COLOR (MAKE_RGB15 (0x00, 0x06, 0x08), 0x62),
+		BUILD_COLOR (MAKE_RGB15 (0x00, 0x0B, 0x00), 0x6D),
+		BUILD_COLOR (MAKE_RGB15 (0x0F, 0x00, 0x00), 0x2D),
+		BUILD_COLOR (MAKE_RGB15 (0x0F, 0x08, 0x00), 0x75),
 	};
 
 	pSolarSysState->MenuState.CurState = 0;
@@ -385,8 +432,7 @@ CheckIntersect (BOOLEAN just_checking)
 	PlanetIntersect.EndPoint = PlanetIntersect.IntersectStamp.origin;
 	if (pSolarSysState->WaitIntersect != (COUNT)~0
 			&& pSolarSysState->WaitIntersect != MAKE_WORD (
-					pCurDesc - pSolarSysState->PlanetDesc + 1, 1
-					))
+			pCurDesc - pSolarSysState->PlanetDesc + 1, 1))
 		PlanetIntersect.IntersectStamp.frame = DecFrameIndex (stars_in_space);
 	else
 		PlanetIntersect.IntersectStamp.frame = pCurDesc->image.frame;
@@ -425,91 +471,89 @@ ShowPlanet:
 		}
 	}
 
+	for (i = pCurDesc->NumPlanets,
+			pCurDesc = pSolarSysState->pBaseDesc; i; --i, ++pCurDesc)
 	{
-		for (i = pCurDesc->NumPlanets,
-				pCurDesc = pSolarSysState->pBaseDesc; i; --i, ++pCurDesc)
+		PlanetIntersect.IntersectStamp.origin = pCurDesc->image.origin;
+		PlanetIntersect.EndPoint = PlanetIntersect.IntersectStamp.origin;
+		if (pSolarSysState->pBaseDesc == pSolarSysState->MoonDesc)
 		{
-			PlanetIntersect.IntersectStamp.origin = pCurDesc->image.origin;
-			PlanetIntersect.EndPoint = PlanetIntersect.IntersectStamp.origin;
-			if (pSolarSysState->pBaseDesc == pSolarSysState->MoonDesc)
-			{
-				PlanetOffset = pCurDesc->pPrevDesc -
-						pSolarSysState->PlanetDesc;
-				MoonOffset = pCurDesc - pSolarSysState->MoonDesc + 2;
-			}
-			else
-			{
-				PlanetOffset = pCurDesc - pSolarSysState->PlanetDesc;
-				MoonOffset = 0;
-			}
-			++PlanetOffset;
-			if (pSolarSysState->WaitIntersect != (COUNT)~0
-					&& pSolarSysState->WaitIntersect != MAKE_WORD (
-					PlanetOffset, MoonOffset))
-				PlanetIntersect.IntersectStamp.frame =
-						DecFrameIndex (stars_in_space);
-			else
-				PlanetIntersect.IntersectStamp.frame = pCurDesc->image.frame;
+			PlanetOffset = pCurDesc->pPrevDesc -
+					pSolarSysState->PlanetDesc;
+			MoonOffset = pCurDesc - pSolarSysState->MoonDesc + 2;
+		}
+		else
+		{
+			PlanetOffset = pCurDesc - pSolarSysState->PlanetDesc;
+			MoonOffset = 0;
+		}
+		++PlanetOffset;
+		if (pSolarSysState->WaitIntersect != (COUNT)~0
+				&& pSolarSysState->WaitIntersect != MAKE_WORD (
+				PlanetOffset, MoonOffset))
+			PlanetIntersect.IntersectStamp.frame =
+					DecFrameIndex (stars_in_space);
+		else
+			PlanetIntersect.IntersectStamp.frame = pCurDesc->image.frame;
 
-			if (DrawablesIntersect (&ShipIntersect,
-					&PlanetIntersect, MAX_TIME_VALUE))
-			{
+		if (DrawablesIntersect (&ShipIntersect,
+				&PlanetIntersect, MAX_TIME_VALUE))
+		{
 //				fprintf (stderr, "1: Planet %d, Moon %d\n", PlanetOffset, MoonOffset);
-				NewWaitPlanet = MAKE_WORD (PlanetOffset, MoonOffset);
-				
-				if (pSolarSysState->WaitIntersect == (COUNT)~0)
-					return;
-				else if (pSolarSysState->WaitIntersect == NewWaitPlanet)
-					continue;
-				else if (pSolarSysState->pBaseDesc ==
-						pSolarSysState->MoonDesc)
-					goto ShowPlanet;
-				else if (!just_checking) /* pBaseDesc == PlanetDesc */
-				{
-					COUNT angle;
-					RECT r;
+			NewWaitPlanet = MAKE_WORD (PlanetOffset, MoonOffset);
+			
+			if (pSolarSysState->WaitIntersect == (COUNT)~0)
+				return;
+			else if (pSolarSysState->WaitIntersect == NewWaitPlanet)
+				continue;
+			else if (pSolarSysState->pBaseDesc ==
+					pSolarSysState->MoonDesc)
+				goto ShowPlanet;
+			else if (!just_checking) /* pBaseDesc == PlanetDesc */
+			{
+				COUNT angle;
+				RECT r;
 
-					angle = FACING_TO_ANGLE (
-							GetFrameIndex (GLOBAL (ShipStamp.frame))
-							) + HALF_CIRCLE;
-					GLOBAL (ShipStamp.origin.x) =
-							(SIS_SCREEN_WIDTH >> 1) + COSINE (
-							angle, MIN_MOON_RADIUS
-							+ ((MAX_MOONS - 1) * MOON_DELTA)
-							+ (MOON_DELTA >> 2));
+				angle = FACING_TO_ANGLE (
+						GetFrameIndex (GLOBAL (ShipStamp.frame))
+						) + HALF_CIRCLE;
+				GLOBAL (ShipStamp.origin.x) =
+						(SIS_SCREEN_WIDTH >> 1) + COSINE (
+						angle, MIN_MOON_RADIUS
+						+ ((MAX_MOONS - 1) * MOON_DELTA)
+						+ (MOON_DELTA >> 2));
+				GLOBAL (ShipStamp.origin.y) =
+						(SIS_SCREEN_HEIGHT >> 1) + SINE (
+						angle, MIN_MOON_RADIUS
+						+ ((MAX_MOONS - 1) * MOON_DELTA)
+						+ (MOON_DELTA >> 2));
+				if (GLOBAL (ShipStamp.origin.y) < 0)
+					GLOBAL (ShipStamp.origin.y) = 1;
+				else if (GLOBAL (ShipStamp.origin.y) >= SIS_SCREEN_HEIGHT)
 					GLOBAL (ShipStamp.origin.y) =
-							(SIS_SCREEN_HEIGHT >> 1) + SINE (
-							angle, MIN_MOON_RADIUS
-							+ ((MAX_MOONS - 1) * MOON_DELTA)
-							+ (MOON_DELTA >> 2));
-					if (GLOBAL (ShipStamp.origin.y) < 0)
-						GLOBAL (ShipStamp.origin.y) = 1;
-					else if (GLOBAL (ShipStamp.origin.y) >= SIS_SCREEN_HEIGHT)
-						GLOBAL (ShipStamp.origin.y) =
-								(SIS_SCREEN_HEIGHT - 1) - 1;
-					pSolarSysState->pBaseDesc = pCurDesc;
-					XFormIPLoc (&pCurDesc->image.origin,
-							&pSolarSysState->SunDesc[0].location, FALSE);
-					ZeroVelocityComponents (&GLOBAL (velocity));
-					GenerateMoons ();
+							(SIS_SCREEN_HEIGHT - 1) - 1;
+				pSolarSysState->pBaseDesc = pCurDesc;
+				XFormIPLoc (&pCurDesc->image.origin,
+						&pSolarSysState->SunDesc[0].location, FALSE);
+				ZeroVelocityComponents (&GLOBAL (velocity));
+				GenerateMoons ();
 
-					NewWaitPlanet = 0;
-					SetTransitionSource (NULL);
-					BatchGraphics ();
-					SetGraphicGrabOther (1);
-					DrawSystem (pSolarSysState->pBaseDesc->pPrevDesc->radius,
-							TRUE);
-					SetGraphicGrabOther (0);
-					r.corner.x = SIS_ORG_X;
-					r.corner.y = SIS_ORG_Y;
-					r.extent.width = SIS_SCREEN_WIDTH;
-					r.extent.height = SIS_SCREEN_HEIGHT;
-					ScreenTransition (3, &r);
-					UnbatchGraphics ();
-					LoadIntoExtraScreen (&r);
-				}
-				break;
+				NewWaitPlanet = 0;
+				SetTransitionSource (NULL);
+				BatchGraphics ();
+				SetGraphicGrabOther (1);
+				DrawSystem (pSolarSysState->pBaseDesc->pPrevDesc->radius,
+						TRUE);
+				SetGraphicGrabOther (0);
+				r.corner.x = SIS_ORG_X;
+				r.corner.y = SIS_ORG_Y;
+				r.extent.width = SIS_SCREEN_WIDTH;
+				r.extent.height = SIS_SCREEN_HEIGHT;
+				ScreenTransition (3, &r);
+				UnbatchGraphics ();
+				LoadIntoExtraScreen (&r);
 			}
+			break;
 		}
 	}
 
@@ -758,8 +802,6 @@ flagship_inertial_thrust (COUNT CurrentAngle)
 	}
 }
 
-extern void DrawIPRadar (BOOLEAN FirstTime);
-
 static void
 ProcessShipControls (void)
 {
@@ -781,11 +823,10 @@ ProcessShipControls (void)
 		
 	if (delta_x || delta_y < 0)
 	{
-		GLOBAL (autopilot.x) =
-				GLOBAL (autopilot.y) = ~0;
+		GLOBAL (autopilot.x) = ~0;
+		GLOBAL (autopilot.y) = ~0;
 	}
-	else if (GLOBAL (autopilot.x) != ~0
-			&& GLOBAL (autopilot.y) != ~0)
+	else if (GLOBAL (autopilot.x) != ~0 && GLOBAL (autopilot.y) != ~0)
 		delta_y = -1;
 	else
 		delta_y = 0;
@@ -801,8 +842,7 @@ ProcessShipControls (void)
 			index = NORMALIZE_FACING (index + 1);
 
 		GLOBAL (ShipStamp.frame) =
-				SetAbsFrameIndex (GLOBAL (ShipStamp.frame),
-				index);
+				SetAbsFrameIndex (GLOBAL (ShipStamp.frame), index);
 
 		pSolarSysState->turn_counter = pSolarSysState->turn_wait;
 	}
@@ -824,6 +864,7 @@ UndrawShip (void)
 	BOOLEAN LeavingInnerSystem;
 
 #ifdef SHOW_RADAR
+	extern void DrawIPRadar (BOOLEAN FirstTime);
 	DrawIPRadar (FALSE);
 #endif /* SHOW_RADAR */
 
@@ -851,10 +892,8 @@ UndrawShip (void)
 			pSolarSysState->pBaseDesc = pSolarSysState->PlanetDesc;
 
 			pSolarSysState->WaitIntersect = MAKE_WORD (
-					pPlanetDesc - pSolarSysState->PlanetDesc + 1, 0
-					);
-			GLOBAL (ip_location) =
-					pSolarSysState->SunDesc[0].location;
+					pPlanetDesc - pSolarSysState->PlanetDesc + 1, 0);
+			GLOBAL (ip_location) = pSolarSysState->SunDesc[0].location;
 			ZeroVelocityComponents (&GLOBAL (velocity));
 		}
 
@@ -996,7 +1035,7 @@ ScaleSystem (void)
 }
 
 /* Constants and routines for handling interplanetary play.  TODO:
-   this is NOT INSTANTIABLE; only one IP task may be active at any
+   this is NOT THREAD-SAFE; only one IP task may be active at any
    given time.  --Michael */
 
 #define IP_FRAME_RATE  (ONE_SECOND / 30)
@@ -1167,8 +1206,8 @@ IP_frame (void)
 		if (pSolarSysState->MenuState.CurState
 		    || pSolarSysState->MenuState.Initialized != 1)
 		{
-			cancel = 0;
-			select = 0;
+			cancel = FALSE;
+			select = FALSE;
 		}
 		else
 		{
@@ -1331,10 +1370,8 @@ StartGroups:
 						pSolarSysState->pOrbitalDesc->image.origin;
 			else
 			{
-				GLOBAL (ShipStamp.origin.x) =
-						SIS_SCREEN_WIDTH >> 1;
-				GLOBAL (ShipStamp.origin.y) =
-						SIS_SCREEN_HEIGHT >> 1;
+				GLOBAL (ShipStamp.origin.x) = SIS_SCREEN_WIDTH >> 1;
+				GLOBAL (ShipStamp.origin.y) = SIS_SCREEN_HEIGHT >> 1;
 			}
   
 		}
@@ -1416,6 +1453,8 @@ InitSolarSys (void)
 
 	if (pSolarSysState->MenuState.Initialized == 0)
 	{
+		LockMutex (GraphicsLock);
+
 		SetTransitionSource (NULL);
 		BatchGraphics ();
 		draw_sys_flags |= UNBATCH_SYS;
@@ -1425,17 +1464,13 @@ InitSolarSys (void)
 			if ((LastActivity & (CHECK_LOAD | CHECK_RESTART)) ==
 					LastActivity)
 			{
-				extern ACTIVITY NextActivity;
-
 				DrawSISFrame ();
 				if (NextActivity)
 					LastActivity &= ~(CHECK_LOAD | CHECK_RESTART);
 			}
 			else
 			{
-				LockMutex (GraphicsLock);
 				ClearSISRect (DRAW_SIS_DISPLAY);
-				UnlockMutex (GraphicsLock);
 
 				LastActivity &= ~CHECK_LOAD;
 			}
@@ -1443,8 +1478,6 @@ InitSolarSys (void)
 
 		// Enabled graphics synchronization again, as in 3DO code originally.
 		// This should fix the 'entering star' lockup/messed graphics problems.
-		// 2002/11/30 by Mika
-		LockMutex (GraphicsLock);
 		DrawSISMessage (NULL_PTR);
 		SetContext (SpaceContext);
 		SetContextFGFrame (Screen);
@@ -1528,7 +1561,6 @@ GenerateRandomIP (BYTE control)
 {
 	COUNT i;
 	DWORD rand_val;
-	PPLANET_DESC pCurDesc;
 
 	switch (control)
 	{
@@ -1587,66 +1619,29 @@ GenerateRandomIP (BYTE control)
 
 			pSolarSysState->SysInfo.PlanetInfo.ScanSeed[ENERGY_SCAN] =
 					rand_val;
-			LoadPlanet (FALSE);
+			LoadPlanet (NULL);
 			break;
 		}
 		case GENERATE_NAME:
 		{
 			i = pSolarSysState->pBaseDesc - pSolarSysState->PlanetDesc;
-			wsprintf (GLOBAL_SIS (PlanetName), "%s",
+			utf8StringCopy (GLOBAL_SIS (PlanetName),
+					sizeof (GLOBAL_SIS (PlanetName)),
 					GAME_STRING (PLANET_NUMBER_BASE + (9 + 7) + i));
 			SET_GAME_STATE (BATTLE_PLANET,
 					pSolarSysState->PlanetDesc[i].data_index);
 			break;
 		}
 		case GENERATE_MOONS:
-			FillOrbits (pSolarSysState->pBaseDesc->NumPlanets,
+			FillOrbits (pSolarSysState,
+					pSolarSysState->pBaseDesc->NumPlanets,
 					&pSolarSysState->MoonDesc[0], FALSE);
 			break;
 		case GENERATE_PLANETS:
 		{
-			FillOrbits ((BYTE)~0, &pSolarSysState->PlanetDesc[0], FALSE);
-			for (i = pSolarSysState->SunDesc[0].NumPlanets,
-					pCurDesc = &pSolarSysState->PlanetDesc[0]; i;
-					--i, ++pCurDesc)
-			{
-				BYTE byte_val;
-				BYTE num_moons;
-
-				rand_val = TFB_Random ();
-				byte_val = LOBYTE (rand_val);
-
-				num_moons = 0;
-				switch (PLANSIZE (PlanData[
-						pCurDesc->data_index & ~PLANET_SHIELDED].Type))
-				{
-					case LARGE_ROCKY_WORLD:
-						if (byte_val < 0x00FF * 25 / 100)
-						{
-							if (byte_val < 0x00FF * 5 / 100)
-								++num_moons;
-							++num_moons;
-						}
-						break;
-					case GAS_GIANT:
-						if (byte_val < 0x00FF * 90 / 100)
-						{
-							if (byte_val < 0x00FF * 75 / 100)
-							{
-								if (byte_val < 0x00FF * 50 / 100)
-								{
-									if (byte_val < 0x00FF * 25 / 100)
-										++num_moons;
-									++num_moons;
-								}
-								++num_moons;
-							}
-							++num_moons;
-						}
-						break;
-				}
-				pCurDesc->NumPlanets = num_moons;
-			}
+			FillOrbits (pSolarSysState,
+					(BYTE)~0, &pSolarSysState->PlanetDesc[0], FALSE);
+			GeneratePlanets (pSolarSysState);
 			break;
 		}
 	}
@@ -1711,18 +1706,21 @@ DrawSystem (SIZE radius, BOOLEAN IsInnerSystem)
 	{
 		for (;;)
 		{
-			COUNT color_index;
-
 			pCurDesc = &pSolarSysState->PlanetDesc[index];
-			/* Star color fix - draw the star using OrbitalCMap */
+			/* Star color fix - draw the star using own cmap */
 			if (pCurDesc == &pSolarSysState->SunDesc[0])
-				color_index = STAR_COLOR (CurStarDescPtr->Type);
+			{
+				SetColorMap (GetColorMapAddress (SetAbsColorMapIndex (
+						SunCMap, STAR_COLOR (CurStarDescPtr->Type)
+						)));
+			}
 			else
-				color_index = PLANCOLOR (PlanData[
-						pCurDesc->data_index & ~PLANET_SHIELDED ].Type);
-
-			SetColorMap (GetColorMapAddress (
-					SetAbsColorMapIndex (OrbitalCMap, color_index)));
+			{
+				SetColorMap (GetColorMapAddress (SetAbsColorMapIndex (
+						OrbitalCMap, PLANCOLOR (PlanData[
+						pCurDesc->data_index & ~PLANET_SHIELDED].Type)
+						)));
+			}
 			DrawStamp (&pCurDesc->image);
 
 			if (index == pSolarSysState->LastPlanetIndex)
@@ -1774,8 +1772,7 @@ DrawStarBackGround (BOOLEAN ForPlanet)
 
 	old_seed = TFB_SeedRandom (
 			MAKE_DWORD (CurStarDescPtr->star_pt.x,
-			CurStarDescPtr->star_pt.y)
-			);
+			CurStarDescPtr->star_pt.y));
 
 #define NUM_DIM_PIECES 8
 	s.frame = SpaceJunkFrame;
@@ -1821,16 +1818,16 @@ DrawStarBackGround (BOOLEAN ForPlanet)
 
 		SetContext (ScreenContext);
 
-		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0xA, 0xA, 0xA),
-				0x08));
+		SetContextForeGroundColor (
+				BUILD_COLOR (MAKE_RGB15 (0xA, 0xA, 0xA), 0x08));
 		r.corner.x = SIS_ORG_X - 1;
 		r.corner.y = (SIS_ORG_Y + SIS_SCREEN_HEIGHT) - MAP_HEIGHT - 4;
 		r.extent.width = SIS_SCREEN_WIDTH + 2;
 		r.extent.height = 3;
 		DrawFilledRectangle (&r);
 
-		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x8, 0x8, 0x8),
-					0x1F));
+		SetContextForeGroundColor (
+				BUILD_COLOR (MAKE_RGB15 (0x8, 0x8, 0x8), 0x1F));
 		r.extent.width = 1;
 		r.extent.height = MAP_HEIGHT + 1;
 		r.corner.y = (SIS_ORG_Y + SIS_SCREEN_HEIGHT) - MAP_HEIGHT;
@@ -1844,8 +1841,8 @@ DrawStarBackGround (BOOLEAN ForPlanet)
 		r.corner.y = (SIS_ORG_Y + SIS_SCREEN_HEIGHT) - MAP_HEIGHT - 5;
 		DrawFilledRectangle (&r);
 
-		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (
-				0x10, 0x10, 0x10), 0x19));
+		SetContextForeGroundColor (
+				BUILD_COLOR (MAKE_RGB15 (0x10, 0x10, 0x10), 0x19));
 		r.corner.y = (SIS_ORG_Y + SIS_SCREEN_HEIGHT) - MAP_HEIGHT - 1;
 		r.extent.width = MAP_WIDTH + 2;
 		r.corner.x = (SIS_ORG_X + SIS_SCREEN_WIDTH) - MAP_WIDTH - 1;
@@ -1892,24 +1889,6 @@ ExploreSolarSys (void)
 {
 	SOLARSYS_STATE SolarSysState;
 	
-#if 0
-	{
-		FILE *out;
-
-		// Write the star and planet info to a file in the current
-		// directory (which currently is the content/ directory).
-		out = fopen("PlanetInfo", "w");
-		if (out == NULL)
-			exit(1);
-		dumpStars(out, DUMP_PLANETS);
-		fclose(out);
-		fprintf(stdout, "*** Star dump complete. You can terminate the "
-				"program now if it does not do so automatically.\n");
-		exit(0);
-				// There may be other threads left.
-	}
-#endif
-
 	if (CurStarDescPtr == 0)
 	{
 		POINT universe;
