@@ -16,14 +16,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "process.h"
-
 #include "build.h"
 #include "collide.h"
 #include "options.h"
 #include "settings.h"
 #include "setup.h"
 #include "sounds.h"
+#include "element.h"
 #include "weapon.h"
 #include "libs/graphics/drawable.h"
 #include "libs/graphics/drawcmd.h"
@@ -948,6 +947,8 @@ PostProcessQueue (VIEW_STATE view_state, SIZE scroll_x,
 									TFB_Image *mmimg = frame->image;
 									DC.Type = TFB_DRAWCOMMANDTYPE_SETMIPMAP;
 									DC.data.setmipmap.image = ((PFRAME_DESC)ElementPtr->next.image.frame)->image;
+									DC.data.setmipmap.hotx = frame->HotSpot.x;
+									DC.data.setmipmap.hoty = frame->HotSpot.y;
 									LockMutex (mmimg->mutex);
 									DC.data.setmipmap.mipmap = mmimg->NormalImg;
 									UnlockMutex (mmimg->mutex);
