@@ -31,18 +31,13 @@
 #include "libs/file.h"
 #include "libs/graphics/gfx_common.h"
 #include "libs/threadlib.h"
+#include "libs/vidlib.h"
 
 #include <assert.h>
 #include <errno.h>
 #include <string.h>
 
 
-//Added by Chris
-
-extern BOOLEAN InitVideo (BOOLEAN UseCDROM);
-
-//End Added by Chris
-
 ACTIVITY LastActivity;
 BYTE PlayerControl[NUM_PLAYERS];
 
@@ -59,7 +54,11 @@ FONT StarConFont;
 FONT MicroFont;
 FONT TinyFont;
 QUEUE race_q[NUM_PLAYERS];
-FRAME ActivityFrame, status, flagship_status, misc_data;
+FRAME ActivityFrame;
+FRAME StatusFrame;
+FRAME FlagStatFrame;
+FRAME MiscDataFrame;
+FRAME FontGradFrame;
 Mutex GraphicsLock;
 STRING GameStrings;
 
@@ -105,7 +104,7 @@ LoadKernel (int argc, char *argv[])
 	SetContextFGFrame (Screen);
 	SetFrameHot (Screen, MAKE_HOT_SPOT (0, 0));
 
-	hResIndex = InitResourceSystem ("starcon", RES_INDEX, NULL);
+	hResIndex = InitResourceSystem ("starcon.lst", RES_INDEX, NULL);
 	if (hResIndex == 0)
 		return FALSE;
 	INIT_INSTANCES ();
@@ -175,8 +174,8 @@ InitKernel (void)
 	if (ActivityFrame == NULL)
 		return FALSE;
 
-	status = CaptureDrawable (LoadGraphic (STATUS_MASK_PMAP_ANIM));
-	if (status == NULL)
+	StatusFrame = CaptureDrawable (LoadGraphic (STATUS_MASK_PMAP_ANIM));
+	if (StatusFrame == NULL)
 		return FALSE;
 
 	GameStrings = CaptureStringTable (LoadStringTableInstance (
