@@ -72,9 +72,9 @@ static RACE_DESC druuge_desc =
 			(FRAME)DRUUGE_SML_MASK_PMAP_ANIM,
 		},
 		{
-			(FRAME)CANNON_BIG_MASK_PMAP_ANIM,
-			(FRAME)CANNON_MED_MASK_PMAP_ANIM,
-			(FRAME)CANNON_SML_MASK_PMAP_ANIM,
+			(FRAME)DRUUGE_CANNON_BIG_MASK_PMAP_ANIM,
+			(FRAME)DRUUGE_CANNON_MED_MASK_PMAP_ANIM,
+			(FRAME)DRUUGE_CANNON_SML_MASK_PMAP_ANIM,
 		},
 		{
 			(FRAME)0,
