@@ -16,10 +16,14 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "reslib.h"
+#include "ships/ship.h"
 #include "ships/sis_ship/resinst.h"
-#include "starcon.h"
+
+#include "colors.h"
 #include "controls.h"
+#include "globdata.h"
+#include "libs/mathlib.h"
+
 
 #define MAX_TRACKING 3
 #define MAX_DEFENSE 8
@@ -163,8 +167,10 @@ LeaveAutoPilot:
 
 		facing = NORMALIZE_FACING (ANGLE_TO_FACING (ARCTAN (udx, udy)));
 
+		/* This prevents ship from flying backwards on auto-pilot.
+		 * It could also theoretically abort autopilot in a bad savegame */
 		if ((StarShipPtr->cur_status_flags & SHIP_AT_MAX_SPEED)
-				|| (ElementPtr->state_flags & APPEARING))
+				/*|| (ElementPtr->state_flags & APPEARING)*/ )
 		{
 			if (NORMALIZE_FACING (StarShipPtr->ShipFacing
 					+ ANGLE_TO_FACING (QUADRANT)
@@ -276,7 +282,7 @@ sis_hyper_postprocess (PELEMENT ElementPtr)
 	GLOBAL (velocity) = ElementPtr->velocity;
 
 	GetElementStarShip (ElementPtr, &StarShipPtr);
-	if (((StarShipPtr->cur_status_flags & WEAPON) || CurrentMenuState.cancel)
+	if (((StarShipPtr->cur_status_flags & WEAPON) || PulsedInputState.key[KEY_MENU_CANCEL])
 			&& StarShipPtr->special_counter == 0)
 	{
 #define MENU_DELAY 10
