@@ -74,9 +74,9 @@ static RACE_DESC yehat_desc =
 			(FRAME)YEHAT_SML_MASK_PMAP_ANIM,
 		},
 		{
-			(FRAME)CANNON_BIG_MASK_PMAP_ANIM,
-			(FRAME)CANNON_MED_MASK_PMAP_ANIM,
-			(FRAME)CANNON_SML_MASK_PMAP_ANIM,
+			(FRAME)YEHAT_CANNON_BIG_MASK_PMAP_ANIM,
+			(FRAME)YEHAT_CANNON_MED_MASK_PMAP_ANIM,
+			(FRAME)YEHAT_CANNON_SML_MASK_PMAP_ANIM,
 		},
 		{
 			(FRAME)SHIELD_BIG_MASK_ANIM,
