@@ -28,24 +28,23 @@ void
 DrawCrewFuelString (COORD y, SIZE state)
 {
 	STAMP Stamp;
-	extern FRAME status;
 
 	Stamp.origin.y = y + GAUGE_YOFFS + STARCON_TEXT_HEIGHT;
 	if (state == 0)
 	{
 		Stamp.origin.x = CREW_XOFFS + (STAT_WIDTH >> 1) + 6;
 		if (optWhichMenu == OPT_PC)
-			Stamp.frame = SetAbsFrameIndex (status, 4);
+			Stamp.frame = SetAbsFrameIndex (StatusFrame, 4);
 		else
-			Stamp.frame = SetAbsFrameIndex (status, 0);
+			Stamp.frame = SetAbsFrameIndex (StatusFrame, 0);
 		DrawStamp (&Stamp);
 	}
 
 	Stamp.origin.x = ENERGY_XOFFS + (STAT_WIDTH >> 1) - 5;
 	if (optWhichMenu == OPT_PC)
-		Stamp.frame = SetAbsFrameIndex (status, 5);
+		Stamp.frame = SetAbsFrameIndex (StatusFrame, 5);
 	else
-		Stamp.frame = SetAbsFrameIndex (status, 1);
+		Stamp.frame = SetAbsFrameIndex (StatusFrame, 1);
 	if (state >= 0)
 		DrawStamp (&Stamp);
 	else
@@ -235,7 +234,7 @@ InitShipStatus (STARSHIPPTR StarShipPtr, PRECT pClipRect)
 				GetStringLength (locString),y);
 
 		{
-			UNICODE buf[3];
+			UNICODE buf[30];
 			TEXT Text;
 			FONT OldFont;
 
@@ -243,7 +242,7 @@ InitShipStatus (STARSHIPPTR StarShipPtr, PRECT pClipRect)
 
 			if (!(GLOBAL (CurrentActivity) & IN_BATTLE))
 			{
-				wsprintf (buf, "%d", SIPtr->ship_cost);
+				sprintf (buf, "%d", SIPtr->ship_cost);
 				Text.pStr = buf;
 				Text.CharCount = (COUNT)~0;
 			}
@@ -328,8 +327,9 @@ DeltaStatistics (STARSHIPPTR StarShipPtr, SIZE crew_delta, SIZE
 					&& (ShipInfoPtr->ship_flags & GOOD_GUY)
 					&& LOBYTE (GLOBAL (CurrentActivity)) != SUPER_MELEE)
 			{
-				if ((crew_delta =
-						GLOBAL_SIS (CrewEnlisted)) >= MAX_CREW_SIZE)
+				// SIS in full game.
+				crew_delta = GLOBAL_SIS (CrewEnlisted);
+				if (crew_delta >= MAX_CREW_SIZE)
 					crew_delta = MAX_CREW_SIZE;
 				else /* if (crew_delta < MAX_CREW_SIZE) */
 				{
@@ -350,8 +350,7 @@ DeltaStatistics (STARSHIPPTR StarShipPtr, SIZE crew_delta, SIZE
 #define ROBOT_UNIT_COLOR BUILD_COLOR (MAKE_RGB15 (0xA, 0xA, 0xA), 0x08)
 			SetContextForeGroundColor (
 					(ShipInfoPtr->ship_flags & CREW_IMMUNE) ?
-					ROBOT_UNIT_COLOR : CREW_UNIT_COLOR
-					);
+					ROBOT_UNIT_COLOR : CREW_UNIT_COLOR);
 			while (crew_delta--)
 			{
 				r.corner.x = x + (CREW_XOFFS + 1);
@@ -364,7 +363,7 @@ DeltaStatistics (STARSHIPPTR StarShipPtr, SIZE crew_delta, SIZE
 				++ShipInfoPtr->crew_level;
 			}
 		}
-		else
+		else  /* crew_delta < 0 */
 		{
 			if (StarShipPtr->captains_name_index == 0
 					&& (ShipInfoPtr->ship_flags & GOOD_GUY)
