@@ -21,11 +21,13 @@
 #include "encount.h"
 #include "gamestr.h"
 #include "options.h"
+#include "starbase.h"
 #include "setup.h"
 #include "state.h"
 #include "libs/graphics/gfx_common.h"
 #include "libs/tasklib.h"
 
+#include <stdio.h>
 
 static const UNICODE *describeWeapon (BYTE moduleType);
 
@@ -142,9 +144,9 @@ SetContextClipRect (&r);
 void
 DrawHyperCoords (POINT universe)
 {
-	UNICODE buf[20];
+	UNICODE buf[100];
 
-	wsprintf (buf, "%03u.%01u : %03u.%01u",
+	sprintf (buf, "%03u.%01u : %03u.%01u",
 			universe.x / 10, universe.x % 10,
 			universe.y / 10, universe.y % 10);
 
@@ -152,25 +154,31 @@ DrawHyperCoords (POINT universe)
 }
 
 void
-DrawSISMessage (UNICODE *pStr)
+DrawSISMessage (const UNICODE *pStr)
 {
-	UNICODE buf[40];
+	DrawSISMessageEx (pStr, -1, -1, DSME_NONE);
+}
+
+BOOLEAN
+DrawSISMessageEx (const UNICODE *pStr, SIZE CurPos, SIZE ExPos, COUNT flags)
+{
+	UNICODE buf[256];
 	CONTEXT OldContext;
+	TEXT t;
+	RECT r;
 
 	OldContext = SetContext (OffScreenContext);
-{
-RECT r;
-
-r.corner.x = SIS_ORG_X + 1;
-r.corner.y = SIS_ORG_Y - SIS_MESSAGE_HEIGHT;
-r.extent.width = SIS_MESSAGE_WIDTH;
-r.extent.height = SIS_MESSAGE_HEIGHT - 1;
-SetContextFGFrame (Screen);
-SetContextClipRect (&r);
-}
+	// prepare the context
+	r.corner.x = SIS_ORG_X + 1;
+	r.corner.y = SIS_ORG_Y - SIS_MESSAGE_HEIGHT;
+	r.extent.width = SIS_MESSAGE_WIDTH;
+	r.extent.height = SIS_MESSAGE_HEIGHT - 1;
+	SetContextFGFrame (Screen);
+	SetContextClipRect (&r);
+	
 	BatchGraphics ();
-	SetContextBackGroundColor (BUILD_COLOR (MAKE_RGB15 (0x00, 0x00, 0x14), 0x01));
-	ClearDrawable ();
+	SetContextBackGroundColor (
+			BUILD_COLOR (MAKE_RGB15 (0x00, 0x00, 0x14), 0x01));
 
 	if (pStr == (UNICODE *)~0L)
 	{
@@ -194,67 +202,147 @@ SetContextClipRect (&r);
 					GetClusterName (CurStarDescPtr, buf);
 					break;
 				case IN_HYPERSPACE:
-					wstrcpy (buf, GAME_STRING (NAVIGATION_STRING_BASE
-										+ (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1 ? 0 : 1)));
+					utf8StringCopy (buf, sizeof (buf),
+							GAME_STRING (NAVIGATION_STRING_BASE
+								+ (GET_GAME_STATE (ARILOU_SPACE_SIDE) <= 1
+									? 0 : 1)));
 					break;
 			}
 
 			pStr = buf;
 		}
 
-		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x1B, 0x00, 0x1B), 0x33));
+		SetContextForeGroundColor (
+				BUILD_COLOR (MAKE_RGB15 (0x1B, 0x00, 0x1B), 0x33));
 	}
 
+	t.baseline.y = SIS_MESSAGE_HEIGHT - 2;
+	t.pStr = pStr;
+	t.CharCount = utf8StringCount(pStr);
+	SetContextFont (TinyFont);
+
+	if (flags & DSME_CLEARFR)
 	{
-		TEXT t;
+		SetFlashRect (NULL_PTR, (FRAME)0);
+	}
 
+	if (CurPos < 0 && ExPos < 0)
+	{	// normal state
+		ClearDrawable ();
 		t.baseline.x = SIS_MESSAGE_WIDTH >> 1;
-		t.baseline.y = SIS_MESSAGE_HEIGHT - 2;
 		t.align = ALIGN_CENTER;
-		t.pStr = pStr;
-		t.CharCount = (COUNT)~0;
-
-		SetContextFont (TinyFont);
 		font_DrawText (&t);
 	}
+	else
+	{	// editing state
+		int i;
+		RECT text_r;
+		BYTE char_deltas[MAX_DESC_CHARS];
+		PBYTE pchar_deltas;
+
+		t.baseline.x = 3;
+		t.align = ALIGN_LEFT;
+
+		TextRect (&t, &text_r, char_deltas);
+		if (text_r.extent.width + t.baseline.x + 2 >= r.extent.width)
+		{	// the text does not fit the input box size and so
+			// will not fit when displayed later
+			// disallow the change
+			UnbatchGraphics ();
+			SetContextClipRect (NULL_PTR);
+			SetContext (OldContext);
+			return (FALSE);
+		}
+
+		ClearDrawable ();
+
+		if (CurPos >= 0 && CurPos <= t.CharCount)
+		{	// calc and draw the cursor
+			RECT cur_r = text_r;
+
+			for (i = CurPos, pchar_deltas = char_deltas; i > 0; --i)
+				cur_r.corner.x += (SIZE)*pchar_deltas++;
+			if (CurPos < t.CharCount) /* end of line */
+				--cur_r.corner.x;
+			
+			if (flags & DSME_BLOCKCUR)
+			{	// Use block cursor for keyboardless systems
+				if (CurPos == t.CharCount)
+				{	// cursor at end-line -- use insertion point
+					cur_r.extent.width = 1;
+				}
+				else if (CurPos + 1 == t.CharCount)
+				{	// extra pixel for last char margin
+					cur_r.extent.width = (SIZE)*pchar_deltas + 2;
+				}
+				else
+				{	// normal mid-line char
+					cur_r.extent.width = (SIZE)*pchar_deltas + 1;
+				}
+			}
+			else
+			{	// Insertion point cursor
+				cur_r.extent.width = 1;
+			}
+			
+			cur_r.corner.y = 0;
+			cur_r.extent.height = r.extent.height;
+			SetContextForeGroundColor (BLACK_COLOR);
+			DrawFilledRectangle (&cur_r);
+		}
+
+		SetContextForeGroundColor (
+				BUILD_COLOR (MAKE_RGB15 (0x1B, 0x00, 0x1B), 0x33));
+
+		if (ExPos >= 0 && ExPos < t.CharCount)
+		{	// handle extra characters
+			t.CharCount = ExPos;
+			font_DrawText (&t);
+
+			// print extra chars
+			SetContextForeGroundColor (
+					BUILD_COLOR (MAKE_RGB15 (0x12, 0x00, 0x12), 0x33));
+			for (i = ExPos, pchar_deltas = char_deltas; i > 0; --i)
+				t.baseline.x += (SIZE)*pchar_deltas++;
+			t.pStr = skipUTF8Chars (t.pStr, ExPos);
+			t.CharCount = (COUNT)~0;
+			font_DrawText (&t);
+		}
+		else
+		{	// just print the text
+			font_DrawText (&t);
+		}
+	}
+
+	if (flags & DSME_SETFR)
+	{
+		r.corner.x = r.corner.y = 0;
+		SetFlashRect (&r, (FRAME)0);
+	}
+
 	UnbatchGraphics ();
 
-SetContextClipRect (NULL_PTR);
-
+	SetContextClipRect (NULL_PTR);
 	SetContext (OldContext);
+
+	return (TRUE);
 }
 
 void
-DateToString (UNICODE *buf, BYTE month_index, BYTE day_index, COUNT
-		year_index)
+DateToString (unsigned char *buf, size_t bufLen,
+		BYTE month_index, BYTE day_index, COUNT year_index)
 {
-	COUNT i;
-
-	wstrcpy (buf, GAME_STRING (MONTHS_STRING_BASE + month_index - 1));
-	buf[3] = ' ';
-	i = day_index;
-	buf[5] = (UNICODE)((i % 10) + '0');
-	i /= 10;
-	buf[4] = (UNICODE)((i % 10) + '0');
-	buf[6] = '_';
-
-	i = year_index;
-	buf[10] = (UNICODE)((i % 10) + '0');
-	i /= 10;
-	buf[9] = (UNICODE)((i % 10) + '0');
-	i /= 10;
-	buf[8] = (UNICODE)((i % 10) + '0');
-	i /= 10;
-	buf[7] = (UNICODE)((i % 10) + '0');
-	buf[11] = '\0';
+	snprintf (buf, bufLen, "%s %02d" STR_MIDDLE_DOT "%04d",
+			GAME_STRING (MONTHS_STRING_BASE + month_index - 1),
+			day_index, year_index);
 }
 
 void
-DrawStatusMessage (UNICODE *pStr)
+DrawStatusMessage (const UNICODE *pStr)
 {
 	RECT r;
 	TEXT t;
-	UNICODE buf[20];
+	UNICODE buf[128];
 	CONTEXT OldContext;
 
 	OldContext = SetContext (StatusContext);
@@ -276,22 +364,24 @@ DrawStatusMessage (UNICODE *pStr)
 		if (pMenuState == 0
 				&& CommData.ConversationPhrases /* Melnorme shenanigans */
 				&& cur_comm == MELNORME_CONVERSATION)
-			wsprintf (buf, "%u Cr", MAKE_WORD (
+			sprintf (buf, "%u %s", MAKE_WORD (
 					GET_GAME_STATE (MELNORME_CREDIT0),
 					GET_GAME_STATE (MELNORME_CREDIT1)
-					));
+					), GAME_STRING (STATUS_STRING_BASE + 0)); // "Cr"
 		else if (GET_GAME_STATE (CHMMR_BOMB_STATE) < 2)
-			wsprintf (buf, "%lu RU", GLOBAL_SIS (ResUnits));
+			sprintf (buf, "%lu %s", GLOBAL_SIS (ResUnits),
+					GAME_STRING (STATUS_STRING_BASE + 1)); // "RU"
 		else
-			if (optWhichMenu == OPT_PC)
-				wstrcpy (buf, "UNLIMITED RU");
-			else
-				wstrcpy (buf, "\x7f RU");
+			sprintf (buf, "%s %s",
+					(optWhichMenu == OPT_PC) ?
+						GAME_STRING (STATUS_STRING_BASE + 2)
+						: STR_INFINITY_SIGN, // "UNLIMITED"
+					GAME_STRING (STATUS_STRING_BASE + 1)); // "RU"
 		pStr = buf;
 	}
 	else if (pStr == 0)
 	{
-		DateToString (buf,
+		DateToString (buf, sizeof buf,
 				GLOBAL (GameClock.month_index),
 				GLOBAL (GameClock.day_index),
 				GLOBAL (GameClock.year_index));
@@ -354,7 +444,8 @@ DrawFlagshipName (BOOLEAN InStatusArea)
 	FONT OldFont;
 	COLOR OldColor;
 	CONTEXT OldContext;
-	UNICODE buf[60];
+	FRAME OldFontEffect;
+	UNICODE buf[250];
 
 	if (InStatusArea)
 	{
@@ -379,9 +470,12 @@ DrawFlagshipName (BOOLEAN InStatusArea)
 		r.extent.height = SHIP_NAME_HEIGHT;
 
 		t.pStr = buf;
-		wsprintf (buf, "%s %s", GAME_STRING (NAMING_STRING_BASE + 1), GLOBAL_SIS (ShipName));
-		wstrupr (buf);
+		sprintf (buf, "%s %s", GAME_STRING (NAMING_STRING_BASE + 1),
+				GLOBAL_SIS (ShipName));
+		// XXX: this will not work with UTF-8 strings
+		strupr (buf);
 	}
+	OldFontEffect = SetContextFontEffect (NULL);
 	OldColor = SetContextForeGroundColor (BLACK_COLOR);
 	DrawFilledRectangle (&r);
 
@@ -389,22 +483,15 @@ DrawFlagshipName (BOOLEAN InStatusArea)
 	t.baseline.y = r.corner.y + (SHIP_NAME_HEIGHT - InStatusArea);
 	t.align = ALIGN_CENTER;
 	t.CharCount = (COUNT)~0;
-	if (optWhichFonts == OPT_PC) {
-		if (InStatusArea)
-			SetContextFontEffect (GRADIENT_EFFECT, 
-				BUILD_COLOR_RGBA (0xF7, 0x2C, 0x00, 0xFF),
-				BUILD_COLOR_RGBA (0xF7, 0xBA, 0x00, 0xFF));
-		else
-			SetContextFontEffect (GRADIENT_EFFECT, 
-				BUILD_COLOR_RGBA (0x00, 0x00, 0x9C, 0xFF),
-				BUILD_COLOR_RGBA (0x08, 0x14, 0xFF, 0xFF));
-	}
+	if (optWhichFonts == OPT_PC)
+		SetContextFontEffect (SetAbsFrameIndex (FontGradFrame,
+				InStatusArea ? 0 : 3));
 	else
 		SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x14, 0x0A, 0x00), 0x0C));
+	
 	font_DrawText (&t);
-	if (optWhichFonts == OPT_PC)
-		SetContextFontEffect (0, 0, 0);
 
+	SetContextFontEffect (OldFontEffect);
 	SetContextForeGroundColor (OldColor);
 	SetContextFont (OldFont);
 	SetContext (OldContext);
@@ -417,8 +504,9 @@ DrawFlagshipStats (void)
 	TEXT t;
 	FONT OldFont;
 	COLOR OldColor;
+	FRAME OldFontEffect;
 	CONTEXT OldContext;
-	UNICODE buf[60];
+	UNICODE buf[128];
 	SIZE leading;
 	BYTE i;
 	BYTE energy_regeneration, energy_wait, turn_wait;
@@ -467,6 +555,7 @@ DrawFlagshipStats (void)
 
 	OldContext = SetContext (SpaceContext);
 	OldFont = SetContextFont (StarConFont);
+	OldFontEffect = SetContextFontEffect (NULL);
 	GetContextFontLeading (&leading);
 
 	/* we need room to play.  full screen width, 4 lines tall */
@@ -483,110 +572,109 @@ DrawFlagshipStats (void)
 	   fact that the leading is way more than is generally needed.
 	*/
 	leading -= 3;
-	t.pStr = buf;
 	t.baseline.x = SIS_SCREEN_WIDTH / 6; //wild-assed guess, but it worked
 	t.baseline.y = r.corner.y + leading + 3;
 	t.align = ALIGN_RIGHT;
 	t.CharCount = (COUNT)~0;
 
-	SetContextFontEffect (GRADIENT_EFFECT, 
-			BUILD_COLOR_RGBA (0x00, 0x00, 0xC0, 0xFF),
-			BUILD_COLOR_RGBA (0x60, 0x6C, 0xFC, 0xFF));
+	SetContextFontEffect (SetAbsFrameIndex (FontGradFrame, 4));
 
-	wsprintf (buf, "nose:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 0); // "nose:"
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "spread:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 1); // "spread:"
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "side:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 2); // "side:"
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "tail:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 3); // "tail:"
 	font_DrawText (&t);
 
 	t.baseline.x += 5;
 	t.baseline.y = r.corner.y + leading + 3;
 	t.align = ALIGN_LEFT;
+	t.pStr = buf;
 
-	wsprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[15])));
+	sprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[15])));
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[14])));
+	sprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[14])));
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[13])));
+	sprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[13])));
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[0])));
+	sprintf (buf, "%-7.7s", describeWeapon (GLOBAL_SIS (ModuleSlots[0])));
 	font_DrawText (&t);
 
 	t.baseline.x = r.extent.width - 25;
 	t.baseline.y = r.corner.y + leading + 3;
 	t.align = ALIGN_RIGHT;
 
-	SetContextFontEffect (GRADIENT_EFFECT, 
-			BUILD_COLOR_RGBA (0x00, 0x44, 0x64, 0xFF),
-			BUILD_COLOR_RGBA (0x58, 0x9C, 0xBC, 0xFF));
+	SetContextFontEffect (SetAbsFrameIndex (FontGradFrame, 5));
 
-	wsprintf (buf, "maximum velocity:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 4); // "maximum velocity:"
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "turning rate:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 5); // "turning rate:"
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "combat energy:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 6); // "combat energy:"
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "maximum fuel:");
+	t.pStr = GAME_STRING (FLAGSHIP_STRING_BASE + 7); // "maximum fuel:"
 	font_DrawText (&t);
 
 	t.baseline.x = r.extent.width - 2;
 	t.baseline.y = r.corner.y + leading + 3;
+	t.pStr = buf;
 
-	wsprintf (buf, "%4u", max_thrust * 4);
+	sprintf (buf, "%4u", max_thrust * 4);
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "%4u", 1 + TURN_WAIT - turn_wait);
+	sprintf (buf, "%4u", 1 + TURN_WAIT - turn_wait);
 	font_DrawText (&t);
 	t.baseline.y += leading;
 	{
 		unsigned int energy_per_10_sec =
 				(((100 * ONE_SECOND * energy_regeneration) /
 				((1 + energy_wait) * BATTLE_FRAME_RATE)) + 5) / 10;
-		wsprintf (buf, "%2u.%1u",
+		sprintf (buf, "%2u.%1u",
 				energy_per_10_sec / 10,
 				energy_per_10_sec % 10);
 	}
 	font_DrawText (&t);
 	t.baseline.y += leading;
-	wsprintf (buf, "%4lu", (fuel / FUEL_TANK_SCALE));
+	sprintf (buf, "%4lu", (fuel / FUEL_TANK_SCALE));
 	font_DrawText (&t);
 
-	SetContextFontEffect (0, 0, 0);
+	SetContextFontEffect (OldFontEffect);
 	SetContextForeGroundColor (OldColor);
 	SetContextFont (OldFont);
 	SetContext (OldContext);
 }
 
 static const UNICODE *
-describeWeapon (BYTE moduleType) {
-	switch (moduleType) {
+describeWeapon (BYTE moduleType)
+{
+	switch (moduleType)
+	{
 		case GUN_WEAPON:
-			return "gun";
+			return GAME_STRING (FLAGSHIP_STRING_BASE + 8); // "gun"
 		case BLASTER_WEAPON:
-			return "blaster";
+			return GAME_STRING (FLAGSHIP_STRING_BASE + 9); // "blaster"
 		case CANNON_WEAPON:
-			return "cannon";
+			return GAME_STRING (FLAGSHIP_STRING_BASE + 10); // "cannon"
 		case BOMB_MODULE_0:
 		case BOMB_MODULE_1:
 		case BOMB_MODULE_2:
 		case BOMB_MODULE_3:
 		case BOMB_MODULE_4:
 		case BOMB_MODULE_5:
-			return "n/a";
+			return GAME_STRING (FLAGSHIP_STRING_BASE + 11); // "n/a"
 		default:
-			return "none";
+			return GAME_STRING (FLAGSHIP_STRING_BASE + 12); // "none"
 	}
 }
 
@@ -598,11 +686,10 @@ DrawLanders (void)
 	RECT r;
 	STAMP s;
 	CONTEXT OldContext;
-	extern FRAME flagship_status;
 
 	OldContext = SetContext (StatusContext);
 
-	s.frame = IncFrameIndex (flagship_status);
+	s.frame = IncFrameIndex (FlagStatFrame);
 	GetFrameRect (s.frame, &r);
 
 	i = GLOBAL_SIS (NumLanders);
@@ -710,12 +797,11 @@ DrawPC_SIS (void)
 {
 	TEXT t;
 	RECT r;
-	UNICODE buf[10];
+
 	GetGaugeRect (&r, FALSE);
 	t.baseline.x = STATUS_WIDTH >> 1;
 	t.baseline.y = r.corner.y - 1;
 	t.align = ALIGN_CENTER;
-	t.pStr = buf;
 	t.CharCount = (COUNT)~0;
 	SetContextFont (TinyFont);
 	SetContextForeGroundColor (BLACK_COLOR);
@@ -725,22 +811,18 @@ DrawPC_SIS (void)
 	r.extent.width += 2;
 	DrawFilledRectangle (&r);
 
-	SetContextFontEffect (GRADIENT_EFFECT,
-		BUILD_COLOR_RGBA (0x6B, 0x00, 0x00, 0xFF),
-		BUILD_COLOR_RGBA (0xF7, 0x00, 0x00, 0xFF));
-	wsprintf (buf, "FUEL");
+	SetContextFontEffect (SetAbsFrameIndex (FontGradFrame, 1));
+	t.pStr = GAME_STRING (STATUS_STRING_BASE + 3); // "FUEL"
 	font_DrawText (&t);
 
 	r.corner.y += 79;
 	t.baseline.y += 79;
 	DrawFilledRectangle (&r);
 
-	SetContextFontEffect (GRADIENT_EFFECT,
-		BUILD_COLOR_RGBA (0x00, 0x4D, 0x00, 0xFF),
-		BUILD_COLOR_RGBA (0x00, 0xAE, 0x00, 0xFF));
-	wsprintf (buf, "CREW");
+	SetContextFontEffect (SetAbsFrameIndex (FontGradFrame, 2));
+	t.pStr = GAME_STRING (STATUS_STRING_BASE + 4); // "CREW"
 	font_DrawText (&t);
-	SetContextFontEffect (0, 0, 0);
+	SetContextFontEffect (NULL);
 
 	r.corner.x = 2 + 1;
 	r.corner.y = 3;
@@ -750,7 +832,7 @@ DrawPC_SIS (void)
 	DrawFilledRectangle (&r);
 	SetContextForeGroundColor (BUILD_COLOR (MAKE_RGB15 (0x02, 0x04, 0x1E), 0x38));
 	t.baseline.y = r.corner.y + 6;
-	wsprintf (buf, "CAPTAIN");
+	t.pStr = GAME_STRING (STATUS_STRING_BASE + 5); // "CAPTAIN"
 	font_DrawText (&t);
 }
 
@@ -760,7 +842,7 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 	STAMP s;
 	RECT r;
 	TEXT t;
-	UNICODE buf[12];
+	UNICODE buf[60];
 	CONTEXT OldContext;
 
 	if (crew_delta == 0 && fuel_delta == 0 && resunit_delta == 0)
@@ -772,10 +854,9 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 	if (crew_delta == UNDEFINED_DELTA)
 	{
 		COUNT i;
-		extern FRAME flagship_status;
 
 		s.origin.x = s.origin.y = 0;
-		s.frame = flagship_status;
+		s.frame = FlagStatFrame;
 		DrawStamp (&s);
 		if (optWhichFonts == OPT_PC)
 			DrawPC_SIS();
@@ -790,7 +871,7 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 					GLOBAL_SIS (DriveSlots[i])) < EMPTY_SLOT)
 			{
 				s.frame = SetAbsFrameIndex (
-						flagship_status, which_piece + 1 + 0
+						FlagStatFrame, which_piece + 1 + 0
 						);
 				DrawStamp (&s);
 				s.frame = IncFrameIndex (s.frame);
@@ -808,7 +889,7 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 					GLOBAL_SIS (JetSlots[i])) < EMPTY_SLOT)
 			{
 				s.frame = SetAbsFrameIndex (
-						flagship_status, which_piece + 1 + 1
+						FlagStatFrame, which_piece + 1 + 1
 						);
 				DrawStamp (&s);
 				s.frame = IncFrameIndex (s.frame);
@@ -827,7 +908,7 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 					GLOBAL_SIS (ModuleSlots[i])) < EMPTY_SLOT)
 			{
 				s.frame = SetAbsFrameIndex (
-						flagship_status, which_piece + 1 + 2
+						FlagStatFrame, which_piece + 1 + 2
 						);
 				DrawStamp (&s);
 			}
@@ -891,7 +972,7 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 				GLOBAL_SIS (CrewEnlisted) = CrewCapacity;
 		}
 
-		wsprintf (buf, "%u", GLOBAL_SIS (CrewEnlisted));
+		sprintf (buf, "%u", GLOBAL_SIS (CrewEnlisted));
 		GetGaugeRect (&r, TRUE);
 		t.baseline.y = r.corner.y + r.extent.height;
 		t.CharCount = (COUNT)~0;
@@ -927,7 +1008,7 @@ DeltaSISGauges (SIZE crew_delta, SIZE fuel_delta, int resunit_delta)
 				);
 		if (new_coarse_fuel != old_coarse_fuel)
 		{
-			wsprintf (buf, "%u", new_coarse_fuel);
+			sprintf (buf, "%u", new_coarse_fuel);
 			GetGaugeRect (&r, FALSE);
 			t.baseline.y = r.corner.y + r.extent.height;
 			t.CharCount = (COUNT)~0;
@@ -1201,8 +1282,10 @@ static FRAME flash_frame;
 static FRAME flash_screen_frame = 0;
 static int flash_changed;
 Mutex flash_mutex = 0;
-void arith_frame_blit (FRAME srcFrame, RECT *rsrc, FRAME dstFrame,
-	   RECT *rdst, int num, int denom);
+// XXX: these are currently defined in libs/graphics/sdl/3do_getbody.c
+//  they should be sorted out and cleaned up at some point
+extern void arith_frame_blit (FRAME srcFrame, RECT *rsrc, FRAME dstFrame,
+		RECT *rdst, int num, int denom);
 
 static int
 flash_rect_func (void *data)
