@@ -204,6 +204,8 @@ typedef struct
 
 	DWORD FuelOnBoard;
 	COUNT CrewEnlisted;
+			// Number of crew on board, not counting the captain.
+			// Set to (COUNT) ~0 to indicate game over.
 	COUNT TotalElementMass, TotalBioMass;
 
 	BYTE ModuleSlots[NUM_MODULE_SLOTS];
@@ -252,11 +254,17 @@ extern void ClearSISRect (BYTE ClearFlags);
 extern void SetFlashRect (PRECT pRect, FRAME f);
 extern void DrawHyperCoords (POINT puniverse);
 extern void DrawSISTitle (UNICODE *pStr);
-extern void DrawSISMessage (UNICODE *pStr);
+extern BOOLEAN DrawSISMessageEx (const UNICODE *pStr, SIZE CurPos,
+		SIZE ExPos, COUNT flags);
+#define DSME_NONE     0
+#define DSME_SETFR    (1 << 0)
+#define DSME_CLEARFR  (1 << 1)
+#define DSME_BLOCKCUR (1 << 2)
+extern void DrawSISMessage (const UNICODE *pStr);
 extern void DrawGameDate (void);
-extern void DateToString (UNICODE *buf, BYTE month_index, BYTE day_index,
-		COUNT year_index);
-extern void DrawStatusMessage (UNICODE *pStr);
+extern void DateToString (unsigned char *buf, size_t bufLen,
+		BYTE month_index, BYTE day_index, COUNT year_index);
+extern void DrawStatusMessage (const UNICODE *pStr);
 extern void DrawLanders (void);
 extern void DrawStorageBays (BOOLEAN Refresh);
 extern void GetGaugeRect (PRECT pRect, BOOLEAN IsCrewRect);
