@@ -19,11 +19,8 @@
 #ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
-#ifdef WIN32
-#	include <direct.h>
-#endif
 
-#ifdef HAVE_GETOPT_H
+#ifdef HAVE_GETOPT_LONG
 #	include <getopt.h>
 #else
 #	include "getopt/getopt.h"
@@ -35,6 +32,7 @@
 #include "libs/tasklib.h"
 #include "file.h"
 #include "port.h"
+#include "libs/platform.h"
 #include "options.h"
 #include "uqmversion.h"
 #include "comm.h"
@@ -60,7 +58,6 @@ struct options_struct {
 	int soundFlags;
 	int width;
 	int height;
-	int bpp;
 	const char *configDir;
 	const char *contentDir;
 	const char **addons;
@@ -72,6 +69,7 @@ struct options_struct {
 	int whichMenu;
 	int whichFonts;
 	int whichIntro;
+	int whichShield;
 	int smoothScroll;
 	int meleeScale;
 	BOOLEAN subTitles;
@@ -96,9 +94,6 @@ static int Check_PC_3DO_opt (const char *value, DWORD mask, const char *opt,
 		int *result);
 static const char *PC_3DO_optString (DWORD optMask);
 
-/* TODO: Remove these global variables once threading is gone. */
-int snddriver, soundflags;
-
 int
 main (int argc, char *argv[])
 {
@@ -111,7 +106,6 @@ main (int argc, char *argv[])
 		/* .soundFlags = */         audio_QUALITY_MEDIUM,
 		/* .width = */              640,
 		/* .height = */             480,
-		/* .bpp = */                16,
 		/* .configDir = */          NULL,
 		/* .contentDir = */         NULL,
 		/* .addons = */             NULL,
@@ -123,6 +117,7 @@ main (int argc, char *argv[])
 		/* .whichMenu = */          OPT_PC,
 		/* .whichFont = */          OPT_PC,
 		/* .whichIntro = */         OPT_3DO,
+		/* .whichShield	= */        OPT_PC,
 		/* .smoothScroll = */       OPT_PC,
 		/* .meleeScale = */         TFB_SCALE_TRILINEAR,
 		/* .subtitles = */          TRUE,
@@ -175,6 +170,160 @@ main (int argc, char *argv[])
 	TFB_PreInit ();
 	mem_init ();
 	InitThreadSystem ();
+	initIO ();
+	prepareConfigDir (options.configDir);
+
+	// Fill in the options struct based on uqm.cfg
+	res_LoadFilename (configDir, "uqm.cfg");
+	if (res_HasKey ("config.reswidth"))
+	{
+		options.width = res_GetInteger ("config.reswidth");
+	}
+	if (res_HasKey ("config.resheight"))
+	{
+		options.height = res_GetInteger ("config.resheight");
+	}
+	if (res_HasKey ("config.alwaysgl"))
+	{
+		if (res_GetBoolean ("config.alwaysgl"))
+		{
+			options.gfxDriver = TFB_GFXDRIVER_SDL_OPENGL;
+		}
+	}
+	if (res_HasKey ("config.usegl"))
+	{
+		options.gfxDriver = res_GetBoolean ("config.usegl") ? TFB_GFXDRIVER_SDL_OPENGL :
+			TFB_GFXDRIVER_SDL_PURE;
+	}
+	if (res_HasKey ("config.scaler"))
+	{
+		const char *optarg = res_GetString ("config.scaler");
+
+		if (!strcmp (optarg, "bilinear"))
+			options.gfxFlags |= TFB_GFXFLAGS_SCALE_BILINEAR;
+		else if (!strcmp (optarg, "biadapt"))
+			options.gfxFlags |= TFB_GFXFLAGS_SCALE_BIADAPT;
+		else if (!strcmp (optarg, "biadv"))
+			options.gfxFlags |= TFB_GFXFLAGS_SCALE_BIADAPTADV;
+		else if (!strcmp (optarg, "triscan"))
+			options.gfxFlags |= TFB_GFXFLAGS_SCALE_TRISCAN;
+		else if (!strcmp (optarg, "hq"))
+			options.gfxFlags |= TFB_GFXFLAGS_SCALE_HQXX;	
+	}
+	if (res_HasKey ("config.scanlines") && res_GetBoolean ("config.scanlines"))
+	{
+		options.gfxFlags |= TFB_GFXFLAGS_SCANLINES;
+	}
+	if (res_HasKey ("config.fullscreen") && res_GetBoolean ("config.fullscreen"))
+	{
+		options.gfxFlags |= TFB_GFXFLAGS_FULLSCREEN;
+	}
+	if (res_HasKey ("config.subtitles"))
+	{
+		options.subTitles = res_GetBoolean ("config.subtitles");
+	}
+	if (res_HasKey ("config.textmenu"))
+	{
+		options.whichMenu = res_GetBoolean ("config.textmenu") ? OPT_PC : OPT_3DO;
+	}
+	if (res_HasKey ("config.textgradients"))
+	{
+		options.whichFonts = res_GetBoolean ("config.textgradients") ? OPT_PC : OPT_3DO;
+	}
+	if (res_HasKey ("config.iconicscan"))
+	{
+		options.whichCoarseScan = res_GetBoolean ("config.iconicscan") ? OPT_3DO : OPT_PC;
+	}
+	if (res_HasKey ("config.smoothscroll"))		
+	{
+		options.smoothScroll = res_GetBoolean ("config.smoothscroll") ? OPT_3DO : OPT_PC;
+	}
+	if (res_HasKey ("config.3domusic"))
+	{
+		options.whichMusic = res_GetBoolean ("config.3domusic") ? OPT_3DO : OPT_PC;
+	}
+	if (res_HasKey ("config.3domovies"))
+	{
+		options.whichIntro = res_GetBoolean ("config.3domovies") ? OPT_3DO : OPT_PC;
+	}
+	if (res_HasKey ("config.showfps") && res_GetBoolean ("config.showfps"))
+	{
+		options.gfxFlags |= TFB_GFXFLAGS_SHOWFPS;
+	}
+	if (res_HasKey ("config.smoothmelee"))
+	{
+		options.meleeScale = res_GetBoolean ("config.smoothmelee") ? TFB_SCALE_TRILINEAR : TFB_SCALE_STEP;
+	}
+	if (res_HasKey ("config.positionalsfx"))
+	{
+		options.stereoSFX = res_GetBoolean ("config.positionalsfx");
+	}
+	if (res_HasKey ("config.audiodriver"))
+	{
+		const char *driverstr = res_GetString ("config.audiodriver");
+		if (!strcmp (driverstr, "openal"))
+		{
+			options.soundDriver = audio_DRIVER_OPENAL;
+		}
+		else if (!strcmp (driverstr, "none"))
+		{
+			options.soundDriver = audio_DRIVER_NOSOUND;
+			options.speechVolumeScale = 0.0f;
+		}
+		else if (!strcmp (driverstr, "mixsdl"))
+		{
+			options.soundDriver = audio_DRIVER_MIXSDL;
+		}
+		else
+		{
+			/* Can't figure it out, leave as initial default */
+		}
+	}
+	if (res_HasKey ("config.audioquality"))
+	{
+		const char *qstr = res_GetString ("config.audioquality");
+		if (!strcmp (qstr, "low"))
+		{
+			options.soundFlags &=
+					~(audio_QUALITY_MEDIUM | audio_QUALITY_HIGH);
+			options.soundFlags |= audio_QUALITY_LOW;
+		}
+		else if (!strcmp (qstr, "medium"))
+		{
+			options.soundFlags &=
+					~(audio_QUALITY_HIGH | audio_QUALITY_LOW);
+			options.soundFlags |= audio_QUALITY_MEDIUM;
+		}
+		else if (!strcmp (qstr, "high"))
+		{
+			options.soundFlags &=
+					~(audio_QUALITY_MEDIUM | audio_QUALITY_LOW);
+			options.soundFlags |= audio_QUALITY_HIGH;
+		}
+		else
+		{
+			/* Can't figure it out, leave as initial default */
+		}
+	}
+	if (res_HasKey ("config.pulseshield"))
+	{
+		options.whichShield = res_GetBoolean ("config.pulseshield") ? OPT_3DO : OPT_PC;
+	}
+	if (res_HasKey ("config.musicvol"))
+	{
+		parseVolume(res_GetString ("config.musicvol"), 
+				&options.musicVolumeScale, "music volume");
+	}		
+	if (res_HasKey ("config.sfxvol"))
+	{
+		parseVolume(res_GetString ("config.sfxvol"), 
+				&options.sfxVolumeScale, "SFX volume");
+	}		
+	if (res_HasKey ("config.speechvol"))
+	{
+		parseVolume(res_GetString ("config.speechvol"), 
+				&options.speechVolumeScale, "speech volume");
+	}		
 
 	optionsResult = parseOptions(argc, argv, &options);
 	if (optionsResult != 0)
@@ -198,6 +347,7 @@ main (int argc, char *argv[])
 	optWhichMenu = options.whichMenu;
 	optWhichFonts = options.whichFonts;
 	optWhichIntro = options.whichIntro;
+	optWhichShield = options.whichShield;
 	optSmoothScroll = options.smoothScroll;
 	optMeleeScale = options.meleeScale;
 	optSubtitles = options.subTitles;
@@ -206,16 +356,12 @@ main (int argc, char *argv[])
 	sfxVolumeScale = options.sfxVolumeScale;
 	speechVolumeScale = options.speechVolumeScale;
 
-	initIO ();
 	prepareContentDir (options.contentDir, options.addons);
 	HFree ((void *) options.addons);
-	prepareConfigDir (options.configDir);
 	prepareMeleeDir ();
 	prepareSaveDir ();
 	initTempDir ();
 
-	initLanguage ();
-
 	InitTimeSystem ();
 	InitTaskSystem ();
 
@@ -223,9 +369,10 @@ main (int argc, char *argv[])
 			SYNC_CLASS_TOPLEVEL | SYNC_CLASS_VIDEO);
 
 	TFB_InitGraphics (options.gfxDriver, options.gfxFlags,
-			options.width, options.height, options.bpp);
+			options.width, options.height);
 	if (options.gammaSet)
 		TFB_SetGamma (options.gamma);
+	InitColorMaps ();
 	init_communication ();
 	/* TODO: Once threading is gone, restore initAudio here.
 	   initAudio calls AssignTask, which currently blocks on
@@ -252,17 +399,18 @@ enum
 	CSCAN_OPT = 1000,
 	MENU_OPT,
 	FONT_OPT,
+	SHIELD_OPT,
 	SCROLL_OPT,
 	SOUND_OPT,
 	STEREOSFX_OPT,
-	ADDON_OPT
+	ADDON_OPT,
+	ACCEL_OPT,
 };
 
 static const char *optString = "+r:d:foc:b:spC:n:?hM:S:T:m:q:ug:l:i:v";
 static struct option longOptions[] = 
 {
 	{"res", 1, NULL, 'r'},
-	{"bpp", 1, NULL, 'd'},
 	{"fullscreen", 0, NULL, 'f'},
 	{"opengl", 0, NULL, 'o'},
 	{"scale", 1, NULL, 'c'},
@@ -287,10 +435,12 @@ static struct option longOptions[] =
 	{"cscan", 1, NULL, CSCAN_OPT},
 	{"menu", 1, NULL, MENU_OPT},
 	{"font", 1, NULL, FONT_OPT},
+	{"shield", 1, NULL, SHIELD_OPT},
 	{"scroll", 1, NULL, SCROLL_OPT},
 	{"sound", 1, NULL, SOUND_OPT},
 	{"stereosfx", 0, NULL, STEREOSFX_OPT},
 	{"addon", 1, NULL, ADDON_OPT},
+	{"accel", 1, NULL, ACCEL_OPT},
 	{0, 0, 0, 0}
 };
 
@@ -316,6 +466,11 @@ preParseOptions(int argc, char *argv[], struct options_struct *options)
 				options->logFile = optarg;
 				break;
 			}
+			case 'C':
+			{
+				options->configDir = optarg;
+				break;
+			}
 			case '?':
 			case 'h':
 				options->runMode = runMode_usage;
@@ -333,7 +488,7 @@ static int
 parseOptions(int argc, char *argv[], struct options_struct *options)
 {
 	int optionIndex = 0;
-	BOOLEAN badArg = 0;
+	BOOLEAN badArg = FALSE;
 
 	options->addons = HMalloc(1 * sizeof (const char *));
 	options->addons[0] = NULL;
@@ -353,9 +508,6 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 			break;
 
 		switch (c) {
-			case 'C':
-				options->configDir = optarg;
-				break;
 			case 'r':
 			{
 				int width, height;
@@ -370,25 +522,6 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 				options->height = height;
 				break;
 			}
-			case 'd':
-			{
-				int bpp;
-				int err = parseIntOption(optarg, &bpp, "bpp");
-				if (err)
-				{
-					badArg = TRUE;
-					break;
-				}
-				if (bpp != 8 && bpp != 16 && bpp != 24 && bpp != 32)
-				{
-					fprintf (stderr, "Error: Invalid value specified for "
-							"bpp; it should be either 8, 16, 24, or 32.\n");
-					badArg = TRUE;
-					break;
-				}
-				options->bpp = bpp;
-				break;
-			}
 			case 'f':
 				options->gfxFlags |= TFB_GFXFLAGS_FULLSCREEN;
 				break;
@@ -396,6 +529,8 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 				options->gfxDriver = TFB_GFXDRIVER_SDL_OPENGL;
 				break;
 			case 'c':
+				// make sure whatever was set by saved config is cleared
+				options->gfxFlags &= ~TFB_GFXFLAGS_SCALE_ANY;
 				if (!strcmp (optarg, "bilinear"))
 					options->gfxFlags |= TFB_GFXFLAGS_SCALE_BILINEAR;
 				else if (!strcmp (optarg, "biadapt"))
@@ -404,7 +539,9 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 					options->gfxFlags |= TFB_GFXFLAGS_SCALE_BIADAPTADV;
 				else if (!strcmp (optarg, "triscan"))
 					options->gfxFlags |= TFB_GFXFLAGS_SCALE_TRISCAN;
-				else
+				else if (!strcmp (optarg, "hq"))
+					options->gfxFlags |= TFB_GFXFLAGS_SCALE_HQXX;
+				else if (strcmp (optarg, "none") != 0)
 				{
 					InvalidArgument(optarg, "--scale or -c");
 					badArg = TRUE;
@@ -501,8 +638,9 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 				break;
 			}
 			case 'l':
-				// -l is a no-op on the second pass..
-				break;
+			case 'C':
+				// -l and -C are no-ops on the second pass.
+				break;			
 			case 'i':
 			{
 				if (Check_PC_3DO_opt (optarg, OPT_PC | OPT_3DO,
@@ -529,6 +667,12 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 						&options->whichFonts) == -1)
 					badArg = TRUE;
 				break;
+			case SHIELD_OPT:
+				if (Check_PC_3DO_opt (optarg, OPT_PC | OPT_3DO,
+						longOptions[optionIndex].name,
+						&options->whichShield) == -1)
+					badArg = TRUE;
+				break;
 			case SCROLL_OPT:
 				if (Check_PC_3DO_opt (optarg, OPT_PC | OPT_3DO,
 						longOptions[optionIndex].name,
@@ -562,12 +706,27 @@ parseOptions(int argc, char *argv[], struct options_struct *options)
 				options->addons[options->numAddons - 1] = optarg;
 				options->addons[options->numAddons] = NULL;
 				break;
+			case ACCEL_OPT:
+				force_platform = PLATFORM_NULL;
+				if (!strcmp (optarg, "mmx"))
+					force_platform = PLATFORM_MMX;
+				else if (!strcmp (optarg, "sse"))
+					force_platform = PLATFORM_SSE;
+				else if (!strcmp (optarg, "3dnow"))
+					force_platform = PLATFORM_3DNOW;
+				else if (!strcmp (optarg, "none"))
+					force_platform = PLATFORM_C;
+				else if (strcmp (optarg, "detect") != 0)
+				{
+					InvalidArgument (optarg, "--accel");
+					badArg = TRUE;
+				}
+				break;
 			default:
 				fprintf (stderr, "Error: Invalid option '%s' not found.\n",
 							longOptions[optionIndex].name);
 				badArg = TRUE;
 				break;
-			break;
 		}
 	}
 
@@ -674,11 +833,10 @@ usage (FILE *out, const struct options_struct *defaultOptions)
 	fprintf (out, "Options:\n");
 	fprintf (out, "  -r, --res=WIDTHxHEIGHT (default 640x480, bigger "
 			"works only with --opengl)\n");
-	fprintf (out, "  -d, --bpp=BITSPERPIXEL (default 16)\n");
 	fprintf (out, "  -f, --fullscreen (default off)\n");
 	fprintf (out, "  -o, --opengl (default off)\n");
-	fprintf (out, "  -c, --scale=MODE (bilinear, biadapt, biadv or triscan, "
-			"default is none)\n");
+	fprintf (out, "  -c, --scale=MODE (bilinear, biadapt, biadv, triscan, "
+			"hq or none (default) )\n");
 	fprintf (out, "  -b, --meleezoom=MODE (step, aka pc, or smooth, aka 3do; "
 			"default is 3do)\n");
 	fprintf (out, "  -s, --scanlines (default off)\n");
@@ -714,6 +872,9 @@ usage (FILE *out, const struct options_struct *defaultOptions)
 			"(default %s)\n", PC_3DO_optString(defaultOptions->whichMenu));
 	fprintf (out, "  --font      : font types and colors (default %s)\n",
 			PC_3DO_optString(defaultOptions->whichFonts));
+	fprintf (out, "  --shield    : slave shield type; pc=static, "
+			"3do=throbbing (default %s)\n",
+			PC_3DO_optString(defaultOptions->whichShield));
 	fprintf (out, "  --scroll    : ff/frev during comm.  pc=per-page, "
 			"3do=smooth (default %s)\n",
 			PC_3DO_optString(defaultOptions->smoothScroll));
